(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 231*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1621785,      60460]*)
(*NotebookOutlinePosition[   1622659,      60490]*)
(*  CellTagsIndexPosition[   1622615,      60486]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[""], "Input"],

Cell["KAPPA TAU CURVES", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
by Rudy Rucker
Copyright \[Copyright] 1994\
\>", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Mathematical Background", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\

     One can associate a trihedron of unit vectors with each point 
of a

space curve.  The tangent vector lies on the striaght  line that best

matches the curve and can be thought of as determined by two

\"consecutive\" points of the curve.  The normal vector points in the

direction in which the tip of the tangent vector is moving,  If one

takes three \"consecutive\" points of the curve one gets a plane, known as

the osculating or \"kissing\" plane which best fits the curve at that

point.  The tangent and the normal vectors lie in the osculating plane

and the binormal vector is perpendicular to the osculating plane.

     For each point of a space curve one can also define the quantities

known as curvature and torsion.  The curve's curvature measures its

tendency to bendaway from its tangent line, and the curve's torsion

measures the tendency of the curve  to twist  out of the osculating

plane.  A theorem of differential geometry states that  a space curve's

shape  is uniquely characterized  by the functions kappa and tau which

give the curves curvature and torsion as functions of the arclength

along the curve.

     In this notebook, I state and use an algorithm for \"kappa tau

curves,\" which are space curves defined in terms of functions for

curvature and torsion.  The algorithm is based on a set of three

formulas known as \"Frenet's formlas for the moving trihedron of a space

curve.\"  These formulas were published by the French mathematicians

Serret and Frenet in 1852.

     Suppose that s parametrizes the arclength along a space curve, and

that kappa and tau are functions of s which give the curvature and the

torsion of the curve.  Suppose also that T, N, and B are vector functions

giving the tangent, normal, and binormal as functions of s.  Then the

Frenet formulas are as follows: 
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open]],

Cell["\<\

dT/ds =             kappa * N

dN/ds = -kappa * T            + tau * B

dB/ds =             -tau * N 
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\

       You can get an intuitive feel for the truth of the Frenet 
formulas

by trying to \"fly\" your hand around as if it were the moving trihedron

of a space curve.  Make a fist with your right hand and then extend your

index finger, middle finger, and thumb so that they are at right angles

to each other.  These fingers play the role of tangent, normal, and

binormal.

     There seem to be three intrinsic ways your hand can rotate: around

your thumb, your middle finger, or your index finger.  To cystallize

what is meant, try grabbing these with your left hand and performing an

\"unscrewing\" motion on each.  These produce motions that are also called

yaw, pitch, and roll.

     If your hand moves along an imaginary space curve so that your

index is always pointing in the direction of motion and your middle

finger is always pointing in the direction in which the index finger is

turning, then there will not actually be any \"pitch\" or \"middle finger

unscrewing\" motion.  The reason is that all the turning of the index

finger or tangent vector is in the direction of the middle finger or

normal.  This is all \"thumb unscrewing\" motion.  The only other motion

allowed is motion which does not move the index finger: this is the

\"index finger unscrewing\" motion.

     The \"thumb unscrewing\" motion is summarized in the first of the

Frenet formulae: the change of the tangent is in the direction of the

normal with a magnitude corresponding to the curvature.  The \"index

finger unscrewing\" motion appears in the third Frenet formula: the

change of the binormal is in the reverse direction of the normal and

with a magnitude corresponding to the torsion.  The second of the Frenet

formulas captures the \"back effects\" of the first and third formulas: As

the tangent turns towards the normal, the normal turns away from the

tangent; and as the binormal turns away from the normal, the normal

turns towards the binormal.

     Our algorithm performs a simple \"Euler-style\" numerical integration

to compute the successive points and trihedra of a space curve given by

a kappa and a tau function.  The curve is displayed as a ribbon by

letting rungs stick out along the normal vectors and by connecting these

rungs to make paved tiles.



     
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Usage and Limitations", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
First select and evaluate the cell containing the Algorithm.  Then 
create  and evaluate a cell of this form: 
 
clear; 
top = <Integer constant.   This measures the number of steps the 
computation goes through.  Values  larger than 200 are likely to cause 
Mathematica to run out of memory and  crash by locking up and destroying 
the active notebook.>; 
kappa[s_] =  <Real number expression in s.>; 
tau[s_] = <Real number expression in s.>; 
 width = <Real number measuring the width of the ribbon.  Mathematica 
scales  the curve to fit in a fixed box, so if you have a large curve 
length you  may want a larger width, and conversely.>; 
ds = <Real number for the step  size.  The total arclength will be top 
times ds.>; 
pribbonfrenet 
 
The  most significant limitation is that when Mathematica runs out of 
memory it  does not issue a warning, instead it crashes by locking up the 
machine and  commonly destroying the active notebook.  Values of top over 
300 reliably  crash a machine with 12 Meg of RAM.  It is good practice to 
save a backup  copy of this notebook under a different name from the 
working copy. 
 
A  second limitation is that we are using the crude \"Euler style\" method 
of  numerical integration instead of a more accurate \"Runge Kutte\" style 
 method.  This can in priciple be changed if there is sufficient need.
\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open]],

Cell[CellGroupData[{

Cell["Algorithm to Display a Kappa-Tau Space Curve as a Ribbon", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(clear := 
      Clear[ds, width, kappa, tau, top, point, tangent, normal, binormal, 
        curve, ncurve, tiles]; \)\), 
    \(\(normalize[vector_] := vector\/\@\(vector.vector\); \)\), 
    \(\(cross[u_, v_] := {
        u\[LeftDoubleBracket]2\[RightDoubleBracket]v\[LeftDoubleBracket]3
              \[RightDoubleBracket] - 
          u\[LeftDoubleBracket]3\[RightDoubleBracket]v\[LeftDoubleBracket]2
              \[RightDoubleBracket], 
        u\[LeftDoubleBracket]3\[RightDoubleBracket]v\[LeftDoubleBracket]1
              \[RightDoubleBracket] - 
          u\[LeftDoubleBracket]1\[RightDoubleBracket]v\[LeftDoubleBracket]3
              \[RightDoubleBracket], 
        u\[LeftDoubleBracket]1\[RightDoubleBracket]v\[LeftDoubleBracket]2
              \[RightDoubleBracket] - 
          u\[LeftDoubleBracket]2\[RightDoubleBracket]v\[LeftDoubleBracket]1
              \[RightDoubleBracket]}; \)\), 
    \(pribbonfrenet := 
      \((point = {0., 0., 0.}; edgepoint = {0., width, 0.}; 
        tangent = 
          If[kappa[0] \[NotEqual] 0. || tau[0] \[NotEqual] 0, 
            normalize[{kappa[0], 0., tau[0]}], {1., 0., 0.}]; 
        normal = {0., 1., 0.}; binormal = cross[tangent, normal]; 
        curve = {point}; edgecurve = {edgepoint}; tiles = {}; 
        rungs = {Line[{point, edgepoint}]}; 
        Do[newpoint = point + ds\ tangent; 
          newtangent = normalize[tangent + kappa[n\ ds]\ normal\ ds]; 
          newnormal = 
            normalize[
              normal + 
                \((tau[n\ ds]\ binormal - kappa[n\ ds]\ tangent)\)\ ds]; 
          newedgepoint = newpoint + width\ newnormal; 
          AppendTo[curve, newpoint]; AppendTo[edgecurve, newedgepoint]; 
          AppendTo[tiles, 
            Polygon[{point, edgepoint, newedgepoint, newpoint}]]; 
          AppendTo[rungs, Line[{newpoint, newedgepoint}]]; 
          tangent = newtangent; normal = newnormal; 
          binormal = cross[tangent, normal]; point = newpoint; 
          \(edgepoint = newedgepoint; \), {n, 1, top, 1}]; 
        Show[Graphics3D[{Thickness[.006], Line[curve]}], 
          Graphics3D[{Thickness[.003], RGBColor[1, 0, 0], Line[edgecurve]}], 
          Graphics3D[{RGBColor[1, 1, 0], EdgeForm[], tiles}], 
          Graphics3D[{GrayLevel[0.25], rungs}], BoxRatios \[Rule] {1, 1, 1}])
        \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(General::"spell1"\( : \ 
        \)"Possible spelling error: new symbol name \"\!\(top\)\" is similar \
to existing symbol \"\!\(Top\)\"."\)], "Message"]
}, Open]]
}, Open]],

Cell[BoxData[
    \(General::"spell1"\( : \ 
        \)"Possible spelling error: new symbol name \"\!\(point\)\" is \
similar to existing symbol \"\!\(Point\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1"\( : \ 
        \)"Possible spelling error: new symbol name \"\!\(normal\)\" is \
similar to existing symbol \"\!\(Normal\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"stop"\( : \ 
        \)"Further output of \!\(General :: \"spell1\"\) will be suppressed \
during this calculation."\)], "Message"],

Cell[BoxData[
    \(General::"spell1"\( : \ 
        \)"Possible spelling error: new symbol name \"\!\(cross\)\" is \
similar to existing symbol \"\!\(Cross\)\"."\)], "Message"],

"\!\(Cross\)\"."\)], "Message"],

aluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

->True],

Cell[CellGroupData[{

stant.", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(clear; top = 60; kappa[s_] = 1.; tau[s_] = 1.; width = .3; ds = .1; \), 
  
    \(pribbonfrenet\)}], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5538 .71891 m .54563 .6391 L .51505 .72847 L .824 .893 .891 r
F
.5538 .71891 m .56212 .62826 L .54563 .6391 L F
.59219 .70649 m .56212 .62826 L .5538 .71891 L .824 .861 .874 r
F
.59219 .70649 m .57809 .61614 L .56212 .62826 L F
.25 g
.5 Mabswid
.5538 .71891 m
.56212 .62826 L
s
.62966 .69122 m .57809 .61614 L .59219 .70649 L .819 .831 .858 r
F
0 g
.006 w
.5538 .71891 m
.59219 .70649 L
s
.51505 .72847 m .52892 .64864 L .47647 .73521 L .814 .924 .908 r
F
.51505 .72847 m .54563 .6391 L .52892 .64864 L F
0 g
.51505 .72847 m
.5538 .71891 L
s
.62966 .69122 m .59325 .60277 L .57809 .61614 L .819 .831 .858 r
F
.25 g
.5 Mabswid
.57809 .61614 m
.59219 .70649 L
s
.66564 .67314 m .59325 .60277 L .62966 .69122 L .811 .802 .843 r
F
0 g
.006 w
.59219 .70649 m
.62966 .69122 L
s
.47647 .73521 m .51228 .65689 L .43864 .73917 L .792 .951 .923 r
F
.47647 .73521 m .52892 .64864 L .51228 .65689 L F
0 g
.47647 .73521 m
.51505 .72847 L
s
.25 g
.5 Mabswid
.47647 .73521 m
.47811 .73251 L
s
.51505 .72847 m
.54478 .64159 L
s
.54478 .64159 m
.54563 .6391 L
s
.66564 .67314 m .60732 .58821 L .59325 .60277 L .811 .802 .843 r
F
.69958 .65229 m .60732 .58821 L .66564 .67314 L .8 .776 .831 r
F
.25 g
.62852 .68846 m
.62966 .69122 L
s
0 g
.006 w
.62966 .69122 m
.66564 .67314 L
s
.43864 .73917 m .49602 .66388 L .4021 .74042 L .752 .969 .93 r
F
.43864 .73917 m .51228 .65689 L .49602 .66388 L F
.25 g
.5 Mabswid
.52746 .65105 m
.52892 .64864 L
s
0 g
.006 w
.43864 .73917 m
.47647 .73521 L
s
.25 g
.5 Mabswid
.43864 .73917 m
.44094 .73659 L
s
.69958 .65229 m .62003 .57254 L .60732 .58821 L .8 .776 .831 r
F
.25 g
.60732 .58821 m
.60894 .59057 L
s
.73092 .62879 m .62003 .57254 L .69958 .65229 L .788 .752 .82 r
F
.25 g
.62852 .68845 m
.62852 .68846 L
s
.66382 .67048 m
.66564 .67314 L
s
0 g
.006 w
.66564 .67314 m
.69958 .65229 L
s
.4021 .74042 m .48043 .66965 L .36743 .73906 L .688 .97 .926 r
F
.4021 .74042 m .49602 .66388 L .48043 .66965 L F
.25 g
.5 Mabswid
.52635 .65289 m
.52746 .65105 L
s
.51024 .65918 m
.51228 .65689 L
s
0 g
.006 w
.4021 .74042 m
.43864 .73917 L
s
.25 g
.5 Mabswid
.4021 .74042 m
.40507 .738 L
s
.73092 .62879 m .63114 .55585 L .62003 .57254 L .788 .752 .82 r
F
.25 g
.62003 .57254 m
.62392 .57643 L
s
.59325 .60277 m
.62852 .68845 L
s
.75908 .60275 m .63114 .55585 L .73092 .62879 L .775 .73 .811 r
F
.25 g
.66381 .67047 m
.66382 .67048 L
s
.69708 .64979 m
.69958 .65229 L
s
0 g
.006 w
.69958 .65229 m
.73092 .62879 L
s
.36743 .73906 m .46581 .67427 L .3352 .73522 L .6 .949 .906 r
F
.36743 .73906 m .48043 .66965 L .46581 .67427 L F
.25 g
.5 Mabswid
.50868 .66092 m
.51024 .65918 L
s
.49343 .666 m
.49602 .66388 L
s
0 g
.006 w
.36743 .73906 m
.4021 .74042 L
s
.25 g
.5 Mabswid
.36984 .73758 m
.37102 .73686 L
s
.36743 .73906 m
.36984 .73758 L
s
.47811 .73251 m
.52495 .65519 L
s
.52495 .65519 m
.52635 .65289 L
s
.75908 .60275 m .6404 .53826 L .63114 .55585 L .775 .73 .811 r
F
.25 g
.63114 .55585 m
.63598 .55939 L
s
.7835 .57437 m .6404 .53826 L .75908 .60275 L .762 .711 .804 r
F
.25 g
.60894 .59057 m
.66381 .67047 L
s
.62392 .57643 m
.69707 .64978 L
s
.69707 .64978 m
.69708 .64979 L
s
.72777 .62648 m
.73092 .62879 L
s
0 g
.006 w
.73092 .62879 m
.75908 .60275 L
s
.3352 .73522 m .45243 .67782 L .30599 .72905 L .492 .904 .87 r
F
.3352 .73522 m .46581 .67427 L .45243 .67782 L F
.25 g
.5 Mabswid
.50672 .6631 m
.50868 .66092 L
s
.49144 .66762 m
.49343 .666 L
s
.47732 .67156 m
.48043 .66965 L
s
0 g
.006 w
.3352 .73522 m
.36743 .73906 L
s
.25 g
.5 Mabswid
.338 .73392 m
.33937 .73328 L
s
.3352 .73522 m
.338 .73392 L
s
.7835 .57437 m .64762 .51992 L .6404 .53826 L .762 .711 .804 r
F
.80365 .54388 m .64762 .51992 L .7835 .57437 L .748 .693 .799 r
F
.25 g
.63598 .55939 m
.72775 .62647 L
s
.72775 .62647 m
.72777 .62648 L
s
.75531 .6007 m
.75908 .60275 L
s
0 g
.006 w
.75908 .60275 m
.7835 .57437 L
s
.80365 .54388 m .65263 .50099 L .64762 .51992 L .748 .693 .799 r
F
.25 g
.5 Mabswid
.6404 .53826 m
.64924 .54307 L
s
.819 .51158 m .65263 .50099 L .80365 .54388 L .734 .677 .795 r
F
.25 g
.64924 .54307 m
.75529 .60069 L
s
.75529 .60069 m
.75531 .6007 L
s
.65768 .52395 m
.77916 .57263 L
s
.77916 .57263 m
.7835 .57437 L
s
.64762 .51992 m
.65768 .52395 L
s
0 g
.006 w
.7835 .57437 m
.80365 .54388 L
s
.30599 .72905 m .44056 .68041 L .28037 .72076 L .372 .839 .824 r
F
.30599 .72905 m .45243 .67782 L .44056 .68041 L F
.25 g
.5 Mabswid
.48896 .66964 m
.49144 .66762 L
s
.47494 .67303 m
.47732 .67156 L
s
.46223 .67594 m
.46581 .67427 L
s
0 g
.006 w
.30599 .72905 m
.3352 .73522 L
s
.25 g
.5 Mabswid
.30914 .72795 m
.31069 .72741 L
s
.30599 .72905 m
.30914 .72795 L
s
.44094 .73659 m
.50435 .66576 L
s
.50435 .66576 m
.50672 .6631 L
s
1 0 0 r
.003 w
.56212 .62826 m
.57809 .61614 L
s
.57809 .61614 m
.59325 .60277 L
s
.54563 .6391 m
.56212 .62826 L
s
.59325 .60277 m
.60732 .58821 L
s
.52892 .64864 m
.54563 .6391 L
s
.819 .51158 m .65528 .48164 L .65263 .50099 L .734 .677 .795 r
F
.82908 .47781 m .65528 .48164 L .819 .51158 L .72 .662 .792 r
F
.25 g
.5 Mabswid
.65983 .50303 m
.7988 .5425 L
s
.7988 .5425 m
.80365 .54388 L
s
.65263 .50099 m
.65983 .50303 L
s
0 g
.006 w
.80365 .54388 m
.819 .51158 L
s
.25 g
.5 Mabswid
.65967 .48245 m
.819 .51158 L
s
1 0 0 r
.003 w
.60732 .58821 m
.62003 .57254 L
s
.51228 .65689 m
.52892 .64864 L
s
.62003 .57254 m
.63114 .55585 L
s
.28037 .72076 m .43047 .68215 L .25893 .71055 L .255 .765 .776 r
F
.28037 .72076 m .44056 .68041 L .43047 .68215 L F
.25 g
.5 Mabswid
.40507 .738 m
.48593 .6721 L
s
.48593 .6721 m
.48896 .66964 L
s
.37102 .73686 m
.47197 .67485 L
s
.47197 .67485 m
.47494 .67303 L
s
.33937 .73328 m
.45949 .67722 L
s
.45949 .67722 m
.46223 .67594 L
s
.44844 .67922 m
.45243 .67782 L
s
0 g
.006 w
.28037 .72076 m
.30599 .72905 L
s
.25 g
.5 Mabswid
.28384 .71988 m
.28555 .71945 L
s
.28037 .72076 m
.28384 .71988 L
s
.44022 .6805 m
.44056 .68041 L
s
1 0 0 r
.003 w
.49602 .66388 m
.51228 .65689 L
s
.63114 .55585 m
.6404 .53826 L
s
.6404 .53826 m
.64762 .51992 L
s
.48043 .66965 m
.49602 .66388 L
s
.64762 .51992 m
.65263 .50099 L
s
.82908 .47781 m .65548 .46209 L .65528 .48164 L .72 .662 .792 r
F
.25 g
.5 Mabswid
.65528 .48164 m
.65967 .48245 L
s
.83346 .44301 m .65548 .46209 L .82908 .47781 L .706 .649 .791 r
F
0 g
.006 w
.819 .51158 m
.82908 .47781 L
s
1 0 0 r
.003 w
.46581 .67427 m
.48043 .66965 L
s
.34465 .16296 m .43665 .27531 L .45062 .27594 L .408 .613 .933 r
F
1 0 0 r
.65263 .50099 m
.65528 .48164 L
s
.45243 .67782 m
.46581 .67427 L
s
.25893 .71055 m .42238 .68318 L .24223 .69873 L .15 .692 .735 r
F
.25893 .71055 m .43047 .68215 L .42238 .68318 L F
.25 g
.5 Mabswid
.31069 .72741 m
.44539 .68029 L
s
.44539 .68029 m
.44844 .67922 L
s
.28555 .71945 m
.43624 .6815 L
s
.43624 .6815 m
.44022 .6805 L
s
0 g
.006 w
.25893 .71055 m
.28037 .72076 L
s
.25 g
.5 Mabswid
.25893 .71055 m
.26451 .70963 L
s
.38283 .15452 m .45062 .27594 L .46619 .27793 L .435 .601 .915 r
F
.25 g
.43436 .27251 m
.43665 .27531 L
s
.34465 .16296 m .45062 .27594 L .38283 .15452 L .408 .613 .933 r
F
1 0 0 r
.003 w
.43665 .27531 m
.45062 .27594 L
s
.83346 .44301 m .65318 .44253 L .65548 .46209 L .706 .649 .791 r
F
1 0 0 r
.65528 .48164 m
.65548 .46209 L
s
.25 g
.5 Mabswid
.65548 .46209 m
.82908 .47781 L
s
1 0 0 r
.003 w
.44056 .68041 m
.45243 .67782 L
s
.83181 .40766 m .65318 .44253 L .83346 .44301 L .691 .637 .791 r
F
0 g
.006 w
.82908 .47781 m
.83346 .44301 L
s
.42477 .14999 m .46619 .27793 L .48307 .28143 L .462 .593 .897 r
F
.25 g
.5 Mabswid
.44894 .27292 m
.45062 .27594 L
s
.4326 .27036 m
.43436 .27251 L
s
.38283 .15452 m .46619 .27793 L .42477 .14999 L .435 .601 .915 r
F
1 0 0 r
.003 w
.45062 .27594 m
.46619 .27793 L
s
.83181 .40766 m .64838 .4232 L .65318 .44253 L .691 .637 .791 r
F
1 0 0 r
.65318 .44253 m
.65548 .46209 L
s
.25 g
.5 Mabswid
.65318 .44253 m
.83346 .44301 L
s
1 0 0 r
.003 w
.43047 .68215 m
.44056 .68041 L
s
.82392 .37231 m .64838 .4232 L .83181 .40766 L .676 .627 .792 r
F
0 g
.006 w
.83181 .40766 m
.83346 .44301 L
s
.82392 .37231 m .64113 .40431 L .64838 .4232 L .676 .627 .792 r
F
1 0 0 r
.003 w
.64838 .4232 m
.65318 .44253 L
s
.25 g
.5 Mabswid
.64838 .4232 m
.83181 .40766 L
s
.46948 .14977 m .48307 .28143 L .5009 .28655 L .488 .588 .88 r
F
.42477 .14999 m .48307 .28143 L .46948 .14977 L .462 .593 .897 r
F
1 0 0 r
.003 w
.46619 .27793 m
.48307 .28143 L
s
.25 g
.5 Mabswid
.42477 .14999 m
.42622 .15448 L
s
.42622 .15448 m
.46619 .27793 L
s
.38283 .15452 m
.44894 .27292 L
s
.34465 .16296 m
.4326 .27036 L
s
.8097 .33754 m .64113 .40431 L .82392 .37231 L .661 .617 .794 r
F
.8097 .33754 m .63155 .38609 L .64113 .40431 L F
1 0 0 r
.003 w
.64113 .40431 m
.64838 .4232 L
s
.24223 .69873 m .41649 .68365 L .23081 .68559 L .065 .628 .709 r
F
.24223 .69873 m .42238 .68318 L .41649 .68365 L F
.25 g
.5 Mabswid
.26451 .70963 m
.42587 .68291 L
s
.42587 .68291 m
.43047 .68215 L
s
0 g
.006 w
.24223 .69873 m
.25893 .71055 L
s
.25 g
.5 Mabswid
.24811 .69822 m
.42238 .68318 L
s
.24223 .69873 m
.24811 .69822 L
s
.51585 .15411 m .5009 .28655 L .5193 .29337 L .512 .584 .864 r
F
.46948 .14977 m .5009 .28655 L .51585 .15411 L .488 .588 .88 r
F
1 0 0 r
.003 w
.48307 .28143 m
.5009 .28655 L
s
.25 g
.5 Mabswid
.46948 .14977 m
.48307 .28143 L
s
.78923 .30401 m .63155 .38609 L .8097 .33754 L .645 .609 .798 r
F
.25 g
.81779 .37338 m
.82392 .37231 L
s
.78923 .30401 m .6198 .36876 L .63155 .38609 L .645 .609 .798 r
F
.25 g
.64113 .40431 m
.81779 .37338 L
s
1 0 0 r
.003 w
.63155 .38609 m
.64113 .40431 L
s
.25 g
.5 Mabswid
.63155 .38609 m
.63612 .38484 L
s
0 g
.006 w
.82392 .37231 m
.83181 .40766 L
s
1 0 0 r
.003 w
.42238 .68318 m
.43047 .68215 L
s
.56267 .16314 m .5193 .29337 L .53788 .30191 L .535 .583 .85 r
F
.51585 .15411 m .5193 .29337 L .56267 .16314 L .512 .584 .864 r
F
1 0 0 r
.5009 .28655 m
.5193 .29337 L
s
.25 g
.5 Mabswid
.5009 .28655 m
.51585 .15411 L
s
.76276 .27236 m .6198 .36876 L .78923 .30401 L .629 .601 .803 r
F
.25 g
.80368 .33918 m
.8097 .33754 L
s
.76276 .27236 m .6061 .35254 L .6198 .36876 L .629 .601 .803 r
F
1 0 0 r
.003 w
.6198 .36876 m
.63155 .38609 L
s
.25 g
.5 Mabswid
.6198 .36876 m
.62411 .36711 L
s
.60872 .17683 m .53788 .30191 L .55625 .31217 L .556 .584 .837 r
F
.25 g
.5193 .29337 m
.52037 .29015 L
s
.56267 .16314 m .53788 .30191 L .60872 .17683 L .535 .583 .85 r
F
1 0 0 r
.003 w
.5193 .29337 m
.53788 .30191 L
s
.25 g
.5 Mabswid
.53788 .30191 m
.54476 .28977 L
s
.73074 .24324 m .6061 .35254 L .76276 .27236 L .612 .595 .809 r
F
.25 g
.78345 .30622 m
.78923 .30401 L
s
.80365 .33919 m
.80368 .33918 L
s
.73074 .24324 m .59072 .33759 L .6061 .35254 L .612 .595 .809 r
F
.25 g
.63612 .38484 m
.80365 .33919 L
s
1 0 0 r
.003 w
.6061 .35254 m
.6198 .36876 L
s
.25 g
.5 Mabswid
.6061 .35254 m
.6131 .34895 L
s
.65281 .19498 m .55625 .31217 L .57398 .3241 L .576 .586 .826 r
F
.25 g
.52037 .29015 m
.5212 .28768 L
s
.60872 .17683 m .55625 .31217 L .65281 .19498 L .556 .584 .837 r
F
.25 g
.5212 .28768 m
.56267 .16314 L
s
1 0 0 r
.003 w
.53788 .30191 m
.55625 .31217 L
s
.25 g
.5 Mabswid
.75913 .27422 m
.76276 .27236 L
s
.55625 .31217 m
.56565 .30076 L
s
.60624 .18121 m
.60872 .17683 L
s
.69381 .21727 m .59072 .33759 L .73074 .24324 L .594 .59 .817 r
F
.25 g
.72747 .24544 m
.73074 .24324 L
s
.72587 .24652 m
.72747 .24544 L
s
.75738 .27511 m
.75913 .27422 L
s
.78342 .30623 m
.78345 .30622 L
s
.69381 .21727 m .57398 .3241 L .59072 .33759 L .594 .59 .817 r
F
1 0 0 r
.003 w
.59072 .33759 m
.6061 .35254 L
s
.25 g
.5 Mabswid
.59072 .33759 m
.60033 .33112 L
s
.65281 .19498 m .57398 .3241 L .69381 .21727 L .576 .586 .826 r
F
.25 g
.57398 .3241 m
.58216 .3168 L
s
.68962 .221 m
.69381 .21727 L
s
.58216 .3168 m
.68962 .221 L
s
1 0 0 r
.003 w
.57398 .3241 m
.59072 .33759 L
s
.55625 .31217 m
.57398 .3241 L
s
.25 g
.5 Mabswid
.60033 .33112 m
.72587 .24652 L
s
.56565 .30076 m
.64944 .19907 L
s
.6131 .34895 m
.75735 .27513 L
s
.75735 .27513 m
.75738 .27511 L
s
.54476 .28977 m
.60624 .18121 L
s
.62411 .36711 m
.78342 .30623 L
s
.64944 .19907 m
.65281 .19498 L
s
0 g
.006 w
.8097 .33754 m
.82392 .37231 L
s
.23081 .68559 m .41649 .68365 L .41299 .68374 L 0 0 0 r
F
.23081 .68559 m .41299 .68374 L .22515 .67153 L F
.25 g
.5 Mabswid
.41233 .6837 m
.41649 .68365 L
s
0 g
.006 w
.23081 .68559 m
.24223 .69873 L
s
1 0 0 r
.003 w
.41649 .68365 m
.42238 .68318 L
s
0 g
.006 w
.78923 .30401 m
.8097 .33754 L
s
.22515 .67153 m .41299 .68374 L .41201 .68362 L 0 .544 .712 r
F
1 0 0 r
.003 w
.41299 .68374 m
.41649 .68365 L
s
.22515 .67153 m .41201 .68362 L .22569 .65696 L 0 .544 .712 r
F
0 g
.006 w
.22515 .67153 m
.23081 .68559 L
s
.25 g
.5 Mabswid
.22515 .67153 m
.41299 .68374 L
s
0 g
.006 w
.34465 .16296 m
.38283 .15452 L
s
.22569 .65696 m .41201 .68362 L .41364 .68348 L 0 .526 .741 r
F
1 0 0 r
.003 w
.41201 .68362 m
.41299 .68374 L
s
0 g
.006 w
.76276 .27236 m
.78923 .30401 L
s
.23275 .64236 m .41364 .68348 L .41792 .68353 L 0 .52 .783 r
F
.25 g
.5 Mabswid
.40719 .68293 m
.41201 .68362 L
s
.22569 .65696 m .41364 .68348 L .23275 .64236 L 0 .526 .741 r
F
.25 g
.22569 .65696 m
.40719 .68293 L
s
1 0 0 r
.003 w
.41201 .68362 m
.41364 .68348 L
s
0 g
.006 w
.22515 .67153 m
.22569 .65696 L
s
.38283 .15452 m
.42477 .14999 L
s
.73074 .24324 m
.76276 .27236 L
s
.24654 .62825 m .41792 .68353 L .42485 .68397 L 0 .525 .831 r
F
.25 g
.5 Mabswid
.409 .68243 m
.41364 .68348 L
s
.23275 .64236 m .41792 .68353 L .24654 .62825 L 0 .52 .783 r
F
1 0 0 r
.003 w
.41364 .68348 m
.41792 .68353 L
s
0 g
.006 w
.22569 .65696 m
.23275 .64236 L
s
.25 g
.5 Mabswid
.23275 .64236 m
.23887 .64375 L
s
0 g
.006 w
.42477 .14999 m
.46948 .14977 L
s
.69381 .21727 m
.73074 .24324 L
s
.65281 .19498 m
.69381 .21727 L
s
.46948 .14977 m
.51585 .15411 L
s
.2671 .61517 m .42485 .68397 L .43436 .68498 L .033 .534 .876 r
F
.25 g
.5 Mabswid
.41356 .68213 m
.41792 .68353 L
s
.40543 .68162 m
.409 .68243 L
s
.24654 .62825 m .42485 .68397 L .2671 .61517 L 0 .525 .831 r
F
.25 g
.23887 .64375 m
.40543 .68162 L
s
1 0 0 r
.003 w
.41792 .68353 m
.42485 .68397 L
s
.25 g
.5 Mabswid
.24654 .62825 m
.25239 .63013 L
s
0 g
.006 w
.60872 .17683 m
.65281 .19498 L
s
.51585 .15411 m
.56267 .16314 L
s
.56267 .16314 m
.60872 .17683 L
s
.2943 .60369 m .43436 .68498 L .44631 .68678 L .097 .545 .91 r
F
.25 g
.5 Mabswid
.42087 .68223 m
.42485 .68397 L
s
.41021 .68105 m
.41356 .68213 L
s
.2671 .61517 m .43436 .68498 L .2943 .60369 L .033 .534 .876 r
F
1 0 0 r
.003 w
.42485 .68397 m
.43436 .68498 L
s
.25 g
.5 Mabswid
.2671 .61517 m
.27256 .61755 L
s
0 g
.006 w
.23275 .64236 m
.24654 .62825 L
s
.3278 .5944 m .44631 .68678 L .46051 .68954 L .166 .554 .93 r
F
.25 g
.5 Mabswid
.43085 .68295 m
.43436 .68498 L
s
.41781 .6809 m
.42087 .68223 L
s
.40601 .67969 m
.41021 .68105 L
s
.2943 .60369 m .44631 .68678 L .3278 .5944 L .097 .545 .91 r
F
1 0 0 r
.003 w
.43436 .68498 m
.44631 .68678 L
s
.25 g
.5 Mabswid
.2943 .60369 m
.29758 .6056 L
s
.29758 .6056 m
.29918 .60653 L
s
.36704 .58782 m .46051 .68954 L .47672 .69343 L .234 .56 .935 r
F
.25 g
.44336 .68448 m
.44631 .68678 L
s
.42815 .68138 m
.43085 .68295 L
s
.41398 .67922 m
.41781 .6809 L
s
.40088 .67803 m
.40601 .67969 L
s
.3278 .5944 m .46051 .68954 L .36704 .58782 L .166 .554 .93 r
F
.25 g
.25239 .63013 m
.40088 .67803 L
s
1 0 0 r
.003 w
.44631 .68678 m
.46051 .68954 L
s
.25 g
.5 Mabswid
.3278 .5944 m
.3306 .59657 L
s
.3306 .59657 m
.33196 .59764 L
s
0 g
.006 w
.24654 .62825 m
.2671 .61517 L
s
.89673 .85636 m .69764 .88576 L .8956 .88937 L .692 .653 .807 r
F
.41122 .58445 m .47672 .69343 L .49462 .69858 L .298 .563 .93 r
F
.25 g
.5 Mabswid
.4582 .68703 m
.46051 .68954 L
s
.44109 .68272 m
.44336 .68448 L
s
.42477 .67942 m
.42815 .68138 L
s
.40928 .67717 m
.41398 .67922 L
s
.36704 .58782 m .47672 .69343 L .41122 .58445 L .234 .56 .935 r
F
.25 g
.27256 .61755 m
.40928 .67717 L
s
1 0 0 r
.003 w
.46051 .68954 m
.47672 .69343 L
s
.25 g
.5 Mabswid
.36704 .58782 m
.36925 .59023 L
s
.36925 .59023 m
.37033 .5914 L
s
.89673 .85636 m .69333 .86601 L .69764 .88576 L .692 .653 .807 r
F
.25 g
.69764 .88576 m
.8956 .88937 L
s
.45935 .5847 m .49462 .69858 L .51385 .70511 L .354 .566 .918 r
F
.25 g
.47511 .69074 m
.47672 .69343 L
s
.41122 .58445 m .49462 .69858 L .45935 .5847 L .298 .563 .93 r
F
1 0 0 r
.003 w
.47672 .69343 m
.49462 .69858 L
s
.25 g
.5 Mabswid
.41122 .58445 m
.41278 .58704 L
s
.41278 .58704 m
.41354 .58831 L
s
.37033 .5914 m
.4582 .68703 L
s
.33196 .59764 m
.44109 .68272 L
s
.29918 .60653 m
.42477 .67942 L
s
.89096 .82302 m .69333 .86601 L .89673 .85636 L .674 .639 .808 r
F
0 g
.006 w
.8956 .88937 m
.89673 .85636 L
s
.89096 .82302 m .68626 .84654 L .69333 .86601 L .674 .639 .808 r
F
1 0 0 r
.003 w
.69333 .86601 m
.69764 .88576 L
s
.25 g
.5 Mabswid
.69333 .86601 m
.89673 .85636 L
s
.51023 .58889 m .51385 .70511 L .53401 .71311 L .403 .568 .903 r
F
.45935 .5847 m .51385 .70511 L .51023 .58889 L .354 .566 .918 r
F
1 0 0 r
.003 w
.49462 .69858 m
.51385 .70511 L
s
.25 g
.5 Mabswid
.45935 .5847 m
.4606 .58875 L
s
.4606 .58875 m
.49462 .69858 L
s
.41354 .58831 m
.47511 .69074 L
s
.87812 .78987 m .68626 .84654 L .89096 .82302 L .655 .627 .81 r
F
.87812 .78987 m .67653 .82754 L .68626 .84654 L F
1 0 0 r
.003 w
.68626 .84654 m
.69333 .86601 L
s
0 g
.006 w
.89096 .82302 m
.89673 .85636 L
s
.2671 .61517 m
.2943 .60369 L
s
.85816 .75743 m .67653 .82754 L .87812 .78987 L .636 .616 .814 r
F
.25 g
.5 Mabswid
.88411 .82381 m
.89096 .82302 L
s
.85816 .75743 m .6643 .80921 L .67653 .82754 L .636 .616 .814 r
F
.25 g
.68626 .84654 m
.88411 .82381 L
s
1 0 0 r
.003 w
.67653 .82754 m
.68626 .84654 L
s
.25 g
.5 Mabswid
.67653 .82754 m
.68171 .82657 L
s
.56257 .59719 m .53401 .71311 L .55467 .72261 L .445 .571 .887 r
F
.51023 .58889 m .53401 .71311 L .56257 .59719 L .403 .568 .903 r
F
1 0 0 r
.003 w
.51385 .70511 m
.53401 .71311 L
s
.25 g
.5 Mabswid
.51023 .58889 m
.51385 .70511 L
s
.83128 .7263 m .6643 .80921 L .85816 .75743 L .615 .607 .819 r
F
.25 g
.8713 .79114 m
.87812 .78987 L
s
.83128 .7263 m .64979 .79175 L .6643 .80921 L .615 .607 .819 r
F
1 0 0 r
.003 w
.6643 .80921 m
.67653 .82754 L
s
.25 g
.5 Mabswid
.6643 .80921 m
.66924 .80789 L
s
.61495 .60965 m .55467 .72261 L .57537 .73363 L .482 .574 .871 r
F
.25 g
.53401 .71311 m
.53471 .71027 L
s
.56257 .59719 m .55467 .72261 L .61495 .60965 L .445 .571 .887 r
F
.25 g
.53471 .71027 m
.56257 .59719 L
s
1 0 0 r
.003 w
.53401 .71311 m
.55467 .72261 L
s
.79788 .69705 m .64979 .79175 L .83128 .7263 L .593 .598 .826 r
F
.25 g
.5 Mabswid
.85155 .7592 m
.85816 .75743 L
s
.87127 .79115 m
.8713 .79114 L
s
.79788 .69705 m .63328 .77531 L .64979 .79175 L .593 .598 .826 r
F
.25 g
.68171 .82657 m
.87127 .79115 L
s
1 0 0 r
.003 w
.64979 .79175 m
.6643 .80921 L
s
.25 g
.5 Mabswid
.64979 .79175 m
.65789 .78883 L
s
.66596 .62616 m .57537 .73363 L .59566 .74614 L .515 .579 .857 r
F
.25 g
.55467 .72261 m
.55615 .71984 L
s
.61495 .60965 m .57537 .73363 L .66596 .62616 L .482 .574 .871 r
F
1 0 0 r
.003 w
.55467 .72261 m
.57537 .73363 L
s
.25 g
.5 Mabswid
.57537 .73363 m
.58411 .72326 L
s
.61282 .61364 m
.61495 .60965 L
s
.75858 .67027 m .63328 .77531 L .79788 .69705 L .57 .591 .835 r
F
.25 g
.79403 .69888 m
.79788 .69705 L
s
.82504 .72855 m
.83128 .7263 L
s
.85152 .75921 m
.85155 .7592 L
s
.75858 .67027 m .61511 .76007 L .63328 .77531 L .57 .591 .835 r
F
1 0 0 r
.003 w
.63328 .77531 m
.64979 .79175 L
s
.25 g
.5 Mabswid
.63328 .77531 m
.64057 .77185 L
s
.71425 .64648 m .59566 .74614 L .61511 .76007 L .544 .584 .845 r
F
.25 g
.55615 .71984 m
.55728 .71771 L
s
.66596 .62616 m .59566 .74614 L .71425 .64648 L .515 .579 .857 r
F
.25 g
.55728 .71771 m
.61282 .61364 L
s
1 0 0 r
.003 w
.57537 .73363 m
.59566 .74614 L
s
.25 g
.5 Mabswid
.79214 .69978 m
.79403 .69888 L
s
.59566 .74614 m
.60368 .7394 L
s
.66277 .62995 m
.66596 .62616 L
s
.71425 .64648 m .61511 .76007 L .75858 .67027 L .544 .584 .845 r
F
.25 g
.61511 .76007 m
.62486 .75396 L
s
.75355 .67342 m
.75858 .67027 L
s
.62486 .75396 m
.75355 .67342 L
s
1 0 0 r
.003 w
.59566 .74614 m
.61511 .76007 L
s
.25 g
.5 Mabswid
.71007 .65 m
.71425 .64648 L
s
.60368 .7394 m
.71007 .65 L
s
.64057 .77185 m
.79214 .69978 L
s
.58411 .72326 m
.66277 .62995 L
s
.65789 .78883 m
.82501 .72856 L
s
.82501 .72856 m
.82504 .72855 L
s
.66924 .80789 m
.85152 .75921 L
s
1 0 0 r
.003 w
.61511 .76007 m
.63328 .77531 L
s
0 g
.006 w
.87812 .78987 m
.89096 .82302 L
s
.2943 .60369 m
.3278 .5944 L
s
.85816 .75743 m
.87812 .78987 L
s
.3278 .5944 m
.36704 .58782 L
s
.83128 .7263 m
.85816 .75743 L
s
.36704 .58782 m
.41122 .58445 L
s
.79788 .69705 m
.83128 .7263 L
s
.41122 .58445 m
.45935 .5847 L
s
.75858 .67027 m
.79788 .69705 L
s
.45935 .5847 m
.51023 .58889 L
s
.71425 .64648 m
.75858 .67027 L
s
.51023 .58889 m
.56257 .59719 L
s
.66596 .62616 m
.71425 .64648 L
s
.56257 .59719 m
.61495 .60965 L
s
.61495 .60965 m
.66596 .62616 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.313, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400049000181000`40O003h00Oogoo2Woo002`Ool2
001GOol00:ioo`800003Ool0000005Ioo`00Zgoo0`000goo0P00EWoo002YOol20006Ool00`00Ool0
001EOol00:Moo`8000Qoo`03001oo`0005Eoo`00Y7oo0`002Woo00@007ooOol005Aoo`00XWoo0P00
3Goo00D007ooOomoo`0005=oo`00Wgoo0`003goo00D007ooOomoo`0005=oo`00WGoo0P004Woo00<0
07ooOol00Woo00<007ooOol0D7oo002KOol2000EOol00`00Oomoo`02Ool00`00Oomoo`1?Ool009Qo
o`<001Moo`03001oogoo009oo`03001oogoo04moo`00UWoo0P006Woo00<007ooOol00goo00<007oo
Ool0CWoo002COol3000LOol00`00Oomoo`03Ool00`00Oomoo`1>Ool0095oo`8001moo`03001oogoo
00Aoo`03001oogoo04eoo`00Sgoo0P008Goo00<007ooOol01Goo00<007ooOol0C7oo002<Ool3000S
Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool008Yoo`8002Ioo`03001oogoo00Ioo`03001oogoo04]o
o`00Qgoo0`00:7oo00<007ooOol01goo00<007ooOol0BWoo0025Ool2000[Ool00`00Oomoo`07Ool0
0`00Oomoo`1:Ool008=oo`8002eoo`03001oogoo00Qoo`03001oogoo04Uoo`00P7oo0`00;goo00<0
07ooOol027oo00<007ooOol0BGoo001nOol2000bOol00`00Oomoo`09Ool00`00Oomoo`18Ool007]o
o`<003Aoo`03001oogoo00Yoo`03001oogoo04Moo`00NGoo0P00=goo00<007ooOol02Woo00<007oo
Ool0Agoo001gOol2000iOol00`00Oomoo`0;Ool00`00Oomoo`16Ool007Aoo`<003]oo`03001oogoo
00aoo`03001oogoo04Eoo`00LWoo0P00?goo00<007ooOol02goo00<007ooOol0AGoo001_Ool30011
Ool00`00Oomoo`0<Ool00`00Oomoo`14Ool006eoo`8004Aoo`03001oogoo00aoo`03001oogoo04Ao
o`00Jgoo0P00AWoo00<007ooOol03Goo00<007ooOol0@goo001XOol30018Ool00`00Oomoo`0>Ool0
0`00Oomoo`12Ool006Ioo`8004]oo`03001oogoo00ioo`03001oogoo049oo`00Hgoo0`00CGoo00<0
07ooOol03goo00<007ooOol0@Goo001QOol2001@Ool00`00Oomoo`0@Ool00`00Oomoo`10Ool005io
o`<0059oo`03001oogoo011oo`03001oogoo041oo`00G7oo0P00EGoo00<007ooOol04Goo00<007oo
Ool0?goo001JOol2001GOol00`00Oomoo`0AOol00`00Oomoo`0oOol005Moo`<005Uoo`03001oogoo
019oo`03001oogoo03ioo`00EGoo0P00G7oo00<007ooOol04goo00<007ooOol0?Goo001BOol3000F
OolG000aOol00`00Oomoo`0COol00`00Oomoo`0mOol0051oo`80019oo`L0000G=U`fOC9L=WdfG1cW
=U/jG3IK>U`fFcYL=U/jG3IK>U`fFacW>U/nG3YK?U/jF`08000YOol00`00Oomoo`0DOol00`00Oomo
o`0lOol004ioo`80015oo`<0008bO@037>LfG3IL00LfG0037>LjG3YK00<jG00D>U/jG3YL>U`jFcYL
7>LnFcYK?U/jFciK>U/nFcYK?U/jFciK7>M2F`@002Eoo`03001oogoo01Eoo`03001oogoo03]oo`00
Bgoo0`003goo100002dbO39m<W`bOC9l7>LbG3Im=U`fOC9L=WdfG3Im<U`fOAcW>U`fFcYL=U/jG3IK
>U`fFcYL=U/LicYK?U/jFciL>U/nFcYK?U`jFciK>U/LiciJ@U/nFT9K?UX010008Goo00<007ooOol0
5Goo00<007ooOol0>goo0019Ool2000@Ool2000:<Wd00acW=U`fG007=U`011cW>U`jG3YK0cYL014j
FcYL>U`jG1cW?U/jFciK>U/nFcYK?U/jFciK>U/nFacW008nF`07@U/nFSiK?U]2FciJ?U/010007Woo
00<007ooOol05Goo00<007ooOol0>Woo0016Ool3000COol0>QcW<W`bOC9l<WdbO39m<W`bOC9l<WdL
icIm<U`fOCIL=WdbG3Im=U`fOAcW>U`fFcYL=U/jG3IK>U`fFcYL=U/LicYK?U`jFciK>U/nG3YK?U/j
FciL>U/LiciJ@U/nFT9K?UY2FciJ@U/nFT9K?UXLid9J10006Woo00<007ooOol05Goo00<007ooOol0
>Woo0014Ool2000GOol00acW<WdbO@08<Wd00acW=U`fG007=U`01AcW>U`jG3YL>U/00cYL014jFcYL
>U`LicYK?U/jFciK>U/nFcYK?U/jFacW?U]2FciJ008nF`07@U/nFSiK?U]2FciJ7>L01T9J10005Woo
00<007ooOol05Woo00<007ooOol0>Goo0012Ool2000IOol0>1cW<WdbO39m<W`bOC9l<WdbO39m<W`L
icIL=WdbG3Im=U`fOC9L=WdfG1cW=U/jG3IK>U`fFcYL=U/jG3IK>U`LiciK>U/nG3YK?U/jFciL>U/n
FacW@U/nFT9K?UY2FciJ@U/nFT9K?UY2FacW@U/3@UX01T9K@UY2FT9J@U]2FP@0019oo`03001oogoo
01Moo`03001oogoo03Qoo`00?goo0`0077oo00<Lic9m<Wd0239m00<LicIL=U`01SIL00<LicYL>U/0
0cYL014jFcYL>U`jG3YK7>LjFciK>U/nFcYK?U/jFciK>U/LiciJ008nF`06@U/nFSiK?U]2FciJ0SiK
00<Lid9J@UX02D9J00=6FQcWAUX00P0047oo00<007ooOol05goo00<007ooOol0>7oo000mOol2000P
Ool0=1cW<WdbO39m<W`bOC9l<WdbO39m7>LfOCIL=WdbG3Im=U`fOC9L=WdLicYL=U/jG3IK>U`fFcYL
=U/jG1cW?U`jFciK>U/nG3YK?U/jFciL7>M2FciJ@U/nFT9K?UY2FciJ@U/nFQcW0d9J00E2Fd9J@UY2
FT9K00=2FP06@U/LidIJ@UU6FT9I0P003Woo00<007ooOol067oo00<007ooOol0=goo000jOol3000S
Ool00acW<WdbO@07<Wd00acW=U`fG006=U`011cW>U`jG3YK0cYL014jFcYL>U`LicYK?U/jFciK>U/n
FcYK?U/jFacW?U]2FciJ008nF`06@U/nFSiK?U]2FacW2d9J00=6FQcWAUX01DIJ0`002goo00<007oo
Ool06Goo00<007ooOol0=Woo000hOol2000WOol0=1cW<WdbO39m<W`bOC9l<WdbO1cW<U`fOCIL=Wdb
G3Im=U`fOAcW>U`fFcYL=U/jG3IK>U`fFcYL7>LnFcYK?U`jFciK>U/nG3YK?U/Lid9K?UY2FciJ@U/n
FT9K?UY2FciJ7>M2FT9K0d9J0152Fd9J@UY2FT9K@UXLid9IAUY2FDIJ@UU6FT9IAUY2FDIJ008000Uo
o`03001oogoo01Uoo`03001oogoo03Ioo`00=Woo0P00:Woo00<Lic9m<Wd01S9m00<LicIL=U`01SIL
00DLicYL>U`jG3YK00<jG00=>U/LicYK?U/jFciK>U/nFcYK?U/jFacW?UX00SiK00M2FciJ?U/nFd9K
?UXLi`0;@UX00dIJ7>M6FP0;AUX20007Ool00`00Oomoo`0JOol00`00Oomoo`0eOol003=oo`<002ao
o`0a7>LbO39m<W`bOC9l<WdbO39m7>LfOC9L=WdfG3Im<U`fOCIL7>LfFcYL=U/jG3IK>U`fFcYL7>Ln
G3YK?U/jFciL>U/nFcYK?U`Lid9K?UY2FciJ@U/nFT9K?UY2FacW@U/00d9J00E2Fd9J@UY2FT9K0092
FP0@7>M6FT9IAUY2FDIJ@UU6FT9IAUY2FDIJ@UU6FQcWBUX20005Ool00`00Oomoo`0JOol00`00Oomo
o`0eOol0035oo`80031oo`037>LbOC9m00HbO@037>LfG3IL00DfG0037>LjG3YK00<jG00A>U/jG3YL
7>LjFciK>U/nFcYK?U/jFciK>U/LiciK@U/nFP02?U/01D9K?UXnFciK7>L02T9J00<LidIJAUX02dIJ
00DLidIIAUU:FTII008000=oo`03001oogoo01]oo`03001oogoo03Aoo`00;Woo0`00<goo02dLic9l
<WdbO39m<W`bOC9l7>LfG3Im<U`fOCIL=WdbG3Im7>LjG3IK>U`fFcYL=U/jG1cW?U/jFciL>U/nFcYK
?U`jFacW?UY2FciJ@U/nFT9K?UY2FciJ7>L00d9J00E2Fd9J@UY2FT9K00=2FP0E7>M2FDIJ@UU6FT9I
AUY2FDIJ@UU6FT9IAUXLidYJAUU:FTIIBUY6FDYJ00800003Ool007oo01eoo`03001oogoo03=oo`00
;7oo0P00=goo00<Lic9m<Wd01C9m00<LicIL=U`01CIL00@LicYL>U`jF`<jG00=>U/LicYK?U/jFciK
>U/nFcYK?U/Lid9K?UX00SiK00I2FciJ?U/nFd9K7>L:@UX00acWAUY6FP0;AUX00acWAUU:FP03AUT0
14YJAUU6FDII0P007Woo00<007ooOol0<goo000ZOol2000jOol0;AcW<W`bOC9l<WdbO39m<W`LicIL
=WdbG3Im=U`fOAcW>U`fFcYL=U/jG3IK>U`LiciL>U/nFcYK?U`jFciK>U/LiciJ@U/nFT9K?UY2FciJ
@U/nFQcW@UY2F`03@UX07T9K@UY2FT9J@U/LidIJ@UU6FT9IAUY2FDIJ@UU6FT9IAUY2FAcWAUU:FTII
BUY6FDYJAUU:FTIIBUY6F@<001eoo`03001oogoo039oo`009goo0`00?Goo00<Lic9m<Wd0139m00<L
icIL=U`01CIL00DLicYL>U`jG3YK00<jG0097>LnFcYK?U/jFciK>U/nFacW008nF`07@U/nFSiK?U]2
FciJ7>L02T9J00<LidIJAUX02TIJ00<LidIIBUX00dII00E:FTIIAUU6FDYJ0096F@04001:FTII000M
Ool00`00Oomoo`0aOol002Eoo`80041oo`0Z7>LbOC9l<WdbO39m<W`bOAcW=WdfG3Im<U`fOCIL7>Lf
FcYL=U/jG3IK>U`fFacW>U/nG3YK?U/jFciL>U/LiciJ@U/nFT9K?UY2FciJ@U/Lid9K0d9J02A2Fd9J
@UY2FT9K@UTLid9IAUY2FDIJ@UU6FT9IAUY2FDIJ@UTLidIIBUY6FDYJAUU:FTIIBUY6FDYJAUU:FTII
0016FAcWBUT2000KOol00`00Oomoo`0aOol0029oo`<004=oo`037>LbOC9m00@bO@037>LfG3IL00@f
G0037>LjG3YK00<jG00=>U/jG1cW?U/jFciK>U/nFcYK?U/Lid9K?UX00SiK00E2FciJ?U/nFacW00U2
FP037>M6FTIJ00U6FP037>M6FDYJ00=6F@05BUY6FDIIAUU:FP03AUT00dYJ000Li`04BUT00`00Oomo
o`0IOol00`00Oomoo`0`Ool0021oo`8004Moo`0V7>LbOC9l<WdbO39m<W`Lic9L=WdfG3Im<U`fOAcW
>U`fFcYL=U/jG3IK7>LjFciK>U/nG3YK?U/jFacW?UY2FciJ@U/nFT9K?UXLi`=2FP0U@U]2FT9J@UY2
Fd9J7>M2FDIJ@UU6FT9IAUY2FDIJ@UU6FT9I7>M6FDYJAUU:FTIIBUY6FDYJAUU:FTIIBUY6FDYJAUTL
i`00BUX00dYI00=:FP00Ool06Goo00<007ooOol0<7oo000NOol2001:Ool00acW<WdbO@03<Wd00acW
=U`fG004=U`011cW>U`jG3YK0cYL00TLiciK>U/nFcYK?U/jFciK7>L00SiK00I2FciJ?U/nFd9K7>L9
@UX00acWAUY6FP09AUX00acWBUY6F@02AUT01DYJAUU6FDIIBUX00dII00E:FQcW7>M:F@0000I:F@80
01Uoo`03001oogoo02moo`006goo0`00CGoo02HLic9m<W`bOC9l<WdLicIm<U`fOCIL=WdLicYL=U/j
G3IK>U`fFacW>U/nG3YK?U/jFciL7>M2FciJ@U/nFT9K?UY2FciJ7>M2FT9K0d9J01i2Fd9J@UXLidIJ
@UU6FT9IAUY2FDIJ@UU6FT9IAUXLidYJAUU:FTIIBUY6FDYJAUU:FTIIBUY6FDYJ7>L2BUT01DYJ001:
FDYIBUX00dYI00=:FTYI00006Goo00<007ooOol0;Woo000IOol2001@Ool00acW<WdbO@03<Wd00acW
=U`fG004=U`04AcW>U`jG3YL>U/jG1cW?U/jFciK>U/nFcYK7>LnFd9K?UX00SiK00=2FciJ7>L02D9J
00<LidIJAUX024IJ00<LidYJAUT00TII00E:FTIIAUU6FDYJ00=6F@03BUXLidYI00=:F@03001:FDYI
00M:F@8001Moo`03001oogoo02ioo`005goo0P00Dgoo02<Lic9l<WdbO39m<W`LicIL=WdbG3Im=U`L
icIK>U`fFcYL=U/LicYK?U/jFciL>U/nFacW@U/nFT9K?UY2FciJ@U/Lid9K00=2FP0N@U]2FT9J@UXL
id9IAUY2FDIJ@UU6FT9IAUY2FDIJ7>M:FTIIBUY6FDYJAUU:FTIIBUY6FDYJAUU:FQcW0TYI00E:FTYI
BUT004YJ00=:F@08BUY:FDYIBUU:FTYI7>L001Moo`03001oogoo02eoo`005goo0P00E7oo00<Lic9m
<Wd00S9m00<LicIL=U`00cIL00<LicYL>U/00cYL00TLiciK>U/nFcYK?U/jFacW?UX00SiK00E2FciJ
?U/nFacW00M2FP037>M6FTIJ00Q6FP037>M:FTII0096F@05BUY6FDIIAUU:FP03AUT00dYJ7>M:F@05
BUT00`00BUU:F@07BUT011cWBUU>F@005goo00<007ooOol0;7oo000GOol00`00Ool0001DOol07acW
<W`bOC9l<WdLicIm=U`fOC9L=WdLicYL=U/jG3IK7>LjFciL>U/nFcYK?U`Lid9K?UY2FciJ@U/nFQcW
00=2FP0N@U]2FT9J@UY2FacWAUY2FDIJ@UU6FT9IAUY2FDIJ@UTLidIIBUY6FDYJAUU:FTIIBUY6FDYJ
AUU:FQcW0TYI00I:FTYIBUU:FDYJ0002BUT01DYJBUU:FDYIBUX00QcW00E:F4iIBUU>F@0001Ioo`03
001oogoo02aoo`005goo00@007ooOol005Aoo`057>LbOC9m<WdLi`05=U`041cW>U`jG3YK>U`LiciK
>U/nFcYK?U/jFacW?U]2FciJ0SiK00=2FacW@UX01T9J00<LidIJAUX024IJ00DLidIIAUU6FDYJ00=6
F@04BUY6FDIIAUT27>L8BUT00`00BUU:F@04BUT02AcWCUU:FDiIBUU>FDYICUT0000FOol00`00Oomo
o`0[Ool001Ioo`03001oogoo009oo`03001oogoo059oo`0O7>LbO39m<W`Lic9L=WdfG3Im7>LjG3IK
>U`fFacW>U/nFcYK?U`jFciK7>M2FciJ@U/nFT9K?UXLid9J@U/00d9J01U2Fd9J7>M2FDIJ@UU6FT9I
AUY2FDIJ@UTLidIIBUY6FDYJAUU:FTIIBUY6FDYJAUTLi`03BUT01DYJBUU:FDYIBUX00TYI00<004YJ
BUT00TYI0QcW00Y>FDYHCUU:FDiIBUQ>FDYICUT001Eoo`03001oogoo02]oo`005Woo00<007ooOol0
0goo00<007ooOol0DGoo00DLic9m<WdbOAcW00DfG00=7>LjG3YL>U`jFacW>U/nFcYK?U/jFacW?UX0
0SiK00=2FciJ7>L01d9J00<LidIJAUX01dIJ00DLidIIAUU6FDYJ00=6F@05BUY6FDIIAUTLi`0;BUT0
4P00BUU:FDYI7>M:FDiIBUU>FDYICUU:FDiIBUU>FDYICUT001Eoo`03001oogoo02Yoo`005Woo00<0
07ooOol017oo00<007ooOol0DGoo01`Lic9m<W`bOAcW=WdbG3Im=U`LicIK>U`fFcYL7>LnG3YK?U/j
FciL7>M2FciJ@U/nFT9K7>M2F`=2FP0I@U]2FT9J7>M6FT9IAUY2FDIJ@UU6FT9I7>M6FDYJAUU:FTII
BUY6FDYJAUU:FTII7>L00dYI00E:FTYIBUU:FDYJ00=:F@03BUX004YI008Li`0?BUU>FDYHCUU:FDiI
BUQ>FDYICUU:F4iIBUU>F@0001Eoo`03001oogoo02Uoo`005Woo00<007ooOol01Goo00<007ooOol0
DGoo00@Lic9m<WdLi`@fG0037>LjG3YK008jG0067>LjFciK>U/nFacW0SiK00E2FciJ?U/nFacW00I2
FP037>M6FTIJ00M6FP047>M6FDIIBUX3AUT01DYJAUU6FDII7>L03DYI01@001cWCUU:FDiIBUU>FDYI
CUU:FDiIBUU>FDYICUU:FDiIBUU>F@0057oo00<007ooOol0:Goo000FOol00`00Oomoo`06Ool00`00
Oomoo`1@Ool01AcWO01l07`07>L00W`0018bG3Im7>LjG3IK>U`LiciK>U/nG3YK7>LnFT9K?UY2FciJ
7>L3@UX06D9K@UY2FQcWAUY2FDIJ@UU6FT9IAUY2FDIJ7>M:FTIIBUY6FDYJAUU:FTIIBUY6FAcW00=:
F@05BUY:FDYIBUU:FP03BUT064YJBUTLi`00CUU:FDiIBUQ>FDYICUU:F4iIBUU>FDYHCUU:FDiIBUQ>
FDYI7>L001Aoo`03001oogoo02Qoo`005Woo00<007ooOol01goo00<007ooOol0EWoo0W`000`Lig`0
>U`jFacW>U/nFcYK?U/Lid9K?UX2?U/00d9K7>M2FP05@UX00acWAUY6FP06AUX011cWAUU6FDYJ0dII
00E:FTIIAUU6FAcW00e:F@0C7>M:F@00BUU>FDYICUU:FDiIBUU>FDYICUU:FDiIBUU>FDYICUT00QcW
0TiI00<007ooOol04Woo00<007ooOol09goo000EOol00`00Oomoo`09Ool00`00Oomoo`1IOol2O000
3QcWO01l03iK>U/LiciJ@U/nFT9K?UXLid9J@U/3@UX04acW@UU6FT9IAUY2FDIJ@UU6FQcWBUY6FDYJ
AUU:FTIIBUY6FDYJ008Li`=:F@05BUY:FDYIBUU:FP03BUT054YJ7>LLidYHCUT004iIBUQ>FDYICUU:
F4iIBUU>FDYHCUU:FDiIBUP27>L01TiiCUQBNDiHCWT001=oo`03001oogoo02Moo`005Goo00<007oo
Ool02Woo00<007ooOol0GGoo0W`000HLig`0?U]2FciJ7>L6@UX00acWAUY6FP05AUX011cWAUU6FDYJ
0dII00A:FTIIAUTLi`e:F@0B7>M>FDYICUU:F@00BUU>FDYICUU:FDiIBUU>FDYICUU:FDiI0QcW00E>
F4iICUU>FDiH00=>F@03001oogoo015oo`03001oogoo02Ioo`005Goo00<007ooOol02goo00<007oo
Ool0H7oo0W`000=2FacW@U/00d9J01E2FacWAUY2FDIJ@UU6FT9IAUXLidYJAUU:FTIIBUY6FDYJAUU:
FQcWBUX00dYI00E:FTYIBUU:FDYJ00=:F@8Li`0@CUU:F4iIBUU>F@00CUU:FDiIBUQ>FDYICUU:F4iI
BUT27>L0359iCUQ>NDiHDWU>F4iiCUQBNDiHCWT0019oo`03001oogoo02Ioo`005Goo00<007ooOol0
37oo00<007ooOol0HGoo0g`0149J00<LidIJAUX01DIJ00<LidIIBUX00dII00A:FTIIAUTLi`a:F@0A
7>M:FDiIBUU>FDYICUU:FDiI001>FDYICUU:FDiIBUU>F@027>L2CUT01DiHCUU>FDiICUP00diI00A>
F4iICUT001=oo`03001oogoo02Eoo`005Goo00<007ooOol03Goo00<007ooOol0Hgoo0W`001A2FQcW
@UU6FT9IAUY2FDIJ@UTLidIIBUY6FDYJAUU:FTIIBUXLidYJ0dYI00E:FTYIBUU:FDYJ009:F@8Li`0?
BUU>FDYHCUU:FDiIBUQ>FDYI001:F4iIBUU>FDYH008Li`0ACWU>F59iCUQ>NDiHDWU>F4iiCUQBNDiH
CWU>F59iCUP0000COol00`00Oomoo`0TOol001Eoo`03001oogoo00ioo`03001oogoo06Aoo`9l00I6
FP037>M6FDYJ00=6F@04BUY6FDII7>L;BUT041cWCUU:FDiIBUU>FDYICUU:FDiIBUU>F@00CUU:FDiI
0QcW00E>F4iICUU>FDiH00=>F@05CUQ>FDiICUU>F003CUT014iHCUU>F@004Woo00<007ooOol097oo
000EOol00`00Oomoo`0?Ool00`00Oomoo`1UOol2O0002d9IAUY2FAcWAUU:FTIIBUY6FDYJAUT00QcW
00E:FTYIBUU:FDYJ00=:F@0BBUY:FAcW7>M>FDYICUU:F4iIBUU>FDYHCUU:FDiIBUP004YI0QcW01AB
NDiHCWU>F59iCUQ>NDiHDWU>F4iiCUQBNDiHCWU>F59iCUQ>NDiH0QcW00<007ooOol047oo00<007oo
Ool08goo000DOol00`00Oomoo`0AOol00`00Oomoo`1VOol2O0000dIJ7>M:FP03AUT00dYJAUTLi`0;
BUT04AcWBUU>FDYICUU:FDiIBUU>FDYICUU:FDiIBUU>F@007>L00TiI00E>F4iICUU>FDiH00=>F@05
CUQ>FDiICUU>F003CUT024iHCUTLiacWCWQBNE9h000BOol00`00Oomoo`0ROol001Aoo`03001oogoo
019oo`03001oogoo06Moo`0:O01:FTIIBUY6FDYJAUTLidYIBUX3BUT01DYJBUU:FDYIBUX00QcW029:
F4iIBUU>FDYHCUU:FDiIBUQ>FDYICUU:F4iI7>L004iHDWU>F4iiCUQBNDiHCWU>F59iCUQ>NDiHDWU>
F4iiCUQBN@<Li`06DWU>F59iCUQBN@004Woo00<007ooOol08Woo000DOol00`00Oomoo`0COol00`00
Oomoo`1WOol01W`0AUU6FDYJAUTLi`Y:F@0?7>M>FDYICUU:FDiIBUU>FDYICUU:FDiIBUU>FDYI008L
i`04CUT004iICUP3CUT01DiHCUU>FDiICUP00diI00=>F4iICUT00QcW00YBNE9hDWU>N59iDWQBNDih
DWT0019oo`03001oogoo025oo`0057oo00<007ooOol057oo00<007ooOol0Igoo0W`000A6FAcWBUU:
FP=:F@04BUY:FDYIBUT27>L03DiIBUQ>FDYICUU:F4iIBUU>FDYHCUU:FDiI008Li`0ACUQ>NDiH001>
F4iiCUQBNDiHCWU>F59iCUQ>NDiHDWU>F0037>L03DiHDWU>F59iCUQBNDiHDWU>F59iCUQBN@00015o
o`03001oogoo025oo`0057oo00<007ooOol05Goo00<007ooOol0J7oo00=l04YIBUT01dYI00hLidYI
CUU:FDiIBUU>FDYICUU:FDiIBUU>FDYI0QcW00=>FDiHCUT00TiI00D004iICUU>FDiH00=>F@04CUQ>
FDiICUT27>L0459hDWU>N59iDWQBNDihDWUBN59iCWQBNE9hDWU>N0004Woo00<007ooOol087oo000D
Ool00`00Oomoo`0FOol00`00Oomoo`1XOol01G`0BUU:FDYIBUX00TYI0QcW00a:FDiIBUQ>FDYICUU:
F4iIBUU>FDYHCUT27>L044iHDWU>F4iiCUQBNDiH001>F59iCUQ>NDiHDWU>F4ii0acW01=BNDiHDWU>
F59iCUQBNDiHDWU>F59iCUQBNDiHDWU>F59iCUP0000BOol00`00Oomoo`0OOol001=oo`03001oogoo
01Moo`03001oogoo06Uoo`9l00=:F@0=7>M>FDYICUU:FDiIBUU>FDYICUU:FDiIBUT00QcW0diI00U>
F4iICUU>FDiHCUT004iICUP00diI01Y>F1cW7>MBNDihDWUBN59iCWQBNE9hDWU>N59iDWQBNDihDWUB
N59iCWQBNE9hDWU>N0004Goo00<007ooOol07goo000COol00`00Oomoo`0HOol00`00Oomoo`1ZOol0
3W`0BUTLidiIBUU>FDYHCUU:FDiIBUQ>FDYICUT27>L03diHCWU>F59iCUQ>NDiHDWU>F4iiCUP004iH
CWU>F0037>L06DiHDWU>F59iCUQBNDiHDWU>F59iCUQBNDiHDWU>F59iCUQBNDiHDWU>F59iCUQBN@00
019oo`03001oogoo01ioo`004goo00<007ooOol06Goo00<007ooOol0JWoo00]l04iIBUU>FDYICUU:
FDiIBUU>FDYI008Li`03CUU>F4iI009>F@05CUQ>FDiICUU>F003CUT07@007>LLiacWCWQBNE9hDWU>
N59iDWQBNDihDWUBN59iCWQBNE9hDWU>N59iDWQBNDihDWUBN59iCWP00acW00<007ooOol047oo00<0
07ooOol07Goo000COol00`00Oomoo`0JOol00`00Oomoo`1ZOol027`0CUU:F4iIBUU>FDYHCUT27>L0
:4iHDWU>F4iiCUQBNDiHCWU>F59iCUQ>NDiHDWTLi`00CUQBNDiHDWU>F59iCUQBNDiHDWU>F59iCUQB
NDiHDWU>F59iCUQBNDiHDWU>F59i11cW00A>F5IiDWP0019oo`03001oogoo01eoo`004goo00<007oo
Ool06goo00<007ooOol0JWoo00El04iIBUU>FDYI008Li`=>F@05CUQ>FDiICUU>F003CUT00diHCUTL
i`027>L05U9i001BNDihDWUBN59iCWQBNE9hDWU>N59iDWQBNDihDWUBN59iCWQBNE9h11cW00EBNE9h
DWQBN59i00=BN003001oogoo011oo`03001oogoo01aoo`004goo00<007ooOol077oo00<007ooOol0
JWoo015l04iIBUPLidiHCWU>F59iCUQ>NDiHDWU>F4iiCUQBNDiH008Li`0FDWU>F59iCUP004iHDWU>
F59iCUQBNDiHDWU>F59iCUQBNDiHDWU>F59iCUP37>L03DiHDWUBN5IiDWQBNE9hEWUBN59iDWQFN@00
019oo`03001oogoo01aoo`004Woo00<007ooOol07Woo00<007ooOol0JWoo00=l01cWCUP00diI00E>
F4iICUU>FDiH009>F@<Li`0DDWQBNDihDWUBN59i001BNE9hDWU>N59iDWQBNDihDWUBN59iCWQBN@@L
i`03DWQBNE9h009BN005DWUBN59hDWQBN@03DWP00e9iDWP0000COol00`00Oomoo`0KOol0019oo`03
001oogoo01moo`03001oogoo06Yoo`0:O01>NDiHDWU>F4iiCUQBNDiHCWT27>L04diHDWU>F59iCUQB
NDiHDWU>F000CUQBNDiHDWU>F59iCUQBNDiH00@Li`0EDWUBN59iDWQFNE9hDWUBN5IiDWQBNE9hEWUB
N59iDWQFNE9hDWUBN00001=oo`03001oogoo01Yoo`004Woo00<007ooOol087oo00<007ooOol0JWoo
00=l04iICUP00diI0acW019BNDihDWUBN59iCWQBNE9hDWU>N59iDWP004ihDWUBN59iCWP37>L014ih
DWQBN59i0e9h00EBNE9hDWQBN59i00=BN005DWUBN59hDWQBN@03DWP00e9i001oo`0BOol00`00Oomo
o`0JOol0019oo`03001oogoo025oo`03001oogoo06Uoo`04O01>F4iiCUP27>L04E9iCUQBNDiHDWU>
F59iCUQBNDiHDWU>F59iCUQBN@00DWT011cW01aBN5IiDWQBNE9hEWUBN59iDWQFNE9hDWUBN5IiDWQB
NE9hEWUBN59iDWQFNE9hDWUBN5IiDWP001Aoo`03001oogoo01Uoo`004Woo00<007ooOol08Woo00<0
07ooOol0JGoo019l01cW7>M>N59iDWQBNDihDWUBN59iCWQBNE9hDWU>N59iDWP27>L00`007>MBN@03
DWP01E9iDWQBN59hDWT00e9h00EBNE9hDWQBN59i00=BN005DWUBN59hDWQBN@03DWP01E9iDWQBN59h
000057oo00<007ooOol067oo000BOol00`00Oomoo`0SOol00`00Oomoo`1YOol03W`0CUQBNDiHDWU>
F59iCUQBNDiHDWU>F59iCUP37>L08DiHDWT005IiDWQBNE9hEWUBN59iDWQFNE9hDWUBN5IiDWQBNE9h
EWUBN59iDWQFNE9hDWUBN5IiDWQBNE9hEWUBN0037>L00`00Oomoo`0BOol00`00Oomoo`0HOol0019o
o`03001oogoo02Aoo`03001oogoo06Qoo`0:O01BNE9hDWU>N59iDWQBNDihDWT47>L00e9hDWUBN002
DWP01@00DWQBN59hDWT00e9h00EBNE9hDWQBN59i00=BN005DWUBN59hDWQBN@03DWP00e9i7>LLi`04
7>L2EWP00e9h001oo`0DOol00`00Oomoo`0GOol0015oo`03001oogoo02Ioo`03001oogoo06Qoo`05
O01BNDiHDWU>F0047>L0759iDWQBNE9hEWUBN59iDWQFN@00DWUBN5IiDWQBNE9hEWUBN59iDWQFNE9h
DWUBN5IiDWQBNE9h1QcW00YFNE9hEWUBN5IiDWQFNE9hEWT001Eoo`03001oogoo01Moo`004Goo00<0
07ooOol09goo00<007ooOol0Igoo00=l04ihDWT00QcW00A>N59hDWQBN@=BN009DWUBN59hDWQBNE9h
001BN59i00=BN005DWUBN59hDWQBN@02DWP67>L01E9hEWQFN5IhDWP00eIh00EBN5IhEWQFN59h00=F
N003001oogoo01=oo`03001oogoo01Ioo`004Goo00<007ooOol0:7oo00<007ooOol0Igoo01Ql01cW
EWUBN59iDWQFNE9hDWUBN5IiDWQBNE9hEWUBN59i001FNE9hDWUBN5IiDWP67>L05eIiDWQFNE9hEWUB
N5IiDWQFNE9hEWUBN5IiDWQFNE9hEWUBN5IiDWQFNE9h00005Woo00<007ooOol05Goo000AOol00`00
Oomoo`0YOol00`00Oomoo`1WOol01G`0DWQBN59hDWT00e9h00EBNE9hDWQBN59i00=BN003000LiacW
00@Li`9FN005DWQFN5IhEWQBN003EWP01E9hEWQFN5IhDWP00eIh00EBN5IhEWQFN59h00=FN003DWQF
N00001Ioo`03001oogoo01Eoo`004Goo00<007ooOol0:Woo00<007ooOol0Igoo00Yl059hEWUBN59i
DWQFNE9hDWUBN0DLi`0T001FNE9hEWUBN5IiDWQFNE9hEWUBN5IiDWQFNE9hEWUBN5IiDWQFNE9hEWUB
N5IiDWQFNE9hEWUBN5IiDWQFNE9hEWUBN0005goo00<007ooOol057oo000AOol00`00Oomoo`0[Ool0
0`00Oomoo`1VOol017`0DWUBN59h1QcW00IBN5IhEWQFN59h0002EWP01E9hEWQFN5IhDWP00eIh00EB
N5IhEWQFN59h00=FN005DWQFN5IhEWQBN003EWP01E9hEWQFN5IhDWP00eIh00=BN000Ool05Woo00<0
07ooOol04goo000@Ool00`00Oomoo`0]Ool00`00Oomoo`1VOol0<g`07>LLieIiDWQFNE9hEWUBN5Ii
DWQFNE9hEWT005IiDWQFNE9hEWUBN5IiDWQFNE9hEWUBN5IiDWQFNE9hEWUBN5IiDWQFNE9hEWUBN5Ii
DWQFNE9hEWUBN5IiDWQFNE9hEWT0000GOol00`00Oomoo`0COol0011oo`03001oogoo02ioo`03001o
ogoo06Eoo`04O01FN5IhDWP3EWP01E9hEWQFN5IhDWP00UIh00<0059hEWP00UIh00EBN5IhEWQFN59h
00=FN005DWQFN5IhEWQBN003EWP01E9hEWQFN5IhDWP00eIh00=BN5Ih7>L011cW00<007ooOol05Woo
00<007ooOol04Woo000@Ool00`00Oomoo`0_Ool00`00Oomoo`1UOol087`0DWQFNE9hEWUBN5IiDWQF
NE9hEWUBN5Ii001FNE9hEWUBN5IiDWQFNE9hEWUBN5IiDWQFNE9hEWUBN5IiDWP<7>L01UJIEWQFVEIh
EYT001Qoo`03001oogoo019oo`0047oo00<007ooOol0<7oo00<007ooOol0I7oo00El05IhEWQFN59h
00=FN006DWQFN5IhEWQBN0000UIh00ABN5IhEWQFN0`Lia5FV003001oogoo01Ioo`8001=oo`0047oo
00<007ooOol0<Goo00<007ooOol0I7oo00Ml05IiDWQFNE9hEWUBN0057>L00`007>LLi`047>L07UJI
EWQFVEIhEYUFN5JIEWQFVEIhEYUFN5JIEWQFVEIhEYUFN5JIEWQFVEIhEYUFN5JIEWQFVEIhEYT001Eo
o`<00003Ool007oo019oo`0047oo00<007ooOol0<Woo00<007ooOol0Hgoo00=l01cW7>L011cW1EJH
00<005JHEYP08EJH00<007ooOol047oo0`0017oo00<007ooOol04Goo000@Ool00`00Oomoo`0cOol0
0`00Oomoo`1ROol0<W`0EYUFN5JIEWQFVEIhEYUFN5JIEWQFVEIh001FN5JIEWQFVEIhEYUFN5JIEWQF
VEIhEYUFN5JIEWQFVEIhEYUFN5JIEWQFVEIhEYUFN5JIEWQFVEIhEYUFN5JIEWQFVEIh000>Ool30007
Ool00`00Oomoo`0AOol000moo`03001oogoo03Eoo`03001oogoo065oo`03O01FV5JH00YFV003001F
V5JH025FV003001oogoo00Uoo`<000]oo`03001oogoo011oo`003goo00<007ooOol0=Woo00<007oo
Ool0HGoo035l05IhEYUFN5JIEWQFVEIhEYUFN5JIEWP005IhEYUFN5JIEWQFVEIhEYUFN5JIEWQFVEIh
EYUFN5JIEWQFVEIhEYUFN5JIEWQFVEIhEYUFN5JIEWQFVEIhEYUFN5JIEWP00008Ool3000>Ool00`00
Oomoo`0@Ool000moo`03001oogoo03Moo`03001oogoo061oo`03O01FV5JH00UFV003001FV5JH025F
V003001oogoo00=oo`<0015oo`03001oogoo011oo`003goo00<007ooOol0>7oo00<007ooOol0Ggoo
039l05IhEYUFN5JIEWQFVEIhEYUFN5JIEWP005IhEYUFN5JIEWQFVEIhEYUFN5JIEWQFVEIhEYUFN5JI
EWQFVEIhEYUFN5JIEWQFVEIhEYUFN5JIEWQFVEIhEYUFN5JIEWP007oo100057oo00<007ooOol047oo
000?Ool00`00Oomoo`0iOol00`00Oomoo`1NOol00g`07>LLi`097>L00`007>LLi`0Q7>L2000HOol0
0`00Oomoo`0@Ool000moo`03001oogoo03Yoo`03001oogoo05eoo`0aO01FV5ZIEYQJVEJHFYUFV5ZI
EYQJVEJH001FV5ZIEYQJVEJHFYUFV5ZIEYQJVEJHFYUFV5ZIEYQJVEJHFYUFV5ZIEYQJVEJHFYUFV5ZI
EYQJVEJHFYUFV5ZIEYQJVEJH00006Goo00<007ooOol047oo000>Ool00`00Oomoo`0lOol00`00Oomo
o`1LOol0<G`0FYQFV5ZHEYQJV5JHFYQFV5ZHEYQJV000FYQFV5ZHEYQJV5JHFYQFV5ZHEYQJV5JHFYQF
V5ZHEYQJV5JHFYQFV5ZHEYQJV5JHFYQFV5ZHEYQJV5JHFYQFV5ZHEYQJV00001Uoo`03001oogoo011o
o`003Woo00<007ooOol0?Goo00<007ooOol0G7oo031l05ZIEYQJVEJHFYUFV5ZIEYQJVEJH001FV5ZI
EYQJVEJHFYUFV5ZIEYQJVEJHFYUFV5ZIEYQJVEJHFYUFV5ZIEYQJVEJHFYUFV5ZIEYQJVEJHFYUFV5ZI
EYQJVEJH000IOol00`00Oomoo`0@Ool000ioo`03001oogoo03ioo`03001oogoo05]oo`0`O01FV5ZH
EYQJV5JHFYQFV5ZHEYQJV000FYQFV5ZHEYQJV5JHFYQFV5ZHEYQJV5JHFYQFV5ZHEYQJV5JHFYQFV5ZH
EYQJV5JHFYQFV5ZHEYQJV5JHFYQFV5ZHEYQJV0006Woo00<007ooOol03goo000>Ool00`00Oomoo`0o
Ool00`00Oomoo`1JOol00g`07>LLi`037>L0:EJHFYUFV5ZIEYP005JHFYUFV5ZIEYQJVEJHFYUFV5ZI
EYQJVEJHFYUFV5ZIEYQJVEJHFYUFV5ZIEYQJVEJHFYUFV5ZIEYQJVEJHFYUFV5ZI00006goo00<007oo
Ool03goo000>Ool00`00Oomoo`10Ool00`00Oomoo`1IOol00g`0FYQJV003FYP57>L00`007>LLi`04
7>L07EZHEYQJV5JHFYQFV5ZHEYQJV5JHFYQFV5ZHEYQJV5JHFYQFV5ZHEYQJV5JHFYQFV5ZHEYQJV5JH
00006goo00<007ooOol03goo000>Ool00`00Oomoo`11Ool00`00Oomoo`1HOol04W`0F[UJV5ZiFYQJ
^EZHF[UJV5ZiFYP005ZHF[UJV5ZiFYQJ^@/Li`0BFYUFV5ZIEYQJVEJHFYUFV5ZIEYQJVEJHFYUFV5ZI
EYQJV@006goo00<007ooOol03goo000>Ool00`00Oomoo`12Ool00`00Oomoo`1GOol00g`0FYQJV008
FYP00`00FYQJV00?FYP<7>L01UJHFYQFV5ZHEYP001]oo`03001oogoo00moo`003Goo00<007ooOol0
A7oo00<007ooOol0EWoo02Ul05ZiFYQJ^EZHF[UJV5ZiFYQJ^EZH001JV5ZiFYQJ^EZHF[UJV5ZiFYQJ
^EZHF[UJV5ZiFYQJ^EZHF[UJV5ZiFYQJ^EZHF[UJV5ZiFYQJ^EZH00DLi`03001oogoo01Uoo`03001o
ogoo00moo`003Goo00<007ooOol0AGoo00<007ooOol0EGoo00Al01cW7>LLi`MJV003001JV5ZH021J
V003001oogoo01Uoo`03001oogoo00moo`003Goo00<007ooOol0AWoo00<007ooOol0E7oo00Al05ji
F[QJ^@DLi`0UF[UJV000FYQJ^EZHF[UJV5ZiFYQJ^EZHF[UJV5ZiFYQJ^EZHF[UJV5ZiFYQJ^EZHF[UJ
V5ZiFYQJ^EZHF[UJV5ZiFYQJ^EZH00007Goo00<007ooOol03Woo000=Ool00`00Oomoo`17Ool00`00
Oomoo`1COol01G`0F[QJ^5ZhG[T00eZh00EN^AcW7>LLi`00008LiaiJV003001oogoo01]oo`03001o
ogoo00ioo`003Goo00<007ooOol0B7oo00<007ooOol0DGoo011l05ZhG[UJ^5jiF[QN^EZhG[UJ^5ji
F[QN^@00G[UJV0DLi`0JFYQJ^EZHF[UJV5ZiFYQJ^EZHF[UJV5ZiFYQJ^EZHF[UJV5ZiFYQJ^EZHF[UJ
V5ZiFYP001eoo`03001oogoo00ioo`003Goo00<007ooOol0B7oo00<007ooOol0DGoo00Al05ZhF[QN
^@=J^009G[UJ^5ZhF[QN^EZh001J^5ji00=J^003G[UJV1cW00@Lia=JV003001oogoo01aoo`03001o
ogoo00ioo`0037oo00<007ooOol0BWoo00<007ooOol0D7oo01Yl01cW7>LLiejiF[QN^EZhG[UJ^5ji
F[QN^@00G[UJ^5jiF[QN^EZhG[UJ^5jiF[QN^EZh1AcW00mJV5ZiFYQJ^EZHF[UJV5ZiFYQJ^EZHF[UJ
V5Zi00007Woo00<007ooOol03Woo000<Ool00`00Oomoo`1;Ool00`00Oomoo`1=Ool2000017`0G[UJ
^5Zh11cW00=J^5jiF[P00UZh00D005ZhF[QJ^5ji00=J^005G[UJ^5ZhF[QN^@03F[P00ejiF[PLi`05
7>L8FYP00`00Oomoo`0LOol00`00Oomoo`0>Ool000aoo`03001oogoo04aoo`03001oogoo04Uoo`<0
009oo`08O01N^5kIF[QNfEjhG[UJ^0<Li`0JF[QN^@00G[UJ^5jiF[QN^EZhG[UJ^5jiF[QN^EZhG[UJ
^5jiF[QN^EZhG[UJ^5jiF[QJ^@DLi`03F[UJV00001moo`03001oogoo00ioo`0037oo00<007ooOol0
CGoo00<007ooOol0AGoo0`0017oo00al05jhG[UN^5jiG[QN^EjhG[UN^5jiF[P27>L00`00F[QN^@03
F[P01EjiF[QJ^5ZhG[T00eZh00EN^EZhF[QJ^5ji00=J^005G[UJ^5ZhF[QN^@02F[P27>L00`00Oomo
o`0NOol00`00Oomoo`0=Ool000aoo`03001oogoo04ioo`03001oogoo045oo`<000Moo`0?O01NfEZh
G]UN^5kIF[QNfEjhG]UJ^5kIG[QNf@0000@Li`0JG[UJ^5jiF[QN^EZhG[UJ^5jiF[QN^EZhG[UJ^5ji
F[QN^EZhG[UJ^5jiF[QN^EZhG[T0025oo`03001oogoo00eoo`0037oo00<007ooOol0Cgoo00<007oo
Ool0?Goo0`002Woo01=l05jhG[UN^5jiG[QN^EjhG[UN^5jiG[QN^Ejh001N^5jiG[QN^@037>L01Eji
F[QJ^5ZhG[T00eZh00EN^EZhF[QJ^5ji00=J^007G[UJ^5ZhF[QN^EZh00008Goo00<007ooOol03Goo
000;Ool00`00Oomoo`1AOol00`00Oomoo`0iOol3000=Ool05W`07>LLiacWF[QNfEjhG]UJ^5kIG[QN
fEZhG]T005kIF[QNfEjhG]UJ^5kI0acW01=N^EZhG[UJ^5jiF[QN^EZhG[UJ^5jiF[QN^EZhG[UJ^5ji
F[P0000ROol00`00Oomoo`0=Ool000]oo`03001oogoo059oo`03001oogoo03Eoo`<000moo`03O01R
fEkH009Nf@8Li`0CG[UN^5jiG[QN^EjhG[UN^000G[QN^EjhG[UN^5jiG[QN^EjhG[T011cW0eZh00EN
^EZhF[QJ^5ji00=J^004G[UJ^5Zh000ROol00`00Oomoo`0=Ool000]oo`03001oogoo05=oo`03001o
ogoo035oo`<0019oo`07O01Nf6;IG]QRfEkHH]T00acW01ANfEZhG]UN^5kI001NfEjhG]UJ^5kIG[QN
fEZhG]UN^5kIF[QNfEjh0acW00]J^5jiF[QN^EZhG[UJ^5jiF[QN^@0002=oo`03001oogoo00eoo`00
2goo00<007ooOol0E7oo00<007ooOol0;Goo0`0057oo00Il05kHG]UNfF;IG]P2G]T00f;IG]QNf@02
7>L05EjhG[UN^000G[QN^EjhG[UN^5jiG[QN^EjhG[UN^5jiG[QN^EjhG[UN^0037>L3F[P01EjiF[QJ
^5Zh00008goo00<007ooOol03Goo000;Ool00`00Oomoo`1EOol00`00Oomoo`0YOol3000GOol03G`0
H]UNf6;IG]QRfEkHH]UNf6;IG]QRfEkH00<Li`0E001NfEZhG]UN^5kIF[QNfEjhG]UJ^5kIG[QNfEZh
G]UN^5kIF[QNfEjh00@Li`03G[UJ^00002Aoo`03001oogoo00eoo`002goo00<007ooOol0EWoo00<0
07ooOol09Goo0`006Goo00El06;i7>LLiekH009Nf@06H]UNf5kIG]URfEkH0UkI01]RfEkH000Lieji
G[QN^EjhG[UN^5jiG[QN^EjhG[UN^5jiG[QN^EjhG[UN^5jiG[QN^EjhG[T00QcW00<007ooOol08goo
00<007ooOol037oo000;Ool00`00Oomoo`1GOol00`00Oomoo`0QOol3000KOol01G`0H_UNf6;iG]T0
0QcW00eRfEkHH]UNf6;IG]QRfEkHH]UNf6;I001Rf@027>L05eZhG]UN^5kIF[QNfEjhG]UJ^5kIG[QN
fEZhG]UN^5kIF[QNfEjhG]UJ^5kI00009Woo00<007ooOol037oo000:Ool00`00Oomoo`1IOol00`00
Oomoo`0MOol3000NOol01g`0H]URnF;IH_URfF;i008Li`03G]URfEkH009Nf@06H]UNf5kIG]T005kH
0UkI0acW01AN^5jiG[QN^EjhG[UN^5jiG[QN^EjhG[UN^5jiG[QN^EjhG[UN^0009Woo00<007ooOol0
37oo000:Ool00`00Oomoo`1JOol00`00Oomoo`0HOol4000POol02W`0G]QRnEkIH_UNf6;iG]URnEkH
0QcW00iRfEkHH]UNf6;IG]QRfEkH001Nf6;IG]QRfEkH0QcW015NfEZhG]UN^5kIF[QNfEjhG]UJ^5kI
G[QNfEZhG]UN^00002Moo`03001oogoo00aoo`002Woo00<007ooOol0Fgoo00<007ooOol057oo0`00
8goo00el06;i7>LLif;iH]URnF;IH_URfF;iH]URn@027>L02EkHG]UNfF;IG]QNf@00H]UNf002G]T0
0f;IG]QNf@037>L03EjiG[QN^EjhG[UN^5jiG[QN^EjhG[UN^00002Qoo`03001oogoo00aoo`002Woo
00<007ooOol0G7oo00<007ooOol047oo0`009Woo00ml06KjH_URnAcWH_UNfF;iG]QRnEkIH_UNf6;i
G]T00QcW00mRfEkHH]UNf000G]QRfEkHH]UNf6;IG]QRfEkHH]T00QcW00]N^5kIF[QNfEjhG]UJ^5kI
G[QNf@0002Qoo`03001oogoo00aoo`002Woo00<007ooOol0GGoo00<007ooOol037oo0`00:7oo00=l
06;iH_T00f;i0QcW00QRfF;iH]URnF;IH_URfF;i0V;I0QcW00=NfF;I00000UkI00IRfEkHG]UNfF;I
G]P2G]T00f;IG]PLi`027>L01ejhG[UN^5jiG[QN^@0002Uoo`03001oogoo00aoo`002Woo00<007oo
Ool0GWoo00<007ooOol027oo0`00:goo00El06;iH_URnFKj009Rn@0OG]PLiekIH_UNf6;iG]URnEkH
H_UNfF;iG]PLiekH001Nf6;IG]QRfEkHH]UNf6;IG]QRfEkHH]UNf6;IG]P00QcW00ENfEjhG]UJ^000
02Yoo`03001oogoo00]oo`002Goo00<007ooOol0H7oo00<007ooOol017oo0`00;Goo00=l06;iH_T0
1f;i010Lif;IH_URfF;iH]URnF;IH_URfF;iH]TLi`00H]UNf09Nf@06H]UNf5kIG]URfEkH0UkI00ER
fEkHG]UNfF;I00<Li`03001oogoo02Uoo`03001oogoo00]oo`002Goo00<007ooOol0HGoo00<007oo
Ool00`00;goo00El06<I7>MRnFKj00=Rn@04I_YRnF;iH_T27>L02f;iG]QRnEkIH_UNf6;iG]URnEkH
00000QcW019Nf6;IG]QRfEkHH]UNf6;IG]QRfEkHH]UNf6;IG]QRfEkH000/Ool00`00Oomoo`0;Ool0
00Uoo`03001oogoo069oo`80035oo`05O01S6FLJHaTLi`0:H_T03AcWH_URfF;iH]URnF;IH_URfF;i
001RnF;I008Li`9Nf@06H]UNf5kIG]URfEkH0UkI00ERfEkHG]UNf@0002eoo`03001oogoo00]oo`00
2Goo00<007ooOol0Fgoo6@008Goo00Ql06LJHaUW6V<I7>MRnFKj0f;i00eVnV;iH_URnFKj7>MRnEkH
H_UNfF;iG]QRn@02000015kHH_UNfF;I0QcW00aNf6;IG]QRfEkHH]UNf6;IG]QRfEkH000^Ool00`00
Oomoo`0;Ool000Uoo`03001oogoo05=oo`P0000E7SdJ?AXm6SdN?AXm7>LR?BHm8SdV?B8m9SdR?BHm
8SdV?B8m7>LZ?2Xm00<Z?003:Sd0000000P001Ioo`08O01W6V<IIaYS6FLJHaTLi`YRn@8Li`03H]UR
n@0000800008H_URf@00H]URnF;IH_UNf08Li`06H]UNf5kIG]URfEkH0UkI00<007ooOol0;Goo00<0
07ooOol02goo0009Ool00`00Oomoo`1=Ool60000:a8l5SdLiahm6SdN?AXl7SdJ?Ahm6S`N?AXm7SdR
?1cW8S`V?B8l9SdR?2Hm8S`V?B8l9SdLibhm:S`^?BXl;SdZ?2hm:S`^?BXl;SdZ?1cW<S`bG2hk00L0
00ioo`0<O00Lif<IIaYS6FLJHaUW6V<I7>MRnFKj0f;i00AVnV;iH_URn@@0000=H_UNfF;iG]QRnEkI
001Nf6;iG]URnEkHH]T00QcW00MNf6;IG]QRfEkHH]T0000_Ool00`00Oomoo`0;Ool000Uoo`03001o
ogoo04Qoo`D000TB?@047>LJ?AXm7Sd36Sd04Qhm6SdJ?AXm7SdLibHm8SdV?B8m9SdR?BHm8SdV?B8m
9SdLi`8Z?005:SdZ?2Xl:S`Z?@03:S`00bXm7>Lb?009<S`50008Ool037`0IcYW>QcWHaUW6V<IIaYS
6FLJHaTLi`ERn@<000=Rn@0@7>MRfF;iH]URnF;IH_T006;iH]URnF;IH_URfF;iG]T27>L2G]T00f;I
001oo`0_Ool00`00Oomoo`0;Ool000Qoo`03001oogoo04Eoo`@000122S`:70Xl7>LF?A8l5SdB?1Hm
4S`F?A8l5SdB?1Hm7>LN?AXm7SdJ?1hm6SdN?AXl7SdJ?BHm7>LV?B8l9SdR?2Hm8S`V?B8l9SdR?1cW
:S`^?BXl;SdZ?2hm:S`^?BXl;SdZ?1cW;S/bG38l<U`^>c9L<S`bG2hk<U`b?39L;S/LicHk10000goo
00ml06LjHcUW>QcWIaYS6FLJHaUW6V<IIaYS6AcWH_T00`0000=RnFKjH_T00V;i01IVnV;i7>LLif;i
G]URnEkHH_T006;iG]QRnEkIH_UNf6;iG]URfAcWH]T0039oo`03001oogoo00Yoo`0027oo00<007oo
Ool0@Goo100020Xl00<Lia8m4Sd02A8m00@LiaXm6SdN?@<J?@0A7SdJ?AXm6SdLib8m9SdR?BHm8SdV
?B8m9SdR?BHm7>LZ?@03:S`01BXm:S`Z?2Xl:Sd00RXl00<Lic8l<S`02c8l00HLicIK=S/fG3Hk=U/3
0005IcX01acWIaYS6FLJHaUW6V<I00<000aRn@0A7>MRnF;IH_URfF;i001RnF;IH_URfF;iH]URnF;I
H_T0000cOol00`00Oomoo`0:Ool000Qoo`03001oogoo03moo`8000866`8Li`092S`:70Xl2Q`:?0XL
2S`:70Xl008Li`124S`F?A8l5SdB?1Hm4S`F?A8l5SdLiahm6SdN?AXl7SdJ?Ahm6S`N?AXm7>LR?2Hm
8S`V?B8l9SdR?2Hm8S`V?AcW;SdZ?2hm:S`^?BXl;SdZ?2hm:S`Lic8l<U`^>c9L<S`bG2hk<U`b?39L
;S/bG1cW=U`f>cYL=S/fG3Hk>U`f>cIL100000ES>FLj7>MW6V<I00<00006HaUW6V<I7>MRnFKj0f;i
00EVnV;iH_URnFKj009Rn@0?7>MRnEkIH_UNf6;i001RnEkHH_UNfF;iG]QRn@0003Aoo`03001oogoo
00Yoo`0027oo00<007ooOol0?Goo0P001PHK0QcW2@Xl00<Lia8m4Sd0218m00@LiaXm6SdN?@<J?@0A
7SdJ?AXm8SdLib8m9SdR?BHm8SdV?B8m9SdR?AcW:S`Z?@03:S`01RXm:S`Z?2Xl:SdLi``b?00>7>Lf
>cIL=S/fFcHk=U`f>cIK=S/fG3Hk=U/f>`D00008HaUW6V<IIaYS6FLJHaTLi`aRn@8Li`0;H]URnF;I
H_T006;iH]URnF;IH_T0000eOol00`00Oomoo`0:Ool000Qoo`03001oogoo03]oo`8000X66`8Li`1;
2S`:70Xl2Q`:?0XL2S`:71cW4S`F?A8l5SdB?1Hm4S`F?A8l5SdLiahm6SdN?AXl7SdJ?Ahm6S`N?AcW
9SdR?2Hm8S`V?B8l9SdR?2Hm7>L^?BXl;SdZ?2hm:S`^?BXl;SdZ?1cW;S/bG38l<U`^>c9L<S`bG2hk
<U`b?39L7>LjG3Hk=U`f>cYL=S/fG3Hk>U`f>cIL00<00003?U/j>P0000<00006IaYS6FLJHaUW6V<I
0QcW00EVnV;iH_URnFKj00=Rn@0>I_YRnF;iG]PLiekIH_UNf6;i001RnEkHH_T003Ioo`03001oogoo
00Yoo`0027oo00<007ooOol0>Woo00<0008I7>L00QcW2@HK00<:?1cW7>L01`Xl0QcW2A8m00@LiaXm
6SdN?@<J?@0=7SdJ?AXm7>LV?B8m9SdR?BHm8SdV?B8m7>L00bXl00DZ?BXl:S`Z?2Xm008Z?0037>Lb
?38l00Xb?0097>Lf>cIK=S/fG3Hk=U/f>cIL00<00009=U`LicYK>S/nFcXk>U/j>ciK00<00006IaYS
6FLJHaURnAcW36;i00PLif;IH_URf@00H]URn@00=goo00<007ooOol02Woo0007Ool00`00Oomoo`0i
Ool200001@8I0QX26@8J0QT00QcW2@HK04@:71cW2Q`:?0XL2S`:70Xl2Q`:?1cW5SdB?1Hm4S`F?A8l
5SdB?1Hm7>LN?AXm7SdJ?1hm6SdN?AXl7>LR?2Hm8S`V?B8l9SdR?2Hm8S`LibXl;SdZ?2hm:S`^?BXl
;SdZ?1cW<S`bG2hk<U`b?39L;S/bG38l<U`^>acW=S/fG3Hk>U`f>cIL0`0000lfG3Hk>U`f>acW>SXn
FcXj?U/j>SiK>SXnFcXj?U/0100000AS6F;i7>MVnP=Rn@05I_YRnF;iH_UVnP03H_T27>L016;iG]P0
0000>7oo00<007ooOol02Woo0007Ool00`00Oomoo`0hOol02P000QX26@8J0QT26P8I0QX26@8J0QcW
2@HK0QcW1`Xl00<Lia8m4Sd01a8m00@LiaXm6SdN?@<J?@0=7SdJ?AcW8SdV?B8m9SdR?BHm8SdV?AcW
:Sd00bXl00HZ?BXl:S`Z?2Xm7>L;<S`011cW=U/f>cIL0`0001HfG3Hk=U/f>cIL=S/LicXk?U/j>cYK
>S/nFcXk>U/j>ciK>S/jFcXk?U/j>`<000037>MRnF;i00]Rn@047>MRn@00000iOol00`00Oomoo`09
Ool000Moo`03001oogoo03Moo`0=000LiacW0QX26@8J0QT26P8I0QX26@8J0QT00QcW20HK00T:?1cW
7>L:70Xl2Q`:?0XL2S`00QcW02lB?1Hm4S`F?A8l5SdB?1Hm7>LN?AXm7SdJ?1hm6SdN?B8l7>LR?2Hm
8S`V?B8l9SdR?1cW:S`^?BXl;SdZ?2hm:S`^?BXl7>L^>c9L<S`bG2hk<U`b?39L;S/bG38l00@0000L
=U`f>cYL=S/fG3Hk>U`f>cIL7>LnFcXj?U/j>SiK>SXnFcXj?U/j>SiK>SXnFcXj?U/Lid9K?UX20000
1FKjH_URnF;iI_X00f;i00IVnV;iH_URnFKj0002Ool00`00Oomoo`0fOol00`00Oomoo`09Ool000Mo
o`03001oogoo03Ioo`040002608H0QX37>L02@8J0QT26P8I0QX26@8J0QT26P037>L71Q/00`Xl7>LL
i`062S`00acW4SdB?@064Sd011cW6SdJ?Ahm0aXm00dN?AcW9SdR?BHm8SdV?B8m9SdR?AcW:S`Z?@03
:S`012Xm:S`Z?1cW238l0`0001hLicIL=S/fFcHk=U`f>cIK=S/fG3Hk=U/LiciK>S/jFcXk?U/j>cYK
>S/nFcXk>U/j>ciK>S/jFacW@U/3?UX00d9K00000009H_T20004Ool00`00Oomoo`0eOol00`00Oomo
o`09Ool000Moo`03001oogoo03Aoo`8000H2600=0QXLiacW7>L26P8I0QX26@8J0QT26P8I0QX00QcW
1`HK030:?1cW2S`:70Xl2Q`:?0XL7>LB?1Hm4S`F?A8l5SdB?1Hm7>LN?AXm7SdJ?1hm6SdN?AcW9SdR
?2Hm8S`V?B8l9SdLibhm:S`^?BXl;SdZ?2hm:S`Lic8l<U`^>c9L<S`300009c8l<U`LicYL=S/fG3Hk
>U`f>cIL=S/jG3Hk=U`f>acW>SXnFcXj?U/j>SiK>SXnFcXj?U/j>SiK>SXnFacW@U/nFT9K?UY2FciJ
@U/nFP0300000f;iI_YRn@02H_T00`00Oomoo`04Ool00`00Oomoo`0eOol00`00Oomoo`09Ool000Mo
o`03001oogoo03=oo`030002608H00X260<Li`080QX26@8J0QT26P8I0QX26@8Li`H66`032S`LiacW
00D:?08Li`HB?@057>LJ?AXm6SdN?@036Sd02AcW8SdV?B8m9SdR?BHm8SdLi`03:S`01RXm:S`Z?2Xl
:SdLi`8b?0<000Db?00M7>Lf>cIK=S/fG3Hk=U/f>cIL=S/fFcHk7>Lj>cYK>S/nFcXk>U/j>ciK>S/j
FcXk?U/j>cYK7>M2F`03?UX01D9K?UXnFSiJ@U/00ciJ0P0000=Rn@00000027oo00<007ooOol0=7oo
00<007ooOol02Goo0007Ool00`00Oomoo`0bOol00`000QHLi`037>L;0QP37>L01`8J0QT26P8I0QX2
6@8J008Li`H66`0W2Q`LiacW2S`:70Xl2Q`:?1cW5SdB?1Hm4S`F?A8l7>LJ?1hm6SdN?AXl7SdJ?AcW
8S`V?B8l9SdR?2Hm8S`LibXl;SdZ?2hm:S`^?BXl00<0000b<S`bG2hk<U`b?39L;S/bG1cW=U`f>cYL
=S/fG3Hk>U`f>cIL=S/jG1cW?U/j>SiK>SXnFcXj?U/j>SiK>SXnFcXj?U/j>QcW?UY2FciJ@U/nFT9K
?UY2FciJ@U/nFT9K?UY2F`8000Yoo`03001oogoo03=oo`03001oogoo00Uoo`001Woo00<007ooOol0
<goo00H0008G0QL25`8F0QL47>L:0QP37>L01P8J0QT26P8I0QX26@<Li`D66`032S`Li`Xl00@:?003
7>LB?A8m00@B?@057>LJ?AXm6SdN?@026Sd02QcW9SdR?BHm8SdV?B8m9SdLibXm0RXl100000<Z?1cW
<S`0238l01/LicHk=U`f>cIK=S/fG3Hk=U/f>cIL7>LjFcXk?U/j>cYK>S/nFcXk>U/j>ciK>S/jFcXk
7>L00ciJ00E2FciJ?UXnFT9K00<nFP06@U/nFSiJ?UXLid9J0P002Goo00<007ooOol0<Woo00<007oo
Ool02Goo0006Ool00`00Oomoo`0bOol02`000QL25P8G0QH25`8F0QL25P8G0QH011cW2@8H0acW00H2
6P8I0QX26@8J0QT27>L51Q/27>L010XL2S`:70Xl0QcW01@B?1Hm4S`F?A8l7>LJ?1hm6SdN?AXl7SdL
ibHm8S`V?B8l9SdR?1cW0`0003d^?BXl;SdZ?2hm7>LbG2hk<U`b?39L;S/bG38l7>Lf>cYL=S/fG3Hk
>U`f>cIL=S/jG3Hk7>Lj>SiK>SXnFcXj?U/j>SiK>SXnFcXj?U/j>QcW?UY2FciJ@U/nFT9K?UY2FciJ
@U/nFT9K?UY2FciJ7>M2FTIJ@UY6FP020008Ool00`00Oomoo`0aOol00`00Oomoo`09Ool000Ioo`03
001oogoo039oo`04000LiacW7>L30QL01@8F0QL25`8G0QH00`8G1AcW1`8H0acW00D26P8I0QX26@8J
008Li`@66`032S`LiacW00@:?0037>LB?A8m00<B?@057>LJ?AXm6SdN?@026Sd011cW9SdR?BHm0`00
00<LibXl:Sd00bXl00<Z?BXl7>L0238l01XLicIL=S/fFcHk=U`f>cIK=S/fG3Hk7>Lj>ciK>S/jFcXk
?U/j>cYK>S/nFcXk>U/j>acW0ciJ00E2FciJ?UXnFT9K00<nFP05@U/nFSiJ?UXLi`03@UX01DIJ@UY2
FT9J00001goo00<007ooOol0<Woo00<007ooOol027oo0006Ool00`00Oomoo`0bOol010000SH25@8f
1acW00T25`8F0QL25P8G0QH25`8F0QL011cW1P8H0acW00@26P8I0QX26@8Li`@66`0C2S`LiacW2Q`:
?0XL7>LB?1Hm4S`F?A8l7>LJ?1hm6SdN?AXl7>L00`0003/V?B8l9SdLibhm:S`^?BXl;SdZ?2hm7>Lb
G38l<U`^>c9L<S`bG2hk7>Lf>cIL=S/jG3Hk=U`f>cYL=S/fG1cW?U/j>SiK>SXnFcXj?U/j>SiK>SXn
FcXj7>LnFT9K?UY2FciJ@U/nFT9K?UY2FciJ@U/nFT9K008Li`09@UY6FT9JAUY2FTIJ@UY6FT9J0080
00Ioo`03001oogoo035oo`03001oogoo00Qoo`001Woo00<007ooOol0<Woo00<0008f0SH0208f1acW
0`8G00<25P8G0QL01AcW108H0acW00<26P8I0QX00acW0`HK00<:?1cW2S`00PXl0QcW118m00<LiaXm
6Sd00`0000LLib8m9SdR?BHm8SdLi`03:S`01BXm:S`Z?2Xl7>L0238l01PLicIK=S/fG3Hk=U/f>cIL
=S/fFacW?U/j>cYK>S/nFcXk>U/j>ciK>S/jFcXk7>L3?UX01D9K?UXnFSiJ@U/00ciJ00E2FciJ?UXL
idIJ00=2FP05AUY2FT9J@UY6FP03@UX00dIJ00000005Ool00`00Oomoo`0`Ool00`00Oomoo`08Ool0
00Ioo`03001oogoo039oo`0B0002=P8E0SH25@8f0QD2=P8E0SH25@8f0QD2=P8E0SH25@8f1QcW00D2
5P8G0QH25`8F00@Li`<260<Li`030QX26@8J008Li`866`092Q`LiacW2S`:71Hm7>LF?A8l00@0001@
7SdJ?Ahm7>LV?B8l9SdR?2Hm8S`LibXl;SdZ?2hm:S`^?AcW<U`^>c9L<S`bG2hk<U`b?1cW=S/jG3Hk
=U`f>cYL=S/fG3Hk7>Lj>SiK>SXnFcXj?U/j>SiK>SXnFcXj?U/Lid9K?UY2FciJ@U/nFT9K?UY2FciJ
@U/nFT9K7>M6FT9JAUY2FTIJ@UY6FT9JAUY2FTIJ@UY6FT9JAUY2FP8000Aoo`03001oogoo02moo`03
001oogoo00Qoo`001Goo00<007ooOol0<goo00<001cW7>L01QcW3`8f1acW00<25P8G7>L00acW0P8H
0acW00@26P8I7>LLi`866`042S`LiacW2S`300034Sd03AcW6SdJ?AXm7SdLibHm8SdV?B8m9SdLibXm
00<Z?003:SdZ?1cW00Lb?00H7>Lf>cIL=S/fFcHk=U`f>cIK=S/LicXk>U/j>ciK>S/jFcXk?U/j>cYK
>S/nFacW0SiJ00E2FciJ?UXnFT9K00<nFP05@U/nFSiJ7>M6FP03@UX01DIJ@UY2FT9JAUX00d9J00E6
FT9J@UY2FTIJ0092FP03001oogoo009oo`03001oogoo02ioo`03001oogoo00Qoo`001Goo00<007oo
Ool0=7oo200041cW00H2=P8E0SH25@8f0QD>7>L0108J7>LLi`HK0`0005XLi`Xl7>LLia8l5SdJ?AcW
6S`N?AXm7SdLibHm8S`V?B8l7>LZ?2hm:S`^?BXl;SdLic9L<S`bG2hk<U`b?39L7>LjG3Hk=U`f>cYL
=S/fG3Hk>U`LiciK>SXnFcXj?U/j>SiK>SXnFcXj?U/Lid9K?UY2FciJ@U/nFT9K?UY2FciJ@U/nFT9K
7>M6FT9JAUY2FTIJ@UY6FT9JAUY2FTIJ@UY6FT9JAUY2FTIJ@UY6FQcWBUX20003Ool00`00Oomoo`0]
Ool00`00Oomoo`08Ool000Eoo`03001oogoo03AooaP001DLi`<0008Li`8:?0047>L:?18m7>L24Sd0
0aXm7>LJ?@026Sd01QcW8SdV?B8m9SdLi`8Z?005:SdZ?2Xl:S`Li`07<S`05QcW=S/fFcHk=U`f>cIK
=S/fG1cW>U/j>ciK>S/jFcXk?U/j>cYK>S/nFacW0SiJ00E2FciJ?UXnFT9K00<nFP05@U/nFSiJ7>M6
FP03@UX01DIJ@UY2FT9JAUX00d9J00I6FT9J@UY2FTIJ@UX27>L01DIJAUU6FTIJ00000Woo00<007oo
Ool0;Goo00<007ooOol027oo0005Ool00`00Oomoo`0eOolX000011cW000000001acW00Al01cW2S`:
708Li`0j5SdJ?AcW6S`N?AXm7>LR?2Hm8S`V?AcW;SdZ?2hm:S`^?AcW<U`^>c9L<S`bG2hk<U`LicIL
=S/jG3Hk=U`f>cYL=S/LicXj?U/j>SiK>SXnFcXj?U/j>SiK7>M2FciJ@U/nFT9K?UY2FciJ@U/nFT9K
?UX27>L04DIJ@UY6FT9JAUY2FTIJ@UY6FT9JAUY2FTIJ@UY6FT9JAUX00QcW00Q6FDYJAUU6FTIIBUY6
F@000Woo00<007ooOol0;Goo00<007ooOol01goo0005Ool00`00Oomoo`0eOol00`001WD6MP021WH0
1@Ie1WH6MPIf1WD00`If00D6M@If1WH6MPIe00<6MP051WD6MPIf1WH6M@031WH010Ie1WH6MPIf11cW
10001acW00@O61cW7>LLi`Il00034SdJ?AcW008J?@067>LV?B8m9SdR?AcW0bXl00<Z?BXl7>L01S8l
01DLicIK=S/fG3Hk=U/f>cIL=S/LicXk?U/j>cYK>S/nFcXk>U/j>ciK7>L00SiJ00E2FciJ?UXnFT9K
00<nFP05@U/nFQcW@UY6FP03@UX01DIJ@UY2FT9JAUX00d9J00I6FT9J@UY2FTIJ7>L3AUX01DIIAUY6
FTIJAUT00TIJ0P0000=oo`00Ool0;Goo00<007ooOol01goo0005Ool00`00Oomoo`0fOol05@001WD6
MPIe1WH6M@If1WD6MPIe1WH6M@If1WD6MPIe1WH6M@If1WD6MP0;7>L011;G000000001AcW00<Nmb<H
7_L01AcW00<kVSnK>iX00QcW00=?g1cW7>L01G`004@N?AcW9SdR?2Hm7>L^?BXl;SdZ?2hm7>LbG38l
<U`^>c9L<S`LicHk>U`f>cIL=S/jG3Hk=U`LiciK>SXnFcXj?U/j>SiK>SXnFciJ7>LnFT9K?UY2FciJ
@U/nFT9K?UY2FciJ7>M2FTIJ@UY6FT9JAUY2FTIJ@UY6FT9JAUY2FTIJ@UY6FT9J0QcW0116FTIIBUY6
FDIJAUU:FTIIAUY6FDYJAUU6FP00Ool002eoo`03001oogoo00Moo`001Goo00<007ooOol0=goo00<0
00Ie1WH00PIf00<6M@If1WH031cW00TB]a:f4[LB]Q:g4[HB]a:f7>L00`000QcW1AlH1QcW00<kVcnK
?i/00acW00=;_4_L7>L00eOM00AGg1cWGmeOg@Al00048SdV?AcW:Sd3:S`00acW<S`b?004<S`05QcW
=U`f>cIK=S/fG3Hk=U/LiciK>S/jFcXk?U/j>cYK>S/nFcXk7>LnFT9K0ciJ00U2FciJ?UXnFT9K?UXL
id9JAUX00d9J00E6FT9J@UY2FTIJ00=2FP06AUY2FT9JAUXLidII0dIJ00E6FDIJAUY6FTII00=6FP04
AUU6FTIJAUX3000/Ool00`00Oomoo`07Ool000Aoo`03001oogoo03Uoo`03000LiacW00@Li`0>3[HB
e`jf4]L>]Q;G3[HBe`jf4]L>]Q;G3[HBe`@Li`<000067aPNmb<H7_LO61kg11cW00L_FQcW7>LkVSnK
>iXoV`027>L00d^lBma;^`027>L035OMEmaGgEOL7>MOg5oMGmaOgAcWImeS_09l000k7>Ml02hm:S`^
?AcW<U`^>c9L<S`bG2hk7>Lf>cIL=S/jG3Hk=U`f>acW>SXnFcXj?U/j>SiK>SXnFcXj7>LnFT9K?UY2
FciJ@U/nFT9K?UY2FciJ7>M2FTIJ@UY6FT9JAUY2FTIJ@UY6FT9JAUY2FTIJ@UY6FP027>L054IIAUY6
FDYJAUU6FTIIBUY6FDIJAUU:FTIIAUY6FDYJAUU6FQcW000/Ool00`00Oomoo`07Ool000Aoo`03001o
ogoo03Yoo`0>000B]Q:g4[HB]a:f4[LB]Q:g4[HB]a:f4[LB]PHLi`@000DO60@Li`8_F@<Li`<oV`06
>i/LiacWBma;_4_L0QcW00IGg5OMEmeGgEOL7>L4Gmd021cWHmeSg6?MHm`006Nl7>L2O0000bXl7>Lb
?004<S`05AcW=S/fFcHk=U`f>cIK=S/LicXk>U/j>ciK>S/jFcXk?U/j>acW?UY2F`03?UX02D9K?UXn
FSiJ@U/nFQcW@UY6FP03@UX01DIJ@UY2FT9JAUX00d9J00I6FT9J7>LLidIJAUT3AUX01DIIAUY6FTIJ
AUT00dIJ00I6FDIJAUY6FTIIAUX27>L00dYI001oo`0ZOol00`00Oomoo`07Ool000Aoo`03001oogoo
03]oo`8000054]L>]Q;G3[HBe`067>L00akg8aPNm`0300001Akg7aPNmb<H7_L011cW00<_FR]I;eX0
0acW00@oVc^J?i/kVP<Li`0:Bk]?g4^lBm`LieOMEmaGgEOLEmd27>L035oLGmeOg5oMHk`Lif>lImeS
_6OM000Li`=W_00SO00Lig`0<S`bG2hk<U`LicIL=S/jG3Hk=U`f>cYL7>LnFcXj?U/j>SiK>SXnFcXj
7>LnFT9K?UY2FciJ@U/nFT9K?UY2F`027>L08d9JAUY2FTIJ@UY6FT9JAUY2FTIJ@UY6FT9JAUY6FAcW
AUU:FTIIAUY6FDYJAUU6FTIIBUY6FDIJAUU:FTIIAUY6FDYJAUT00QcW00E:NTYIBWY6F@0002Yoo`03
001oogoo00Moo`0017oo00<007ooOol0?Goo00<001cW7>L00QcW1QlH0`0011lH11cW1BmI0QcW0cnK
00TkVcnK7>LLid^lBma;_4_LBk`00QcW00=GgEOLEmd00UOM00<LieoMGmd00eoM00USg1cWHmaSgF?L
Hmd006Nl7>L01VNl0g`001@b?1cW=S/fG3Hk=U/f>cIL7>LjFcXk?U/j>cYK>S/nFcXk7>LnFT9K0ciJ
00I2FciJ?UXnFT9K7>L2@UX01DIJ@UY2FT9JAUX00d9J00E6FT9J@UY2FTIJ008Li`96FP05AUU6FTIJ
AUY6F@03AUX01DIIAUY6FTIJAUT00dIJ0QcW00=:FDYJBUT00TYI00=:FTYI0000:Woo00<007ooOol0
1Woo0004Ool00`00Oomoo`0nOol200001Akg7aPNmb<H7_L00`0000<NmalH7_L011cW00H_FRmI;eX[
FBmJ;eT37>L01C^J?i/kVSnK>iX00QcW00E?g4^lBma;^doL008Li`0EEmaGgEOLEmeGg5OM7>MOgEoL
GmeOg5oMHk`Lif>lImeS_6OMHk`001cW00MW_0037>M[W6NK009l000l>U`f>cIL=S/jG3Hk7>Lj>SiK
>SXnFcXj?U/j>T9K7>M2FciJ@U/nFT9K?UY2FciJ@U/LidIJ@UY6FT9JAUY2FTIJ@UY6FT9JAUY2FTIJ
@UY:FQcWAUY6FDYJAUU6FTIIBUY6FDIJAUU:FTIIAUY6FDYJAUU6FTII0QcW00Y:NTIIBWY:FDYjAUU:
NTYIBWY6F@8002Qoo`03001oogoo00Ioo`0017oo00<007ooOol0@7oo1@000QlH11cW1bmI0acW0SnK
00@kVcnK?i/oV`8Li`07Bka;g4^lBma;_4_L7>L00eOM00EGg5OMEmeGgAcW00EOg@09Hm`Lif?LHmeS
g6?MHm`001cW00QW_0057>MWVfNLIi]WW002O0003SHk=U`f>acW>S/nFcXk>U/j>ciK>S/nFQcW@U/3
?UX01T9K?UXnFSiJ@U/Li`92FP05AUY2FT9J@UY6FP03@UX014IJ@UY2FTIJ0QcW0dIJ00E6FDIJAUY6
FTII00=6FP06AUU6FTIJAUY6FDIJ0QcW0dYI00E:FTYIBUU:FDYJ00=:F@04BUX004YI000WOol00`00
Oomoo`06Ool000=oo`03001oogoo03moo`H000<Li`09;eX[FBmJ;eT_FR]I;eX_FBmJ008Li`06>iXo
Vc^J?i/kVSnK0acW00I;g4^kCma;_4_LBk/27>L05eOMEmaGgEOLEmeGg5oM7>MOgEoLGmeOg5oMGm`L
if>lImeS_6OMHkaWgFNl7>L026Nl00LLif^LIi][W6NKJiaWV`02O0008AcW>SXnFcXj?U/j>SiK>SXn
FacW@U/nFT9K?UY2FciJ@U/nFT9K7>M6FT9JAUY2FTIJ@UY6FT9JAUY2FTIJ@UY6FP027>L04DIIAUY6
FDYJAUU6FTIIBUY6FDIJAUU:FTIIAUY6FDYJAUT00QcW019:NTYIBWY6FDYjBUU:NTIIBWY:FDYjAUU:
NTYIBWX004Yj000VOol00`00Oomoo`06Ool000=oo`03001oogoo03aoo`<000Moo`<000D_F@<Li`03
?i/kVcnK008oV`0=>i/LiacWBma;_4_LBka;g4^lBma;_1cWEm`00eOM00EGg5OMEmeOgAcW00IOg@09
7>MSg6?MHmaSgF?LHmd001cW00QW_0037>MWW6NK00D0009oo`9l0008>S/jFcXk?U/j>cYK7>M2F`<n
FP06@U/nFSiJ?UY2FacW0T9J00E6FT9J@UY2FTIJ00=2FP06AUY2FTIJ7>M6FTII0dIJ00E6FDIJAUY6
FTII00=6FP04AUU6FTIJAUX27>L00dYIBUY:F@02BUT01DYJBUU:FDYIBUX00dYI00Q:FTYIBUU:FDYJ
001:F@009Goo00<007ooOol01Woo0003Ool00`00Oomoo`0iOol3000=Ool200037>L01cnK>iXoVc^J
?i/kVSnK008Li`08Bk]?g4^lBma;^doLBka;g08Li`07EmaGgEOLEmeGg5OMEm`00QcW011OgEoLGmeO
g5oMGm`Lif>lImeS_6OMHkaWgF>lIk`Li`IW_08000037>L0000000Uoo`=l000;>SXnFacW@U/nFT9K
?UY2FciJ@U/nFP027>L034IJ@UY6FT9JAUY2FTIJ@UY6FT9JAUY2FP8Li`0@BUY6FDIJAUU:FTIIAUY6
FDYJAUU6FTIIBUY6FDIJAUT27>L064YjAUU:NTYIBWY6FDYjBUU:NTIIBWY:FDYjAUU:NTYIBWY6FDYj
BUU:NP007>L002Aoo`03001oogoo00Ioo`000goo00<007ooOol0=Woo0`004goo100000<kVcnK?i/0
0QcW00Q;g4^lBma;_4_LBka;g4^l0QcW00=GgEOLEmd00UOM00AGg5OMEmdLi`MOg@0;7>MSg6?MHmaS
gF?LHmeSg0007>MW_006000AOol2O0001D9K?UXnFSiJ@U/00ciJ00DLid9J@UY2FTIJ00=2FP05AUY2
FT9J@UY6FP027>L2AUX01DIIAUY6FTIJAUT00dIJ00I6FDIJAUY6FTIIBUT27>L3BUT01DYJBUU:FDYI
BUX00dYI00E:FTYIBUU:FDYJ00=:F@08BUXLiacW7>M>N@00CWT002=oo`03001oogoo00Ioo`000goo
00<007ooOol0<goo0`006Woo0`0000PLi`00000004^lBma;^doL0QcW01IGg5OMEmaGgEOLEmeGg5OM
Gm`LieoLGmeOg5oMGmaOgEoL7>MS_6OMHkaWg@L001Uoo`0UO012FciJ@U/nFT9K?UXLid9JAUY2FTIJ
@UY6FT9JAUY2FTIJ@UY:FQcWAUY6FDYJAUU6FTIIBUY6FDIJAUU:FTIIAUY6FDYJBUT00QcW01=:NTYI
BWY6FDYjBUU:NTIIBWY:FDYjAUU:NTYIBWY6FDYjBUU:NP037>L024iiBUU>NTYICWT004ij000ROol0
0`00Oomoo`06Ool000=oo`03001oogoo02moo`@002Aoo`h000037>L0000000/0025oo`9l00<nFP05
7>M2FT9J@UY6FP03@UX014IJ@UY2FT9J0QcW0dIJ00E6FDIJAUY6FTII00=6FP03AUU6FTIJ00<Li`03
BUU:FTYI009:F@05BUY:FDYIBUU:FP03BUT01TYJBUU:FDYIBUY:F@8Li`03CWU:NDii009>N@07BWU>
NDii001:NDii00008Woo00<007ooOol01Goo0002Ool00`00Oomoo`0]Ool3000gOol00`00Oomoo`0]
Ool07G`0?UXLid9JAUY2FTIJ@UY6FT9JAUY2FTIJAUTLidIIAUY6FDYJAUU6FTIIBUY6FDIJAUU:FTII
AUX00QcW01=:FDYjAUU:NTYIBWY6FDYjBUU:NTIIBWY:FDYjAUU:NTYIBWY6F@037>L03dYICWY:FDii
BUU>NTYICWU:FDijBUT004YICWX0000QOol00`00Oomoo`05Ool0009oo`03001oogoo02Yoo`<003Yo
o`03001oogoo02ioo`05O012FT9J@UY6FP03@UX00dIJ@UY6FP027>L01DIIAUY6FTIJAUT00dIJ00E6
FDIJAUY6FTII008Li`05BUY:FDYIBUU:FP03BUT01DYJBUU:FDYIBUX00dYI00=:FTYI7>L00QcW00E:
NDiiCWU>NDYi00=>N@05BWU>NDiiCWU:N@02CWT00`00BWT0000QOol00`00Oomoo`05Ool0009oo`03
001oogoo02Moo`<003eoo`03001oogoo02moo`9l0006AUY2FTIJ@UY6FT9J0QcW00e:FTIIAUY6FDYJ
AUU6FTIIBUY6FDIJAUU:NP027>L04DIIBWY:FDYjAUU:NTYIBWY6FDYjBUU:NTIIBWY:FDYjAUT00acW
01I:FDijBUU>NDYICWY:FDiiBUU>NTYICWU:FDijBUU>NDYICWY:F@00BUT0021oo`03001oogoo00Eo
o`000Woo00<007ooOol097oo0`00@7oo00<007ooOol0<Goo0W`000A2FTIJ7>LLi`96FP05AUU6FTIJ
AUY6F@03AUX00dIIAUY:F@027>L2BUT01DYJBUU:FDYIBUX00dYI00I:FTYIBUU:FDYJBUT37>L01DYi
CWU>NDiiBWT00dii00E:NDiiCWU>NDYi00=>N@05BWU>NDiiCWU:N@02CWT00`00BWT0000OOol00`00
Oomoo`05Ool0009oo`03001oogoo021oo`@004=oo`03001oogoo03=oo`0?O00LidIJAUU:FTIIAUY6
FDYJAUU6FTIIBUY6FDYj008Li`0@BUU:NTIIBWY:FDYjAUU:NTYIBWY6FDYjBUU:NTIIBWX27>L06dYI
CWY:FDiiBUU>NTYICWU:FDijBUU>NDYICWY:FDiiBUU>NTYICWU:FDijBUU>NDYICWX000027>L00`00
Oomoo`0LOol00`00Oomoo`05Ool0009oo`03001oogoo01eoo`<004Moo`03001oogoo03Aoo`04O016
FTIJAUT3AUX01DIIAUY6FTIJBUT00QcW00E:FTYIBUU:FDYJ00=:F@05BUY:FDYIBUU:FP02BUT37>L3
CWT01DYiCWU>NDiiBWT00dii00E:NDiiCWU>NDYi00=>N@06BWU>NDiiCWU:NDii11cW00@004iiCWT0
01eoo`03001oogoo00Eoo`000Woo00<007ooOol06Woo0`00BWoo00<007ooOol0=Goo0W`000M6FTII
BUY6FDIJAUU:NP027>L03TIIBWY:FDYjAUU:NTYIBWY6FDYjBUU:NTIIBWX37>L064ijBUU>NDYICWY:
FDiiBUU>NTYICWU:FDijBUU>NDYICWY:FDiiBUU>NTYICWU:F@@Li`09DWU>NE9iCWUBN@00DWU>N@00
01eoo`03001oogoo00Aoo`0000=oo`00Ool06Goo0`00CGoo00<007ooOol0=goo00El04IJAUU6FTYI
008Li`9:F@05BUY:FDYIBUU:FP03BUT00dYJBUU:F@037>L3CWT01DYiCWU>NDiiBWT00dii00E:NDii
CWU>NDYi00=>N@04BWU>NDiiCWT47>L:CWT00`00CWT0000MOol00`00Oomoo`04Ool00003Ool007oo
01Ioo`<0051oo`03001oogoo03Qoo`0@O00LiacW7>M:FDYjAUU:NTYIBWY6FDYjBUU:NTIIBWX37>L0
5dijBUU>NDYICWY:FDiiBUU>NTYICWU:FDijBUU>NDYICWY:FDiiBUU>NTYICWT00acW019BNDiiDWU>
NE9iCWUBNDiiDWU>NE9iCWUBNDiiDWT0059i000LOol00`00Oomoo`04Ool00003Ool007oo019oo`@0
05=oo`03001oogoo03Uoo`03O01:FTYI009:F@05BUY:FDYIBUU:FP03BUT27>L3CWT01DYiCWU>NDii
BWT00dii00E:NDiiCWU>NDYi00=>N@03BWU>NDii00@Lia9>N@04001>NDii000KOol00`00Oomoo`04
Ool00003Ool007oo00moo`<005Moo`03001oogoo03Yoo`09O01:NTIIBWY:FDYjAUU:NTYI00<Li`0D
BUU>NDYICWY:FDiiBUU>NTYICWU:FDijBUU>NDYICWY:FDiiBUU>NP@Li`0KCWUBNDiiDWU>NE9iCWUB
NDiiDWU>NE9iCWUBNDiiDWU>NE9iCWUBNDiiDWU>N@00CWUBN@0001Yoo`03001oogoo00Aoo`0000=o
o`00Ool037oo0`00FWoo00<007ooOol0>Woo00=l04YIBUX00dYI0acW0Tii00E:NDiiCWU>NDYi00=>
N@05BWU>NDiiCWU:N@03CWT00dYi7>LLi`027>LLCWT00`00CWT0000JOol00`00Oomoo`04Ool00003
Ool007oo00Uoo`<005eoo`03001oogoo03]oo`03O01:FDYj008Li`0BBUU>NDYICWY:FDiiBUU>NTYI
CWU:FDijBUU>NDYICWY:FDii11cW02A>NE9iCWUBNDiiDWU>NE9iCWUBNDiiDWU>NE9iCWUBNDiiDWU>
NE9iCWUBNDiiDWU>NE9iCWUBNDiiDWU>NE9iCWT004ii000IOol00`00Oomoo`04Ool00003001oogoo
00Ioo`<0061oo`03001oogoo03aoo`04O00LidiiBWT3CWT01DYiCWU>NDiiBWT00dii00A:NDiiCWU>
N@<Lib=>N@<Li`8001Uoo`03001oogoo00Aoo`0000<007ooOol00Woo1000Hgoo00<007ooOol0?Goo
00il04YICWU:FDijBUU>NDYICWY:FDiiBUU>NTYI11cW021BNDiiDWU>NE9iCWUBNDiiDWU>NE9iCWUB
NDiiDWU>NE9iCWUBNDiiDWU>NE9iCWUBNDiiDWU>NE9iCWUBNDii1QcW0e9i00=>N00000006Goo00<0
07ooOol00goo00000`00Ool00002001WOol00`00Oomoo`0nOol017`0CWU>NDYi0dii00=:NDii7>L0
0acW7dii1AcW2U9i0P006Goo00<007ooOol00goo0002001ZOol00`00Oomoo`0oOol017`0BUU>NDYI
11cW01eBNDiiDWU>NE9iCWUBNDiiDWU>NE9iCWUBNDiiDWU>NE9iCWUBNDiiDWU>NE9iCWUBNDiiDWU>
NE9i00HLi`05CWQBNE9iDWU>N003DWT01DihDWUBNE9iCWP00e9i00<007ooOol05goo00<007ooOol0
0goo00000goo0000001YOol00`00Oomoo`10Ool00g`07>LLi`0LCWT57>LGDWT00`00Oomoo`0FOol0
0`00Oomoo`03Ool000=oo`03001oogoo06Ioo`03001oogoo045oo`0HO01>NE9iCWUBNDiiDWU>NE9i
CWUBNDiiDWU>NE9iCWUBNDiiDWU>NE9iCWUBNDii1QcW00=BNDihDWT00U9i00E>N59iDWUBNDih00=B
N@05CWQBNE9iDWU>N003DWT01DihDWUBNE9iCWP00U9i0P005goo00<007ooOol00goo0004Ool00`00
Oomoo`1UOol00`00Oomoo`11Ool00g`0CWU>N@0?CWT67>LRDWT00`00Ool0000FOol00`00Oomoo`03
Ool000Eoo`8006Eoo`03001oogoo049oo`0<O01BNDiiDWU>NE9iCWUBNDiiDWU>NE9i1AcW0e9i00E>
N59iDWUBNDih00=BN@05CWQBNE9iDWU>N003DWT01DihDWUBNE9iCWP00e9i00E>N59iDWUBNDih00=B
N@06CWQBNE9iDWU>N59i0P005Woo00<007ooOol00goo0007Ool00`00Oomoo`1ROol00`00Oomoo`12
Ool00g`0CWU>N@03CWT67>LXDWT67>L00`00Ool0000FOol00`00Oomoo`02Ool000Qoo`80069oo`03
001oogoo04=oo`03O00LiacW008Li`05CWQBNE9iDWU>N003DWT01DihDWUBNE9iCWP00e9i00E>N59i
DWUBNDih00=BN@05CWQBNE9iDWU>N003DWT01TihDWUBNE9iCWQBN@PLi`07DWUFVE9hEYUBN5JI0000
0Woo00<007ooOol04goo00<007ooOol00Woo000:Ool00`00Oomoo`1OOol00`00Oomoo`14Ool00g`0
DWUBN@0NDWT97>L03eJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVEJIDYT00003Ool00`00Oomoo`0BOol0
0`00Oomoo`02Ool000]oo`8005ioo`03001oogoo04Eoo`03O01BNDih00=BN@05CWQBNE9iDWU>N003
DWT01DihDWUBNE9iCWP00e9i00=>N59i7>L021cW01UFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9h
EYUBN5JIDWQFVE9hEYUBN5JIDWP00003Ool00`00Oomoo`0AOol00`00Oomoo`02Ool000eoo`03001o
ogoo05]oo`03001oogoo04Ioo`03O01BNE9i00aBN@PLi`0REYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:I
EYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVEJI0003Ool00`00Oomoo`0AOol0
0`00Oomoo`02Ool000ioo`03001oogoo05Yoo`03001oogoo04Ioo`04O01BNE9iCWP2DWT97>L0:U9h
EYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9h
EYUBN5JIDWQFVE9hEYUBN5JIDWP000Aoo`03001oogoo011oo`03001oogoo009oo`003goo0P00FWoo
00<007ooOol0Agoo00=l01cW7>L00QcW03=BVEJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:I
EYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:I
EYUBVEJI00001Goo00<007ooOol03goo00<007ooOol00Woo000AOol00`00Oomoo`1GOol00`00Oomo
o`17Ool0>G`0EYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9hEYUB
N5JIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9hEYT0
0005Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool0019oo`8005Moo`03001oogoo04Qoo`0hO01FVE:I
EYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:I
EYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVEJIDYT000Ioo`03001oogoo00io
o`03001oogoo005oo`0057oo00<007ooOol0E7oo00<007ooOol0B7oo02Yl059hEYUBN5JIDWQFVE9h
EYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFVE9h
EYUBN5JIDWP=7>L00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`01Ool001Eoo`03001oogoo
05=oo`03001oogoo04Uoo`0>O01BVEJIDYUFVE:IEYUBVEJIDYUFVE:IEYUBVA/Li`eFV@03001oogoo
00Eoo`03001oogoo00eoo`03001oogoo005oo`005Woo0P00Dgoo00<007ooOol0BGoo00=l01cW7>L0
2acW02UFV5ZIEYQFVEJHFYUFV5JIEYQJVEJHEYUFV5ZIEYQFVEJHFYUFV5JIEYQJVEJHEYUFV5ZIEYQF
VEJHFYUFV5JIEYQJVEJHEYUFV5ZIEYQFV@0000Qoo`03001oogoo00aoo`03001oogoo005oo`0067oo
00<007ooOol0D7oo00<007ooOol0BGoo00=l05JIEYT0<eJI00<007ooOol01goo00<007ooOol02goo
00<007ooOol00Goo000IOol2001@Ool00`00Oomoo`19Ool0=g`0FYUFV5JIEYQJVEJHEYUFV5ZIEYQF
VEJHFYUFV5JIEYQJVEJHEYUFV5ZIEYQFVEJHFYUFV5JIEYQJVEJHEYUFV5ZIEYQFVEJHFYUFV5JIEYQJ
VEJHEYUFV5ZIEYQFVEJHFYUFV5JIEYQJV@0000Yoo`03001oogoo00Yoo`03001oogoo005oo`006goo
00<007ooOol0CGoo00<007ooOol0BWoo00=l05JIEYT0<EJI00<007ooOol02Woo00<007ooOol02Goo
00<007ooOol00Goo000LOol2001=Ool00`00Oomoo`1:Ool0=G`0EYQJVEJHEYUFV5ZIEYQFVEJHFYUF
V5JIEYQJVEJHEYUFV5ZIEYQFVEJHFYUFV5JIEYQJVEJHEYUFV5ZIEYQFVEJHFYUFV5JIEYQJVEJHEYUF
V5ZIEYQFVEJHFYUFV5JIEYQJVEJH000037oo00<007ooOol02Woo0@000Goo0Goo000NOol00`00Oomo
o`1:Ool00`00Oomoo`1:Ool00g`0EYUFV@0aEYT00`00Oomoo`0;Ool00`00Oomoo`09Ool10001Ool1
Ool001moo`03001oogoo04Uoo`03001oogoo04Yoo`03O00LiacW01LLi`0KEYUFV5ZIEYQFVEJHFYUF
V5JIEYQJVEJHEYUFV5ZIEYQFVEJHFYUFV5JIEYQJVEJHEYUFV00000ioo`03001oogoo00Qoo`40005o
o`5oo`0087oo0P00BGoo00<007ooOol0I7oo6QcW00<007ooOol03Goo00<007ooOol01goo0@000Goo
0Goo000ROol00`00Oomoo`16Ool00`00Oomoo`2?Ool00`00Oomoo`06Ool10001Ool1Ool002=oo`80
04Ioo`03001oogoo08moo`03001oogoo00Ioo`40005oo`5oo`009Goo00<007ooOol0@goo00<007oo
Ool0T7oo00<007ooOol01Goo0@000Goo0Goo000VOol20013Ool00`00Oomoo`2AOol00`00Oomoo`05
Ool10001Ool002Qoo`03001oogoo041oo`03001oogoo099oo`03001oogoo00Aoo`40005oo`00:Goo
00<007ooOol0?goo00<007ooOol0Tgoo00<007ooOol00goo0@000Goo000ZOol2000oOol00`00Oomo
o`2DOol00`00Oomoo`02Ool10001Ool002aoo`03001oogoo03aoo`03001oogoo09Aoo`03001oogoo
009oo`40005oo`00;Goo0P00?7oo00<007ooOol0UGoo00D007ooOomoo`00005oo`00;goo00<007oo
Ool0>Goo00<007ooOol0UWoo00@007ooOol0005oo`00<7oo00<007ooOol0>7oo00<007ooOol0Ugoo
00<007oo00000Goo000aOol2000gOol00`00Oomoo`2IOol10001Ool1000003=oo`03001oogoo03Ao
o`03001oogoo09Uoo`40005oo`400000=7oo0P00=7oo00<007ooOol0VWoo0P00000fOol00`00Oomo
o`0aOol00`00Oomoo`2IOol3000003Moo`80035oo`03001oogoo09Eoo`@000=oo`00>Goo00<007oo
Ool0;Woo00<007ooOol0T7oo1@001goo000jOol00`00Oomoo`0]Ool00`00Oomoo`2<Ool4000<Ool0
03]oo`8002eoo`03001oogoo08Qoo`@0011oo`00?Goo00<007ooOol0:Woo00<007ooOol0Pgoo1@00
57oo000nOol2000ZOol00`00Oomoo`1oOol4000IOol0041oo`03001oogoo02Moo`03001oogoo07Yo
o`D001eoo`00@Goo00<007ooOol09Woo00<007ooOol0MWoo10008Woo0012Ool2000VOol00`00Oomo
o`1bOol4000VOol004Aoo`03001oogoo02=oo`03001oogoo06eoo`D002Yoo`00AGoo0P008goo00<0
07ooOol0JGoo1000;goo0017Ool00`00Oomoo`0POol00`00Oomoo`1TOol5000cOol004Qoo`80021o
o`03001oogoo061oo`@003Qoo`00BWoo00<007ooOol07Goo00<007ooOol0Fgoo1@00?7oo001;Ool0
0`00Oomoo`0LOol00`00Oomoo`1GOol40011Ool004aoo`8001aoo`03001oogoo05=oo`@004Eoo`00
CWoo00<007ooOol06Goo00<007ooOol0CWoo1@00BGoo001?Ool2000IOol00`00Oomoo`1:Ool4001>
Ool0055oo`03001oogoo01Ioo`03001oogoo04Eoo`D0059oo`00DWoo0P005Woo00<007ooOol0@Goo
1000Egoo001DOol00`00Oomoo`0COol00`00Oomoo`0mOol4001KOol005Eoo`03001oogoo019oo`03
001oogoo03Qoo`D005moo`00EWoo0P004Goo00<007ooOol0=Goo1000I7oo001HOol00`00Oomoo`0>
Ool00`00Oomoo`0`Ool5001XOol005Uoo`8000ioo`03001oogoo02aoo`@006eoo`00Fgoo00<007oo
Ool02goo00<007ooOol09goo1@00LGoo001LOol00`00Oomoo`0:Ool00`00Oomoo`0SOol4001fOol0
05eoo`8000Yoo`03001oogoo01moo`@007Yoo`00Ggoo00<007ooOol01goo00<007ooOol06Woo1@00
OWoo001POol20007Ool00`00Oomoo`0FOol40023Ool0069oo`03001oogoo00Aoo`03001oogoo015o
o`D008Moo`00Hgoo0P0017oo00<007ooOol03Goo1000S7oo001UOol01@00Oomoogoo00002goo1000
T7oo001VOol01000Oomoo`001Woo1@00U7oo001WOol30002Ool4002IOol006Uoo`<009eoo`00
\>"],
  ImageRangeCache->{{{0, 264.313}, {287, 0}} -> {0.0486402, -0.000148683, 
  0.00324458, 0.00324458}}]
}, Open]]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[CellGroupData[{

utput"],

Cell[CellGroupData[{

t, Tau periodic.", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

lse,
  AspectRatioFixed->True],

l stitch if tau is Sin and kappa is 1.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(clear; top = 125; kappa[s_] = 1; tau[s_] := Sin[s]; width = .3; 
    ds = .1; \), 
    \(pribbonfrenet\)}], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-016 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.42591 .62314 m .42162 .60783 L .41589 .60061 L .835 .672 .13 r
F
.42591 .62314 m .42199 .62721 L .42162 .60783 L F
.43555 .64579 m .42199 .62721 L .42591 .62314 L .984 .792 .389 r
F
.41589 .60061 m .42126 .58839 L .40577 .57825 L 0 0 .213 r
F
.41589 .60061 m .42162 .60783 L .42126 .58839 L F
0 g
.006 w
.41589 .60061 m
.42174 .61375 L
s
.25 g
.5 Mabswid
.41589 .60061 m
.42162 .60783 L
s
.43555 .64579 m .42228 .64649 L .42199 .62721 L .984 .792 .389 r
F
.25 g
.42199 .62721 m
.42591 .62314 L
s
.44453 .6685 m .42228 .64649 L .43555 .64579 L .996 .798 .519 r
F
0 g
.006 w
.42591 .62314 m
.43555 .64579 L
s
.40577 .57825 m .42094 .56897 L .39583 .55614 L 0 0 .466 r
F
.40577 .57825 m .42126 .58839 L .42094 .56897 L F
0 g
.40577 .57825 m
.41589 .60061 L
s
.25 g
.5 Mabswid
.40577 .57825 m
.42126 .58839 L
s
.44453 .6685 m .42244 .66561 L .42228 .64649 L .996 .798 .519 r
F
.25 g
.42228 .64649 m
.43555 .64579 L
s
.45262 .69119 m .42244 .66561 L .44453 .6685 L .97 .77 .579 r
F
0 g
.006 w
.43555 .64579 m
.44453 .6685 L
s
.39583 .55614 m .42075 .54962 L .38638 .5343 L .148 .145 .597 r
F
.39583 .55614 m .42094 .56897 L .42075 .54962 L F
0 g
.39583 .55614 m
.40577 .57825 L
s
.25 g
.5 Mabswid
.39583 .55614 m
.42094 .56897 L
s
.45262 .69119 m .42237 .68451 L .42244 .66561 L .97 .77 .579 r
F
.25 g
.42244 .66561 m
.44453 .6685 L
s
.45958 .71378 m .42237 .68451 L .45262 .69119 L .938 .737 .605 r
F
0 g
.006 w
.44453 .6685 m
.45262 .69119 L
s
.38638 .5343 m .42076 .53039 L .37769 .51279 L .305 .28 .665 r
F
.38638 .5343 m .42075 .54962 L .42076 .53039 L F
0 g
.38638 .5343 m
.39583 .55614 L
s
.25 g
.5 Mabswid
.38638 .5343 m
.42075 .54962 L
s
.45958 .71378 m .42198 .70309 L .42237 .68451 L .938 .737 .605 r
F
.25 g
.42237 .68451 m
.45262 .69119 L
s
.4652 .73617 m .42198 .70309 L .45958 .71378 L .91 .707 .615 r
F
0 g
.006 w
.45262 .69119 m
.45958 .71378 L
s
.37769 .51279 m .42105 .51135 L .37008 .49165 L .407 .369 .704 r
F
.37769 .51279 m .42076 .53039 L .42105 .51135 L F
0 g
.37769 .51279 m
.38638 .5343 L
s
.25 g
.5 Mabswid
.37769 .51279 m
.42076 .53039 L
s
.4652 .73617 m .42117 .72128 L .42198 .70309 L .91 .707 .615 r
F
.25 g
.42198 .70309 m
.45958 .71378 L
s
.46929 .75827 m .42117 .72128 L .4652 .73617 L .887 .679 .616 r
F
0 g
.006 w
.45958 .71378 m
.4652 .73617 L
s
.37008 .49165 m .42173 .49258 L .36381 .47093 L .476 .432 .729 r
F
.37008 .49165 m .42105 .51135 L .42173 .49258 L F
0 g
.37008 .49165 m
.37769 .51279 L
s
.46929 .75827 m .41982 .73898 L .42117 .72128 L .887 .679 .616 r
F
.25 g
.5 Mabswid
.42117 .72128 m
.4652 .73617 L
s
.47169 .77994 m .41982 .73898 L .46929 .75827 L .869 .655 .611 r
F
0 g
.006 w
.4652 .73617 m
.46929 .75827 L
s
.36381 .47093 m .42294 .47414 L .35917 .45066 L .526 .481 .748 r
F
.36381 .47093 m .42173 .49258 L .42294 .47414 L F
0 g
.36381 .47093 m
.37008 .49165 L
s
.25 g
.5 Mabswid
.36381 .47093 m
.36574 .47165 L
s
.41835 .51031 m
.42105 .51135 L
s
.37008 .49165 m
.41835 .51031 L
s
.47169 .77994 m .41783 .75607 L .41982 .73898 L .869 .655 .611 r
F
.47227 .80107 m .41783 .75607 L .47169 .77994 L .855 .634 .602 r
F
.25 g
.46794 .75774 m
.46929 .75827 L
s
0 g
.006 w
.46929 .75827 m
.47169 .77994 L
s
.35917 .45066 m .4248 .45612 L .35638 .43089 L .564 .52 .764 r
F
.35917 .45066 m .42294 .47414 L .4248 .45612 L F
0 g
.35917 .45066 m
.36381 .47093 L
s
.25 g
.5 Mabswid
.35917 .45066 m
.36132 .45145 L
s
.4182 .49126 m
.42173 .49258 L
s
.36574 .47165 m
.4182 .49126 L
s
.47227 .80107 m .41509 .77243 L .41783 .75607 L .855 .634 .602 r
F
.25 g
.41982 .73898 m
.42286 .74016 L
s
.42286 .74016 m
.46794 .75774 L
s
.47091 .82151 m .41509 .77243 L .47227 .80107 L .845 .615 .591 r
F
.25 g
.47029 .77933 m
.47169 .77994 L
s
0 g
.006 w
.47169 .77994 m
.47227 .80107 L
s
1 0 0 r
.003 w
.42162 .60783 m
.42199 .62721 L
s
.42199 .62721 m
.42228 .64649 L
s
.42126 .58839 m
.42162 .60783 L
s
.42228 .64649 m
.42244 .66561 L
s
.42094 .56897 m
.42126 .58839 L
s
.42237 .68451 m
.42244 .66561 L
s
.42075 .54962 m
.42094 .56897 L
s
.42198 .70309 m
.42237 .68451 L
s
.42075 .54962 m
.42076 .53039 L
s
.42117 .72128 m
.42198 .70309 L
s
.42076 .53039 m
.42105 .51135 L
s
.35638 .43089 m .42748 .43862 L .35568 .41167 L .594 .553 .778 r
F
.35638 .43089 m .4248 .45612 L .42748 .43862 L F
0 g
.006 w
.35638 .43089 m
.35917 .45066 L
s
.25 g
.5 Mabswid
.35638 .43089 m
.35872 .43176 L
s
.41849 .4725 m
.42294 .47414 L
s
.36132 .45145 m
.41849 .4725 L
s
1 0 0 r
.003 w
.42105 .51135 m
.42173 .49258 L
s
.47091 .82151 m .41151 .78793 L .41509 .77243 L .845 .615 .591 r
F
.25 g
.5 Mabswid
.41783 .75607 m
.42215 .75799 L
s
.42215 .75799 m
.47029 .77933 L
s
.46754 .8411 m .41151 .78793 L .47091 .82151 L .839 .599 .577 r
F
.25 g
.47089 .80038 m
.47227 .80107 L
s
0 g
.006 w
.47091 .82151 m
.47227 .80107 L
s
1 0 0 r
.003 w
.41982 .73898 m
.42117 .72128 L
s
.42173 .49258 m
.42294 .47414 L
s
.41783 .75607 m
.41982 .73898 L
s
.42294 .47414 m
.4248 .45612 L
s
.35568 .41167 m .43114 .42173 L .35725 .39305 L .617 .582 .791 r
F
.35568 .41167 m .42748 .43862 L .43114 .42173 L F
0 g
.006 w
.35568 .41167 m
.35638 .43089 L
s
.25 g
.5 Mabswid
.35568 .41167 m
.35818 .41261 L
s
.35818 .41261 m
.42748 .43862 L
s
.41936 .45411 m
.4248 .45612 L
s
.35872 .43176 m
.41936 .45411 L
s
1 0 0 r
.003 w
.41509 .77243 m
.41783 .75607 L
s
.46754 .8411 m .40703 .80242 L .41151 .78793 L .839 .599 .577 r
F
.25 g
.5 Mabswid
.41509 .77243 m
.42137 .77558 L
s
.42137 .77558 m
.47089 .80038 L
s
.46209 .85966 m .40703 .80242 L .46754 .8411 L .836 .587 .561 r
F
.25 g
.41151 .78793 m
.46967 .82081 L
s
.46967 .82081 m
.47091 .82151 L
s
0 g
.006 w
.46754 .8411 m
.47091 .82151 L
s
1 0 0 r
.003 w
.4248 .45612 m
.42748 .43862 L
s
.41151 .78793 m
.41509 .77243 L
s
.35725 .39305 m .43593 .40556 L .36125 .37509 L .636 .608 .804 r
F
.35725 .39305 m .43114 .42173 L .43593 .40556 L F
0 g
.006 w
.35568 .41167 m
.35725 .39305 L
s
.25 g
.5 Mabswid
.35725 .39305 m
.43114 .42173 L
s
1 0 0 r
.003 w
.42748 .43862 m
.43114 .42173 L
s
.46209 .85966 m .40159 .81574 L .40703 .80242 L .836 .587 .561 r
F
1 0 0 r
.40703 .80242 m
.41151 .78793 L
s
.45456 .87702 m .40159 .81574 L .46209 .85966 L .838 .578 .545 r
F
.25 g
.5 Mabswid
.40703 .80242 m
.46668 .84055 L
s
.46668 .84055 m
.46754 .8411 L
s
0 g
.006 w
.46209 .85966 m
.46754 .8411 L
s
.36125 .37509 m .43593 .40556 L .44199 .39022 L .651 .631 .818 r
F
1 0 0 r
.003 w
.43114 .42173 m
.43593 .40556 L
s
.36125 .37509 m .44199 .39022 L .36779 .35786 L .651 .631 .818 r
F
0 g
.006 w
.35725 .39305 m
.36125 .37509 L
s
.25 g
.5 Mabswid
.36125 .37509 m
.43593 .40556 L
s
.45456 .87702 m .3952 .82775 L .40159 .81574 L .838 .578 .545 r
F
1 0 0 r
.003 w
.40159 .81574 m
.40703 .80242 L
s
.44496 .89297 m .3952 .82775 L .45456 .87702 L .844 .573 .529 r
F
.25 g
.5 Mabswid
.40159 .81574 m
.46209 .85966 L
s
0 g
.006 w
.45456 .87702 m
.46209 .85966 L
s
.36779 .35786 m .44199 .39022 L .44944 .37582 L .661 .653 .832 r
F
1 0 0 r
.003 w
.43593 .40556 m
.44199 .39022 L
s
.36779 .35786 m .44944 .37582 L .37694 .34142 L .661 .653 .832 r
F
0 g
.006 w
.36125 .37509 m
.36779 .35786 L
s
.25 g
.5 Mabswid
.36779 .35786 m
.44199 .39022 L
s
.37694 .34142 m .44944 .37582 L .45837 .36248 L .668 .673 .846 r
F
1 0 0 r
.003 w
.44199 .39022 m
.44944 .37582 L
s
.44496 .89297 m .38788 .83831 L .3952 .82775 L .844 .573 .529 r
F
1 0 0 r
.3952 .82775 m
.40159 .81574 L
s
.25 g
.5 Mabswid
.3952 .82775 m
.45456 .87702 L
s
.43335 .90731 m .38788 .83831 L .44496 .89297 L .853 .573 .513 r
F
0 g
.006 w
.44496 .89297 m
.45456 .87702 L
s
.38873 .32587 m .45837 .36248 L .46883 .35033 L .67 .69 .86 r
F
.25 g
.5 Mabswid
.43665 .36975 m
.44944 .37582 L
s
.37694 .34142 m .45837 .36248 L .38873 .32587 L .668 .673 .846 r
F
.25 g
.37694 .34142 m
.43665 .36975 L
s
1 0 0 r
.003 w
.44944 .37582 m
.45837 .36248 L
s
0 g
.006 w
.36779 .35786 m
.37694 .34142 L
s
.43335 .90731 m .3797 .84728 L .38788 .83831 L .853 .573 .513 r
F
1 0 0 r
.003 w
.38788 .83831 m
.3952 .82775 L
s
.25 g
.5 Mabswid
.38788 .83831 m
.44496 .89297 L
s
.40314 .31129 m .46883 .35033 L .48082 .33947 L .668 .704 .874 r
F
.25 g
.44263 .35421 m
.45837 .36248 L
s
.38873 .32587 m .46883 .35033 L .40314 .31129 L .67 .69 .86 r
F
1 0 0 r
.003 w
.45837 .36248 m
.46883 .35033 L
s
0 g
.006 w
.37694 .34142 m
.38873 .32587 L
s
.25 g
.5 Mabswid
.38873 .32587 m
.3915 .32732 L
s
.41981 .91982 m .3797 .84728 L .43335 .90731 L .866 .579 .501 r
F
0 g
.006 w
.43335 .90731 m
.44496 .89297 L
s
.41981 .91982 m .37078 .85454 L .3797 .84728 L .866 .579 .501 r
F
1 0 0 r
.003 w
.3797 .84728 m
.38788 .83831 L
s
.25 g
.5 Mabswid
.3797 .84728 m
.43335 .90731 L
s
.4201 .29779 m .48082 .33947 L .49431 .33002 L .662 .714 .887 r
F
.25 g
.44807 .33799 m
.46883 .35033 L
s
.4285 .34678 m
.44263 .35421 L
s
.40314 .31129 m .48082 .33947 L .4201 .29779 L .668 .704 .874 r
F
.25 g
.3915 .32732 m
.4285 .34678 L
s
1 0 0 r
.003 w
.46883 .35033 m
.48082 .33947 L
s
.25 g
.5 Mabswid
.40314 .31129 m
.40589 .31293 L
s
0 g
.006 w
.38873 .32587 m
.40314 .31129 L
s
.4045 .9303 m .37078 .85454 L .41981 .91982 L .882 .593 .493 r
F
0 g
.41981 .91982 m
.43335 .90731 L
s
.4045 .9303 m .36125 .86001 L .37078 .85454 L .882 .593 .493 r
F
1 0 0 r
.003 w
.37078 .85454 m
.3797 .84728 L
s
.25 g
.5 Mabswid
.37078 .85454 m
.41981 .91982 L
s
.43949 .28549 m .49431 .33002 L .5092 .32208 L .651 .719 .898 r
F
.4201 .29779 m .49431 .33002 L .43949 .28549 L .662 .714 .887 r
F
.25 g
.40589 .31293 m
.42548 .32457 L
s
.42548 .32457 m
.44807 .33799 L
s
1 0 0 r
.003 w
.48082 .33947 m
.49431 .33002 L
s
.25 g
.5 Mabswid
.4201 .29779 m
.42304 .29981 L
s
.89561 .52453 m .87046 .54056 L .89765 .55159 L .942 .619 .395 r
F
.89561 .52453 m .86273 .52167 L .87046 .54056 L F
.89232 .49755 m .86273 .52167 L .89561 .52453 L .909 .608 .463 r
F
.89232 .49755 m .85376 .50303 L .86273 .52167 L F
.25 g
.86273 .52167 m
.89561 .52453 L
s
.88758 .47086 m .85376 .50303 L .89232 .49755 L .872 .595 .515 r
F
0 g
.006 w
.89232 .49755 m
.89561 .52453 L
s
.89765 .55159 m .87696 .55956 L .89863 .57852 L .961 .626 .309 r
F
.89765 .55159 m .87046 .54056 L .87696 .55956 L F
0 g
.89561 .52453 m
.89765 .55159 L
s
.25 g
.5 Mabswid
.87046 .54056 m
.89765 .55159 L
s
.88758 .47086 m .84359 .48477 L .85376 .50303 L .872 .595 .515 r
F
.25 g
.85376 .50303 m
.89232 .49755 L
s
.88121 .44471 m .84359 .48477 L .88758 .47086 L .838 .585 .556 r
F
0 g
.006 w
.88758 .47086 m
.89232 .49755 L
s
.43949 .28549 m .5092 .32208 L .46115 .2745 L .651 .719 .898 r
F
.4549 .27644 m .49561 .32669 L .51288 .32055 L .659 .724 .897 r
F
1 0 0 r
.003 w
.49431 .33002 m
.5092 .32208 L
s
.25 g
.5 Mabswid
.44826 .31712 m
.48082 .33947 L
s
.89863 .57852 m .88225 .5785 L .89873 .60511 L .951 .621 .209 r
F
.89863 .57852 m .87696 .55956 L .88225 .5785 L F
0 g
.006 w
.89765 .55159 m
.89863 .57852 L
s
.88121 .44471 m .83224 .46701 L .84359 .48477 L .838 .585 .556 r
F
.25 g
.5 Mabswid
.84359 .48477 m
.88758 .47086 L
s
.87305 .41932 m .83224 .46701 L .88121 .44471 L .807 .577 .589 r
F
0 g
.006 w
.88121 .44471 m
.88758 .47086 L
s
.25 g
.5 Mabswid
.50904 .32192 m
.5092 .32208 L
s
.43949 .28549 m
.44256 .28798 L
s
.42304 .29981 m
.44826 .31712 L
s
0 g
.006 w
.40314 .31129 m
.4201 .29779 L
s
.89873 .60511 m .88636 .59719 L .89813 .63115 L .907 .602 .11 r
F
.89873 .60511 m .88225 .5785 L .88636 .59719 L F
0 g
.89863 .57852 m
.89873 .60511 L
s
.25 g
.5 Mabswid
.89814 .60415 m
.89873 .60511 L
s
.8798 .56204 m
.89863 .57852 L
s
.87696 .55956 m
.8798 .56204 L
s
.48029 .26668 m .51288 .32055 L .53113 .31612 L .647 .715 .898 r
F
.4549 .27644 m .51288 .32055 L .48029 .26668 L .659 .724 .897 r
F
.25 g
.48499 .31358 m
.49561 .32669 L
s
1 0 0 r
.003 w
.49561 .32669 m
.51288 .32055 L
s
.87305 .41932 m .81979 .44984 L .83224 .46701 L .807 .577 .589 r
F
.86295 .39492 m .81979 .44984 L .87305 .41932 L .78 .571 .617 r
F
.25 g
.5 Mabswid
.87959 .44545 m
.88121 .44471 L
s
0 g
.006 w
.87305 .41932 m
.88121 .44471 L
s
.38758 .93853 m .36125 .86001 L .4045 .9303 L .9 .613 .491 r
F
0 g
.4045 .9303 m
.41981 .91982 L
s
.38758 .93853 m .35128 .86363 L .36125 .86001 L .9 .613 .491 r
F
1 0 0 r
.003 w
.36125 .86001 m
.37078 .85454 L
s
.25 g
.5 Mabswid
.36125 .86001 m
.4045 .9303 L
s
.89813 .63115 m .88933 .61544 L .89699 .65646 L .841 .578 .034 r
F
.89813 .63115 m .88636 .59719 L .88933 .61544 L F
0 g
.006 w
.89813 .63115 m
.89873 .60511 L
s
.25 g
.5 Mabswid
.89769 .62989 m
.89813 .63115 L
s
.88483 .58266 m
.89814 .60415 L
s
.88225 .5785 m
.88483 .58266 L
s
.50717 .25861 m .53113 .31612 L .55016 .31343 L .636 .701 .893 r
F
.48029 .26668 m .53113 .31612 L .50717 .25861 L .647 .715 .898 r
F
1 0 0 r
.003 w
.51288 .32055 m
.53113 .31612 L
s
.25 g
.5 Mabswid
.48029 .26668 m
.48312 .27135 L
s
.48312 .27135 m
.48347 .27193 L
s
.44256 .28798 m
.49431 .33002 L
s
.4549 .27644 m
.48499 .31358 L
s
.86295 .39492 m .80629 .43333 L .81979 .44984 L .78 .571 .617 r
F
.25 g
.81979 .44984 m
.82271 .44816 L
s
.83224 .46701 m
.87959 .44545 L
s
.85079 .37174 m .80629 .43333 L .86295 .39492 L .756 .567 .642 r
F
.25 g
.8713 .42032 m
.87305 .41932 L
s
0 g
.006 w
.86295 .39492 m
.87305 .41932 L
s
.5352 .25238 m .55016 .31343 L .56976 .3125 L .627 .684 .884 r
F
.50717 .25861 m .55016 .31343 L .5352 .25238 L .636 .701 .893 r
F
1 0 0 r
.003 w
.53113 .31612 m
.55016 .31343 L
s
.25 g
.5 Mabswid
.50717 .25861 m
.50758 .2596 L
s
.50758 .2596 m
.5131 .27285 L
s
.5131 .27285 m
.53113 .31612 L
s
.48347 .27193 m
.51288 .32055 L
s
0 g
.006 w
.4201 .29779 m
.43949 .28549 L
s
.85079 .37174 m .79182 .41755 L .80629 .43333 L .756 .567 .642 r
F
.25 g
.5 Mabswid
.80629 .43333 m
.80894 .43153 L
s
.82271 .44816 m
.8713 .42032 L
s
.8365 .35001 m .79182 .41755 L .85079 .37174 L .734 .566 .664 r
F
.25 g
.8611 .39617 m
.86295 .39492 L
s
0 g
.006 w
.85079 .37174 m
.86295 .39492 L
s
.89699 .65646 m .89122 .63307 L .89547 .68084 L .781 .566 0 r
F
.89699 .65646 m .88933 .61544 L .89122 .63307 L F
0 g
.89699 .65646 m
.89813 .63115 L
s
.25 g
.5 Mabswid
.8967 .65488 m
.89699 .65646 L
s
.88863 .60374 m
.89769 .62989 L
s
.88636 .59719 m
.88863 .60374 L
s
.3693 .94432 m .35128 .86363 L .38758 .93853 L .919 .641 .497 r
F
0 g
.006 w
.38758 .93853 m
.4045 .9303 L
s
.3693 .94432 m .34107 .86537 L .35128 .86363 L .919 .641 .497 r
F
1 0 0 r
.003 w
.35128 .86363 m
.36125 .86001 L
s
.25 g
.5 Mabswid
.35128 .86363 m
.38758 .93853 L
s
.56403 .24813 m .56976 .3125 L .58971 .31333 L .623 .666 .871 r
F
.5352 .25238 m .56976 .3125 L .56403 .24813 L .627 .684 .884 r
F
1 0 0 r
.003 w
.55016 .31343 m
.56976 .3125 L
s
.25 g
.5 Mabswid
.5352 .25238 m
.55016 .31343 L
s
.5933 .24598 m .58971 .31333 L .60983 .31589 L .622 .648 .855 r
F
.56403 .24813 m .58971 .31333 L .5933 .24598 L .623 .666 .871 r
F
1 0 0 r
.003 w
.56976 .3125 m
.58971 .31333 L
s
.25 g
.5 Mabswid
.56403 .24813 m
.56976 .3125 L
s
.8365 .35001 m .77647 .40256 L .79182 .41755 L .734 .566 .664 r
F
.25 g
.79182 .41755 m
.79414 .41574 L
s
.82004 .32993 m .77647 .40256 L .8365 .35001 L .716 .566 .684 r
F
.25 g
.84888 .37323 m
.85079 .37174 L
s
0 g
.006 w
.8365 .35001 m
.85079 .37174 L
s
.62265 .24603 m .60983 .31589 L .62994 .32011 L .624 .631 .838 r
F
.5933 .24598 m .60983 .31589 L .62265 .24603 L .622 .648 .855 r
F
1 0 0 r
.003 w
.58971 .31333 m
.60983 .31589 L
s
.25 g
.5 Mabswid
.58971 .31333 m
.5933 .24598 L
s
.89547 .68084 m .89207 .64987 L .89368 .70409 L .749 .575 0 r
F
.89547 .68084 m .89122 .63307 L .89207 .64987 L F
.25 g
.88933 .61544 m
.89125 .62575 L
s
0 g
.006 w
.89547 .68084 m
.89699 .65646 L
s
.25 g
.5 Mabswid
.89529 .67889 m
.89547 .68084 L
s
.65169 .24838 m .62994 .32011 L .64988 .32591 L .629 .616 .819 r
F
.62265 .24603 m .62994 .32011 L .65169 .24838 L .624 .631 .838 r
F
1 0 0 r
.003 w
.60983 .31589 m
.62994 .32011 L
s
.25 g
.5 Mabswid
.60983 .31589 m
.62265 .24603 L
s
0 g
.006 w
.43949 .28549 m
.45561 .27731 L
s
.82004 .32993 m .7603 .38842 L .77647 .40256 L .716 .566 .684 r
F
.25 g
.5 Mabswid
.77647 .40256 m
.78022 .39928 L
s
.80894 .43153 m
.8611 .39617 L
s
.80141 .3117 m .7603 .38842 L .82004 .32993 L .699 .568 .704 r
F
.25 g
.83456 .35171 m
.8365 .35001 L
s
0 g
.006 w
.82004 .32993 m
.8365 .35001 L
s
.68007 .25308 m .64988 .32591 L .66953 .3332 L .636 .603 .799 r
F
.65169 .24838 m .64988 .32591 L .68007 .25308 L .629 .616 .819 r
F
.25 g
.5 Mabswid
.62994 .32011 m
.65169 .24838 L
s
1 0 0 r
.003 w
.62994 .32011 m
.64988 .32591 L
s
.34992 .94748 m .34107 .86537 L .3693 .94432 L .937 .674 .513 r
F
0 g
.006 w
.3693 .94432 m
.38758 .93853 L
s
.34992 .94748 m .33081 .86524 L .34107 .86537 L .937 .674 .513 r
F
1 0 0 r
.003 w
.34107 .86537 m
.35128 .86363 L
s
.25 g
.5 Mabswid
.34107 .86537 m
.3693 .94432 L
s
.70744 .26016 m .66953 .3332 L .68879 .34188 L .646 .592 .78 r
F
.68007 .25308 m .66953 .3332 L .70744 .26016 L .636 .603 .799 r
F
.25 g
.64988 .32591 m
.67915 .25528 L
s
1 0 0 r
.003 w
.64988 .32591 m
.66953 .3332 L
s
.25 g
.5 Mabswid
.67915 .25528 m
.68007 .25308 L
s
.73351 .26962 m .68879 .34188 L .70756 .35184 L .657 .583 .76 r
F
.70744 .26016 m .68879 .34188 L .73351 .26962 L .646 .592 .78 r
F
.25 g
.66953 .3332 m
.70628 .26241 L
s
1 0 0 r
.003 w
.66953 .3332 m
.68879 .34188 L
s
.25 g
.5 Mabswid
.70628 .26241 m
.70744 .26016 L
s
.75801 .28142 m .70756 .35184 L .72578 .36298 L .67 .576 .742 r
F
.73351 .26962 m .70756 .35184 L .75801 .28142 L .657 .583 .76 r
F
1 0 0 r
.003 w
.68879 .34188 m
.70756 .35184 L
s
.25 g
.5 Mabswid
.73212 .27187 m
.73351 .26962 L
s
.7807 .29548 m .72578 .36298 L .74338 .3752 L .683 .571 .723 r
F
.25 g
.70756 .35184 m
.7077 .35165 L
s
.68879 .34188 m
.68914 .34132 L
s
.75801 .28142 m .72578 .36298 L .7807 .29548 L .67 .576 .742 r
F
.25 g
.81815 .33178 m
.82004 .32993 L
s
.68914 .34132 m
.73212 .27187 L
s
1 0 0 r
.003 w
.70756 .35184 m
.72578 .36298 L
s
.25 g
.5 Mabswid
.72578 .36298 m
.72906 .35895 L
s
.75642 .28364 m
.75801 .28142 L
s
.80141 .3117 m .74338 .3752 L .7603 .38842 L .699 .568 .704 r
F
.25 g
.7077 .35165 m
.70853 .35049 L
s
.7603 .38842 m
.76338 .3854 L
s
.7807 .29548 m .74338 .3752 L .80141 .3117 L .683 .571 .723 r
F
.25 g
.79414 .41574 m
.84888 .37323 L
s
0 g
.006 w
.80141 .3117 m
.82004 .32993 L
s
.25 g
.5 Mabswid
.78022 .39928 m
.83456 .35171 L
s
.76338 .3854 m
.81812 .33181 L
s
.81812 .33181 m
.81815 .33178 L
s
.70853 .35049 m
.75642 .28364 L
s
.72906 .35895 m
.77895 .29763 L
s
1 0 0 r
.003 w
.72578 .36298 m
.74338 .3752 L
s
.25 g
.5 Mabswid
.74766 .37051 m
.79956 .31373 L
s
.79956 .31373 m
.7996 .31368 L
s
.7996 .31368 m
.80141 .3117 L
s
.74338 .3752 m
.74766 .37051 L
s
.77901 .29756 m
.7807 .29548 L
s
.77895 .29763 m
.77901 .29756 L
s
1 0 0 r
.003 w
.74338 .3752 m
.7603 .38842 L
s
.7603 .38842 m
.77647 .40256 L
s
0 g
.006 w
.7807 .29548 m
.80141 .3117 L
s
1 0 0 r
.003 w
.77647 .40256 m
.79182 .41755 L
s
.79182 .41755 m
.80629 .43333 L
s
.89368 .70409 m .89194 .66566 L .89173 .72604 L .752 .61 .041 r
F
.89368 .70409 m .89207 .64987 L .89194 .66566 L F
.25 g
.5 Mabswid
.89275 .65035 m
.89529 .67889 L
s
.89122 .63307 m
.89275 .65035 L
s
0 g
.006 w
.89368 .70409 m
.89547 .68084 L
s
.25 g
.5 Mabswid
.89207 .64987 m
.8936 .70151 L
s
.8936 .70151 m
.89368 .70409 L
s
.89301 .63513 m
.8967 .65488 L
s
.89125 .62575 m
.89301 .63513 L
s
1 0 0 r
.003 w
.80629 .43333 m
.81979 .44984 L
s
.81979 .44984 m
.83224 .46701 L
s
.83224 .46701 m
.84359 .48477 L
s
0 g
.006 w
.4549 .27644 m
.48029 .26668 L
s
1 0 0 r
.003 w
.84359 .48477 m
.85376 .50303 L
s
.85376 .50303 m
.86273 .52167 L
s
0 g
.006 w
.75801 .28142 m
.7807 .29548 L
s
.32976 .94788 m .33081 .86524 L .34992 .94748 L .952 .712 .538 r
F
0 g
.34992 .94748 m
.3693 .94432 L
s
.32976 .94788 m .32072 .8633 L .33081 .86524 L .952 .712 .538 r
F
1 0 0 r
.003 w
.33081 .86524 m
.34107 .86537 L
s
.25 g
.5 Mabswid
.33081 .86524 m
.34992 .94748 L
s
1 0 0 r
.003 w
.86273 .52167 m
.87046 .54056 L
s
.87046 .54056 m
.87696 .55956 L
s
0 g
.006 w
.48029 .26668 m
.50717 .25861 L
s
.73351 .26962 m
.75801 .28142 L
s
.89173 .72604 m .89087 .68027 L .88971 .74649 L .788 .665 .114 r
F
.89173 .72604 m .89194 .66566 L .89087 .68027 L F
0 g
.89173 .72604 m
.89368 .70409 L
s
.25 g
.5 Mabswid
.89173 .72604 m
.89174 .72264 L
s
.89174 .72264 m
.89194 .66566 L
s
1 0 0 r
.003 w
.87696 .55956 m
.88225 .5785 L
s
0 g
.006 w
.70744 .26016 m
.73351 .26962 L
s
.50717 .25861 m
.5352 .25238 L
s
1 0 0 r
.003 w
.88225 .5785 m
.88636 .59719 L
s
.30918 .9454 m .32072 .8633 L .32976 .94788 L .963 .752 .571 r
F
0 g
.006 w
.32976 .94788 m
.34992 .94748 L
s
.30918 .9454 m .31099 .85963 L .32072 .8633 L .963 .752 .571 r
F
1 0 0 r
.003 w
.32072 .8633 m
.33081 .86524 L
s
.25 g
.5 Mabswid
.32072 .8633 m
.32976 .94788 L
s
0 g
.006 w
.68007 .25308 m
.70744 .26016 L
s
.5352 .25238 m
.56403 .24813 L
s
1 0 0 r
.003 w
.88636 .59719 m
.88933 .61544 L
s
0 g
.006 w
.65169 .24838 m
.68007 .25308 L
s
.56403 .24813 m
.5933 .24598 L
s
.88971 .74649 m .88887 .69355 L .88766 .76525 L .846 .731 .207 r
F
.88971 .74649 m .89087 .68027 L .88887 .69355 L F
0 g
.88971 .74649 m
.89173 .72604 L
s
.25 g
.5 Mabswid
.88971 .74649 m
.89087 .68027 L
s
0 g
.006 w
.62265 .24603 m
.65169 .24838 L
s
.5933 .24598 m
.62265 .24603 L
s
1 0 0 r
.003 w
.88933 .61544 m
.89122 .63307 L
s
.28854 .93997 m .31099 .85963 L .30918 .9454 L .967 .79 .612 r
F
.28854 .93997 m .3018 .85434 L .31099 .85963 L F
1 0 0 r
.31099 .85963 m
.32072 .8633 L
s
.25 g
.5 Mabswid
.30918 .9454 m
.31099 .85963 L
s
0 g
.006 w
.30918 .9454 m
.32976 .94788 L
s
1 0 0 r
.003 w
.89122 .63307 m
.89207 .64987 L
s
.88766 .76525 m .88596 .70536 L .88561 .78212 L .909 .789 .307 r
F
.88766 .76525 m .88887 .69355 L .88596 .70536 L F
0 g
.006 w
.88766 .76525 m
.88971 .74649 L
s
.25 g
.5 Mabswid
.88766 .76525 m
.88887 .69355 L
s
.26828 .93158 m .3018 .85434 L .28854 .93997 L .964 .825 .658 r
F
.26828 .93158 m .2933 .84757 L .3018 .85434 L F
1 0 0 r
.003 w
.3018 .85434 m
.31099 .85963 L
s
.89194 .66566 m
.89207 .64987 L
s
0 g
.006 w
.28854 .93997 m
.30918 .9454 L
s
1 0 0 r
.003 w
.89087 .68027 m
.89194 .66566 L
s
.24879 .92028 m .2933 .84757 L .26828 .93158 L .953 .853 .705 r
F
.25 g
.5 Mabswid
.28854 .93997 m
.28901 .93696 L
s
.24879 .92028 m .28562 .83946 L .2933 .84757 L .953 .853 .705 r
F
.25 g
.28901 .93696 m
.3018 .85434 L
s
1 0 0 r
.003 w
.2933 .84757 m
.3018 .85434 L
s
.25 g
.5 Mabswid
.2915 .85361 m
.2933 .84757 L
s
.88561 .78212 m .88215 .71562 L .88358 .7969 L .959 .826 .396 r
F
.88561 .78212 m .88596 .70536 L .88215 .71562 L F
0 g
.006 w
.88561 .78212 m
.88766 .76525 L
s
.25 g
.5 Mabswid
.88561 .78212 m
.88596 .70536 L
s
0 g
.006 w
.26828 .93158 m
.28854 .93997 L
s
1 0 0 r
.003 w
.88887 .69355 m
.89087 .68027 L
s
.23051 .90615 m .28562 .83946 L .24879 .92028 L .935 .874 .752 r
F
.25 g
.5 Mabswid
.26828 .93158 m
.26915 .92866 L
s
.23051 .90615 m .27886 .83018 L .28562 .83946 L .935 .874 .752 r
F
.25 g
.26915 .92866 m
.2915 .85361 L
s
1 0 0 r
.003 w
.28562 .83946 m
.2933 .84757 L
s
.25 g
.5 Mabswid
.28331 .84453 m
.28562 .83946 L
s
1 0 0 r
.003 w
.88596 .70536 m
.88887 .69355 L
s
0 g
.006 w
.24879 .92028 m
.26828 .93158 L
s
.88358 .7969 m .8774 .72424 L .88151 .8094 L .989 .837 .462 r
F
.88358 .7969 m .88215 .71562 L .8774 .72424 L F
0 g
.88358 .7969 m
.88561 .78212 L
s
.25 g
.5 Mabswid
.88215 .71562 m
.88358 .7969 L
s
.21383 .88938 m .27886 .83018 L .23051 .90615 L .911 .885 .795 r
F
.25 g
.24879 .92028 m
.25006 .9175 L
s
.21383 .88938 m .27311 .81986 L .27886 .83018 L .911 .885 .795 r
F
.25 g
.25006 .9175 m
.28331 .84453 L
s
1 0 0 r
.003 w
.27886 .83018 m
.28562 .83946 L
s
.25 g
.5 Mabswid
.27623 .83432 m
.27886 .83018 L
s
1 0 0 r
.003 w
.88215 .71562 m
.88596 .70536 L
s
0 g
.006 w
.23051 .90615 m
.24879 .92028 L
s
.19914 .87018 m .27311 .81986 L .21383 .88938 L .881 .888 .833 r
F
.25 g
.5 Mabswid
.23051 .90615 m
.23215 .90357 L
s
.19914 .87018 m .26841 .80865 L .27311 .81986 L .881 .888 .833 r
F
.25 g
.23215 .90357 m
.27623 .83432 L
s
1 0 0 r
.003 w
.27311 .81986 m
.27886 .83018 L
s
.25 g
.5 Mabswid
.27033 .82312 m
.27311 .81986 L
s
.88151 .8094 m .87171 .73121 L .87936 .81943 L 1 .826 .502 r
F
.88151 .8094 m .8774 .72424 L .87171 .73121 L F
0 g
.006 w
.88151 .8094 m
.88358 .7969 L
s
.25 g
.5 Mabswid
.8774 .72424 m
.88151 .8094 L
s
1 0 0 r
.003 w
.8774 .72424 m
.88215 .71562 L
s
0 g
.006 w
.21383 .88938 m
.23051 .90615 L
s
.18678 .84883 m .26841 .80865 L .19914 .87018 L .847 .882 .865 r
F
.25 g
.5 Mabswid
.21383 .88938 m
.21583 .88704 L
s
.18678 .84883 m .26483 .79668 L .26841 .80865 L .847 .882 .865 r
F
.25 g
.21583 .88704 m
.27033 .82312 L
s
1 0 0 r
.003 w
.26841 .80865 m
.27311 .81986 L
s
.25 g
.5 Mabswid
.26567 .81109 m
.26841 .80865 L
s
0 g
.006 w
.19914 .87018 m
.21383 .88938 L
s
.87936 .81943 m .86504 .73651 L .87702 .82679 L .997 .798 .517 r
F
.87936 .81943 m .87171 .73121 L .86504 .73651 L F
0 g
.87936 .81943 m
.88151 .8094 L
s
.25 g
.5 Mabswid
.87171 .73121 m
.87936 .81943 L
s
1 0 0 r
.003 w
.87171 .73121 m
.8774 .72424 L
s
.17705 .82566 m .26483 .79668 L .18678 .84883 L .81 .868 .89 r
F
.25 g
.5 Mabswid
.19914 .87018 m
.20145 .86813 L
s
.17705 .82566 m .26242 .78407 L .26483 .79668 L .81 .868 .89 r
F
.25 g
.20145 .86813 m
.26567 .81109 L
s
1 0 0 r
.003 w
.26483 .79668 m
.26841 .80865 L
s
.25 g
.5 Mabswid
.26228 .79839 m
.26483 .79668 L
s
0 g
.006 w
.18678 .84883 m
.19914 .87018 L
s
.17018 .80103 m .26242 .78407 L .17705 .82566 L .772 .847 .908 r
F
.25 g
.5 Mabswid
.18678 .84883 m
.18935 .84711 L
s
.17018 .80103 m .26122 .77091 L .26242 .78407 L .772 .847 .908 r
F
.25 g
.18935 .84711 m
.26228 .79839 L
s
1 0 0 r
.003 w
.26242 .78407 m
.26483 .79668 L
s
.25 g
.5 Mabswid
.26022 .78514 m
.26242 .78407 L
s
.87702 .82679 m .85737 .74017 L .87437 .83132 L .986 .762 .513 r
F
.87702 .82679 m .86504 .73651 L .85737 .74017 L F
0 g
.006 w
.87702 .82679 m
.87936 .81943 L
s
.25 g
.5 Mabswid
.86504 .73651 m
.87702 .82679 L
s
1 0 0 r
.003 w
.86504 .73651 m
.87171 .73121 L
s
0 g
.006 w
.17705 .82566 m
.18678 .84883 L
s
.16638 .77532 m .26122 .77091 L .17018 .80103 L .733 .82 .918 r
F
.25 g
.5 Mabswid
.17705 .82566 m
.17983 .8243 L
s
.17983 .8243 m
.26022 .78514 L
s
.16638 .77532 m .26132 .75733 L .26122 .77091 L .733 .82 .918 r
F
1 0 0 r
.003 w
.26122 .77091 m
.26242 .78407 L
s
.25 g
.5 Mabswid
.25951 .77148 m
.26122 .77091 L
s
0 g
.006 w
.17018 .80103 m
.17705 .82566 L
s
.87437 .83132 m .85737 .74017 L .84868 .74226 L .972 .72 .494 r
F
1 0 0 r
.003 w
.85737 .74017 m
.86504 .73651 L
s
.87437 .83132 m .84868 .74226 L .87126 .83287 L .972 .72 .494 r
F
0 g
.006 w
.87437 .83132 m
.87702 .82679 L
s
.25 g
.5 Mabswid
.85737 .74017 m
.87437 .83132 L
s
.16576 .74895 m .26132 .75733 L .16638 .77532 L .696 .788 .922 r
F
.25 g
.16638 .77532 m
.26021 .75754 L
s
.17018 .80103 m
.17312 .80005 L
s
.17312 .80005 m
.25951 .77148 L
s
.16576 .74895 m .26278 .74342 L .26132 .75733 L .696 .788 .922 r
F
1 0 0 r
.003 w
.26122 .77091 m
.26132 .75733 L
s
.25 g
.5 Mabswid
.26021 .75754 m
.26132 .75733 L
s
0 g
.006 w
.16638 .77532 m
.17018 .80103 L
s
.87126 .83287 m .84868 .74226 L .83894 .74285 L .955 .673 .461 r
F
1 0 0 r
.003 w
.84868 .74226 m
.85737 .74017 L
s
.16839 .72232 m .26278 .74342 L .16576 .74895 L .66 .753 .919 r
F
0 g
.006 w
.16576 .74895 m
.16638 .77532 L
s
.16839 .72232 m .26569 .72931 L .26278 .74342 L .66 .753 .919 r
F
1 0 0 r
.003 w
.26132 .75733 m
.26278 .74342 L
s
.25 g
.5 Mabswid
.16576 .74895 m
.26278 .74342 L
s
.8675 .83134 m .83894 .74285 L .82815 .74204 L .937 .621 .414 r
F
.87126 .83287 m .83894 .74285 L .8675 .83134 L .955 .673 .461 r
F
.25 g
.84868 .74226 m
.87126 .83287 L
s
1 0 0 r
.003 w
.83894 .74285 m
.84868 .74226 L
s
0 g
.006 w
.87126 .83287 m
.87437 .83132 L
s
.17427 .69586 m .26569 .72931 L .16839 .72232 L .628 .716 .91 r
F
0 g
.16576 .74895 m
.16839 .72232 L
s
.17427 .69586 m .27017 .71513 L .26569 .72931 L .628 .716 .91 r
F
1 0 0 r
.003 w
.26278 .74342 m
.26569 .72931 L
s
.25 g
.5 Mabswid
.16839 .72232 m
.26569 .72931 L
s
.86289 .82667 m .82815 .74204 L .81632 .73992 L .914 .56 .352 r
F
.8675 .83134 m .82815 .74204 L .86289 .82667 L .937 .621 .414 r
F
.25 g
.83894 .74285 m
.86663 .82865 L
s
1 0 0 r
.003 w
.82815 .74204 m
.83894 .74285 L
s
0 g
.006 w
.8675 .83134 m
.87126 .83287 L
s
.25 g
.5 Mabswid
.86663 .82865 m
.8675 .83134 L
s
.18336 .66995 m .27017 .71513 L .17427 .69586 L .601 .679 .896 r
F
0 g
.006 w
.16839 .72232 m
.17427 .69586 L
s
.18336 .66995 m .2763 .70105 L .27017 .71513 L .601 .679 .896 r
F
1 0 0 r
.003 w
.26569 .72931 m
.27017 .71513 L
s
.25 g
.5 Mabswid
.17427 .69586 m
.27017 .71513 L
s
.77642 .72835 m .7896 .73215 L .77476 .72667 L .773 .271 .003 r
F
.85719 .81885 m .81691 .74105 L .80367 .7369 L .885 .487 .268 r
F
.80367 .7369 m .81632 .73992 L .80347 .73659 L F
.81691 .74105 m .81632 .73992 L .80367 .7369 L F
.85719 .81885 m .80577 .74012 L .85019 .80795 L F
.80577 .74012 m .80443 .73806 L .80587 .74026 L F
.80577 .74012 m .80587 .74026 L .85019 .80795 L F
.80443 .73806 m .8046 .73832 L .85019 .80795 L F
.80367 .7369 m .8038 .7371 L .85019 .80795 L F
.75561 .71894 m .75896 .72026 L .75487 .71848 L .478 0 0 r
F
.85019 .80795 m .80594 .74036 L .79113 .73406 L .842 .395 .156 r
F
.85019 .80795 m .79113 .73406 L .84164 .79411 L F
.79113 .73406 m .8038 .7371 L .7896 .73215 L F
.80443 .73806 m .80367 .7369 L .8046 .73832 L .885 .487 .268 r
F
.80594 .74036 m .8038 .7371 L .79113 .73406 L .842 .395 .156 r
F
.79113 .73406 m .7896 .73215 L .79145 .73434 L F
.79113 .73406 m .79145 .73434 L .84164 .79411 L F
.84054 .79301 m .80382 .74913 L .7859 .73791 L .773 .271 .003 r
F
.80382 .74913 m .79144 .73434 L .7859 .73791 L F
.7859 .73791 m .79144 .73434 L .77642 .72835 L F
.79144 .73434 m .78078 .72972 L .77642 .72835 L F
.83993 .79208 m .78999 .73261 L .84054 .79301 L F
.78999 .73261 m .7896 .73215 L .77642 .72835 L F
.84164 .79411 m .83993 .79208 L .84054 .79301 L F
.84164 .79411 m .77551 .72743 L .83132 .77757 L F
.77551 .72743 m .77476 .72667 L .77596 .72775 L F
.77551 .72743 m .77596 .72775 L .83132 .77757 L F
.82975 .77633 m .77595 .72775 L .75896 .72026 L .66 .105 0 r
F
.82948 .77591 m .77476 .72667 L .82975 .77633 L F
.83132 .77757 m .82948 .77591 L .82975 .77633 L F
.83132 .77757 m .75896 .72026 L .81904 .75862 L F
.81773 .75784 m .75487 .71848 L .74235 .71304 L .478 0 0 r
F
.81783 .7579 m .8177 .75782 L .81773 .75784 L F
.8177 .75782 m .75487 .71848 L .81773 .75784 L F
.77595 .72775 m .77476 .72667 L .75896 .72026 L .66 .105 0 r
F
.81728 .75756 m .75947 .72058 L .75561 .71894 L .478 0 0 r
F
.81783 .7579 m .81725 .75753 L .81728 .75756 L F
.81725 .75753 m .75947 .72058 L .81728 .75756 L F
.75947 .72058 m .75896 .72026 L .75561 .71894 L F
.80367 .7369 m .80347 .73659 L .8038 .7371 L .885 .487 .268 r
F
.8038 .7371 m .80347 .73659 L .7896 .73215 L .842 .395 .156 r
F
.79144 .73434 m .78999 .73261 L .78078 .72972 L .773 .271 .003 r
F
.74235 .71304 m .75487 .71848 L .74223 .71297 L .478 0 0 r
F
.81904 .75862 m .81776 .7578 L .81783 .7579 L F
.81776 .7578 m .75896 .72026 L .81783 .7579 L F
1 0 0 r
.003 w
.81748 .74012 m
.82815 .74204 L
s
.25 g
.5 Mabswid
.82815 .74204 m
.82825 .74227 L
s
.82825 .74227 m
.82901 .74413 L
s
.82901 .74413 m
.83014 .74688 L
s
.86289 .82667 m .81632 .73992 L .85719 .81885 L .914 .56 .352 r
F
.25 g
.83014 .74688 m
.86181 .82404 L
s
1 0 0 r
.003 w
.81632 .73992 m
.81748 .74012 L
s
.25 g
.5 Mabswid
.8559 .81635 m
.85719 .81885 L
s
.81935 .74577 m
.8559 .81635 L
s
.81792 .74301 m
.81935 .74577 L
s
.81691 .74105 m
.81792 .74301 L
s
.81632 .73992 m
.81691 .74105 L
s
0 g
.006 w
.86289 .82667 m
.8675 .83134 L
s
.25 g
.5 Mabswid
.86181 .82404 m
.86289 .82667 L
s
1 0 0 r
.003 w
.80347 .73659 m
.81632 .73992 L
s
.19558 .64498 m .2763 .70105 L .18336 .66995 L .579 .644 .879 r
F
0 g
.006 w
.17427 .69586 m
.18336 .66995 L
s
.19558 .64498 m .28417 .68726 L .2763 .70105 L .579 .644 .879 r
F
1 0 0 r
.003 w
.27017 .71513 m
.2763 .70105 L
s
.25 g
.5 Mabswid
.18336 .66995 m
.2763 .70105 L
s
.80403 .73744 m
.80464 .73839 L
s
.80464 .73839 m
.80594 .74036 L
s
.80594 .74036 m
.81706 .75736 L
s
.80347 .73659 m
.8038 .7371 L
s
.8038 .7371 m
.80403 .73744 L
s
1 0 0 r
.003 w
.7896 .73215 m
.80347 .73659 L
s
0 g
.006 w
.85719 .81885 m
.86289 .82667 L
s
.21079 .62131 m .28417 .68726 L .19558 .64498 L .563 .611 .859 r
F
0 g
.18336 .66995 m
.19558 .64498 L
s
.21079 .62131 m .29385 .67396 L .28417 .68726 L .563 .611 .859 r
F
1 0 0 r
.003 w
.2763 .70105 m
.28417 .68726 L
s
.25 g
.5 Mabswid
.19558 .64498 m
.28417 .68726 L
s
.78999 .73261 m
.79035 .73303 L
s
.79035 .73303 m
.79145 .73434 L
s
.79145 .73434 m
.8035 .7487 L
s
.7896 .73215 m
.78999 .73261 L
s
1 0 0 r
.003 w
.77476 .72667 m
.7896 .73215 L
s
.22884 .59928 m .29385 .67396 L .21079 .62131 L .553 .583 .838 r
F
0 g
.006 w
.19558 .64498 m
.21079 .62131 L
s
.22884 .59928 m .30538 .66138 L .29385 .67396 L .553 .583 .838 r
F
1 0 0 r
.003 w
.28417 .68726 m
.29385 .67396 L
s
.25 g
.5 Mabswid
.21079 .62131 m
.29385 .67396 L
s
0 g
.006 w
.85019 .80795 m
.85719 .81885 L
s
.25 g
.5 Mabswid
.77495 .72684 m
.77596 .72775 L
s
.77596 .72775 m
.78881 .73932 L
s
.77476 .72667 m
.77495 .72684 L
s
1 0 0 r
.003 w
.75896 .72026 m
.77476 .72667 L
s
.24953 .5792 m .30538 .66138 L .22884 .59928 L .549 .56 .818 r
F
0 g
.006 w
.21079 .62131 m
.22884 .59928 L
s
.24953 .5792 m .31878 .64975 L .30538 .66138 L .549 .56 .818 r
F
1 0 0 r
.003 w
.29385 .67396 m
.30538 .66138 L
s
.25 g
.5 Mabswid
.22884 .59928 m
.30538 .66138 L
s
.75896 .72026 m
.75948 .72059 L
s
.27265 .56135 m .31878 .64975 L .24953 .5792 L .551 .544 .8 r
F
0 g
.006 w
.22884 .59928 m
.24953 .5792 L
s
.27265 .56135 m .33401 .63932 L .31878 .64975 L .551 .544 .8 r
F
1 0 0 r
.003 w
.30538 .66138 m
.31878 .64975 L
s
.25 g
.5 Mabswid
.24953 .5792 m
.31878 .64975 L
s
0 g
.006 w
.84164 .79411 m
.85019 .80795 L
s
.29797 .54599 m .33401 .63932 L .27265 .56135 L .558 .534 .785 r
F
0 g
.24953 .5792 m
.27265 .56135 L
s
.29797 .54599 m .35099 .6303 L .33401 .63932 L .558 .534 .785 r
F
1 0 0 r
.003 w
.31878 .64975 m
.33401 .63932 L
s
.25 g
.5 Mabswid
.27265 .56135 m
.33401 .63932 L
s
.80464 .73767 m .74223 .71297 L .72458 .70491 L 0 .342 .7 r
F
.25 g
.75948 .72059 m
.76064 .72133 L
s
.81904 .75862 m .74223 .71297 L .80464 .73767 L .478 0 0 r
F
.25 g
.74223 .71297 m
.74229 .713 L
s
.32525 .53333 m .35099 .6303 L .29797 .54599 L .568 .531 .773 r
F
0 g
.006 w
.27265 .56135 m
.29797 .54599 L
s
.32525 .53333 m .36961 .62289 L .35099 .6303 L .568 .531 .773 r
F
1 0 0 r
.003 w
.33401 .63932 m
.35099 .6303 L
s
.25 g
.5 Mabswid
.29797 .54599 m
.35099 .6303 L
s
.78799 .71517 m .72458 .70491 L .70603 .69617 L .039 .534 .88 r
F
.25 g
.74229 .713 m
.74439 .71383 L
s
.80464 .73767 m .72458 .70491 L .78799 .71517 L 0 .342 .7 r
F
1 0 0 r
.003 w
.72458 .70491 m
.74223 .71297 L
s
.25 g
.5 Mabswid
.80327 .73713 m
.80464 .73767 L
s
.80253 .73683 m
.80327 .73713 L
s
.80251 .73683 m
.80253 .73683 L
s
0 g
.006 w
.83132 .77757 m
.84164 .79411 L
s
.35421 .52359 m .36961 .62289 L .32525 .53333 L .581 .533 .766 r
F
0 g
.29797 .54599 m
.32525 .53333 L
s
.35421 .52359 m .38971 .61727 L .36961 .62289 L .581 .533 .766 r
F
1 0 0 r
.003 w
.35099 .6303 m
.36961 .62289 L
s
.25 g
.5 Mabswid
.32525 .53333 m
.36961 .62289 L
s
.76906 .69166 m .70603 .69617 L .68659 .68688 L .257 .649 .964 r
F
.78799 .71517 m .70603 .69617 L .76906 .69166 L .039 .534 .88 r
F
1 0 0 r
.003 w
.70603 .69617 m
.72458 .70491 L
s
.25 g
.5 Mabswid
.78581 .71482 m
.78799 .71517 L
s
.72458 .70491 m
.78581 .71482 L
s
.74439 .71383 m
.80251 .73683 L
s
.3846 .51691 m .38971 .61727 L .35421 .52359 L .595 .54 .763 r
F
0 g
.006 w
.32525 .53333 m
.35421 .52359 L
s
.3846 .51691 m .4111 .61356 L .38971 .61727 L .595 .54 .763 r
F
1 0 0 r
.003 w
.36961 .62289 m
.38971 .61727 L
s
.74782 .66768 m .68659 .68688 L .66627 .67719 L .408 .702 .982 r
F
.76906 .69166 m .68659 .68688 L .74782 .66768 L .257 .649 .964 r
F
1 0 0 r
.68659 .68688 m
.70603 .69617 L
s
.25 g
.5 Mabswid
.70603 .69617 m
.76906 .69166 L
s
0 g
.006 w
.81904 .75862 m
.83132 .77757 L
s
.41612 .51342 m .4111 .61356 L .3846 .51691 L .609 .552 .765 r
F
.25 g
.5 Mabswid
.35421 .52359 m
.38971 .61727 L
s
.41612 .51342 m .43356 .61181 L .4111 .61356 L .609 .552 .765 r
F
1 0 0 r
.003 w
.38971 .61727 m
.4111 .61356 L
s
.25 g
.5 Mabswid
.3846 .51691 m
.4111 .61356 L
s
0 g
.006 w
.35421 .52359 m
.3846 .51691 L
s
.72436 .64381 m .66627 .67719 L .64511 .6673 L .505 .717 .967 r
F
.25 g
.5 Mabswid
.68659 .68688 m
.69004 .68579 L
s
.74782 .66768 m .66627 .67719 L .72436 .64381 L .408 .702 .982 r
F
.25 g
.69004 .68579 m
.74782 .66768 L
s
1 0 0 r
.003 w
.66627 .67719 m
.68659 .68688 L
s
.44848 .5132 m .43356 .61181 L .41612 .51342 L .622 .566 .771 r
F
.44848 .5132 m .45684 .61205 L .43356 .61181 L F
1 0 0 r
.4111 .61356 m
.43356 .61181 L
s
.25 g
.5 Mabswid
.41612 .51342 m
.43356 .61181 L
s
.6988 .62064 m .64511 .6673 L .62315 .65745 L .567 .713 .94 r
F
.25 g
.66627 .67719 m
.67004 .67502 L
s
.72436 .64381 m .64511 .6673 L .6988 .62064 L .505 .717 .967 r
F
1 0 0 r
.003 w
.64511 .6673 m
.66627 .67719 L
s
.25 g
.5 Mabswid
.72231 .645 m
.72436 .64381 L
s
0 g
.006 w
.3846 .51691 m
.41612 .51342 L
s
.48136 .51629 m .45684 .61205 L .44848 .5132 L .633 .584 .781 r
F
.48136 .51629 m .4807 .6142 L .45684 .61205 L F
1 0 0 r
.003 w
.43356 .61181 m
.45684 .61205 L
s
.25 g
.5 Mabswid
.44848 .5132 m
.45684 .61205 L
s
.67132 .59869 m .62315 .65745 L .60046 .64788 L .605 .701 .911 r
F
.25 g
.64511 .6673 m
.64911 .66383 L
s
.67004 .67502 m
.67295 .67335 L
s
.6988 .62064 m .62315 .65745 L .67132 .59869 L .567 .713 .94 r
F
.25 g
.67295 .67335 m
.72231 .645 L
s
1 0 0 r
.003 w
.62315 .65745 m
.64511 .6673 L
s
.25 g
.5 Mabswid
.69688 .6223 m
.6988 .62064 L
s
0 g
.006 w
.80464 .73767 m
.81904 .75862 L
s
.51443 .52268 m .4807 .6142 L .48136 .51629 L .641 .603 .795 r
F
.51443 .52268 m .5049 .61816 L .4807 .6142 L F
1 0 0 r
.003 w
.45684 .61205 m
.4807 .6142 L
s
.25 g
.5 Mabswid
.4807 .6142 m
.48136 .51629 L
s
.64215 .57847 m .60046 .64788 L .57714 .63888 L .629 .683 .882 r
F
.25 g
.62315 .65745 m
.62728 .65241 L
s
.67132 .59869 m .60046 .64788 L .64215 .57847 L .605 .701 .911 r
F
1 0 0 r
.003 w
.60046 .64788 m
.62315 .65745 L
s
.25 g
.5 Mabswid
.66954 .60085 m
.67132 .59869 L
s
.64911 .66383 m
.69688 .6223 L
s
.54738 .53227 m .5049 .61816 L .51443 .52268 L .646 .623 .812 r
F
.54738 .53227 m .52918 .62375 L .5049 .61816 L F
1 0 0 r
.003 w
.4807 .6142 m
.5049 .61816 L
s
.25 g
.5 Mabswid
.5049 .61816 m
.51443 .52268 L
s
.61157 .56043 m .57714 .63888 L .55333 .63075 L .641 .664 .856 r
F
.25 g
.60046 .64788 m
.60459 .641 L
s
.64215 .57847 m .57714 .63888 L .61157 .56043 L .629 .683 .882 r
F
1 0 0 r
.003 w
.57714 .63888 m
.60046 .64788 L
s
.25 g
.5 Mabswid
.64063 .58101 m
.64215 .57847 L
s
.62728 .65241 m
.66954 .60085 L
s
.57987 .54493 m .52918 .62375 L .54738 .53227 L .647 .643 .832 r
F
.57987 .54493 m .55333 .63075 L .52918 .62375 L F
1 0 0 r
.003 w
.5049 .61816 m
.52918 .62375 L
s
.25 g
.5 Mabswid
.52918 .62375 m
.54738 .53227 L
s
.61157 .56043 m .55333 .63075 L .57987 .54493 L .641 .664 .856 r
F
.25 g
.57887 .54817 m
.57987 .54493 L
s
.55333 .63075 m
.57887 .54817 L
s
1 0 0 r
.003 w
.52918 .62375 m
.55333 .63075 L
s
.55333 .63075 m
.57714 .63888 L
s
.25 g
.5 Mabswid
.57714 .63888 m
.58113 .62979 L
s
.58113 .62979 m
.61029 .56334 L
s
.61029 .56334 m
.61157 .56043 L
s
.60459 .641 m
.64063 .58101 L
s
0 g
.006 w
.41612 .51342 m
.44848 .5132 L
s
.78799 .71517 m
.80464 .73767 L
s
.44848 .5132 m
.48136 .51629 L
s
.48136 .51629 m
.51443 .52268 L
s
.76906 .69166 m
.78799 .71517 L
s
.51443 .52268 m
.54738 .53227 L
s
.74782 .66768 m
.76906 .69166 L
s
.54738 .53227 m
.57987 .54493 L
s
.72436 .64381 m
.74782 .66768 L
s
.57987 .54493 m
.61157 .56043 L
s
.6988 .62064 m
.72436 .64381 L
s
.61157 .56043 m
.64215 .57847 L
s
.67132 .59869 m
.6988 .62064 L
s
.64215 .57847 m
.67132 .59869 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.313, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open]]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[%, ViewPoint \[Rule] {3, \(-.4\), .8}, Boxed \[Rule] False]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.04084 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.143646 1.17891 0 1.17891 [
[ 0 0 0 0 ]
[ 1 1.04084 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.04084 L
0 1.04084 L
closepath
clip
newpath
.59816 .41337 m .56178 .43501 L .57284 .39701 L .917 .616 .459 r
F
.59816 .41337 m .57542 .45392 L .56178 .43501 L F
.62247 .43117 m .57542 .45392 L .59816 .41337 L .893 .635 .541 r
F
.57284 .39701 m .5476 .41666 L .54686 .382 L .927 .571 .332 r
F
.57284 .39701 m .56178 .43501 L .5476 .41666 L F
0 g
.006 w
.57284 .39701 m
.59816 .41337 L
s
.25 g
.5 Mabswid
.56178 .43501 m
.57284 .39701 L
s
.62247 .43117 m .58841 .47337 L .57542 .45392 L .893 .635 .541 r
F
.64549 .45047 m .58841 .47337 L .62247 .43117 L .866 .64 .595 r
F
.25 g
.59744 .41465 m
.59816 .41337 L
s
0 g
.006 w
.59816 .41337 m
.62247 .43117 L
s
.54686 .382 m .53297 .39895 L .52052 .36821 L .895 .473 .133 r
F
.54686 .382 m .5476 .41666 L .53297 .39895 L F
0 g
.54686 .382 m
.57284 .39701 L
s
.25 g
.5 Mabswid
.54686 .382 m
.5476 .41666 L
s
.64549 .45047 m .60068 .49331 L .58841 .47337 L .866 .64 .595 r
F
.25 g
.58841 .47337 m
.58922 .47237 L
s
.57542 .45392 m
.59744 .41465 L
s
.6669 .4713 m .60068 .49331 L .64549 .45047 L .838 .638 .632 r
F
.25 g
.62141 .43249 m
.62247 .43117 L
s
0 g
.006 w
.62247 .43117 m
.64549 .45047 L
s
.52052 .36821 m .51803 .3819 L .49416 .35552 L .772 .294 0 r
F
.52052 .36821 m .53297 .39895 L .51803 .3819 L F
0 g
.52052 .36821 m
.54686 .382 L
s
.25 g
.5 Mabswid
.52052 .36821 m
.53297 .39895 L
s
.6669 .4713 m .61211 .51369 L .60068 .49331 L .838 .638 .632 r
F
.25 g
.60068 .49331 m
.60141 .4926 L
s
.68642 .49367 m .61211 .51369 L .6669 .4713 L .812 .631 .657 r
F
.25 g
.58922 .47237 m
.62141 .43249 L
s
.60141 .4926 m
.64409 .4518 L
s
.64409 .4518 m
.64549 .45047 L
s
0 g
.006 w
.64549 .45047 m
.6669 .4713 L
s
.68642 .49367 m .62261 .53449 L .61211 .51369 L .812 .631 .657 r
F
.25 g
.5 Mabswid
.61211 .51369 m
.61366 .51249 L
s
.70379 .51752 m .62261 .53449 L .68642 .49367 L .787 .62 .674 r
F
.25 g
.61366 .51249 m
.66521 .47261 L
s
.66521 .47261 m
.6669 .4713 L
s
0 g
.006 w
.6669 .4713 m
.68642 .49367 L
s
.49416 .35552 m .50291 .36556 L .4681 .34377 L .53 .041 0 r
F
.49416 .35552 m .51803 .3819 L .50291 .36556 L F
0 g
.49416 .35552 m
.52052 .36821 L
s
.70379 .51752 m .63204 .55567 L .62261 .53449 L .787 .62 .674 r
F
.25 g
.5 Mabswid
.62261 .53449 m
.62266 .53446 L
s
.71877 .54278 m .63204 .55567 L .70379 .51752 L .764 .608 .685 r
F
.25 g
.62266 .53446 m
.68447 .49491 L
s
.68447 .49491 m
.68642 .49367 L
s
0 g
.006 w
.68642 .49367 m
.70379 .51752 L
s
.4681 .34377 m .48777 .34995 L .44264 .3328 L 0 .207 .712 r
F
.4681 .34377 m .50291 .36556 L .48777 .34995 L F
0 g
.4924 .35473 m
.49416 .35552 L
s
.25 g
.5 Mabswid
.4681 .34377 m
.46925 .34449 L
s
.51656 .38027 m
.51803 .3819 L
s
.49416 .35552 m
.51656 .38027 L
s
.71877 .54278 m .64026 .57718 L .63204 .55567 L .764 .608 .685 r
F
.73116 .56934 m .64026 .57718 L .71877 .54278 L .742 .594 .692 r
F
.25 g
.63204 .55567 m
.70162 .51867 L
s
.70162 .51867 m
.70379 .51752 L
s
0 g
.006 w
.70379 .51752 m
.71877 .54278 L
s
.44264 .3328 m .47282 .33511 L .4181 .32244 L .008 .388 .847 r
F
.44264 .3328 m .48777 .34995 L .47282 .33511 L F
0 g
.44264 .3328 m
.4681 .34377 L
s
.25 g
.5 Mabswid
.44264 .3328 m
.44416 .33337 L
s
.50044 .36401 m
.50291 .36556 L
s
.46925 .34449 m
.50044 .36401 L
s
.73116 .56934 m .64712 .59899 L .64026 .57718 L .742 .594 .692 r
F
.74077 .59703 m .64712 .59899 L .73116 .56934 L .722 .579 .694 r
F
.25 g
.64026 .57718 m
.71643 .54381 L
s
.71643 .54381 m
.71877 .54278 L
s
0 g
.006 w
.71877 .54278 m
.73116 .56934 L
s
.74077 .59703 m .65247 .62102 L .64712 .59899 L .722 .579 .694 r
F
.74747 .62568 m .65247 .62102 L .74077 .59703 L .703 .563 .693 r
F
.25 g
.5 Mabswid
.64712 .59899 m
.7287 .57021 L
s
.7287 .57021 m
.73116 .56934 L
s
0 g
.006 w
.73116 .56934 m
.74077 .59703 L
s
.4181 .32244 m .45826 .32103 L .39476 .31253 L .183 .507 .911 r
F
.4181 .32244 m .47282 .33511 L .45826 .32103 L F
0 g
.4181 .32244 m
.44264 .3328 L
s
.25 g
.5 Mabswid
.4181 .32244 m
.41996 .32287 L
s
.41996 .32287 m
.47282 .33511 L
s
.48411 .34856 m
.48777 .34995 L
s
.44416 .33337 m
.48411 .34856 L
s
1 0 0 r
.003 w
.63204 .55567 m
.64026 .57718 L
s
.64026 .57718 m
.64712 .59899 L
s
.62261 .53449 m
.63204 .55567 L
s
.74747 .62568 m .65615 .64319 L .65247 .62102 L .703 .563 .693 r
F
1 0 0 r
.64712 .59899 m
.65247 .62102 L
s
.25 g
.5 Mabswid
.65247 .62102 m
.74077 .59703 L
s
1 0 0 r
.003 w
.61211 .51369 m
.62261 .53449 L
s
.75114 .65505 m .65615 .64319 L .74747 .62568 L .686 .546 .689 r
F
0 g
.006 w
.74077 .59703 m
.74747 .62568 L
s
.75114 .65505 m .658 .66538 L .65615 .64319 L .686 .546 .689 r
F
1 0 0 r
.003 w
.65247 .62102 m
.65615 .64319 L
s
.25 g
.5 Mabswid
.65615 .64319 m
.74747 .62568 L
s
1 0 0 r
.003 w
.60068 .49331 m
.61211 .51369 L
s
.75171 .68489 m .658 .66538 L .75114 .65505 L .672 .529 .682 r
F
0 g
.006 w
.74747 .62568 m
.75114 .65505 L
s
.75171 .68489 m .65789 .68748 L .658 .66538 L .672 .529 .682 r
F
1 0 0 r
.003 w
.65615 .64319 m
.658 .66538 L
s
.25 g
.5 Mabswid
.658 .66538 m
.75114 .65505 L
s
1 0 0 r
.003 w
.58841 .47337 m
.60068 .49331 L
s
.74914 .71492 m .65789 .68748 L .75171 .68489 L .66 .514 .674 r
F
.74914 .71492 m .65572 .7093 L .65789 .68748 L F
1 0 0 r
.65789 .68748 m
.658 .66538 L
s
.25 g
.5 Mabswid
.65789 .68748 m
.75171 .68489 L
s
1 0 0 r
.003 w
.57542 .45392 m
.58841 .47337 L
s
.74344 .74484 m .65572 .7093 L .74914 .71492 L .652 .499 .664 r
F
.74344 .74484 m .65141 .73068 L .65572 .7093 L F
1 0 0 r
.65572 .7093 m
.65789 .68748 L
s
.25 g
.5 Mabswid
.65572 .7093 m
.74914 .71492 L
s
0 g
.006 w
.75114 .65505 m
.75171 .68489 L
s
.73465 .77433 m .65141 .73068 L .74344 .74484 L .647 .488 .653 r
F
.73465 .77433 m .64493 .75142 L .65141 .73068 L F
1 0 0 r
.003 w
.65141 .73068 m
.65572 .7093 L
s
.25 g
.5 Mabswid
.65141 .73068 m
.74344 .74484 L
s
1 0 0 r
.003 w
.56178 .43501 m
.57542 .45392 L
s
.72284 .80307 m .64493 .75142 L .73465 .77433 L .646 .479 .643 r
F
.72284 .80307 m .63629 .7713 L .64493 .75142 L F
1 0 0 r
.64493 .75142 m
.65141 .73068 L
s
.39476 .31253 m .44435 .30771 L .37292 .30291 L .303 .586 .942 r
F
.39476 .31253 m .45826 .32103 L .44435 .30771 L F
0 g
.006 w
.39476 .31253 m
.4181 .32244 L
s
.25 g
.5 Mabswid
.39476 .31253 m
.45826 .32103 L
s
1 0 0 r
.003 w
.5476 .41666 m
.56178 .43501 L
s
.70812 .83072 m .63629 .7713 L .72284 .80307 L .65 .475 .634 r
F
.70812 .83072 m .62554 .79014 L .63629 .7713 L F
.25 g
.5 Mabswid
.64493 .75142 m
.73465 .77433 L
s
1 0 0 r
.003 w
.63629 .7713 m
.64493 .75142 L
s
0 g
.006 w
.74914 .71492 m
.75171 .68489 L
s
.69063 .85696 m .62554 .79014 L .70812 .83072 L .657 .476 .628 r
F
.25 g
.5 Mabswid
.70889 .79795 m
.72284 .80307 L
s
.69063 .85696 m .61278 .80772 L .62554 .79014 L .657 .476 .628 r
F
.25 g
.63629 .7713 m
.70889 .79795 L
s
1 0 0 r
.003 w
.62554 .79014 m
.63629 .7713 L
s
.53297 .39895 m
.5476 .41666 L
s
.67056 .88146 m .61278 .80772 L .69063 .85696 L .668 .482 .624 r
F
.25 g
.5 Mabswid
.67247 .84547 m
.69063 .85696 L
s
.70321 .82831 m
.70812 .83072 L
s
.67056 .88146 m .59815 .82388 L .61278 .80772 L .668 .482 .624 r
F
1 0 0 r
.003 w
.61278 .80772 m
.62554 .79014 L
s
.6481 .90393 m .59815 .82388 L .67056 .88146 L .681 .493 .625 r
F
.25 g
.5 Mabswid
.66051 .87347 m
.67056 .88146 L
s
.70308 .82825 m
.70321 .82831 L
s
.6481 .90393 m .58182 .83847 L .59815 .82388 L .681 .493 .625 r
F
.25 g
.62554 .79014 m
.70308 .82825 L
s
1 0 0 r
.003 w
.59815 .82388 m
.61278 .80772 L
s
0 g
.006 w
.74344 .74484 m
.74914 .71492 L
s
1 0 0 r
.003 w
.51803 .3819 m
.53297 .39895 L
s
.62349 .92409 m .58182 .83847 L .6481 .90393 L .696 .508 .628 r
F
.25 g
.5 Mabswid
.62575 .84582 m
.66051 .87347 L
s
.62349 .92409 m .56399 .85138 L .58182 .83847 L .696 .508 .628 r
F
.25 g
.61278 .80772 m
.67247 .84547 L
s
.59815 .82388 m
.62575 .84582 L
s
1 0 0 r
.003 w
.58182 .83847 m
.59815 .82388 L
s
.59699 .9417 m .56399 .85138 L .62349 .92409 L .712 .526 .636 r
F
.25 g
.5 Mabswid
.59983 .89518 m
.62349 .92409 L
s
.64541 .90128 m
.6481 .90393 L
s
.61503 .87127 m
.64541 .90128 L
s
.59882 .85525 m
.61503 .87127 L
s
.59699 .9417 m .54487 .86257 L .56399 .85138 L .712 .526 .636 r
F
.25 g
.58182 .83847 m
.59882 .85525 L
s
1 0 0 r
.003 w
.56399 .85138 m
.58182 .83847 L
s
0 g
.006 w
.73465 .77433 m
.74344 .74484 L
s
.37292 .30291 m .43133 .29514 L .35284 .29343 L .386 .642 .958 r
F
.37292 .30291 m .44435 .30771 L .43133 .29514 L F
0 g
.37292 .30291 m
.39476 .31253 L
s
.25 g
.5 Mabswid
.37292 .30291 m
.44435 .30771 L
s
1 0 0 r
.003 w
.50291 .36556 m
.51803 .3819 L
s
.56887 .95656 m .54487 .86257 L .59699 .9417 L .728 .548 .647 r
F
.25 g
.5 Mabswid
.58529 .87742 m
.59983 .89518 L
s
.57553 .86549 m
.58529 .87742 L
s
.56887 .95656 m .52469 .87199 L .54487 .86257 L .728 .548 .647 r
F
.25 g
.56399 .85138 m
.57553 .86549 L
s
1 0 0 r
.003 w
.54487 .86257 m
.56399 .85138 L
s
0 g
.006 w
.72284 .80307 m
.73465 .77433 L
s
.53943 .96851 m .52469 .87199 L .56887 .95656 L .743 .572 .662 r
F
.25 g
.5 Mabswid
.59502 .93872 m
.59699 .9417 L
s
.55947 .88473 m
.59502 .93872 L
s
.54487 .86257 m
.55947 .88473 L
s
.53943 .96851 m .50367 .87969 L .52469 .87199 L .743 .572 .662 r
F
1 0 0 r
.003 w
.52469 .87199 m
.54487 .86257 L
s
.25 g
.5 Mabswid
.52469 .87199 m
.53486 .89145 L
s
1 0 0 r
.003 w
.48777 .34995 m
.50291 .36556 L
s
0 g
.006 w
.70812 .83072 m
.72284 .80307 L
s
.50896 .97744 m .50367 .87969 L .53943 .96851 L .757 .597 .68 r
F
.25 g
.5 Mabswid
.56724 .95345 m
.56887 .95656 L
s
.53486 .89145 m
.56724 .95345 L
s
.50896 .97744 m .48203 .88573 L .50367 .87969 L .757 .597 .68 r
F
1 0 0 r
.003 w
.50367 .87969 m
.52469 .87199 L
s
.25 g
.5 Mabswid
.50367 .87969 m
.50763 .88953 L
s
0 g
.006 w
.69063 .85696 m
.70812 .83072 L
s
.47778 .98332 m .48203 .88573 L .50896 .97744 L .768 .624 .7 r
F
.25 g
.5 Mabswid
.48461 .89451 m
.50896 .97744 L
s
.53814 .96531 m
.53943 .96851 L
s
.50763 .88953 m
.53814 .96531 L
s
.47778 .98332 m .45997 .89021 L .48203 .88573 L .768 .624 .7 r
F
1 0 0 r
.003 w
.48203 .88573 m
.50367 .87969 L
s
.25 g
.5 Mabswid
.48203 .88573 m
.48461 .89451 L
s
0 g
.006 w
.67056 .88146 m
.69063 .85696 L
s
1 0 0 r
.003 w
.47282 .33511 m
.48777 .34995 L
s
.44619 .98613 m .45997 .89021 L .47778 .98332 L .778 .652 .723 r
F
.44619 .98613 m .43765 .89325 L .45997 .89021 L F
1 0 0 r
.45997 .89021 m
.48203 .88573 L
s
.41449 .98595 m .43765 .89325 L .44619 .98613 L .785 .68 .748 r
F
0 g
.006 w
.44619 .98613 m
.47778 .98332 L
s
.41449 .98595 m .41525 .895 L .43765 .89325 L .785 .68 .748 r
F
.25 g
.5 Mabswid
.43765 .89325 m
.44619 .98613 L
s
.38295 .9829 m .41525 .895 L .41449 .98595 L .788 .709 .776 r
F
0 g
.006 w
.41449 .98595 m
.44619 .98613 L
s
.25 g
.5 Mabswid
.45997 .89021 m
.47778 .98332 L
s
0 g
.006 w
.47778 .98332 m
.50896 .97744 L
s
.38295 .9829 m .39289 .89559 L .41525 .895 L .788 .709 .776 r
F
.25 g
.5 Mabswid
.41449 .98595 m
.41525 .895 L
s
.35184 .97714 m .39289 .89559 L .38295 .9829 L .787 .738 .807 r
F
0 g
.006 w
.38295 .9829 m
.41449 .98595 L
s
.50896 .97744 m
.53943 .96851 L
s
.6481 .90393 m
.67056 .88146 L
s
.35284 .29343 m .41947 .2833 L .3348 .28395 L .444 .685 .967 r
F
.35284 .29343 m .43133 .29514 L .41947 .2833 L F
0 g
.35284 .29343 m
.37292 .30291 L
s
.25 g
.5 Mabswid
.35284 .29343 m
.43133 .29514 L
s
0 g
.006 w
.53943 .96851 m
.56887 .95656 L
s
.35184 .97714 m .37068 .89517 L .39289 .89559 L .787 .738 .807 r
F
.25 g
.5 Mabswid
.38295 .9829 m
.39289 .89559 L
s
.32142 .96889 m .37068 .89517 L .35184 .97714 L .78 .767 .841 r
F
0 g
.006 w
.35184 .97714 m
.38295 .9829 L
s
.62349 .92409 m
.6481 .90393 L
s
.56887 .95656 m
.59699 .9417 L
s
1 0 0 r
.003 w
.43765 .89325 m
.45997 .89021 L
s
0 g
.006 w
.59699 .9417 m
.62349 .92409 L
s
.32142 .96889 m .34873 .89386 L .37068 .89517 L .78 .767 .841 r
F
.25 g
.5 Mabswid
.35184 .97714 m
.37068 .89517 L
s
.2919 .95839 m .34873 .89386 L .32142 .96889 L .765 .796 .878 r
F
0 g
.006 w
.32142 .96889 m
.35184 .97714 L
s
1 0 0 r
.003 w
.45826 .32103 m
.47282 .33511 L
s
.41525 .895 m
.43765 .89325 L
s
.2919 .95839 m .32711 .89177 L .34873 .89386 L .765 .796 .878 r
F
.26349 .94595 m .32711 .89177 L .2919 .95839 L .739 .822 .916 r
F
.25 g
.5 Mabswid
.32142 .96889 m
.32231 .96646 L
s
0 g
.006 w
.2919 .95839 m
.32142 .96889 L
s
.26349 .94595 m .30592 .889 L .32711 .89177 L .739 .822 .916 r
F
.25 g
.5 Mabswid
.32592 .89402 m
.32711 .89177 L
s
.32231 .96646 m
.34873 .89386 L
s
.23634 .93186 m .30592 .889 L .26349 .94595 L .694 .841 .954 r
F
.25 g
.2919 .95839 m
.29303 .95626 L
s
0 g
.006 w
.26349 .94595 m
.2919 .95839 L
s
1 0 0 r
.003 w
.39289 .89559 m
.41525 .895 L
s
.44435 .30771 m
.45826 .32103 L
s
.3348 .28395 m .40901 .27219 L .31903 .27436 L .485 .721 .975 r
F
.3348 .28395 m .41947 .2833 L .40901 .27219 L F
0 g
.006 w
.3348 .28395 m
.35284 .29343 L
s
.25 g
.5 Mabswid
.3348 .28395 m
.41947 .2833 L
s
.23634 .93186 m .28524 .88561 L .30592 .889 L .694 .841 .954 r
F
.25 g
.30479 .89051 m
.30592 .889 L
s
.29303 .95626 m
.32592 .89402 L
s
.21062 .91647 m .28524 .88561 L .23634 .93186 L .622 .848 .985 r
F
.25 g
.26349 .94595 m
.26483 .94415 L
s
0 g
.006 w
.23634 .93186 m
.26349 .94595 L
s
1 0 0 r
.003 w
.37068 .89517 m
.39289 .89559 L
s
.43133 .29514 m
.44435 .30771 L
s
.34873 .89386 m
.37068 .89517 L
s
.21062 .91647 m .26517 .88167 L .28524 .88561 L .622 .848 .985 r
F
.25 g
.5 Mabswid
.28429 .88651 m
.28524 .88561 L
s
.18644 .90011 m .26517 .88167 L .21062 .91647 L .514 .829 1 r
F
.25 g
.23634 .93186 m
.23787 .93042 L
s
0 g
.006 w
.21062 .91647 m
.23634 .93186 L
s
1 0 0 r
.003 w
.32711 .89177 m
.34873 .89386 L
s
.18644 .90011 m .24582 .87724 L .26517 .88167 L .514 .829 1 r
F
.25 g
.5 Mabswid
.26337 .88281 m
.26517 .88167 L
s
.26483 .94415 m
.30479 .89051 L
s
.16391 .88313 m .24582 .87724 L .18644 .90011 L .362 .772 .981 r
F
.25 g
.23787 .93042 m
.28429 .88651 L
s
.21062 .91647 m
.2123 .9154 L
s
0 g
.006 w
.18644 .90011 m
.21062 .91647 L
s
1 0 0 r
.003 w
.41947 .2833 m
.43133 .29514 L
s
.31903 .27436 m .40021 .2618 L .30577 .26455 L .511 .751 .982 r
F
.31903 .27436 m .40901 .27219 L .40021 .2618 L F
0 g
.006 w
.31903 .27436 m
.3348 .28395 L
s
.25 g
.5 Mabswid
.31903 .27436 m
.40901 .27219 L
s
1 0 0 r
.003 w
.30592 .889 m
.32711 .89177 L
s
.16391 .88313 m .22731 .8724 L .24582 .87724 L .362 .772 .981 r
F
.25 g
.5 Mabswid
.24452 .87774 m
.24582 .87724 L
s
.14312 .86587 m .22731 .8724 L .16391 .88313 L .173 .667 .918 r
F
.25 g
.2123 .9154 m
.26337 .88281 L
s
.18644 .90011 m
.18825 .89941 L
s
.18825 .89941 m
.24452 .87774 L
s
0 g
.006 w
.16391 .88313 m
.18644 .90011 L
s
.25 g
.5 Mabswid
.16391 .88313 m
.22667 .87251 L
s
1 0 0 r
.003 w
.40901 .27219 m
.41947 .2833 L
s
.28524 .88561 m
.30592 .889 L
s
.30577 .26455 m .39329 .25212 L .29526 .25448 L .525 .776 .989 r
F
.30577 .26455 m .40021 .2618 L .39329 .25212 L F
0 g
.006 w
.30577 .26455 m
.31903 .27436 L
s
.25 g
.5 Mabswid
.30577 .26455 m
.40021 .2618 L
s
.14312 .86587 m .20978 .86722 L .22731 .8724 L .173 .667 .918 r
F
.25 g
.22667 .87251 m
.22731 .8724 L
s
.12415 .84869 m .20978 .86722 L .14312 .86587 L 0 .525 .813 r
F
0 g
.006 w
.14312 .86587 m
.16391 .88313 L
s
1 0 0 r
.003 w
.26517 .88167 m
.28524 .88561 L
s
.40021 .2618 m
.40901 .27219 L
s
.24582 .87724 m
.26517 .88167 L
s
.12415 .84869 m .1934 .8618 L .20978 .86722 L 0 .525 .813 r
F
.25 g
.5 Mabswid
.14312 .86587 m
.20978 .86722 L
s
.10706 .8319 m .1934 .8618 L .12415 .84869 L 0 .373 .691 r
F
0 g
.006 w
.12415 .84869 m
.14312 .86587 L
s
.29526 .25448 m .38844 .24319 L .2877 .24409 L .525 .796 .995 r
F
.29526 .25448 m .39329 .25212 L .38844 .24319 L F
0 g
.29526 .25448 m
.30577 .26455 L
s
.25 g
.5 Mabswid
.29526 .25448 m
.39329 .25212 L
s
1 0 0 r
.003 w
.39329 .25212 m
.40021 .2618 L
s
.22731 .8724 m
.24582 .87724 L
s
.10706 .8319 m .17832 .85625 L .1934 .8618 L 0 .373 .691 r
F
.09192 .81583 m .17832 .85625 L .10706 .8319 L .352 0 0 r
F
.25 g
.5 Mabswid
.12415 .84869 m
.12616 .84907 L
s
0 g
.006 w
.10706 .8319 m
.12415 .84869 L
s
1 0 0 r
.003 w
.20978 .86722 m
.22731 .8724 L
s
.2877 .24409 m .38582 .23503 L .28328 .23339 L .511 .809 .999 r
F
.2877 .24409 m .38844 .24319 L .38582 .23503 L F
0 g
.006 w
.2877 .24409 m
.29526 .25448 L
s
.25 g
.5 Mabswid
.2877 .24409 m
.38844 .24319 L
s
1 0 0 r
.003 w
.38844 .24319 m
.39329 .25212 L
s
.1934 .8618 m
.20978 .86722 L
s
.38582 .23503 m
.38844 .24319 L
s
.09192 .81583 m .16473 .85071 L .17832 .85625 L .352 0 0 r
F
.25 g
.5 Mabswid
.19102 .86135 m
.1934 .8618 L
s
.07878 .80079 m .16473 .85071 L .09192 .81583 L .452 0 0 r
F
.25 g
.12616 .84907 m
.19102 .86135 L
s
.10706 .8319 m
.10908 .83259 L
s
0 g
.006 w
.09192 .81583 m
.10706 .8319 L
s
.27993 .23821 m .38159 .24343 L .38378 .23475 L .533 .812 .997 r
F
0 g
.28539 .23849 m
.2877 .24409 L
s
1 0 0 r
.003 w
.17832 .85625 m
.1934 .8618 L
s
.27993 .23821 m .38378 .23475 L .28244 .22433 L .533 .812 .997 r
F
.25 g
.5 Mabswid
.27993 .23821 m
.38159 .24343 L
s
.38372 .23499 m
.38582 .23503 L
s
.07878 .80079 m .1528 .84533 L .16473 .85071 L .452 0 0 r
F
.25 g
.17521 .85518 m
.17832 .85625 L
s
.06773 .78707 m .1528 .84533 L .07878 .80079 L .513 0 0 r
F
.25 g
.10908 .83259 m
.17521 .85518 L
s
.09192 .81583 m
.09393 .8168 L
s
.09393 .8168 m
.15006 .84368 L
s
0 g
.006 w
.07878 .80079 m
.09192 .81583 L
s
.28244 .22433 m .38378 .23475 L .38836 .227 L .495 .805 1 r
F
1 0 0 r
.003 w
.38159 .24343 m
.38378 .23475 L
s
.16473 .85071 m
.17832 .85625 L
s
.28244 .22433 m .38836 .227 L .2885 .21032 L .495 .805 1 r
F
0 g
.006 w
.27993 .23821 m
.28244 .22433 L
s
.25 g
.5 Mabswid
.28244 .22433 m
.38378 .23475 L
s
.2885 .21032 m .38836 .227 L .39531 .22029 L .448 .786 .998 r
F
1 0 0 r
.003 w
.38378 .23475 m
.38836 .227 L
s
.06773 .78707 m .14272 .84028 L .1528 .84533 L .513 0 0 r
F
1 0 0 r
.1528 .84533 m
.16473 .85071 L
s
.05884 .77493 m .14272 .84028 L .06773 .78707 L .539 0 0 r
F
.25 g
.5 Mabswid
.07878 .80079 m
.08075 .80198 L
s
.08075 .80198 m
.13328 .83358 L
s
0 g
.006 w
.06773 .78707 m
.07878 .80079 L
s
.29817 .19638 m .39531 .22029 L .40453 .21473 L .399 .758 .994 r
F
.2885 .21032 m .39531 .22029 L .29817 .19638 L .448 .786 .998 r
F
.25 g
.5 Mabswid
.2885 .21032 m
.38836 .227 L
s
1 0 0 r
.003 w
.38836 .227 m
.39531 .22029 L
s
0 g
.006 w
.28244 .22433 m
.2885 .21032 L
s
.05884 .77493 m .13466 .83573 L .14272 .84028 L .539 0 0 r
F
1 0 0 r
.003 w
.14272 .84028 m
.1528 .84533 L
s
.05219 .76461 m .13466 .83573 L .05884 .77493 L .533 0 0 r
F
.25 g
.5 Mabswid
.06773 .78707 m
.06961 .7884 L
s
.06961 .7884 m
.122 .82558 L
s
0 g
.006 w
.05884 .77493 m
.06773 .78707 L
s
.31148 .18271 m .40453 .21473 L .41591 .21044 L .354 .722 .987 r
F
.29817 .19638 m .40453 .21473 L .31148 .18271 L .399 .758 .994 r
F
.25 g
.5 Mabswid
.30037 .19692 m
.39531 .22029 L
s
1 0 0 r
.003 w
.39531 .22029 m
.40453 .21473 L
s
0 g
.006 w
.2885 .21032 m
.29817 .19638 L
s
.25 g
.5 Mabswid
.29817 .19638 m
.30037 .19692 L
s
.32842 .16961 m .41591 .21044 L .42928 .2075 L .318 .683 .978 r
F
.31148 .18271 m .41591 .21044 L .32842 .16961 L .354 .722 .987 r
F
1 0 0 r
.003 w
.40453 .21473 m
.41591 .21044 L
s
0 g
.006 w
.29817 .19638 m
.31148 .18271 L
s
.25 g
.5 Mabswid
.31148 .18271 m
.31386 .18353 L
s
.05219 .76461 m .12879 .83183 L .13466 .83573 L .533 0 0 r
F
1 0 0 r
.003 w
.13466 .83573 m
.14272 .84028 L
s
.25 g
.5 Mabswid
.05884 .77493 m
.11808 .82243 L
s
.04788 .75636 m .12879 .83183 L .05219 .76461 L .494 0 0 r
F
0 g
.006 w
.05219 .76461 m
.05884 .77493 L
s
.3489 .15736 m .42928 .2075 L .44445 .20602 L .295 .644 .967 r
F
.32842 .16961 m .42928 .2075 L .3489 .15736 L .318 .683 .978 r
F
.25 g
.5 Mabswid
.31386 .18353 m
.40453 .21473 L
s
1 0 0 r
.003 w
.41591 .21044 m
.42928 .2075 L
s
.25 g
.5 Mabswid
.42484 .20474 m
.42928 .2075 L
s
.32842 .16961 m
.33082 .17073 L
s
0 g
.006 w
.31148 .18271 m
.32842 .16961 L
s
.04788 .75636 m .12527 .82873 L .12879 .83183 L .494 0 0 r
F
1 0 0 r
.003 w
.12879 .83183 m
.13466 .83573 L
s
.25 g
.5 Mabswid
.05219 .76461 m
.12879 .83183 L
s
.04602 .75036 m .12527 .82873 L .04788 .75636 L 0 .064 .571 r
F
0 g
.006 w
.04788 .75636 m
.05219 .76461 L
s
.37277 .14633 m .44445 .20602 L .46122 .20605 L .287 .606 .953 r
F
.3489 .15736 m .44445 .20602 L .37277 .14633 L .295 .644 .967 r
F
.25 g
.5 Mabswid
.33082 .17073 m
.41591 .21044 L
s
1 0 0 r
.003 w
.42928 .2075 m
.44445 .20602 L
s
.25 g
.5 Mabswid
.44136 .20345 m
.44445 .20602 L
s
.3489 .15736 m
.35094 .15864 L
s
.35094 .15864 m
.35121 .15881 L
s
.04602 .75036 m .12424 .82654 L .12527 .82873 L 0 .064 .571 r
F
1 0 0 r
.003 w
.12527 .82873 m
.12879 .83183 L
s
.25 g
.5 Mabswid
.04788 .75636 m
.12527 .82873 L
s
0 g
.006 w
.32842 .16961 m
.3489 .15736 L
s
.39981 .13687 m .46122 .20605 L .47938 .20762 L .293 .572 .935 r
F
.37277 .14633 m .46122 .20605 L .39981 .13687 L .287 .606 .953 r
F
1 0 0 r
.003 w
.44445 .20602 m
.46122 .20605 L
s
.25 g
.5 Mabswid
.45914 .2037 m
.46122 .20605 L
s
.37277 .14633 m
.37471 .14794 L
s
.37471 .14794 m
.37491 .14811 L
s
.04674 .74677 m .12424 .82654 L .04602 .75036 L 0 .129 .644 r
F
0 g
.006 w
.04602 .75036 m
.04788 .75636 L
s
.04674 .74677 m .12581 .82534 L .12424 .82654 L 0 .129 .644 r
F
1 0 0 r
.003 w
.12424 .82654 m
.12527 .82873 L
s
.25 g
.5 Mabswid
.04602 .75036 m
.12424 .82654 L
s
.42971 .12935 m .47938 .20762 L .49873 .21075 L .31 .541 .913 r
F
.39981 .13687 m .47938 .20762 L .42971 .12935 L .293 .572 .935 r
F
1 0 0 r
.003 w
.46122 .20605 m
.47938 .20762 L
s
.25 g
.5 Mabswid
.47598 .20226 m
.47938 .20762 L
s
.39981 .13687 m
.40155 .13883 L
s
.40155 .13883 m
.40169 .13898 L
s
.35121 .15881 m
.42484 .20474 L
s
0 g
.006 w
.3489 .15736 m
.37277 .14633 L
s
.4621 .12415 m .49873 .21075 L .51905 .21545 L .334 .516 .886 r
F
.42971 .12935 m .49873 .21075 L .4621 .12415 L .31 .541 .913 r
F
1 0 0 r
.003 w
.47938 .20762 m
.49873 .21075 L
s
.25 g
.5 Mabswid
.49799 .209 m
.49873 .21075 L
s
.42971 .12935 m
.43117 .13165 L
s
.43117 .13165 m
.43126 .13179 L
s
.40169 .13898 m
.45914 .2037 L
s
.37491 .14811 m
.44136 .20345 L
s
.05016 .74571 m .12581 .82534 L .04674 .74677 L 0 .205 .714 r
F
0 g
.006 w
.04602 .75036 m
.04674 .74677 L
s
.05016 .74571 m .13007 .82514 L .12581 .82534 L 0 .205 .714 r
F
1 0 0 r
.003 w
.12424 .82654 m
.12581 .82534 L
s
.25 g
.5 Mabswid
.04674 .74677 m
.12581 .82534 L
s
0 g
.006 w
.37277 .14633 m
.39981 .13687 L
s
.49653 .12163 m .51905 .21545 L .54016 .2217 L .363 .495 .858 r
F
.4621 .12415 m .51905 .21545 L .49653 .12163 L .334 .516 .886 r
F
1 0 0 r
.003 w
.49873 .21075 m
.51905 .21545 L
s
.25 g
.5 Mabswid
.51871 .21407 m
.51905 .21545 L
s
.4621 .12415 m
.46327 .1269 L
s
.43126 .13179 m
.47598 .20226 L
s
.05641 .74727 m .13007 .82514 L .05016 .74571 L 0 .283 .775 r
F
0 g
.006 w
.04674 .74677 m
.05016 .74571 L
s
.05641 .74727 m .13708 .82594 L .13007 .82514 L 0 .283 .775 r
F
1 0 0 r
.003 w
.12581 .82534 m
.13007 .82514 L
s
.25 g
.5 Mabswid
.05016 .74571 m
.13007 .82514 L
s
0 g
.006 w
.39981 .13687 m
.42971 .12935 L
s
.53249 .12209 m .54016 .2217 L .56188 .22949 L .393 .479 .829 r
F
.49653 .12163 m .54016 .2217 L .53249 .12209 L .363 .495 .858 r
F
1 0 0 r
.003 w
.51905 .21545 m
.54016 .2217 L
s
.25 g
.5 Mabswid
.49653 .12163 m
.49726 .12465 L
s
.49726 .12465 m
.51871 .21407 L
s
.46327 .1269 m
.49799 .209 L
s
.56942 .1258 m .56188 .22949 L .58404 .23879 L .425 .467 .801 r
F
.53249 .12209 m .56188 .22949 L .56942 .1258 L .393 .479 .829 r
F
1 0 0 r
.003 w
.54016 .2217 m
.56188 .22949 L
s
.25 g
.5 Mabswid
.53249 .12209 m
.54016 .2217 L
s
.06564 .75146 m .13708 .82594 L .05641 .74727 L 0 .356 .825 r
F
0 g
.006 w
.05016 .74571 m
.05641 .74727 L
s
.06564 .75146 m .14685 .82764 L .13708 .82594 L 0 .356 .825 r
F
1 0 0 r
.003 w
.13007 .82514 m
.13708 .82594 L
s
0 g
.006 w
.42971 .12935 m
.4621 .12415 L
s
.60673 .13297 m .58404 .23879 L .60647 .24961 L .456 .459 .773 r
F
.56942 .1258 m .58404 .23879 L .60673 .13297 L .425 .467 .801 r
F
1 0 0 r
.003 w
.56188 .22949 m
.58404 .23879 L
s
.25 g
.5 Mabswid
.56188 .22949 m
.56942 .1258 L
s
.07796 .75825 m .14685 .82764 L .06564 .75146 L .031 .423 .865 r
F
.25 g
.05641 .74727 m
.06 .75077 L
s
.07796 .75825 m .15936 .83012 L .14685 .82764 L .031 .423 .865 r
F
.25 g
.06 .75077 m
.13708 .82594 L
s
1 0 0 r
.003 w
.13708 .82594 m
.14685 .82764 L
s
.25 g
.5 Mabswid
.1228 .80509 m
.14685 .82764 L
s
0 g
.006 w
.05641 .74727 m
.06564 .75146 L
s
.4621 .12415 m
.49653 .12163 L
s
.64382 .14371 m .60647 .24961 L .62897 .26195 L .486 .455 .748 r
F
.25 g
.5 Mabswid
.58404 .23879 m
.58459 .23623 L
s
.60673 .13297 m .60647 .24961 L .64382 .14371 L .456 .459 .773 r
F
.25 g
.58459 .23623 m
.60673 .13297 L
s
1 0 0 r
.003 w
.58404 .23879 m
.60647 .24961 L
s
0 g
.006 w
.49653 .12163 m
.53249 .12209 L
s
.68011 .15806 m .62897 .26195 L .65134 .27582 L .516 .453 .724 r
F
.25 g
.5 Mabswid
.60647 .24961 m
.60763 .24632 L
s
.64382 .14371 m .62897 .26195 L .68011 .15806 L .486 .455 .748 r
F
.25 g
.60763 .24632 m
.64257 .14724 L
s
1 0 0 r
.003 w
.60647 .24961 m
.62897 .26195 L
s
.25 g
.5 Mabswid
.64257 .14724 m
.64382 .14371 L
s
.09347 .76751 m .15936 .83012 L .07796 .75825 L .082 .482 .894 r
F
.25 g
.06564 .75146 m
.06901 .75462 L
s
.09347 .76751 m .17453 .8332 L .15936 .83012 L .082 .482 .894 r
F
.25 g
.06901 .75462 m
.1228 .80509 L
s
1 0 0 r
.003 w
.14685 .82764 m
.15936 .83012 L
s
.25 g
.5 Mabswid
.1419 .81471 m
.15936 .83012 L
s
.71505 .176 m .65134 .27582 L .67336 .29124 L .546 .454 .703 r
F
.25 g
.62897 .26195 m
.63091 .25799 L
s
.68011 .15806 m .65134 .27582 L .71505 .176 L .516 .453 .724 r
F
1 0 0 r
.003 w
.62897 .26195 m
.65134 .27582 L
s
.25 g
.5 Mabswid
.6784 .16155 m
.68011 .15806 L
s
0 g
.006 w
.53249 .12209 m
.56942 .1258 L
s
.06564 .75146 m
.07796 .75825 L
s
.11225 .77906 m .17453 .8332 L .09347 .76751 L .112 .532 .914 r
F
.25 g
.5 Mabswid
.07796 .75825 m
.0812 .76111 L
s
.11225 .77906 m .19224 .83666 L .17453 .8332 L .112 .532 .914 r
F
1 0 0 r
.003 w
.15936 .83012 m
.17453 .8332 L
s
.25 g
.5 Mabswid
.16092 .82218 m
.17453 .8332 L
s
.74812 .19739 m .67336 .29124 L .69478 .30823 L .575 .458 .683 r
F
.25 g
.65134 .27582 m
.65423 .27128 L
s
.63091 .25799 m
.63262 .25452 L
s
.71505 .176 m .67336 .29124 L .74812 .19739 L .546 .454 .703 r
F
.25 g
.63262 .25452 m
.6784 .16155 L
s
1 0 0 r
.003 w
.65134 .27582 m
.67336 .29124 L
s
.25 g
.5 Mabswid
.7129 .17937 m
.71505 .176 L
s
0 g
.006 w
.56942 .1258 m
.60673 .13297 L
s
.77888 .22205 m .69478 .30823 L .71532 .3268 L .604 .465 .665 r
F
.25 g
.5 Mabswid
.67336 .29124 m
.67733 .28625 L
s
.65423 .27128 m
.65663 .26753 L
s
.74812 .19739 m .69478 .30823 L .77888 .22205 L .575 .458 .683 r
F
.25 g
.65663 .26753 m
.7129 .17937 L
s
1 0 0 r
.003 w
.67336 .29124 m
.69478 .30823 L
s
.25 g
.5 Mabswid
.74557 .20059 m
.74812 .19739 L
s
0 g
.006 w
.60673 .13297 m
.64382 .14371 L
s
.1343 .79261 m .19224 .83666 L .11225 .77906 L .117 .57 .918 r
F
.25 g
.5 Mabswid
.09347 .76751 m
.09661 .77005 L
s
.0812 .76111 m
.08136 .76125 L
s
.1343 .79261 m .21234 .84027 L .19224 .83666 L .117 .57 .918 r
F
.25 g
.08136 .76125 m
.1419 .81471 L
s
1 0 0 r
.003 w
.17453 .8332 m
.19224 .83666 L
s
.25 g
.5 Mabswid
.17267 .82257 m
.18127 .82876 L
s
.18127 .82876 m
.19224 .83666 L
s
0 g
.006 w
.64382 .14371 m
.68011 .15806 L
s
.80697 .24972 m .71532 .3268 L .73469 .34693 L .633 .474 .649 r
F
.25 g
.5 Mabswid
.69478 .30823 m
.69995 .30293 L
s
.67733 .28625 m
.68051 .28227 L
s
.77888 .22205 m .71532 .3268 L .80697 .24972 L .604 .465 .665 r
F
1 0 0 r
.003 w
.69478 .30823 m
.71532 .3268 L
s
.25 g
.5 Mabswid
.77598 .22502 m
.77888 .22205 L
s
.89916 .42163 m .80359 .46801 L .90726 .46014 L .772 .561 .614 r
F
.89916 .42163 m .79444 .44157 L .80359 .46801 L F
.88757 .38399 m .79444 .44157 L .89916 .42163 L .747 .539 .614 r
F
.90726 .46014 m .80998 .49513 L .9119 .49917 L .794 .585 .617 r
F
.90726 .46014 m .80359 .46801 L .80998 .49513 L F
0 g
.006 w
.89916 .42163 m
.90726 .46014 L
s
.25 g
.5 Mabswid
.80359 .46801 m
.90726 .46014 L
s
.88757 .38399 m .78273 .41605 L .79444 .44157 L .747 .539 .614 r
F
.25 g
.79444 .44157 m
.89916 .42163 L
s
.87249 .34761 m .78273 .41605 L .88757 .38399 L .72 .519 .618 r
F
0 g
.006 w
.88757 .38399 m
.89916 .42163 L
s
.87249 .34761 m .76869 .39166 L .78273 .41605 L .72 .519 .618 r
F
.85396 .31285 m .76869 .39166 L .87249 .34761 L .691 .501 .625 r
F
.25 g
.5 Mabswid
.8838 .38514 m
.88757 .38399 L
s
0 g
.006 w
.87249 .34761 m
.88757 .38399 L
s
.9119 .49917 m .81348 .52266 L .91315 .53835 L .813 .608 .625 r
F
.9119 .49917 m .80998 .49513 L .81348 .52266 L F
0 g
.90726 .46014 m
.9119 .49917 L
s
.25 g
.5 Mabswid
.80998 .49513 m
.9119 .49917 L
s
0 g
.006 w
.68011 .15806 m
.71505 .176 L
s
.07796 .75825 m
.09347 .76751 L
s
.85396 .31285 m .75258 .36858 L .76869 .39166 L .691 .501 .625 r
F
.25 g
.5 Mabswid
.71532 .3268 m
.72679 .31716 L
s
.76869 .39166 m
.78003 .38685 L
s
.78273 .41605 m
.8838 .38514 L
s
.83206 .2801 m .75258 .36858 L .85396 .31285 L .662 .486 .636 r
F
.25 g
.86881 .34917 m
.87249 .34761 L
s
0 g
.006 w
.85396 .31285 m
.87249 .34761 L
s
.25 g
.5 Mabswid
.85033 .31485 m
.85396 .31285 L
s
.91315 .53835 m .814 .5503 L .91106 .57735 L .826 .63 .637 r
F
.91315 .53835 m .81348 .52266 L .814 .5503 L F
0 g
.006 w
.9119 .49917 m
.91315 .53835 L
s
.25 g
.5 Mabswid
.81348 .52266 m
.91315 .53835 L
s
.83206 .2801 m .73469 .34693 L .75258 .36858 L .662 .486 .636 r
F
.25 g
.69995 .30293 m
.70398 .2988 L
s
.75258 .36858 m
.76211 .36334 L
s
.78003 .38685 m
.86881 .34917 L
s
.68051 .28227 m
.68462 .27711 L
s
.80697 .24972 m .73469 .34693 L .83206 .2801 L .633 .474 .649 r
F
.25 g
.68462 .27711 m
.74557 .20059 L
s
1 0 0 r
.003 w
.71532 .3268 m
.73469 .34693 L
s
.25 g
.5 Mabswid
.72679 .31716 m
.80377 .25241 L
s
.76211 .36334 m
.85033 .31485 L
s
.70398 .2988 m
.77598 .22502 L
s
0 g
.006 w
.83206 .2801 m
.85396 .31285 L
s
.25 g
.5 Mabswid
.74263 .34149 m
.82863 .28246 L
s
.73469 .34693 m
.74263 .34149 L
s
.82863 .28246 m
.82971 .28172 L
s
.82971 .28172 m
.83206 .2801 L
s
.80377 .25241 m
.80697 .24972 L
s
0 g
.006 w
.80697 .24972 m
.83206 .2801 L
s
.71505 .176 m
.74812 .19739 L
s
.77888 .22205 m
.80697 .24972 L
s
.74812 .19739 m
.77888 .22205 L
s
1 0 0 r
.003 w
.73469 .34693 m
.75258 .36858 L
s
.91106 .57735 m .8115 .57776 L .90572 .61584 L .835 .648 .651 r
F
.91106 .57735 m .814 .5503 L .8115 .57776 L F
0 g
.006 w
.91106 .57735 m
.91315 .53835 L
s
.25 g
.5 Mabswid
.814 .5503 m
.91106 .57735 L
s
.1596 .80781 m .21234 .84027 L .1343 .79261 L .094 .591 .899 r
F
.25 g
.11225 .77906 m
.11528 .78124 L
s
.09661 .77005 m
.09674 .77016 L
s
.16101 .80867 m .23462 .84376 L .21234 .84027 L .094 .591 .899 r
F
.16065 .80845 m .16138 .8088 L .16101 .80867 L F
.16138 .8088 m .23462 .84376 L .16101 .80867 L F
.16236 .80913 m .23462 .84376 L .16065 .80845 L F
.1596 .80781 m .16236 .80913 L .16065 .80845 L F
.18805 .82421 m .23462 .84376 L .1596 .80781 L .038 .583 .84 r
F
.18805 .82421 m .25885 .84689 L .23462 .84376 L F
.25365 .85851 m .28183 .8503 L .21949 .8413 L .164 0 0 r
F
.21949 .8413 m .25705 .84664 L .18805 .82421 L 0 .532 .725 r
F
.25705 .84664 m .25885 .84689 L .25283 .84496 L F
.25705 .84664 m .25283 .84496 L .18805 .82421 L F
.21949 .8413 m .28477 .84944 L .25885 .84689 L F
.28183 .8503 m .28477 .84944 L .27626 .84838 L .164 0 0 r
F
.28183 .8503 m .27626 .84838 L .21949 .8413 L F
.25 g
.09674 .77016 m
.16092 .82218 L
s
.11528 .78124 m
.11539 .78132 L
s
.11539 .78132 m
.17267 .82257 L
s
1 0 0 r
.003 w
.19224 .83666 m
.21234 .84027 L
s
.25 g
.5 Mabswid
.1343 .79261 m
.13721 .79439 L
s
.13721 .79439 m
.1373 .79444 L
s
.1373 .79444 m
.19645 .83056 L
s
.19645 .83056 m
.21234 .84027 L
s
1 0 0 r
.003 w
.21234 .84027 m
.21974 .84142 L
s
.75258 .36858 m
.76869 .39166 L
s
.90572 .61584 m .80597 .60475 L .8972 .65349 L .837 .662 .666 r
F
.90572 .61584 m .8115 .57776 L .80597 .60475 L F
0 g
.006 w
.90572 .61584 m
.91106 .57735 L
s
1 0 0 r
.003 w
.76869 .39166 m
.78273 .41605 L
s
.8972 .65349 m .79747 .63098 L .88557 .68999 L .834 .671 .68 r
F
.8972 .65349 m .80597 .60475 L .79747 .63098 L F
0 g
.006 w
.8972 .65349 m
.90572 .61584 L
s
.25 g
.5 Mabswid
.88739 .64824 m
.8972 .65349 L
s
.8115 .57776 m
.90572 .61584 L
s
1 0 0 r
.003 w
.78273 .41605 m
.79444 .44157 L
s
.25 g
.5 Mabswid
.1596 .80781 m
.16236 .80913 L
s
.16236 .80913 m
.20547 .82979 L
s
.88557 .68999 m .78608 .6562 L .87091 .72503 L .826 .673 .693 r
F
.88557 .68999 m .79747 .63098 L .78608 .6562 L F
0 g
.006 w
.88557 .68999 m
.8972 .65349 L
s
.25 g
.5 Mabswid
.80597 .60475 m
.88739 .64824 L
s
1 0 0 r
.003 w
.79444 .44157 m
.80359 .46801 L
s
0 g
.006 w
.09347 .76751 m
.11225 .77906 L
s
1 0 0 r
.003 w
.80359 .46801 m
.80998 .49513 L
s
.87091 .72503 m .77194 .68019 L .85327 .75831 L .814 .668 .702 r
F
.87091 .72503 m .78608 .6562 L .77194 .68019 L F
0 g
.006 w
.87091 .72503 m
.88557 .68999 L
s
.25 g
.5 Mabswid
.86988 .7242 m
.87091 .72503 L
s
.18805 .82421 m
.19063 .82504 L
s
.19063 .82504 m
.24236 .84161 L
s
.24236 .84161 m
.25535 .84577 L
s
1 0 0 r
.003 w
.80998 .49513 m
.81348 .52266 L
s
.81348 .52266 m
.814 .5503 L
s
.85327 .75831 m .75519 .70277 L .83273 .78952 L .798 .657 .707 r
F
.85327 .75831 m .77194 .68019 L .75519 .70277 L F
0 g
.006 w
.85327 .75831 m
.87091 .72503 L
s
.25 g
.5 Mabswid
.85252 .75758 m
.85327 .75831 L
s
.85163 .75673 m
.85252 .75758 L
s
.77194 .68019 m
.78659 .69426 L
s
.79747 .63098 m
.88557 .68999 L
s
1 0 0 r
.003 w
.8115 .57776 m
.814 .5503 L
s
.25 g
.5 Mabswid
.21949 .8413 m
.27626 .84838 L
s
.25365 .85851 m .31214 .85121 L .28477 .84944 L .164 0 0 r
F
.25 g
.27626 .84838 m
.28477 .84944 L
s
1 0 0 r
.003 w
.80597 .60475 m
.8115 .57776 L
s
0 g
.006 w
.11225 .77906 m
.1343 .79261 L
s
.83273 .78952 m .73603 .72378 L .80935 .81835 L .781 .641 .707 r
F
.83273 .78952 m .75519 .70277 L .73603 .72378 L F
.25 g
.5 Mabswid
.78608 .6562 m
.86988 .7242 L
s
.78659 .69426 m
.85163 .75673 L
s
0 g
.006 w
.83273 .78952 m
.85327 .75831 L
s
.25 g
.5 Mabswid
.8314 .78803 m
.83273 .78952 L
s
.83088 .78744 m
.8314 .78803 L
s
.75519 .70277 m
.76416 .7128 L
s
1 0 0 r
.003 w
.79747 .63098 m
.80597 .60475 L
s
.29023 .87523 m .31214 .85121 L .25365 .85851 L .278 0 0 r
F
.29023 .87523 m .34067 .85202 L .31214 .85121 L F
1 0 0 r
.28477 .84944 m
.31214 .85121 L
s
.78608 .6562 m
.79747 .63098 L
s
.77194 .68019 m
.78608 .6562 L
s
.32883 .89085 m .34067 .85202 L .29023 .87523 L .376 0 0 r
F
.25 g
.5 Mabswid
.25365 .85851 m
.25574 .85825 L
s
.25574 .85825 m
.31214 .85121 L
s
.32883 .89085 m .37011 .85177 L .34067 .85202 L .376 0 0 r
F
1 0 0 r
.003 w
.31214 .85121 m
.34067 .85202 L
s
.25 g
.5 Mabswid
.33785 .85332 m
.34067 .85202 L
s
.80935 .81835 m .71467 .74314 L .78322 .84452 L .763 .62 .701 r
F
.80935 .81835 m .73603 .72378 L .71467 .74314 L F
.25 g
.76416 .7128 m
.83088 .78744 L
s
0 g
.006 w
.80935 .81835 m
.83273 .78952 L
s
.25 g
.5 Mabswid
.8078 .81634 m
.80935 .81835 L
s
.80744 .81589 m
.8078 .81634 L
s
.75149 .74373 m
.80744 .81589 L
s
.73603 .72378 m
.75149 .74373 L
s
1 0 0 r
.003 w
.75519 .70277 m
.77194 .68019 L
s
.369 .90476 m .37011 .85177 L .32883 .89085 L .45 0 .048 r
F
.25 g
.5 Mabswid
.32883 .89085 m
.36812 .85366 L
s
.29023 .87523 m
.29201 .87441 L
s
.29201 .87441 m
.33785 .85332 L
s
.369 .90476 m .40023 .85035 L .37011 .85177 L .45 0 .048 r
F
1 0 0 r
.003 w
.34067 .85202 m
.37011 .85177 L
s
.25 g
.5 Mabswid
.36812 .85366 m
.37011 .85177 L
s
1 0 0 r
.003 w
.73603 .72378 m
.75519 .70277 L
s
0 g
.006 w
.1343 .79261 m
.1596 .80781 L
s
.41027 .9164 m .40023 .85035 L .369 .90476 L .505 .092 .19 r
F
.25 g
.5 Mabswid
.369 .90476 m
.39894 .8526 L
s
.41027 .9164 m .43079 .84771 L .40023 .85035 L .505 .092 .19 r
F
1 0 0 r
.003 w
.37011 .85177 m
.40023 .85035 L
s
.25 g
.5 Mabswid
.39894 .8526 m
.40023 .85035 L
s
.78322 .84452 m .69132 .7608 L .75443 .86774 L .744 .595 .691 r
F
.78322 .84452 m .71467 .74314 L .69132 .7608 L F
0 g
.006 w
.78322 .84452 m
.80935 .81835 L
s
.25 g
.5 Mabswid
.71467 .74314 m
.78322 .84452 L
s
1 0 0 r
.003 w
.71467 .74314 m
.73603 .72378 L
s
.45213 .92528 m .43079 .84771 L .41027 .9164 L .546 .182 .302 r
F
.45213 .92528 m .46157 .84379 L .43079 .84771 L F
1 0 0 r
.40023 .85035 m
.43079 .84771 L
s
.25 g
.5 Mabswid
.41027 .9164 m
.43079 .84771 L
s
.75443 .86774 m .69132 .7608 L .66623 .77673 L .725 .567 .675 r
F
1 0 0 r
.003 w
.69132 .7608 m
.71467 .74314 L
s
.49407 .93099 m .46157 .84379 L .45213 .92528 L .578 .257 .389 r
F
.49407 .93099 m .49237 .83855 L .46157 .84379 L F
1 0 0 r
.43079 .84771 m
.46157 .84379 L
s
.25 g
.5 Mabswid
.45213 .92528 m
.46157 .84379 L
s
.7231 .88775 m .66623 .77673 L .63964 .79095 L .706 .535 .655 r
F
.75443 .86774 m .66623 .77673 L .7231 .88775 L .725 .567 .675 r
F
1 0 0 r
.003 w
.66623 .77673 m
.69132 .7608 L
s
0 g
.006 w
.75443 .86774 m
.78322 .84452 L
s
.53562 .9332 m .49237 .83855 L .49407 .93099 L .605 .32 .458 r
F
.53562 .9332 m .523 .83196 L .49237 .83855 L F
1 0 0 r
.003 w
.46157 .84379 m
.49237 .83855 L
s
.25 g
.5 Mabswid
.49237 .83855 m
.49407 .93099 L
s
.6894 .90431 m .63964 .79095 L .61179 .80353 L .687 .501 .629 r
F
.7231 .88775 m .63964 .79095 L .6894 .90431 L .706 .535 .655 r
F
1 0 0 r
.003 w
.63964 .79095 m
.66623 .77673 L
s
.25 g
.5 Mabswid
.63964 .79095 m
.64113 .79434 L
s
.72142 .88446 m
.7231 .88775 L
s
.69132 .7608 m
.75443 .86774 L
s
.5763 .9317 m .523 .83196 L .53562 .9332 L .628 .374 .514 r
F
.5763 .9317 m .55325 .82397 L .523 .83196 L F
1 0 0 r
.003 w
.49237 .83855 m
.523 .83196 L
s
.25 g
.5 Mabswid
.523 .83196 m
.53562 .9332 L
s
0 g
.006 w
.7231 .88775 m
.75443 .86774 L
s
.65353 .91724 m .61179 .80353 L .58292 .81451 L .668 .463 .598 r
F
.6894 .90431 m .61179 .80353 L .65353 .91724 L .687 .501 .629 r
F
1 0 0 r
.003 w
.61179 .80353 m
.63964 .79095 L
s
.25 g
.5 Mabswid
.61179 .80353 m
.61275 .80614 L
s
.68789 .90086 m
.6894 .90431 L
s
.66623 .77673 m
.72142 .88446 L
s
.61573 .92639 m .55325 .82397 L .5763 .9317 L .649 .421 .56 r
F
.61573 .92639 m .58292 .81451 L .55325 .82397 L F
1 0 0 r
.003 w
.523 .83196 m
.55325 .82397 L
s
.25 g
.5 Mabswid
.55325 .82397 m
.5763 .9317 L
s
.65353 .91724 m .58292 .81451 L .61573 .92639 L .668 .463 .598 r
F
.25 g
.58292 .81451 m
.58348 .81642 L
s
.58348 .81642 m
.61469 .92284 L
s
.61469 .92284 m
.61573 .92639 L
s
1 0 0 r
.003 w
.55325 .82397 m
.58292 .81451 L
s
.58292 .81451 m
.61179 .80353 L
s
.25 g
.5 Mabswid
.61275 .80614 m
.65223 .9137 L
s
.65223 .9137 m
.65353 .91724 L
s
.64113 .79434 m
.68789 .90086 L
s
0 g
.006 w
.1596 .80781 m
.18805 .82421 L
s
.6894 .90431 m
.7231 .88775 L
s
.65353 .91724 m
.6894 .90431 L
s
.18805 .82421 m
.21949 .8413 L
s
.61573 .92639 m
.65353 .91724 L
s
.21949 .8413 m
.25365 .85851 L
s
.5763 .9317 m
.61573 .92639 L
s
.25365 .85851 m
.29023 .87523 L
s
.53562 .9332 m
.5763 .9317 L
s
.29023 .87523 m
.32883 .89085 L
s
.49407 .93099 m
.53562 .9332 L
s
.32883 .89085 m
.369 .90476 L
s
.45213 .92528 m
.49407 .93099 L
s
.41027 .9164 m
.45213 .92528 L
s
.369 .90476 m
.41027 .9164 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{276.688, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(clear; top = 125; kappa[s_] = 1; tau[s_] := Sin[s]; width = 1.0; 
    ds = .1; \), 
    \(pribbonfrenet\)}], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.45486 .63609 m .4231 .62595 L .44548 .61385 L .489 .902 .836 r
F
.4231 .62595 m .42293 .6259 L .42317 .62577 L F
.4231 .62595 m .42317 .62577 L .44548 .61385 L F
.44548 .61385 m .42317 .62577 L .44521 .61586 L 0 0 0 r
F
.42317 .62577 m .42293 .6259 L .44521 .61586 L F
.44548 .61385 m .44521 .61586 L .43565 .59169 L F
.43579 .59175 m .44521 .61586 L .46766 .60517 L F
.43565 .59169 m .43574 .5919 L .43579 .59175 L F
.43574 .5919 m .44521 .61586 L .43579 .59175 L F
.25 g
.5 Mabswid
.42317 .62577 m
.4446 .61432 L
s
.43565 .59169 m .46766 .60517 L .42565 .56968 L 0 0 0 r
F
.25 g
.43565 .59169 m
.43574 .5919 L
s
.45486 .63609 m .40142 .6353 L .42293 .6259 L .489 .902 .836 r
F
.25 g
.42293 .6259 m
.42317 .62577 L
s
.46357 .65833 m .40142 .6353 L .45486 .63609 L .619 .948 .937 r
F
0 g
.006 w
.44614 .61542 m
.45486 .63609 L
s
.42565 .56968 m .48965 .59383 L .41572 .54788 L .202 0 0 r
F
.42565 .56968 m .46766 .60517 L .48965 .59383 L F
.25 g
.5 Mabswid
.44511 .6156 m
.44521 .61586 L
s
0 g
.006 w
.42565 .56968 m
.43565 .59169 L
s
.25 g
.5 Mabswid
.42565 .56968 m
.42601 .56999 L
s
.46357 .65833 m .38118 .64409 L .40142 .6353 L .619 .948 .937 r
F
.25 g
.40142 .6353 m
.45486 .63609 L
s
.47137 .68051 m .38118 .64409 L .46357 .65833 L .68 .933 .968 r
F
0 g
.006 w
.45486 .63609 m
.46357 .65833 L
s
.41572 .54788 m .51058 .58184 L .40615 .52635 L .356 0 .107 r
F
.41572 .54788 m .48965 .59383 L .51058 .58184 L F
.25 g
.5 Mabswid
.4672 .60479 m
.46766 .60517 L
s
0 g
.006 w
.41572 .54788 m
.42565 .56968 L
s
.25 g
.5 Mabswid
.41637 .54828 m
.41638 .54829 L
s
.41572 .54788 m
.41637 .54828 L
s
.4451 .6156 m
.44511 .6156 L
s
.43574 .5919 m
.4451 .6156 L
s
.47137 .68051 m .36262 .65228 L .38118 .64409 L .68 .933 .968 r
F
.47805 .70252 m .36262 .65228 L .47137 .68051 L .704 .897 .966 r
F
.25 g
.46289 .65822 m
.46357 .65833 L
s
0 g
.006 w
.46357 .65833 m
.47137 .68051 L
s
.47805 .70252 m .346 .65988 L .36262 .65228 L .704 .897 .966 r
F
.25 g
.5 Mabswid
.36262 .65228 m
.36362 .65254 L
s
.38118 .64409 m
.46289 .65822 L
s
.48343 .72428 m .346 .65988 L .47805 .70252 L .708 .857 .953 r
F
.25 g
.47048 .68028 m
.47137 .68051 L
s
0 g
.006 w
.47137 .68051 m
.47805 .70252 L
s
.40615 .52635 m .52991 .56927 L .39722 .50515 L .462 .087 .241 r
F
.40615 .52635 m .51058 .58184 L .52991 .56927 L F
.25 g
.5 Mabswid
.48885 .59333 m
.48965 .59383 L
s
0 g
.006 w
.40615 .52635 m
.41572 .54788 L
s
.25 g
.5 Mabswid
.40615 .52635 m
.40709 .52685 L
s
.40709 .52685 m
.40709 .52685 L
s
.4672 .60478 m
.4672 .60479 L
s
.42601 .56999 m
.4672 .60478 L
s
.48343 .72428 m .33146 .66686 L .346 .65988 L .708 .857 .953 r
F
.48734 .74568 m .33146 .66686 L .48343 .72428 L .703 .818 .936 r
F
.25 g
.47699 .70218 m
.47805 .70252 L
s
0 g
.006 w
.47805 .70252 m
.48343 .72428 L
s
.39722 .50515 m .5472 .55621 L .38918 .48433 L .535 .192 .333 r
F
.39722 .50515 m .52991 .56927 L .5472 .55621 L F
.25 g
.5 Mabswid
.48884 .59332 m
.48885 .59333 L
s
.50946 .58124 m
.51058 .58184 L
s
0 g
.006 w
.39722 .50515 m
.40615 .52635 L
s
.25 g
.5 Mabswid
.39722 .50515 m
.39843 .50574 L
s
.39843 .50574 m
.39843 .50574 L
s
.48734 .74568 m .31903 .67316 L .33146 .66686 L .703 .818 .936 r
F
.48963 .7666 m .31903 .67316 L .48734 .74568 L .694 .782 .919 r
F
.25 g
.48223 .72383 m
.48343 .72428 L
s
0 g
.006 w
.48343 .72428 m
.48734 .74568 L
s
.38918 .48433 m .56216 .54279 L .38231 .46395 L .589 .271 .397 r
F
.38918 .48433 m .5472 .55621 L .56216 .54279 L F
.25 g
.5 Mabswid
.50946 .58124 m
.50946 .58124 L
s
.52852 .5686 m
.52991 .56927 L
s
0 g
.006 w
.38918 .48433 m
.39722 .50515 L
s
.25 g
.5 Mabswid
.38918 .48433 m
.39016 .48478 L
s
.39016 .48478 m
.39066 .48501 L
s
.41638 .54829 m
.48884 .59332 L
s
.48963 .7666 m .30865 .67871 L .31903 .67316 L .694 .782 .919 r
F
.49019 .78692 m .30865 .67871 L .48963 .7666 L .682 .748 .901 r
F
.25 g
.48605 .74512 m
.48734 .74568 L
s
0 g
.006 w
.48734 .74568 m
.48963 .7666 L
s
.38231 .46395 m .57466 .52916 L .37686 .44405 L .631 .332 .444 r
F
.38231 .46395 m .56216 .54279 L .57466 .52916 L F
.25 g
.5 Mabswid
.5285 .56859 m
.52852 .5686 L
s
.54559 .55548 m
.5472 .55621 L
s
0 g
.006 w
.38231 .46395 m
.38918 .48433 L
s
.25 g
.5 Mabswid
.38231 .46395 m
.38347 .46445 L
s
.38347 .46445 m
.38404 .46471 L
s
.49019 .78692 m .30019 .68339 L .30865 .67871 L .682 .748 .901 r
F
.48891 .80649 m .30019 .68339 L .49019 .78692 L .669 .717 .884 r
F
.25 g
.4883 .76595 m
.48963 .7666 L
s
0 g
.006 w
.48963 .7666 m
.49019 .78692 L
s
.37686 .44405 m .5847 .51554 L .37306 .4247 L .666 .381 .479 r
F
.37686 .44405 m .57466 .52916 L .5847 .51554 L F
.25 g
.5 Mabswid
.54556 .55547 m
.54559 .55548 L
s
.56041 .54202 m
.56216 .54279 L
s
0 g
.006 w
.37686 .44405 m
.38231 .46395 L
s
.25 g
.5 Mabswid
.37686 .44405 m
.37686 .44405 L
s
.37686 .44405 m
.37819 .44462 L
s
.37819 .44462 m
.37882 .44489 L
s
.40709 .52685 m
.50946 .58124 L
s
.43719 .28615 m .53796 .37101 L .45579 .27626 L .9 .674 .586 r
F
.53796 .37101 m .55463 .38505 L .51653 .33783 L F
.55463 .38505 m .5464 .36812 L .51653 .33783 L F
.53796 .37101 m .51653 .33783 L .45579 .27626 L F
.42071 .2974 m .55991 .39681 L .43719 .28615 L .88 .64 .571 r
F
.55991 .39681 m .56716 .40199 L .55482 .38627 L F
.56716 .40199 m .56477 .39473 L .55482 .38627 L F
.55991 .39681 m .55482 .38627 L .43719 .28615 L F
.40649 .30991 m .54512 .39561 L .42071 .2974 L .857 .614 .569 r
F
.55918 .4133 m .57851 .43575 L .56592 .42177 L .966 .667 .409 r
F
.55337 .40599 m .55909 .41276 L .55918 .4133 L F
.55909 .41276 m .57851 .43575 L .55918 .4133 L F
.55325 .40538 m .57851 .43575 L .55337 .40599 L F
.54507 .39539 m .57851 .43575 L .54512 .39561 L F
.56592 .42177 m .57851 .43575 L .57806 .43687 L F
.54512 .39561 m .53182 .37887 L .42071 .2974 L .857 .614 .569 r
F
.53178 .37876 m .57851 .43575 L .53206 .3797 L .966 .667 .409 r
F
.56229 .43217 m .56645 .43438 L .56097 .42416 L .812 .564 .564 r
F
.42071 .2974 m .53182 .37887 L .53102 .37618 L .88 .64 .571 r
F
.50572 .34622 m .57851 .43575 L .50634 .34772 L .966 .667 .409 r
F
.54512 .39561 m .55325 .40538 L .55337 .40599 L F
.54209 .3918 m .54507 .39539 L .54512 .39561 L F
.40649 .30991 m .54619 .40012 L .54512 .39561 L .857 .614 .569 r
F
.54512 .39561 m .5527 .40029 L .53182 .37887 L F
.53206 .3797 m .54209 .3918 L .56592 .42177 L .966 .667 .409 r
F
.54523 .39606 m .57731 .43593 L .55626 .40231 L F
.57731 .43593 m .57806 .43687 L .57725 .43558 L F
.57731 .43593 m .57725 .43558 L .55626 .40231 L F
.5527 .40029 m .54584 .38916 L .53182 .37887 L .857 .614 .569 r
F
.54512 .39561 m .54788 .39756 L .5527 .40029 L F
.56139 .41336 m .56454 .41544 L .5649 .41905 L .982 .697 .387 r
F
.56454 .41544 m .57771 .43631 L .5649 .41905 L F
.55658 .40456 m .55645 .40363 L .54512 .39561 L .857 .614 .569 r
F
.54619 .40012 m .55695 .40707 L .54512 .39561 L F
.55419 .40439 m .55658 .40456 L .54512 .39561 L F
.55695 .40707 m .55678 .40591 L .55419 .40439 L F
.55678 .40591 m .55658 .40456 L .55419 .40439 L F
.54523 .39606 m .55626 .40231 L .54957 .39172 L .966 .667 .409 r
F
.55626 .40231 m .56095 .40974 L .55626 .40232 L .982 .697 .387 r
F
.56095 .40974 m .57806 .43687 L .56095 .40975 L F
.56095 .40974 m .56095 .40975 L .55626 .40232 L F
.55552 .41687 m .56229 .42079 L .55427 .41057 L .835 .589 .567 r
F
.55678 .40591 m .56113 .41125 L .56139 .41336 L .982 .697 .387 r
F
.56113 .41125 m .56454 .41544 L .56139 .41336 L F
.55626 .40232 m .56454 .41544 L .56409 .41489 L F
.55629 .40251 m .56409 .41489 L .55678 .40591 L F
.55626 .40232 m .56409 .41489 L .55629 .40251 L F
.54523 .39606 m .54957 .39172 L .53827 .38396 L .966 .667 .409 r
F
.5527 .40029 m .55629 .40251 L .54584 .38916 L .857 .614 .569 r
F
.54957 .39172 m .55626 .40231 L .54958 .39172 L .982 .697 .387 r
F
.53102 .37618 m .54928 .39008 L .54911 .38909 L .88 .64 .571 r
F
.55626 .40231 m .55626 .40232 L .54958 .39174 L .982 .697 .387 r
F
.54851 .39098 m .54928 .39008 L .53102 .37618 L .88 .64 .571 r
F
.54961 .39192 m .54957 .39172 L .54851 .39098 L F
.54957 .39172 m .54928 .39008 L .54851 .39098 L F
.50634 .34772 m .53178 .37876 L .53206 .3797 L .966 .667 .409 r
F
.43719 .28615 m .5046 .34352 L .50422 .3426 L .9 .674 .586 r
F
.45017 .27791 m .50572 .34622 L .50634 .34772 L .966 .667 .409 r
F
.56092 .40538 m .56377 .40714 L .56076 .40398 L .857 .614 .569 r
F
.55626 .40231 m .54958 .39174 L .54958 .39172 L .982 .697 .387 r
F
.50422 .3426 m .53812 .37165 L .53796 .37101 L .9 .674 .586 r
F
.53182 .37887 m .54961 .39192 L .53102 .37618 L .88 .64 .571 r
F
.5046 .34352 m .53824 .37215 L .50422 .3426 L .9 .674 .586 r
F
.53824 .37215 m .55482 .38627 L .53812 .37165 L F
.55482 .38627 m .55477 .38592 L .53812 .37165 L F
.53796 .37101 m .5547 .38548 L .55463 .38505 L F
.5649 .41905 m .57771 .43631 L .57728 .43908 L .982 .697 .387 r
F
.57728 .43908 m .57771 .43631 L .57772 .43979 L F
.56139 .41336 m .57708 .43875 L .56672 .41592 L F
.57708 .43875 m .57708 .43862 L .56672 .41592 L F
.57728 .43908 m .57722 .4387 L .56672 .41592 L F
.56645 .43438 m .57281 .43775 L .56575 .42748 L .812 .564 .564 r
F
.57366 .43805 m .57747 .44437 L .57728 .45044 L .952 .706 .249 r
F
.57266 .43464 m .57359 .43653 L .57366 .43805 L F
.57359 .43653 m .57747 .44437 L .57366 .43805 L F
.56927 .42606 m .57772 .43979 L .57747 .44437 L .983 .712 .332 r
F
.56719 .42141 m .56888 .4207 L .56927 .42606 L F
.57708 .43875 m .57728 .43908 L .57708 .43862 L .982 .697 .387 r
F
.57728 .43908 m .57772 .43979 L .57722 .4387 L F
.56888 .4207 m .57772 .43979 L .56927 .42606 L .983 .712 .332 r
F
.56673 .41605 m .57772 .43979 L .56673 .41606 L F
.53812 .37165 m .55477 .38592 L .53796 .37101 L .9 .674 .586 r
F
.55477 .38592 m .55473 .3857 L .53796 .37101 L F
.56475 .39447 m .56474 .39436 L .55472 .38563 L F
.55473 .3857 m .55472 .38563 L .53796 .37101 L F
.56475 .39447 m .55472 .38563 L .55473 .3857 L F
.56473 .3943 m .56471 .39414 L .5547 .38548 L F
.57145 .40022 m .5547 .38548 L .55472 .38563 L F
.55477 .38592 m .56475 .39447 L .55473 .3857 L F
.55629 .40251 m .55033 .39305 L .54584 .38916 L .857 .614 .569 r
F
.54956 .3917 m .55626 .40232 L .55571 .40159 L .982 .697 .387 r
F
.55033 .39305 m .54961 .39192 L .54584 .38916 L .857 .614 .569 r
F
.54941 .39161 m .55571 .40159 L .54686 .38985 L .982 .697 .387 r
F
.54956 .3917 m .55571 .40159 L .54941 .39161 L F
.56866 .4089 m .56738 .40495 L .54961 .39192 L .857 .614 .569 r
F
.5687 .40904 m .54961 .39192 L .55033 .39305 L F
.57328 .41301 m .56866 .4089 L .5687 .40904 L F
.56866 .4089 m .54961 .39192 L .5687 .40904 L F
.56377 .40714 m .56184 .40307 L .55033 .39305 L F
.55678 .40591 m .56139 .41336 L .56407 .41016 L .982 .697 .387 r
F
.56139 .41336 m .56672 .41592 L .56407 .41016 L F
.54961 .39192 m .56025 .39972 L .54928 .39008 L .88 .64 .571 r
F
.56025 .39972 m .56009 .39831 L .54928 .39008 L F
.55472 .38563 m .5547 .38548 L .53796 .37101 L .9 .674 .586 r
F
.56673 .41605 m .56673 .41606 L .56409 .41035 L .983 .712 .332 r
F
.5527 .40029 m .56389 .40837 L .56377 .40714 L .857 .614 .569 r
F
.54788 .39756 m .56395 .40895 L .5527 .40029 L F
.56395 .40895 m .56932 .41275 L .56389 .40837 L F
.56932 .41275 m .56929 .41225 L .56389 .40837 L F
.57656 .41504 m .60615 .43884 L .60582 .43313 L F
.56917 .41047 m .57332 .41428 L .57328 .41301 L F
.56377 .40714 m .56922 .41121 L .56917 .41047 L F
.56922 .41121 m .57332 .41428 L .56917 .41047 L F
.56389 .40837 m .57335 .41519 L .56377 .40714 L F
.57335 .41519 m .57334 .41489 L .56377 .40714 L F
.57658 .41751 m .57657 .41671 L .56377 .40714 L F
.56395 .40895 m .56389 .40837 L .5527 .40029 L F
.56673 .41605 m .56409 .41034 L .56409 .41034 L .983 .712 .332 r
F
.56673 .41605 m .56409 .41035 L .56409 .41034 L F
.56025 .39972 m .57253 .40872 L .56009 .39831 L .88 .64 .571 r
F
.57253 .40872 m .57647 .41161 L .57249 .40775 L F
.57647 .41161 m .57647 .41078 L .57249 .40775 L F
.57335 .41519 m .57658 .41751 L .57334 .41489 L .857 .614 .569 r
F
.57328 .41301 m .57657 .41671 L .57656 .41504 L F
.57332 .41428 m .57657 .41671 L .57328 .41301 L F
.56932 .41275 m .60615 .43884 L .56929 .41225 L F
.57253 .40872 m .57249 .40775 L .56009 .39831 L .88 .64 .571 r
F
.55399 .39931 m .55626 .40232 L .55678 .40591 L .982 .697 .387 r
F
.56092 .40538 m .56076 .40398 L .55033 .39305 L .857 .614 .569 r
F
.55629 .40251 m .56092 .40538 L .55033 .39305 L F
.54911 .38909 m .56004 .39791 L .55991 .39681 L .88 .64 .571 r
F
.54928 .39008 m .56009 .39831 L .54911 .38909 L F
.56009 .39831 m .56004 .39791 L .54911 .38909 L F
.57345 .41772 m .57337 .41562 L .56395 .40895 L .857 .614 .569 r
F
.56405 .40993 m .56395 .40895 L .55645 .40363 L F
.57345 .41772 m .56395 .40895 L .56405 .40993 L F
.56673 .41605 m .56409 .41034 L .56409 .41034 L .983 .712 .332 r
F
.5641 .41042 m .55645 .40363 L .55658 .40456 L .857 .614 .569 r
F
.56409 .41033 m .56673 .41605 L .56409 .41034 L .983 .712 .332 r
F
.56405 .40993 m .55645 .40363 L .5641 .41042 L .857 .614 .569 r
F
.55695 .40707 m .56423 .41177 L .55658 .40456 L F
.56407 .41016 m .56672 .41592 L .56409 .41033 L .983 .712 .332 r
F
.56672 .41592 m .57772 .43979 L .56673 .41605 L F
.56672 .41592 m .56673 .41605 L .56409 .41033 L F
.56166 .41565 m .56701 .41932 L .56153 .41452 L .835 .589 .567 r
F
.39464 .32357 m .56685 .41742 L .40649 .30991 L F
.56673 .41606 m .56843 .41973 L .56754 .41892 L .983 .712 .332 r
F
.56673 .41606 m .56754 .41892 L .56685 .41742 L F
.56685 .41742 m .56423 .41177 L .40649 .30991 L .835 .589 .567 r
F
.56701 .41932 m .56693 .41836 L .56153 .41452 L F
.56423 .41177 m .5641 .41042 L .55658 .40456 L .857 .614 .569 r
F
.55678 .40591 m .56407 .41016 L .49605 .26253 L .982 .697 .387 r
F
.5672 .42162 m .56701 .41932 L .56166 .41565 L .835 .589 .567 r
F
.56153 .41452 m .56693 .41836 L .56685 .41742 L F
.56125 .40815 m .56673 .41606 L .56719 .42141 L .983 .712 .332 r
F
.56062 .40286 m .56673 .41606 L .56125 .40815 L F
.5789 .42399 m .60615 .43884 L .57922 .42145 L .835 .589 .567 r
F
.57103 .42209 m .60616 .44624 L .57098 .42124 L F
.57771 .43631 m .57806 .43687 L .57772 .43979 L .982 .697 .387 r
F
.57686 .4399 m .60565 .45517 L .57682 .43516 L .812 .564 .564 r
F
.57647 .41161 m .60582 .43313 L .57647 .41078 L .88 .64 .571 r
F
.57658 .41751 m .60615 .43884 L .57657 .41671 L .857 .614 .569 r
F
.57657 .41671 m .60615 .43884 L .57656 .41504 L F
.56719 .42141 m .5771 .44356 L .5711 .42337 L .983 .712 .332 r
F
.5771 .44356 m .5771 .44335 L .5711 .42337 L F
.57728 .44395 m .57747 .44437 L .57721 .44352 L F
.57728 .44395 m .57721 .44352 L .5711 .42337 L F
.57283 .42918 m .57747 .44437 L .57674 .44235 L .952 .706 .249 r
F
.57283 .42918 m .57674 .44235 L .57351 .43332 L F
.57252 .43009 m .57351 .43332 L .57244 .43032 L F
.57283 .42918 m .57351 .43332 L .57252 .43009 L F
.3852 .33828 m .57241 .42975 L .39464 .32357 L .812 .564 .564 r
F
.57283 .42918 m .57244 .43032 L .57235 .42855 L .952 .706 .249 r
F
.57241 .42975 m .57125 .42599 L .39464 .32357 L .812 .564 .564 r
F
.57111 .42356 m .57283 .42918 L .57132 .42719 L .952 .706 .249 r
F
.56685 .41742 m .5789 .42399 L .56423 .41177 L .835 .589 .567 r
F
.56843 .41973 m .56888 .4207 L .56693 .41836 L .983 .712 .332 r
F
.56701 .41932 m .57103 .42209 L .56693 .41836 L .835 .589 .567 r
F
.57103 .42209 m .57098 .42124 L .56693 .41836 L F
.5789 .42399 m .57922 .42145 L .56423 .41177 L F
.56685 .41742 m .56754 .41892 L .56693 .41836 L .983 .712 .332 r
F
.56693 .41836 m .56888 .4207 L .56719 .42141 L F
.56423 .41177 m .57345 .41772 L .5641 .41042 L .857 .614 .569 r
F
.57345 .41772 m .56405 .40993 L .5641 .41042 L F
.56009 .39831 m .56834 .40459 L .56004 .39791 L .88 .64 .571 r
F
.57125 .42599 m .57103 .42209 L .56701 .41932 L .835 .589 .567 r
F
.57125 .42599 m .56701 .41932 L .5672 .42162 L F
.55482 .38627 m .57146 .40043 L .55477 .38592 L .9 .674 .586 r
F
.57146 .40043 m .57634 .40458 L .57146 .40036 L F
.57146 .40043 m .57146 .40036 L .55477 .38592 L F
.57634 .40458 m .57634 .40454 L .57146 .40032 L F
.57146 .40036 m .57146 .40032 L .55477 .38592 L F
.57634 .40458 m .57146 .40032 L .57146 .40036 L F
.58015 .40782 m .58016 .40768 L .57634 .40441 L F
.57146 .40032 m .57145 .40022 L .55477 .38592 L F
.58019 .40657 m .60531 .42924 L .60473 .42724 L F
.5714 .39917 m .57634 .40398 L .57633 .40333 L F
.55463 .38505 m .57143 .39969 L .5714 .39917 L F
.57143 .39969 m .57634 .40398 L .5714 .39917 L F
.5547 .38548 m .57634 .40419 L .55463 .38505 L F
.57634 .40419 m .60531 .42924 L .57634 .40398 L F
.57634 .40419 m .57634 .40398 L .55463 .38505 L F
.56377 .40714 m .57328 .41301 L .56184 .40307 L .857 .614 .569 r
F
.55991 .39681 m .56834 .40459 L .57646 .41 L .88 .64 .571 r
F
.57645 .40862 m .57646 .41 L .60531 .42924 L F
.55991 .39681 m .57646 .41 L .57645 .40862 L F
.57229 .42728 m .57747 .44437 L .5723 .42743 L .952 .706 .249 r
F
.57691 .44238 m .60434 .46543 L .60565 .45517 L .79 .54 .559 r
F
.57258 .4332 m .57334 .43493 L .57266 .43464 L .952 .706 .249 r
F
.57569 .4403 m .57747 .44437 L .57579 .44099 L F
.56943 .42829 m .57245 .43053 L .57241 .42975 L .812 .564 .564 r
F
.5771 .44356 m .57728 .44395 L .5771 .44335 L .983 .712 .332 r
F
.57281 .43775 m .57253 .43218 L .56575 .42748 L .812 .564 .564 r
F
.57253 .43218 m .57245 .43053 L .56943 .42829 L F
.57132 .42719 m .57244 .43032 L .57153 .43078 L .952 .706 .249 r
F
.57244 .43032 m .57747 .44437 L .57258 .4332 L F
.56956 .43012 m .57253 .43218 L .56943 .42829 L .812 .564 .564 r
F
.57244 .43032 m .57258 .4332 L .57153 .43078 L .952 .706 .249 r
F
.57253 .43218 m .5749 .43382 L .57245 .43053 L .812 .564 .564 r
F
.5749 .43382 m .57485 .43232 L .57245 .43053 L F
.57245 .43053 m .57485 .43232 L .57241 .42975 L F
.57485 .43232 m .60565 .45517 L .57483 .4316 L F
.57485 .43232 m .57483 .4316 L .57241 .42975 L F
.57266 .43464 m .57728 .45044 L .57495 .43561 L .952 .706 .249 r
F
.56004 .39791 m .56834 .40459 L .55991 .39681 L .88 .64 .571 r
F
.57089 .41962 m .57414 .42348 L .57407 .42136 L .835 .589 .567 r
F
.56685 .41742 m .57096 .42084 L .57089 .41962 L F
.57096 .42084 m .57414 .42348 L .57089 .41962 L F
.56693 .41836 m .57098 .42124 L .56685 .41742 L F
.57098 .42124 m .57414 .42348 L .57096 .42084 L F
.57098 .42124 m .57096 .42084 L .56685 .41742 L F
.57229 .42728 m .5723 .42743 L .57111 .42356 L .952 .706 .249 r
F
.55463 .38505 m .5714 .39917 L .5464 .36812 L .9 .674 .586 r
F
.5714 .39917 m .57103 .39709 L .5464 .36812 L F
.57633 .40333 m .57621 .39833 L .57016 .39219 L F
.57103 .39709 m .57016 .39219 L .5464 .36812 L F
.57633 .40333 m .57016 .39219 L .57103 .39709 L F
.57102 .42333 m .5711 .42337 L .57095 .42286 L .983 .712 .332 r
F
.57102 .42333 m .57095 .42286 L .53847 .31562 L F
.56719 .42141 m .57102 .42333 L .53847 .31562 L F
.57111 .42347 m .57111 .42356 L .56973 .41901 L .952 .706 .249 r
F
.57229 .42728 m .57111 .42356 L .57111 .42347 L F
.56971 .41877 m .5711 .42337 L .57107 .42335 L F
.5711 .42337 m .57229 .42728 L .57111 .42347 L F
.5711 .42337 m .57111 .42347 L .57107 .42335 L F
.56971 .41877 m .57107 .42335 L .56973 .41901 L F
.57241 .42975 m .60616 .44624 L .57125 .42599 L .812 .564 .564 r
F
.57241 .42975 m .60565 .45517 L .60616 .44624 L F
.57235 .42855 m .57244 .43032 L .57132 .42719 L .952 .706 .249 r
F
.56973 .41901 m .57111 .42356 L .57002 .42356 L F
.56229 .42079 m .57125 .42599 L .56685 .42125 L .835 .589 .567 r
F
.57111 .42356 m .57132 .42719 L .57002 .42356 L .952 .706 .249 r
F
.57266 .43464 m .5743 .43534 L .57253 .43218 L .812 .564 .564 r
F
.57378 .44098 m .57552 .44238 L .57551 .44175 L .79 .54 .559 r
F
.37819 .35396 m .57551 .44175 L .3852 .33828 L F
.57496 .43579 m .57543 .43879 L .57528 .44034 L .87 .667 .139 r
F
.57496 .43579 m .57528 .44034 L .57505 .43894 L F
.57543 .43879 m .57728 .45044 L .57555 .4435 L F
.57551 .44175 m .57505 .43894 L .3852 .33828 L .79 .54 .559 r
F
.57418 .45057 m .57576 .45135 L .57378 .44098 L F
.57543 .43865 m .57728 .45044 L .57543 .43865 L .87 .667 .139 r
F
.57796 .45243 m .60434 .46543 L .57807 .44442 L .79 .54 .559 r
F
.57686 .4399 m .57682 .43516 L .5749 .43382 L .812 .564 .564 r
F
.57498 .43655 m .5749 .43382 L .57253 .43218 L F
.57495 .43561 m .57728 .45044 L .57496 .43579 L .87 .667 .139 r
F
.57495 .43561 m .57543 .43865 L .57495 .43561 L F
.57686 .4399 m .5749 .43382 L .57498 .43655 L .812 .564 .564 r
F
.57328 .41301 m .57253 .40872 L .56738 .40495 L .857 .614 .569 r
F
.57328 .41301 m .56738 .40495 L .56866 .4089 L F
.57145 .40022 m .57144 .39995 L .56471 .39414 L .9 .674 .586 r
F
.57145 .40022 m .56471 .39414 L .56473 .3943 L F
.57153 .43078 m .57258 .4332 L .57266 .43464 L .952 .706 .249 r
F
.57125 .42599 m .60616 .44624 L .57103 .42209 L .835 .589 .567 r
F
.56475 .39447 m .57145 .40022 L .56474 .39436 L .9 .674 .586 r
F
.56834 .40459 m .60582 .43313 L .60542 .43004 L .88 .64 .571 r
F
.56834 .40459 m .60542 .43004 L .60531 .42924 L F
.56716 .40199 m .57645 .40862 L .56477 .39473 L F
.57645 .40862 m .60531 .42924 L .57634 .40458 L F
.57645 .40862 m .57634 .40458 L .56477 .39473 L F
.57796 .45243 m .57807 .44442 L .57692 .4435 L .79 .54 .559 r
F
.57694 .44825 m .57692 .4435 L .57552 .44238 L F
.57266 .43464 m .57495 .43561 L .54679 .25606 L .952 .706 .249 r
F
.57443 .4323 m .57495 .43561 L .57444 .43253 L .87 .667 .139 r
F
.57495 .43561 m .57496 .43579 L .57444 .43253 L F
.57576 .45135 m .57552 .44238 L .57378 .44098 L .79 .54 .559 r
F
.57608 .45057 m .57728 .45044 L .57717 .45777 L .87 .667 .139 r
F
.57523 .44488 m .576 .44699 L .57608 .45057 L F
.576 .44699 m .57728 .45044 L .57608 .45057 L F
.57514 .44181 m .57728 .45044 L .57523 .44488 L F
.57567 .4478 m .57608 .45057 L .57696 .44826 L F
.57608 .45057 m .57717 .45777 L .57702 .45082 L F
.57608 .45057 m .57702 .45082 L .57696 .44826 L F
.57696 .44826 m .57702 .45082 L .57696 .44826 L .729 .587 .013 r
F
.57702 .45082 m .57717 .45777 L .57702 .45082 L F
.57702 .45082 m .57702 .45082 L .57696 .44826 L F
.57771 .45448 m .58907 .46497 L .60434 .46543 L .768 .514 .55 r
F
.58907 .46497 m .60192 .47684 L .60359 .46894 L F
.58907 .46497 m .60359 .46894 L .60434 .46543 L F
.57543 .43865 m .57543 .43865 L .57495 .43561 L .87 .667 .139 r
F
.57543 .43879 m .57544 .43915 L .5754 .43913 L F
.57544 .43915 m .57555 .4435 L .5754 .43913 L F
.5754 .43913 m .57555 .4435 L .57514 .44181 L F
.57505 .43894 m .57686 .4399 L .57498 .43655 L .812 .564 .564 r
F
.57576 .45135 m .57699 .45195 L .57639 .44806 L .79 .54 .559 r
F
.57567 .4478 m .57639 .44806 L .57552 .44238 L F
.57576 .45135 m .57639 .44806 L .57567 .4478 L F
.57699 .45195 m .57696 .44832 L .57552 .44238 L F
.57551 .44175 m .60565 .45517 L .57505 .43894 L F
.57551 .44175 m .57692 .4435 L .57691 .44238 L F
.57552 .44238 m .57692 .4435 L .57551 .44175 L F
.5714 .39917 m .57633 .40333 L .57103 .39709 L .9 .674 .586 r
F
.5749 .43382 m .60565 .45517 L .57485 .43232 L .812 .564 .564 r
F
.57634 .40454 m .57634 .40441 L .57145 .40022 L .9 .674 .586 r
F
.57634 .40454 m .57145 .40022 L .57146 .40032 L F
.57145 .40022 m .60531 .42924 L .57144 .39995 L F
.57407 .42136 m .60616 .44624 L .60615 .43884 L .835 .589 .567 r
F
.57414 .42348 m .60616 .44624 L .57407 .42136 L F
.57345 .41772 m .60615 .43884 L .57337 .41562 L .857 .614 .569 r
F
.57328 .41301 m .60582 .43313 L .57253 .40872 L F
.57567 .4478 m .57696 .44826 L .57272 .25344 L .87 .667 .139 r
F
.57677 .43973 m .57702 .45082 L .57677 .43973 L .729 .587 .013 r
F
.57702 .45082 m .57717 .45777 L .57702 .45082 L F
.57702 .45082 m .57702 .45082 L .57677 .43973 L F
.5764 .46495 m .57712 .46529 L .57616 .45384 L .768 .514 .55 r
F
.57712 .46529 m .57704 .45464 L .57616 .45384 L F
.57616 .45384 m .57704 .45464 L .57704 .45421 L F
.37356 .37051 m .57704 .45421 L .37819 .35396 L F
.57704 .45421 m .57704 .45414 L .37819 .35396 L F
.57696 .44832 m .57696 .44826 L .57694 .44825 L .79 .54 .559 r
F
.57677 .43973 m .57717 .45777 L .57708 .45569 L .729 .587 .013 r
F
.57677 .43973 m .57708 .45569 L .57682 .44445 L F
.57771 .45448 m .57796 .45243 L .57699 .45195 L .768 .514 .55 r
F
.57704 .45414 m .57699 .45195 L .37819 .35396 L F
.57771 .45448 m .57699 .45195 L .57704 .45414 L F
.57682 .44445 m .57708 .45569 L .57688 .4512 L .729 .587 .013 r
F
.57688 .4512 m .57708 .45569 L .57719 .46604 L F
.57708 .45569 m .57717 .45777 L .57717 .45992 L F
.57708 .45569 m .57717 .45992 L .57719 .46604 L F
.57704 .45421 m .57771 .45448 L .57704 .45414 L .768 .514 .55 r
F
.5771 .46169 m .57719 .46604 L .57762 .46183 L .729 .587 .013 r
F
.57762 .4619 m .57719 .46604 L .57758 .46526 L 0 0 .108 r
F
.57758 .4655 m .60192 .47684 L .5777 .45522 L .768 .514 .55 r
F
.57785 .45963 m .57762 .46183 L .57785 .45973 L 0 0 .108 r
F
.57762 .46183 m .57719 .46604 L .57762 .4619 L F
.57762 .46183 m .57762 .4619 L .57785 .45973 L F
.57736 .46736 m .60192 .47684 L .57758 .4655 L .745 .486 .539 r
F
.57736 .46736 m .59806 .48914 L .60192 .47684 L F
.57736 .46736 m .57719 .46604 L .57725 .46828 L 0 0 .108 r
F
.57726 .47985 m .59806 .48914 L .57736 .46736 L .745 .486 .539 r
F
.57762 .4652 m .57725 .46828 L .57745 .47494 L 0 0 .108 r
F
.37125 .38786 m .57726 .47985 L .57736 .46736 L .745 .486 .539 r
F
.57762 .4652 m .57738 .46567 L .57736 .46736 L 0 0 .108 r
F
.57738 .46567 m .57719 .46604 L .57736 .46736 L F
.57859 .46327 m .57762 .4652 L .57745 .47494 L F
.37125 .38786 m .57736 .46736 L .37356 .37051 L .745 .486 .539 r
F
.57736 .46736 m .57758 .4655 L .37356 .37051 L F
.57712 .46529 m .57758 .4655 L .57704 .45464 L .768 .514 .55 r
F
.57758 .4655 m .5777 .45522 L .57704 .45464 L F
.57704 .45421 m .57771 .45481 L .57771 .45448 L F
.57771 .45481 m .60192 .47684 L .57771 .45448 L F
.57704 .45464 m .60192 .47684 L .57704 .45421 L F
.57696 .44826 m .57692 .4435 L .57694 .44825 L .79 .54 .559 r
F
.57796 .45243 m .57692 .4435 L .57696 .44832 L F
.57344 .28752 m .5767 .43634 L .57681 .44798 L .729 .587 .013 r
F
.57341 .28639 m .57345 .28787 L .57344 .28752 L F
.57345 .28787 m .5767 .43634 L .57344 .28752 L F
.5769 .44563 m .57696 .44826 L .5769 .44563 L F
.57696 .44826 m .57696 .44826 L .5769 .44563 L F
.57699 .45195 m .57796 .45243 L .57696 .44832 L .79 .54 .559 r
F
.57771 .45448 m .60434 .46543 L .57796 .45243 L .768 .514 .55 r
F
.57664 .43358 m .57664 .43358 L .5736 .29395 L .729 .587 .013 r
F
.5736 .29395 m .5736 .29395 L .57274 .25439 L F
.57664 .43358 m .5736 .29395 L .5736 .29395 L F
.57633 .40333 m .60473 .42724 L .57621 .39833 L .9 .674 .586 r
F
.57274 .25439 m .5736 .29394 L .57341 .28639 L .729 .587 .013 r
F
.5736 .29394 m .5767 .43634 L .57341 .28639 L F
.57692 .4435 m .60434 .46543 L .57691 .44238 L .79 .54 .559 r
F
.57681 .44798 m .57677 .43973 L .57688 .4512 L .729 .587 .013 r
F
.5767 .43634 m .57677 .43973 L .57681 .44798 L F
.57677 .43973 m .57677 .43973 L .57664 .43358 L F
.57664 .43358 m .57664 .43358 L .57274 .25439 L F
.57677 .43973 m .57664 .43358 L .57664 .43358 L F
.57275 .25471 m .57664 .43358 L .57274 .25439 L F
.57664 .43358 m .57677 .43973 L .57664 .43358 L F
.57633 .40333 m .58017 .40731 L .58019 .40657 L .9 .674 .586 r
F
.57634 .40398 m .58017 .40731 L .57633 .40333 L F
.58017 .40731 m .60531 .42924 L .58019 .40657 L F
.58015 .40782 m .57634 .40441 L .57634 .40454 L F
.5767 .43633 m .5767 .43633 L .57664 .43358 L .729 .587 .013 r
F
.57664 .43357 m .57664 .43358 L .57273 .25383 L F
.5767 .43633 m .57664 .43358 L .57664 .43357 L F
.57273 .254 m .57664 .43357 L .57273 .25383 L F
.57664 .43357 m .5767 .43633 L .57664 .43357 L F
.57664 .43357 m .57664 .43357 L .57273 .25383 L F
.57634 .40458 m .58015 .40782 L .57634 .40454 L .9 .674 .586 r
F
.58015 .40782 m .60531 .42924 L .58016 .40768 L F
.5767 .43633 m .5769 .44563 L .5767 .43633 L .729 .587 .013 r
F
.5769 .44563 m .5769 .44563 L .5767 .43633 L F
.57273 .25383 m .57275 .25471 L .57274 .25439 L F
.57272 .25344 m .57273 .254 L .57273 .25383 L F
.57272 .25344 m .5771 .46169 L .5991 .25455 L F
.5771 .46169 m .57762 .46183 L .5991 .25455 L F
.579 .44878 m .57762 .4619 L .57859 .46327 L 0 0 .108 r
F
.57762 .4619 m .57758 .46526 L .57859 .46327 L F
.37356 .37051 m .5764 .46495 L .57616 .45384 L .768 .514 .55 r
F
.57281 .43775 m .57505 .43894 L .5743 .43534 L .812 .564 .564 r
F
.57419 .43799 m .57514 .44181 L .57523 .44488 L .87 .667 .139 r
F
.57505 .43894 m .57498 .43655 L .5743 .43534 L .812 .564 .564 r
F
.57505 .43894 m .57528 .44034 L .57514 .44181 L .87 .667 .139 r
F
.57245 .41965 m .57245 .41965 L .55324 .29723 L F
.57266 .43464 m .54679 .25606 L .54677 .25607 L .952 .706 .249 r
F
.55324 .29723 m .55324 .29723 L .54676 .25588 L .87 .667 .139 r
F
.57245 .41965 m .55324 .29723 L .55324 .29723 L F
.54679 .25606 m .55325 .29726 L .54676 .25588 L F
.55325 .29726 m .57245 .41965 L .55324 .29723 L F
.55325 .29726 m .55324 .29723 L .54676 .25588 L F
.57245 .41965 m .57245 .41965 L .55324 .29722 L F
.55324 .29723 m .55324 .29722 L .54676 .25588 L F
.57245 .41965 m .55324 .29722 L .55324 .29723 L F
.57385 .42883 m .57493 .4356 L .57409 .43525 L F
.57493 .4356 m .57496 .43579 L .57409 .43525 L F
.57281 .43775 m .5743 .43534 L .57266 .43464 L .812 .564 .564 r
F
.57409 .43525 m .57496 .43579 L .57419 .43799 L .87 .667 .139 r
F
.57496 .43579 m .57514 .44181 L .57419 .43799 L F
.57384 .42855 m .57495 .43561 L .57384 .42855 L F
.57495 .43561 m .57495 .43561 L .57384 .42855 L F
.57297 .42993 m .57385 .42883 L .57419 .43799 L F
.55245 .29371 m .57247 .4201 L .57297 .42993 L F
.57247 .4201 m .57385 .42883 L .57297 .42993 L F
.54677 .25607 m .54679 .25606 L .54653 .25445 L .952 .706 .249 r
F
.57384 .42855 m .57384 .42855 L .57245 .41965 L .87 .667 .139 r
F
.57384 .42855 m .57245 .41965 L .57245 .41965 L F
.57245 .41965 m .57384 .42855 L .57245 .41965 L F
.57317 .42432 m .57317 .42454 L .57247 .4201 L F
.57246 .41986 m .57247 .4201 L .55245 .29371 L F
.57317 .42432 m .57247 .4201 L .57246 .41986 L F
.57385 .4286 m .57385 .42883 L .57317 .42454 L F
.57385 .4286 m .57317 .42454 L .57317 .42432 L F
.57443 .4323 m .57444 .43253 L .57385 .42883 L F
.57443 .4323 m .57385 .42883 L .57385 .4286 L F
.54673 .25569 m .54679 .25606 L .54671 .25559 L F
.54679 .25606 m .54676 .25588 L .54671 .25559 L F
.54657 .2547 m .54673 .25569 L .54656 .25462 L F
.54673 .25569 m .54671 .25559 L .54656 .25462 L F
.55484 .3074 m .57245 .41965 L .55245 .29371 L F
.57245 .41965 m .57443 .4323 L .57246 .41986 L F
.57245 .41965 m .57246 .41986 L .55245 .29371 L F
.54656 .25462 m .55484 .3074 L .55245 .29371 L F
.54653 .25445 m .54657 .2547 L .54656 .25462 L F
.54653 .25445 m .57567 .4478 L .57275 .25522 L F
.54653 .25445 m .57275 .25522 L .57272 .25344 L F
.58743 .37338 m .579 .44878 L .57859 .46327 L 0 0 .108 r
F
.59473 .29909 m .58333 .40754 L .58743 .37338 L F
.58333 .40754 m .579 .44878 L .58743 .37338 L F
.57901 .44845 m .57785 .45963 L .579 .44878 L F
.57785 .45963 m .57785 .45973 L .579 .44878 L F
.59342 .30943 m .57901 .44845 L .59473 .29909 L F
.57901 .44845 m .579 .44878 L .59473 .29909 L F
.5991 .25455 m .59342 .30943 L .59473 .29909 L F
.55576 .39211 m .56407 .41016 L .56399 .41011 L .983 .712 .332 r
F
.56407 .41016 m .56409 .41033 L .56399 .41011 L F
.55576 .39211 m .56399 .41011 L .55581 .39244 L F
.55581 .39244 m .56409 .41033 L .55581 .39246 L F
.56409 .41033 m .56409 .41034 L .55581 .39246 L F
.56409 .41034 m .56062 .40285 L .56062 .40285 L F
.56409 .41034 m .56062 .40285 L .56409 .41034 L F
.56062 .40285 m .55581 .39247 L .55581 .39246 L F
.56062 .40285 m .55581 .39247 L .56062 .40285 L F
.56594 .4066 m .56973 .41901 L .5667 .41425 L .952 .706 .249 r
F
.56973 .41901 m .57002 .42356 L .5667 .41425 L F
.5659 .40619 m .56971 .41877 L .56594 .4066 L F
.56971 .41877 m .56973 .41901 L .56594 .4066 L F
.53699 .31457 m .53847 .31562 L .52087 .25752 L .983 .712 .332 r
F
.56409 .41034 m .56062 .40286 L .56062 .40285 L F
.56409 .41034 m .56062 .40286 L .56409 .41034 L F
.56409 .41034 m .56398 .41011 L .56398 .41011 L F
.56409 .41034 m .56409 .41035 L .56398 .41011 L F
.56719 .42141 m .53847 .31562 L .53699 .31457 L F
.5659 .40619 m .56594 .4066 L .53346 .30015 L .952 .706 .249 r
F
.53359 .30056 m .53346 .30015 L .53043 .29021 L F
.5659 .40619 m .53346 .30015 L .53359 .30056 L F
.53482 .30357 m .53847 .31562 L .53043 .29021 L F
.53847 .31562 m .5659 .40619 L .53359 .30056 L F
.53847 .31562 m .53359 .30056 L .53043 .29021 L F
.5667 .41425 m .57132 .42719 L .57153 .43078 L F
.53043 .29021 m .56594 .4066 L .5667 .41425 L F
.52087 .25752 m .53482 .30357 L .53043 .29021 L F
.52087 .25752 m .57266 .43464 L .54677 .25607 L F
.52087 .25752 m .54677 .25607 L .54653 .25445 L F
.54686 .38985 m .55399 .39931 L .55678 .40591 L .982 .697 .387 r
F
.56398 .41011 m .56398 .41011 L .56062 .40286 L .983 .712 .332 r
F
.56062 .40285 m .56062 .40286 L .55581 .39247 L F
.55581 .39246 m .55581 .39247 L .50777 .28871 L F
.5084 .29001 m .55581 .39244 L .50777 .28871 L F
.55581 .39244 m .55581 .39246 L .50777 .28871 L F
.51322 .2998 m .55576 .39211 L .50702 .28703 L F
.55576 .39211 m .55581 .39244 L .50702 .28703 L F
.51573 .30591 m .55581 .39247 L .51109 .29611 L F
.55581 .39247 m .56062 .40286 L .55582 .3925 L F
.55581 .39247 m .55582 .3925 L .51109 .29611 L F
.55669 .39796 m .56062 .40286 L .56125 .40815 L F
.51109 .29611 m .55582 .3925 L .55669 .39796 L F
.55582 .3925 m .56062 .40286 L .55669 .39796 L F
.50777 .28871 m .51573 .30591 L .51109 .29611 L F
.50702 .28703 m .5084 .29001 L .50777 .28871 L F
.49605 .26253 m .51322 .2998 L .50702 .28703 L F
.49605 .26253 m .56719 .42141 L .52087 .25752 L F
.56205 .41885 m .56685 .42125 L .56166 .41565 L .835 .589 .567 r
F
.56229 .42079 m .56685 .42125 L .56205 .41885 L F
.37819 .35396 m .57418 .45057 L .57378 .44098 L .79 .54 .559 r
F
.53824 .37215 m .53812 .37165 L .50422 .3426 L .9 .674 .586 r
F
.53827 .38396 m .54957 .39172 L .47239 .26937 L .966 .667 .409 r
F
.53981 .37845 m .54956 .3917 L .54686 .38985 L .982 .697 .387 r
F
.47413 .27218 m .53891 .37483 L .53981 .37845 L F
.53891 .37483 m .54956 .3917 L .53981 .37845 L F
.54958 .39172 m .54958 .39174 L .53891 .37483 L F
.53891 .37482 m .53891 .37483 L .47413 .27218 L F
.54958 .39172 m .53891 .37483 L .53891 .37482 L F
.45017 .27791 m .53206 .3797 L .47602 .27568 L .966 .667 .409 r
F
.53206 .3797 m .54523 .39606 L .53827 .38396 L F
.53206 .3797 m .53827 .38396 L .47602 .27568 L F
.56229 .42079 m .56166 .41565 L .55427 .41057 L .835 .589 .567 r
F
.47567 .27457 m .54957 .39172 L .47413 .27218 L .982 .697 .387 r
F
.54957 .39172 m .54958 .39172 L .47413 .27218 L F
.47239 .26937 m .47567 .27457 L .47413 .27218 L F
.47239 .26937 m .55678 .40591 L .49605 .26253 L F
.55427 .41057 m .56166 .41565 L .56153 .41452 L .835 .589 .567 r
F
.47219 .26945 m .47602 .27568 L .47239 .26937 L .966 .667 .409 r
F
.45017 .27791 m .47602 .27568 L .47219 .26945 L F
.56645 .43438 m .56575 .42748 L .56097 .42416 L .812 .564 .564 r
F
.56097 .42416 m .56956 .43012 L .56943 .42829 L F
.3852 .33828 m .56229 .43217 L .56097 .42416 L F
.39464 .32357 m .55552 .41687 L .55427 .41057 L .835 .589 .567 r
F
.48891 .80649 m .29351 .68711 L .30019 .68339 L .669 .717 .884 r
F
.48572 .82516 m .29351 .68711 L .48891 .80649 L .656 .687 .867 r
F
.25 g
.48888 .7862 m
.49019 .78692 L
s
0 g
.006 w
.48891 .80649 m
.49019 .78692 L
s
.37306 .4247 m .59242 .50212 L .37113 .40595 L .695 .421 .505 r
F
.25 g
.5 Mabswid
.57305 .52847 m
.57466 .52916 L
s
.37306 .4247 m .5847 .51554 L .59242 .50212 L .695 .421 .505 r
F
.25 g
.56035 .54199 m
.56041 .54202 L
s
.37882 .44489 m
.41023 .45841 L
s
.57283 .52838 m
.57305 .52847 L
s
0 g
.006 w
.37306 .4247 m
.37686 .44405 L
s
.25 g
.5 Mabswid
.37306 .4247 m
.3731 .42471 L
s
.3731 .42471 m
.37454 .42533 L
s
.37454 .42533 m
.37523 .42563 L
s
.40264 .43739 m
.41844 .44417 L
s
.39198 .43282 m
.40264 .43739 L
s
.38575 .43014 m
.39198 .43282 L
s
.37523 .42563 m
.38575 .43014 L
s
.57648 .51201 m
.57788 .51261 L
s
.57788 .51261 m
.5847 .51554 L
s
.39843 .50574 m
.5285 .56859 L
s
1 0 0 r
.003 w
.60473 .42724 m
.60531 .42924 L
s
.25 g
.5 Mabswid
.43719 .28615 m
.44001 .28855 L
s
.44001 .28855 m
.44015 .28867 L
s
.44015 .28867 m
.49939 .33909 L
s
1 0 0 r
.003 w
.60531 .42924 m
.60582 .43313 L
s
.25 g
.5 Mabswid
.60366 .43155 m
.60582 .43313 L
s
.42071 .2974 m
.42335 .29934 L
s
.42335 .29934 m
.42352 .29946 L
s
.42352 .29946 m
.53079 .37812 L
s
1 0 0 r
.003 w
.60582 .43313 m
.60615 .43884 L
s
.25 g
.5 Mabswid
.60461 .43785 m
.60615 .43884 L
s
.60266 .43659 m
.60461 .43785 L
s
.40649 .30991 m
.4091 .31159 L
s
.4091 .31159 m
.40926 .31169 L
s
.40926 .31169 m
.5018 .37145 L
s
1 0 0 r
.003 w
.60615 .43884 m
.60616 .44624 L
s
.25 g
.5 Mabswid
.6047 .44539 m
.60616 .44624 L
s
.60377 .44485 m
.6047 .44539 L
s
.60131 .44342 m
.60377 .44485 L
s
.47188 .36836 m
.49257 .38036 L
s
.39464 .32357 m
.39724 .32508 L
s
.39724 .32508 m
.47188 .36836 L
s
1 0 0 r
.003 w
.60565 .45517 m
.60616 .44624 L
s
.48572 .82516 m .28848 .68973 L .29063 .68861 L .656 .687 .867 r
F
.48438 .82976 m .28848 .68973 L .48572 .82516 L .644 .658 .849 r
F
.48059 .84277 m .47346 .83709 L .48438 .82976 L F
.47346 .83709 m .28848 .68973 L .48438 .82976 L F
.42629 .90844 m .40875 .88049 L .44074 .89894 L .55 .51 .765 r
F
.48059 .84277 m .46755 .83267 L .28848 .68973 L .644 .658 .849 r
F
.46755 .83267 m .28497 .69115 L .28643 .69056 L F
.46755 .83267 m .28643 .69056 L .28848 .68973 L F
.47349 .85915 m .46292 .84973 L .48059 .84277 L .639 .632 .827 r
F
.46292 .84973 m .28497 .69115 L .46755 .83267 L F
.46292 .84973 m .46755 .83267 L .48059 .84277 L F
.47349 .85915 m .2829 .69129 L .28497 .69115 L F
.46444 .8741 m .2829 .69129 L .47349 .85915 L .52 .579 .855 r
F
.46143 .87106 m .28227 .69012 L .2829 .69129 L F
.4614 .87103 m .28227 .69012 L .46143 .87106 L F
.4613 .87093 m .46122 .87084 L .46181 .87145 L F
.46122 .87084 m .28227 .69012 L .4614 .87103 L F
.46122 .87084 m .4614 .87103 L .46181 .87145 L F
.46181 .87145 m .4614 .87103 L .46143 .87106 L F
.46444 .8741 m .4613 .87093 L .46181 .87145 L F
.4535 .88743 m .28227 .69012 L .46444 .8741 L .573 .568 .809 r
F
.4535 .88743 m .28309 .68766 L .28227 .69012 L F
.44074 .89894 m .28507 .69031 L .45288 .88671 L .563 .54 .787 r
F
.28507 .69031 m .2836 .68834 L .28675 .69204 L F
.28507 .69031 m .28675 .69204 L .45288 .88671 L F
.2836 .68834 m .28309 .68766 L .28382 .68851 L F
.2836 .68834 m .28382 .68851 L .4535 .88743 L F
.44074 .89894 m .28543 .68397 L .28309 .68766 L F
.28654 .68575 m .28689 .68599 L .29112 .69184 L .55 .51 .765 r
F
.29043 .69112 m .29112 .69184 L .44074 .89894 L F
.28654 .68575 m .29112 .69184 L .29043 .69112 L F
.40875 .88049 m .28892 .68953 L .4213 .87207 L F
.28892 .68953 m .28654 .68575 L .29043 .69112 L F
.28892 .68953 m .29043 .69112 L .4213 .87207 L F
.45242 .8884 m .45288 .88671 L .4535 .88743 L .563 .54 .787 r
F
.44074 .89894 m .45288 .88671 L .45242 .8884 L F
.40875 .88049 m .4213 .87207 L .44074 .89894 L .55 .51 .765 r
F
.28654 .68575 m .28543 .68397 L .28689 .68599 L F
.48379 .82377 m .29063 .68861 L .29351 .68711 L .656 .687 .867 r
F
.48572 .82516 m .29063 .68861 L .48379 .82377 L F
.25 g
.5 Mabswid
.29068 .69124 m
.2907 .69125 L
s
.2907 .69125 m
.48492 .82461 L
s
.48492 .82461 m
.48572 .82516 L
s
0 g
.006 w
.48572 .82516 m
.48891 .80649 L
s
.25 g
.5 Mabswid
.29351 .68711 m
.29541 .68827 L
s
.29541 .68827 m
.2955 .68832 L
s
.2955 .68832 m
.47677 .79907 L
s
.47677 .79907 m
.48773 .80577 L
s
.48773 .80577 m
.48891 .80649 L
s
.48319 .78311 m
.48888 .7862 L
s
.48462 .76417 m
.4883 .76595 L
s
.48401 .74424 m
.48605 .74512 L
s
.48172 .72364 m
.48223 .72383 L
s
0 g
.006 w
.48059 .84277 m
.48572 .82516 L
s
.62534 .25786 m .57745 .47494 L .57762 .4774 L 0 0 .203 r
F
.57658 .48127 m .59806 .48914 L .57699 .47973 L .721 .456 .524 r
F
.37113 .40595 m .59242 .50212 L .59806 .48914 L F
.58593 .44661 m .57762 .4774 L .57811 .48409 L 0 0 .203 r
F
.62534 .25786 m .57762 .4774 L .58593 .44661 L F
.37113 .40595 m .57658 .48127 L .37125 .38786 L .721 .456 .524 r
F
.57658 .48127 m .57699 .47973 L .37125 .38786 L F
.25 g
.5 Mabswid
.37346 .40696 m
.39284 .41538 L
s
.39284 .41538 m
.39973 .41838 L
s
.39973 .41838 m
.41173 .42359 L
s
.41173 .42359 m
.42989 .43148 L
s
.42989 .43148 m
.45494 .44237 L
s
.45494 .44237 m
.48707 .45633 L
s
.48707 .45633 m
.57591 .49494 L
s
.37274 .40665 m
.37346 .40696 L
s
.3712 .40598 m
.37274 .40665 L
s
.37113 .40595 m
.3712 .40598 L
s
.49257 .38036 m
.53954 .4076 L
s
.53954 .4076 m
.55552 .41687 L
s
.55552 .41687 m
.56229 .42079 L
s
.56229 .42079 m
.56738 .42375 L
s
.56738 .42375 m
.5699 .42521 L
s
.58166 .43203 m
.58632 .43473 L
s
.58819 .43581 m
.60131 .44342 L
s
.5018 .37145 m
.53974 .39596 L
s
.53974 .39596 m
.54619 .40012 L
s
.54619 .40012 m
.55695 .40707 L
s
.55695 .40707 m
.56232 .41053 L
s
.58249 .42356 m
.588 .42712 L
s
.58977 .42826 m
.60266 .43659 L
s
.54584 .38916 m
.54691 .38994 L
s
.58319 .41654 m
.58934 .42105 L
s
.59102 .42228 m
.60366 .43155 L
s
.58374 .41088 m
.59034 .41649 L
s
.59194 .41785 m
.60531 .42924 L
s
.58418 .40641 m
.58424 .40647 L
s
.58424 .40647 m
.59103 .41336 L
s
.59256 .4149 m
.60473 .42724 L
s
0 g
.006 w
.37113 .40595 m
.37306 .4247 L
s
.25 g
.5 Mabswid
.41844 .44417 m
.43977 .45333 L
s
.43977 .45333 m
.46658 .46484 L
s
.46658 .46484 m
.57648 .51201 L
s
.57272 .52833 m
.57283 .52838 L
s
.4514 .47612 m
.57272 .52833 L
s
.41023 .45841 m
.4514 .47612 L
s
.38404 .46471 m
.56035 .54199 L
s
.39066 .48501 m
.54556 .55547 L
s
.57591 .49494 m
.57682 .49534 L
s
.57682 .49534 m
.59242 .50212 L
s
0 g
.006 w
.37113 .40595 m
.37125 .38786 L
s
.25 g
.5 Mabswid
.60347 .45401 m
.60565 .45517 L
s
.58069 .44193 m
.58431 .44385 L
s
.58629 .4449 m
.60347 .45401 L
s
.57281 .43775 m
.57427 .43853 L
s
.56645 .43438 m
.57281 .43775 L
s
.56229 .43217 m
.56645 .43438 L
s
.54407 .42252 m
.56229 .43217 L
s
.49097 .39436 m
.54407 .42252 L
s
.4628 .37943 m
.49097 .39436 L
s
.44877 .37199 m
.4628 .37943 L
s
.3852 .33828 m
.38779 .33966 L
s
.38779 .33966 m
.44877 .37199 L
s
1 0 0 r
.003 w
.60434 .46543 m
.60565 .45517 L
s
.25 g
.5 Mabswid
.37819 .35396 m
.37838 .35405 L
s
.60276 .46466 m
.60434 .46543 L
s
.57576 .45135 m
.57689 .4519 L
s
.57958 .45323 m
.58198 .45441 L
s
.58409 .45545 m
.60276 .46466 L
s
.5675 .44727 m
.57576 .45135 L
s
.5511 .43919 m
.5675 .44727 L
s
.49585 .41196 m
.5511 .43919 L
s
.46121 .39488 m
.49585 .41196 L
s
.44085 .38485 m
.46121 .39488 L
s
.43008 .37954 m
.44085 .38485 L
s
.37838 .35405 m
.43008 .37954 L
s
1 0 0 r
.003 w
.60192 .47684 m
.60434 .46543 L
s
.25 g
.5 Mabswid
.57762 .46183 m
.57785 .45963 L
s
.47763 .84048 m
.48059 .84277 L
s
.46755 .83267 m
.47763 .84048 L
s
.2978 .7011 m
.46755 .83267 L
s
0 g
.006 w
.47349 .85915 m
.48059 .84277 L
s
.25 g
.5 Mabswid
.37125 .38786 m
.37135 .38791 L
s
.37135 .38791 m
.37297 .38863 L
s
.37297 .38863 m
.37372 .38897 L
s
.57468 .4787 m
.57699 .47973 L
s
.57699 .47973 m
.57782 .4801 L
s
.57885 .48056 m
.59806 .48914 L
s
.57453 .47864 m
.57468 .4787 L
s
.51558 .45231 m
.57453 .47864 L
s
.47562 .43447 m
.51558 .45231 L
s
.4453 .42093 m
.47562 .43447 L
s
.42396 .4114 m
.4453 .42093 L
s
.41021 .40526 m
.42396 .4114 L
s
.40249 .40181 m
.41021 .40526 L
s
.37372 .38897 m
.40249 .40181 L
s
0 g
.006 w
.37125 .38786 m
.37356 .37051 L
s
.25 g
.5 Mabswid
.37356 .37051 m
.37371 .37058 L
s
.37371 .37058 m
.37537 .37135 L
s
.57712 .46529 m
.57758 .4655 L
s
.57834 .46586 m
.57935 .46632 L
s
.5816 .46737 m
.60192 .47684 L
s
.57158 .46271 m
.57712 .46529 L
s
.50495 .43168 m
.57158 .46271 L
s
.46616 .41362 m
.50495 .43168 L
s
.43999 .40144 m
.46616 .41362 L
s
.42373 .39387 m
.43999 .40144 L
s
.41482 .38972 m
.42373 .39387 L
s
.37537 .37135 m
.41482 .38972 L
s
1 0 0 r
.003 w
.59806 .48914 m
.60192 .47684 L
s
.5991 .25455 m .57745 .47494 L .62534 .25786 L 0 0 .108 r
F
1 0 0 r
.57733 .47097 m
.57745 .47494 L
s
.25 g
.5 Mabswid
.57785 .45963 m
.57901 .44845 L
s
1 0 0 r
.003 w
.57745 .47494 m
.57762 .4774 L
s
.59242 .50212 m
.59806 .48914 L
s
.25 g
.5 Mabswid
.46811 .85441 m
.47349 .85915 L
s
.46462 .85134 m
.46811 .85441 L
s
.30439 .71022 m
.46462 .85134 L
s
0 g
.006 w
.46444 .8741 m
.47349 .85915 L
s
.37356 .37051 m
.37819 .35396 L
s
1 0 0 r
.003 w
.5847 .51554 m
.59242 .50212 L
s
.65112 .26342 m .57811 .48409 L .5794 .49312 L 0 0 .268 r
F
.25 g
.5 Mabswid
.57745 .47494 m
.57777 .47346 L
s
.62534 .25786 m .57811 .48409 L .65112 .26342 L 0 0 .203 r
F
1 0 0 r
.003 w
.57762 .4774 m
.57811 .48409 L
s
.25 g
.5 Mabswid
.62489 .25989 m
.62534 .25786 L
s
1 0 0 r
.003 w
.57466 .52916 m
.5847 .51554 L
s
.25 g
.5 Mabswid
.4613 .87093 m
.46444 .8741 L
s
.46122 .87084 m
.4613 .87093 L
s
.3104 .71853 m
.46122 .87084 L
s
0 g
.006 w
.4535 .88743 m
.46444 .8741 L
s
.37819 .35396 m
.3852 .33828 L
s
.67612 .27123 m .5794 .49312 L .58158 .50164 L 0 0 .305 r
F
.25 g
.5 Mabswid
.57811 .48409 m
.57865 .48246 L
s
.57777 .47346 m
.57784 .47316 L
s
.65112 .26342 m .5794 .49312 L .67612 .27123 L 0 0 .268 r
F
.25 g
.57784 .47316 m
.5869 .4321 L
s
1 0 0 r
.003 w
.57811 .48409 m
.5794 .49312 L
s
.25 g
.5 Mabswid
.65048 .26536 m
.65112 .26342 L
s
.65042 .26551 m
.65048 .26536 L
s
1 0 0 r
.003 w
.56216 .54279 m
.57466 .52916 L
s
0 g
.006 w
.3852 .33828 m
.39464 .32357 L
s
.25 g
.5 Mabswid
.45112 .88464 m
.4535 .88743 L
s
.31578 .72598 m
.45112 .88464 L
s
0 g
.006 w
.44074 .89894 m
.4535 .88743 L
s
.70007 .28127 m .58158 .50164 L .58496 .50933 L .049 0 .321 r
F
.25 g
.5 Mabswid
.5794 .49312 m
.58017 .49135 L
s
.57865 .48246 m
.57873 .4822 L
s
.67612 .27123 m .58158 .50164 L .70007 .28127 L 0 0 .305 r
F
1 0 0 r
.003 w
.5794 .49312 m
.58158 .50164 L
s
.25 g
.5 Mabswid
.67562 .27237 m
.67612 .27123 L
s
.67525 .27323 m
.67562 .27237 L
s
.67519 .27335 m
.67525 .27323 L
s
.84744 .48002 m .71974 .51874 L .85257 .50578 L .053 0 0 r
F
.71974 .51874 m .72037 .5188 L .7205 .51879 L F
.72018 .5187 m .7205 .51879 L .85257 .50578 L F
.71974 .51874 m .7205 .51879 L .72018 .5187 L F
.85257 .50578 m .72037 .5188 L .73907 .51675 L .086 .644 .714 r
F
.72037 .5188 m .71914 .51893 L .73907 .51675 L F
.85257 .50578 m .73994 .51667 L .85634 .53176 L F
.73994 .51667 m .73985 .51668 L .73997 .51669 L F
.73994 .51667 m .73997 .51669 L .85634 .53176 L F
.73992 .51669 m .74026 .5169 L .85634 .53176 L F
.73985 .51668 m .74 .51676 L .73992 .51669 L F
.74 .51676 m .74026 .5169 L .73992 .51669 L F
.79317 .51383 m .77645 .51398 L .7929 .51355 L .443 .792 .998 r
F
.73985 .51668 m .73907 .51675 L .74026 .5169 L .086 .644 .714 r
F
.85585 .53167 m .73907 .51675 L .75835 .51506 L .231 .742 .877 r
F
.85522 .53161 m .73907 .51675 L .85585 .53167 L F
.85634 .53176 m .85522 .53161 L .85585 .53167 L F
.85634 .53176 m .75927 .51522 L .85889 .55776 L F
.75927 .51522 m .75929 .51525 L .85889 .55776 L F
.75917 .5152 m .75945 .51553 L .85889 .55776 L F
.77702 .51429 m .75835 .51506 L .77645 .51398 L .354 .787 .968 r
F
.85831 .55746 m .75946 .51553 L .77702 .51429 L F
.75927 .51522 m .75917 .5152 L .75929 .51525 L .231 .742 .877 r
F
.75917 .5152 m .75835 .51506 L .75945 .51553 L F
.75946 .51553 m .75835 .51506 L .77702 .51429 L .354 .787 .968 r
F
.85789 .55734 m .75835 .51506 L .85831 .55746 L F
.85889 .55776 m .85789 .55734 L .85831 .55746 L F
.85889 .55776 m .77743 .51451 L .86038 .58358 L F
.77743 .51451 m .77721 .51439 L .77749 .51462 L F
.77743 .51451 m .77749 .51462 L .86038 .58358 L F
.77721 .51439 m .77728 .5145 L .86038 .58358 L F
.77702 .51429 m .77732 .5147 L .77747 .51483 L F
.77728 .5145 m .77747 .51483 L .86038 .58358 L F
.77702 .51429 m .77747 .51483 L .77728 .5145 L F
.85989 .58308 m .83649 .56369 L .83383 .55603 L .443 .792 .998 r
F
.83649 .56369 m .77732 .5147 L .83383 .55603 L F
.83383 .55603 m .77732 .5147 L .79317 .51383 L F
.77721 .51439 m .77702 .51429 L .77728 .5145 L .354 .787 .968 r
F
.77702 .51429 m .77645 .51398 L .77732 .5147 L F
.77732 .5147 m .77645 .51398 L .79317 .51383 L .443 .792 .998 r
F
.85953 .58288 m .77645 .51398 L .85989 .58308 L F
.86038 .58358 m .85953 .58288 L .85989 .58308 L F
.86038 .58358 m .79427 .51497 L .86097 .60902 L F
.79427 .51497 m .794 .5147 L .79428 .51509 L F
.79427 .51497 m .79428 .51509 L .86097 .60902 L F
.794 .5147 m .79409 .51497 L .86097 .60902 L F
.79362 .5143 m .79385 .51489 L .86097 .60902 L F
.80852 .51586 m .7929 .51355 L .80732 .51373 L .503 .776 .993 r
F
.86065 .60846 m .79433 .51557 L .80852 .51586 L F
.794 .5147 m .79362 .5143 L .79409 .51497 L .443 .792 .998 r
F
.79362 .5143 m .7929 .51355 L .79385 .51489 L F
.79433 .51557 m .7929 .51355 L .80852 .51586 L .503 .776 .993 r
F
.86047 .60832 m .7929 .51355 L .86065 .60846 L F
.83982 .81164 m .80622 .52636 L .79577 .52845 L .66 .567 .739 r
F
.80351 .59793 m .79577 .52845 L .79184 .52924 L F
.83982 .81164 m .79577 .52845 L .80351 .59793 L F
.86097 .60902 m .86047 .60832 L .86065 .60846 L .503 .776 .993 r
F
.86097 .60902 m .80926 .51717 L .86081 .6339 L F
.80926 .51717 m .80952 .51833 L .86081 .6339 L F
.80804 .51502 m .80813 .51537 L .80829 .51572 L F
.80827 .51554 m .80829 .51572 L .86081 .6339 L F
.80804 .51502 m .80829 .51572 L .80827 .51554 L F
.80774 .51448 m .80794 .51512 L .80826 .51585 L F
.80813 .51537 m .80826 .51585 L .86081 .6339 L F
.80774 .51448 m .80826 .51585 L .80813 .51537 L F
.81958 .5149 m .80732 .51373 L .81941 .5144 L .544 .752 .973 r
F
.80926 .51717 m .80804 .51502 L .80952 .51833 L .503 .776 .993 r
F
.86048 .63296 m .80794 .51512 L .81958 .5149 L .544 .752 .973 r
F
.80804 .51502 m .80774 .51448 L .80813 .51537 L .503 .776 .993 r
F
.80774 .51448 m .80732 .51373 L .80794 .51512 L F
.80794 .51512 m .80732 .51373 L .81958 .5149 L .544 .752 .973 r
F
.86055 .63315 m .86043 .63289 L .86048 .63296 L F
.86043 .63289 m .80732 .51373 L .86048 .63296 L F
.86077 .63379 m .86042 .63299 L .86055 .63315 L F
.86042 .63299 m .80732 .51373 L .86055 .63315 L F
.86081 .6339 m .86075 .63378 L .86077 .63379 L F
.86075 .63378 m .80732 .51373 L .86077 .63379 L F
.86081 .6339 m .82056 .51773 L .86004 .65803 L F
.82056 .51773 m .82077 .51897 L .86004 .65803 L F
.8198 .51554 m .8199 .51603 L .81999 .51637 L F
.81998 .51616 m .81999 .51637 L .86004 .65803 L F
.8198 .51554 m .81999 .51637 L .81998 .51616 L F
.81958 .5149 m .81974 .51558 L .81997 .5164 L F
.8199 .51603 m .81997 .5164 L .86004 .65803 L F
.81958 .5149 m .81997 .5164 L .8199 .51603 L F
.8597 .65684 m .81941 .5144 L .85972 .65688 L .572 .727 .947 r
F
.82056 .51773 m .8198 .51554 L .82077 .51897 L .544 .752 .973 r
F
.85982 .65706 m .81974 .51558 L .82895 .51544 L .572 .727 .947 r
F
.8198 .51554 m .81958 .5149 L .8199 .51603 L .544 .752 .973 r
F
.81958 .5149 m .81941 .5144 L .81974 .51558 L F
.81974 .51558 m .81941 .5144 L .82895 .51544 L .572 .727 .947 r
F
.85972 .65688 m .81941 .5144 L .85982 .65706 L F
.85998 .65784 m .8597 .65684 L .86 .65786 L F
.8597 .65684 m .85972 .65688 L .86 .65786 L F
.86 .65786 m .85972 .65688 L .85982 .65706 L F
.86004 .65803 m .85998 .65784 L .86 .65786 L F
.85888 .65272 m .82953 .51812 L .85724 .67267 L F
.82953 .51812 m .82977 .51999 L .85878 .68123 L F
.85888 .65272 m .85724 .67267 L .85878 .68123 L F
.82953 .51812 m .82895 .51544 L .82977 .51999 L F
.85856 .6797 m .82895 .51544 L .8358 .51668 L .592 .703 .92 r
F
.85853 .67961 m .82895 .51544 L .85856 .6797 L F
.85859 .67995 m .82895 .51544 L .8586 .67998 L F
.85848 .67952 m .82895 .51544 L .85862 .68012 L F
.85872 .68094 m .82895 .51544 L .85874 .68097 L F
.84913 .77136 m .83514 .52161 L .84826 .77699 L .654 .64 .824 r
F
.85073 .76114 m .8504 .75601 L .84913 .77136 L F
.8504 .75601 m .83514 .52161 L .84913 .77136 L F
.86004 .65803 m .85888 .65272 L .85878 .68123 L .572 .727 .947 r
F
.8586 .67998 m .85853 .67961 L .85856 .6797 L .592 .703 .92 r
F
.85862 .68012 m .85859 .67995 L .8586 .67998 L F
.85874 .68097 m .85848 .67952 L .85862 .68012 L F
.85878 .68123 m .85872 .68094 L .85874 .68097 L F
.85878 .68123 m .83601 .51823 L .85713 .70332 L F
.83601 .51823 m .8358 .51668 L .83619 .52011 L F
.83601 .51823 m .83619 .52011 L .85713 .70332 L F
.85695 .70131 m .8358 .51668 L .83986 .51799 L .604 .678 .894 r
F
.85698 .70168 m .85693 .70122 L .85695 .70131 L F
.85693 .70122 m .8358 .51668 L .85695 .70131 L F
.85692 .70144 m .85685 .70082 L .85693 .7015 L F
.85685 .70082 m .8358 .51668 L .85687 .70092 L F
.85685 .70082 m .85687 .70092 L .85693 .7015 L F
.85708 .70287 m .85692 .70144 L .8571 .70291 L F
.85692 .70144 m .85693 .7015 L .8571 .70291 L F
.8571 .70291 m .85693 .7015 L .85698 .70168 L F
.85693 .7015 m .8358 .51668 L .85698 .70168 L F
.85713 .70332 m .85708 .70287 L .8571 .70291 L F
.85713 .70332 m .83986 .51799 L .8552 .72412 L F
.85502 .72165 m .85496 .72083 L .85503 .72169 L .589 .638 .867 r
F
.85496 .72083 m .83986 .51799 L .85497 .72091 L F
.85496 .72083 m .85497 .72091 L .85503 .72169 L F
.84564 .79081 m .82805 .52283 L .82066 .52397 L .658 .602 .781 r
F
.83529 .68977 m .82066 .52397 L .81836 .52433 L F
.84564 .79081 m .82066 .52397 L .83529 .68977 L F
.85515 .72342 m .85502 .72165 L .85516 .72344 L .589 .638 .867 r
F
.85502 .72165 m .85503 .72169 L .85516 .72344 L F
.85504 .72167 m .83986 .51799 L .84109 .51926 L F
.85516 .72344 m .85499 .72115 L .85504 .72167 L F
.85499 .72115 m .83986 .51799 L .85504 .72167 L F
.84284 .80242 m .81836 .52433 L .80933 .52584 L .66 .585 .76 r
F
.82025 .63212 m .80933 .52584 L .80622 .52636 L F
.84284 .80242 m .80933 .52584 L .82025 .63212 L F
.8552 .72412 m .85515 .72342 L .85516 .72344 L .589 .638 .867 r
F
.71974 .51874 m .71914 .51893 L .72037 .5188 L .053 0 0 r
F
0 g
.006 w
.85634 .53176 m
.85889 .55776 L
s
.85257 .50578 m
.85634 .53176 L
s
1 0 0 r
.003 w
.5472 .55621 m
.56216 .54279 L
s
0 g
.006 w
.85889 .55776 m
.86038 .58358 L
s
.84744 .48002 m .69913 .52138 L .71914 .51893 L .053 0 0 r
F
.84078 .45471 m .69913 .52138 L .84744 .48002 L .159 0 0 r
F
0 g
.84744 .48002 m
.85257 .50578 L
s
.25 g
.5 Mabswid
.80783 .54001 m
.80806 .5402 L
s
0 g
.006 w
.86038 .58358 m
.86097 .60902 L
s
.84078 .45471 m .67961 .52382 L .69913 .52138 L .159 0 0 r
F
.83247 .43005 m .67961 .52382 L .84078 .45471 L .229 0 0 r
F
.25 g
.5 Mabswid
.84604 .48041 m
.84744 .48002 L
s
0 g
.006 w
.84078 .45471 m
.84744 .48002 L
s
.25 g
.5 Mabswid
.82087 .55278 m
.82134 .55345 L
s
.83094 .56691 m
.83107 .56709 L
s
0 g
.006 w
.86081 .6339 m
.86097 .60902 L
s
.39464 .32357 m
.40649 .30991 L
s
1 0 0 r
.003 w
.52991 .56927 m
.5472 .55621 L
s
.83247 .43005 m .66113 .52593 L .67961 .52382 L .229 0 0 r
F
.8224 .40628 m .66113 .52593 L .83247 .43005 L .267 0 .01 r
F
.25 g
.5 Mabswid
.84603 .48041 m
.84604 .48041 L
s
.83927 .45536 m
.84078 .45471 L
s
0 g
.006 w
.83247 .43005 m
.84078 .45471 L
s
.25 g
.5 Mabswid
.29112 .69184 m
.42131 .87206 L
s
.28958 .68972 m
.29112 .69184 L
s
.42131 .87206 m
.44074 .89894 L
s
.72271 .2935 m .58496 .50933 L .58983 .51588 L .129 0 .32 r
F
.25 g
.58158 .50164 m
.58258 .49978 L
s
.58017 .49135 m
.58026 .49114 L
s
.70007 .28127 m .58496 .50933 L .72271 .2935 L .049 0 .321 r
F
1 0 0 r
.003 w
.58158 .50164 m
.58496 .50933 L
s
.25 g
.5 Mabswid
.69943 .28246 m
.70007 .28127 L
s
.69898 .28329 m
.69943 .28246 L
s
.69893 .28339 m
.69898 .28329 L
s
1 0 0 r
.003 w
.28227 .69012 m
.2829 .69129 L
s
.28227 .69012 m
.28309 .68766 L
s
0 g
.006 w
.86004 .65803 m
.86081 .6339 L
s
1 0 0 r
.003 w
.29063 .68861 m
.29351 .68711 L
s
.28928 .68931 m
.29063 .68861 L
s
.8224 .40628 m .64415 .52737 L .66113 .52593 L .267 0 .01 r
F
.81047 .3836 m .64415 .52737 L .8224 .40628 L .282 0 .111 r
F
0 g
.006 w
.8224 .40628 m
.83247 .43005 L
s
.25 g
.5 Mabswid
.83926 .45536 m
.83927 .45536 L
s
.83087 .43095 m
.83247 .43005 L
s
.42532 .9069 m .28939 .67923 L .28543 .68397 L .55 .51 .765 r
F
.42464 .90568 m .28939 .67923 L .42532 .9069 L F
.42629 .90844 m .42464 .90568 L .42532 .9069 L F
.41031 .91572 m .28939 .67923 L .42629 .90844 L .535 .48 .741 r
F
.40923 .91361 m .29506 .67367 L .28939 .67923 L F
.40914 .91337 m .29506 .67367 L .40923 .91361 L F
.40897 .9129 m .29506 .67367 L .40953 .91419 L F
.40953 .91419 m .40914 .91337 L .40923 .91361 L F
.41031 .91572 m .40897 .9129 L .40953 .91419 L F
.39302 .92061 m .29541 .67454 L .41031 .91572 L .521 .449 .715 r
F
.29541 .67454 m .29587 .67536 L .41031 .91572 L F
.29541 .67454 m .29506 .67367 L .29587 .67536 L F
.39218 .9185 m .30254 .66761 L .29506 .67367 L F
.39302 .92061 m .39195 .91761 L .39218 .9185 L F
.39195 .91761 m .30254 .66761 L .39218 .9185 L F
.37466 .92295 m .37422 .92141 L .39302 .92061 L .508 .417 .687 r
F
.37422 .92141 m .30279 .6685 L .39195 .91761 L F
.37422 .92141 m .39195 .91761 L .39302 .92061 L F
.30279 .6685 m .30317 .66937 L .39302 .92061 L F
.30279 .6685 m .30254 .66761 L .30317 .66937 L F
.37406 .92083 m .31185 .66143 L .30254 .66761 L F
.37466 .92295 m .37393 .91992 L .37406 .92083 L F
.37393 .91992 m .31185 .66143 L .37406 .92083 L F
.3555 .92259 m .35524 .92105 L .37466 .92295 L .497 .385 .657 r
F
.35524 .92105 m .31212 .66302 L .37393 .91992 L F
.35524 .92105 m .37393 .91992 L .37466 .92295 L F
.31212 .66302 m .31243 .66381 L .37466 .92295 L F
.31212 .66302 m .31185 .66143 L .31243 .66381 L F
.35515 .92049 m .32298 .65555 L .31185 .66143 L F
.3555 .92259 m .35513 .91955 L .35515 .92049 L F
.35513 .91955 m .32298 .65555 L .35515 .92049 L F
.33588 .91944 m .33581 .91792 L .3555 .92259 L .487 .354 .624 r
F
.33581 .91792 m .32306 .65713 L .35513 .91955 L F
.33581 .91792 m .35513 .91955 L .3555 .92259 L F
.32306 .65713 m .32327 .65793 L .3555 .92259 L F
.32306 .65713 m .32298 .65555 L .32327 .65793 L F
.33578 .91737 m .33581 .65043 L .32298 .65555 L F
.33588 .91944 m .33588 .91643 L .33578 .91737 L F
.33588 .91643 m .33581 .65043 L .33578 .91737 L F
.31614 .91345 m .31626 .91195 L .33588 .91944 L .481 .323 .589 r
F
.31626 .91195 m .33569 .65199 L .33588 .91643 L F
.31626 .91195 m .33588 .91643 L .33588 .91944 L F
.33569 .65199 m .33581 .65282 L .33588 .91944 L F
.33569 .65199 m .33581 .65043 L .33581 .65282 L F
.3163 .91142 m .35013 .64653 L .33581 .65043 L F
.31614 .91345 m .31652 .91051 L .3163 .91142 L F
.31652 .91051 m .35013 .64653 L .3163 .91142 L F
.29666 .90461 m .29696 .90317 L .31614 .91345 L .477 .294 .553 r
F
.29696 .90317 m .34981 .64806 L .31652 .91051 L F
.29696 .90317 m .31652 .91051 L .31614 .91345 L F
.34981 .64806 m .34983 .6489 L .31614 .91345 L F
.34981 .64806 m .35013 .64653 L .34983 .6489 L F
.29706 .90266 m .36564 .64425 L .35013 .64653 L F
.29666 .90461 m .29741 .90178 L .29706 .90266 L F
.29741 .90178 m .36564 .64425 L .29706 .90266 L F
.27781 .89298 m .2783 .8916 L .29666 .90461 L .478 .267 .515 r
F
.2783 .8916 m .36511 .64574 L .29741 .90178 L F
.2783 .8916 m .29741 .90178 L .29666 .90461 L F
.36511 .64574 m .36502 .64658 L .29666 .90461 L F
.36511 .64574 m .36564 .64425 L .36502 .64658 L F
.27847 .89113 m .38193 .64394 L .36564 .64425 L F
.27781 .89298 m .27893 .89031 L .27847 .89113 L F
.27893 .89031 m .38193 .64394 L .27847 .89113 L F
.25999 .87865 m .26066 .87738 L .27781 .89298 L .483 .244 .476 r
F
.26066 .87738 m .38118 .64537 L .27893 .89031 L F
.26066 .87738 m .27893 .89031 L .27781 .89298 L F
.38118 .64537 m .38098 .6462 L .27781 .89298 L F
.38118 .64537 m .38193 .64394 L .38098 .6462 L F
.26088 .87694 m .39852 .64585 L .38193 .64394 L F
.25999 .87865 m .26146 .8762 L .26088 .87694 L F
.26146 .8762 m .39852 .64585 L .26088 .87694 L F
.24357 .86182 m .2444 .86066 L .25999 .87865 L .493 .226 .438 r
F
.2444 .86066 m .39756 .64718 L .26145 .87619 L F
.2444 .86066 m .26145 .87619 L .25999 .87865 L F
.39756 .64718 m .39725 .64799 L .25999 .87865 L F
.39756 .64718 m .39852 .64585 L .39725 .64799 L F
.24468 .86027 m .41489 .6501 L .39852 .64585 L F
.24357 .86182 m .24535 .85961 L .24468 .86027 L F
.24535 .85961 m .41489 .6501 L .24468 .86027 L F
.2289 .84269 m .22988 .84167 L .24357 .86182 L .508 .214 .402 r
F
.22988 .84167 m .41373 .65131 L .24535 .85961 L F
.22988 .84167 m .24535 .85961 L .24357 .86182 L F
.41373 .65131 m .41329 .65207 L .24357 .86182 L F
.41373 .65131 m .41489 .6501 L .41329 .65207 L F
.2302 .84134 m .4305 .65669 L .41489 .6501 L F
.2289 .84269 m .23096 .84078 L .2302 .84134 L F
.23096 .84078 m .4305 .65669 L .2302 .84134 L F
.2163 .82155 m .21741 .82069 L .2289 .84269 L .528 .208 .369 r
F
.21741 .82069 m .42915 .65774 L .23096 .84078 L F
.21741 .82069 m .23096 .84078 L .2289 .84269 L F
.42915 .65774 m .4286 .65845 L .2289 .84269 L F
.42915 .65774 m .4305 .65669 L .4286 .65845 L F
.21777 .82042 m .44483 .66547 L .4305 .65669 L F
.2163 .82155 m .2186 .81998 L .21777 .82042 L F
.2186 .81998 m .44483 .66547 L .21777 .82042 L F
.20605 .79872 m .20727 .79804 L .2163 .82155 L .553 .209 .34 r
F
.20727 .79804 m .44331 .66633 L .2186 .81998 L F
.20727 .79804 m .2186 .81998 L .2163 .82155 L F
.44331 .66633 m .44266 .66696 L .2163 .82155 L F
.44331 .66633 m .44483 .66547 L .44266 .66696 L F
.20765 .79783 m .45743 .67617 L .44483 .66547 L F
.20605 .79872 m .20854 .79751 L .20765 .79783 L F
.20854 .79751 m .45743 .67617 L .20765 .79783 L F
.19839 .77456 m .19969 .77407 L .20605 .79872 L .583 .219 .316 r
F
.19969 .77407 m .45576 .67681 L .20854 .79751 L F
.19969 .77407 m .20854 .79751 L .20605 .79872 L F
.45576 .67681 m .45502 .67735 L .20605 .79872 L F
.45576 .67681 m .45743 .67617 L .45502 .67735 L F
.20009 .77392 m .46793 .6884 L .45743 .67617 L F
.19839 .77456 m .20101 .77373 L .20009 .77392 L F
.20101 .77373 m .46793 .6884 L .20009 .77392 L F
.1935 .74945 m .19485 .74915 L .19839 .77456 L .615 .235 .299 r
F
.19485 .74915 m .46616 .6888 L .20101 .77372 L F
.19485 .74915 m .20101 .77372 L .19839 .77456 L F
.46616 .6888 m .46534 .68923 L .19839 .77456 L F
.46616 .6888 m .46793 .6884 L .46534 .68923 L F
.19524 .74907 m .4761 .7017 L .46793 .6884 L F
.1935 .74945 m .19618 .749 L .19524 .74907 L F
.19618 .749 m .4761 .7017 L .19524 .74907 L F
.19149 .7238 m .19285 .7237 L .1935 .74945 L .65 .258 .288 r
F
.19285 .7237 m .47427 .70185 L .19618 .749 L F
.19285 .7237 m .19618 .749 L .1935 .74945 L F
.47427 .70185 m .47339 .70216 L .1935 .74945 L F
.47427 .70185 m .4761 .7017 L .47339 .70216 L F
.19324 .72367 m .48185 .71557 L .4761 .7017 L F
.19149 .7238 m .19417 .72373 L .19324 .72367 L F
.19417 .72373 m .48185 .71557 L .19324 .72367 L F
.19243 .69801 m .19378 .69809 L .19149 .7238 L .686 .287 .285 r
F
.19378 .69809 m .47999 .71546 L .19417 .72373 L F
.19378 .69809 m .19417 .72373 L .19149 .7238 L F
.47999 .71546 m .47908 .71565 L .19149 .7238 L F
.47999 .71546 m .48185 .71557 L .47908 .71565 L F
.19415 .69811 m .48523 .72949 L .48185 .71557 L F
.19243 .69801 m .19506 .69829 L .19415 .69811 L F
.19506 .69829 m .48523 .72949 L .19415 .69811 L F
.19634 .67248 m .19765 .67274 L .19243 .69801 L .723 .321 .287 r
F
.19765 .67274 m .4834 .72913 L .19506 .69829 L F
.19765 .67274 m .19506 .69829 L .19243 .69801 L F
.4834 .72913 m .48247 .72919 L .19243 .69801 L F
.4834 .72913 m .48523 .72949 L .48247 .72919 L F
.19634 .67248 m .48643 .743 L .48523 .72949 L F
.20318 .64759 m .48467 .7424 L .19634 .67248 L .758 .358 .295 r
F
.48467 .7424 m .48375 .74234 L .19634 .67248 L F
.48467 .7424 m .48643 .743 L .48375 .74234 L F
.20443 .64801 m .48578 .75569 L .48643 .743 L F
.20318 .64759 m .20574 .64857 L .20443 .64801 L F
.20574 .64857 m .48578 .75569 L .20443 .64801 L F
.21288 .62372 m .48412 .75488 L .20318 .64759 L .792 .398 .308 r
F
.48412 .75488 m .48323 .75471 L .20318 .64759 L F
.48412 .75488 m .48578 .75569 L .48323 .75471 L F
.21404 .62428 m .48367 .76725 L .48578 .75569 L F
.21288 .62372 m .21527 .62498 L .21404 .62428 L F
.21527 .62498 m .48367 .76725 L .21404 .62428 L F
.22532 .60121 m .48272 .76664 L .21288 .62372 L .824 .44 .326 r
F
.48272 .76664 m .48169 .7662 L .21288 .62372 L F
.48272 .76664 m .48367 .76725 L .48169 .7662 L F
.22637 .60189 m .48057 .77749 L .48367 .76725 L F
.22532 .60121 m .2275 .60272 L .22637 .60189 L F
.2275 .60272 m .48057 .77749 L .22637 .60189 L F
.24037 .58039 m .47975 .77682 L .22532 .60121 L .854 .482 .346 r
F
.47975 .77682 m .47884 .7763 L .22532 .60121 L F
.47975 .77682 m .48057 .77749 L .47884 .7763 L F
.27312 .60727 m .47695 .78631 L .48057 .77749 L F
.51821 .52471 m .47812 .80188 L .4889 .51457 L .977 .919 .622 r
F
.47812 .80188 m .47725 .80788 L .47751 .8013 L F
.47812 .80188 m .47751 .8013 L .4889 .51457 L F
.24129 .58115 m .29337 .62649 L .27312 .60727 L .854 .482 .346 r
F
.29337 .62649 m .47695 .78631 L .27312 .60727 L F
.24037 .58039 m .2423 .58208 L .24129 .58115 L F
.2423 .58208 m .47695 .78631 L .24129 .58115 L F
.25784 .56155 m .47626 .78561 L .24037 .58039 L .881 .525 .369 r
F
.47626 .78561 m .47548 .78503 L .24037 .58039 L F
.47626 .78561 m .47695 .78631 L .47548 .78503 L F
.26964 .57365 m .47325 .79371 L .47695 .78631 L F
.27841 .58368 m .47325 .79371 L .26964 .57365 L F
.2595 .56334 m .47325 .79371 L .25861 .56234 L F
.25861 .56234 m .27841 .58368 L .26964 .57365 L F
.25784 .56155 m .2595 .56334 L .25861 .56234 L F
.27756 .54496 m .47269 .79301 L .25784 .56155 L .905 .567 .394 r
F
.47269 .79301 m .47325 .79371 L .47204 .7924 L F
.47269 .79301 m .47204 .7924 L .25784 .56155 L F
.46296 .78063 m .46988 .79975 L .47325 .79371 L F
.27882 .54656 m .46336 .79111 L .46296 .78063 L F
.46336 .79111 m .46988 .79975 L .46296 .78063 L F
.27945 .54743 m .46988 .79975 L .27882 .54656 L F
.27889 .54672 m .46988 .79975 L .27816 .54571 L F
.27816 .54571 m .27945 .54743 L .27882 .54656 L F
.27756 .54496 m .27889 .54672 L .27816 .54571 L F
.29932 .53084 m .46945 .79907 L .27756 .54496 L .927 .608 .418 r
F
.46945 .79907 m .46891 .79847 L .27756 .54496 L F
.46945 .79907 m .46988 .79975 L .46891 .79847 L F
.2997 .53145 m .46716 .80454 L .46988 .79975 L F
.29932 .53084 m .30023 .53234 L .2997 .53145 L F
.30023 .53234 m .46716 .80454 L .2997 .53145 L F
.32289 .51942 m .46684 .80391 L .30023 .53234 L .947 .649 .441 r
F
.32289 .51942 m .30023 .53234 L .29932 .53084 L F
.46684 .80391 m .46716 .80454 L .46642 .80333 L F
.46684 .80391 m .46642 .80333 L .29932 .53084 L F
.32296 .51957 m .46534 .80821 L .46716 .80454 L F
.3231 .51984 m .46534 .80821 L .32296 .51957 L F
.32289 .51942 m .3231 .51984 L .32296 .51957 L F
.45235 .77528 m .46512 .80765 L .32289 .51942 L .966 .688 .456 r
F
.34805 .51086 m .45235 .77528 L .32289 .51942 L F
.46512 .80765 m .46481 .80713 L .32289 .51942 L F
.34805 .51086 m .46457 .81083 L .46261 .80127 L F
.37456 .5053 m .46445 .81041 L .34805 .51086 L .958 .662 .232 r
F
.46445 .81041 m .46457 .81083 L .46425 .81 L F
.46445 .81041 m .46425 .81 L .34805 .51086 L F
.46512 .80765 m .46534 .80821 L .46481 .80713 L .966 .688 .456 r
F
.46261 .80127 m .46457 .81083 L .46534 .80821 L F
.46404 .80902 m .46483 .8121 L .46457 .81083 L .958 .662 .232 r
F
.46483 .8121 m .46493 .81247 L .46457 .81083 L F
.37456 .5053 m .46406 .80951 L .46404 .80902 L F
.46406 .80951 m .46493 .81247 L .46404 .80902 L F
.4596 .5075 m .46891 .80911 L .4306 .50358 L .992 .847 .595 r
F
.46891 .80911 m .46901 .81267 L .4685 .80856 L F
.46891 .80911 m .4685 .80856 L .4306 .50358 L F
.4889 .51457 m .47291 .8061 L .4596 .5075 L .99 .885 .611 r
F
.47291 .8061 m .47265 .81099 L .47241 .80552 L F
.47291 .8061 m .47241 .80552 L .4596 .5075 L F
0 g
.006 w
.42629 .90844 m
.44074 .89894 L
s
.25 g
.5 Mabswid
.39808 .72214 m
.40387 .72495 L
s
.48427 .764 m
.48462 .76417 L
s
.36801 .72034 m
.43924 .75916 L
s
.48101 .78191 m
.48319 .78311 L
s
.46489 .67883 m
.46699 .67937 L
s
1 0 0 r
.003 w
.51058 .58184 m
.52991 .56927 L
s
.25 g
.5 Mabswid
.42464 .90568 m
.42629 .90844 L
s
.42455 .90553 m
.42464 .90568 L
s
.33603 .75732 m
.42455 .90553 L
s
.81941 .5144 m
.82036 .51775 L
s
.82036 .51775 m
.82205 .52376 L
s
0 g
.006 w
.85878 .68123 m
.86004 .65803 L
s
.40649 .30991 m
.42071 .2974 L
s
.81047 .3836 m .62903 .52783 L .64415 .52737 L .282 0 .111 r
F
.79664 .36222 m .62903 .52783 L .81047 .3836 L .279 0 .186 r
F
.25 g
.5 Mabswid
.83086 .43096 m
.83087 .43095 L
s
.80732 .51373 m
.80857 .51655 L
s
.80857 .51655 m
.81247 .52531 L
s
.82072 .40742 m
.8224 .40628 L
s
0 g
.006 w
.81047 .3836 m
.8224 .40628 L
s
.25 g
.5 Mabswid
.40897 .9129 m
.41031 .91572 L
s
.40891 .91277 m
.40897 .9129 L
s
.33584 .75931 m
.40891 .91277 L
s
0 g
.006 w
.41031 .91572 m
.42629 .90844 L
s
1 0 0 r
.003 w
.50989 .58224 m
.51058 .58184 L
s
.74383 .30784 m .58983 .51588 L .5965 .52109 L .189 0 .307 r
F
.25 g
.5 Mabswid
.58496 .50933 m
.58619 .5074 L
s
.58258 .49978 m
.58267 .49962 L
s
.72271 .2935 m .58983 .51588 L .74383 .30784 L .129 0 .32 r
F
.25 g
.57901 .44845 m
.59342 .30943 L
s
1 0 0 r
.003 w
.58496 .50933 m
.58983 .51588 L
s
.25 g
.5 Mabswid
.58983 .51588 m
.58994 .51575 L
s
.72194 .29471 m
.72271 .2935 L
s
.72143 .2955 m
.72194 .29471 L
s
.72138 .29558 m
.72143 .2955 L
s
.79664 .36222 m .616 .52703 L .62903 .52783 L .279 0 .186 r
F
.25 g
.58994 .51575 m
.5909 .51445 L
s
.62903 .52783 m
.62914 .52774 L
s
.64415 .52737 m
.64438 .52721 L
s
.7809 .34235 m .616 .52703 L .79664 .36222 L .263 0 .241 r
F
.25 g
.7929 .51355 m
.79433 .51557 L
s
.79433 .51557 m
.80255 .52709 L
s
0 g
.006 w
.79664 .36222 m
.81047 .3836 L
s
.25 g
.5 Mabswid
.80876 .38496 m
.81047 .3836 L
s
.79555 .36321 m
.79664 .36222 L
s
.39199 .91773 m
.39302 .92061 L
s
.39195 .91761 m
.39199 .91773 L
s
.33584 .76073 m
.39195 .91761 L
s
.82895 .51544 m
.82959 .51901 L
s
0 g
.006 w
.85713 .70332 m
.85878 .68123 L
s
1 0 0 r
.003 w
.48441 .59653 m
.48567 .59588 L
s
0 g
.006 w
.42071 .2974 m
.43719 .28615 L
s
.25 g
.5 Mabswid
.37395 .92002 m
.37466 .92295 L
s
.33588 .76149 m
.37395 .92002 L
s
.7809 .34235 m .60517 .52481 L .616 .52703 L .263 0 .241 r
F
.25 g
.616 .52703 m
.61604 .527 L
s
.61604 .527 m
.61725 .5259 L
s
.61725 .5259 m
.61785 .52535 L
s
.5909 .51445 m
.59133 .51386 L
s
.62914 .52774 m
.63031 .52681 L
s
.63031 .52681 m
.63089 .52634 L
s
.64438 .52721 m
.64545 .52649 L
s
.64545 .52649 m
.64598 .52612 L
s
.66244 .5252 m
.66289 .52494 L
s
.66113 .52593 m
.66244 .5252 L
s
.76327 .32417 m .60517 .52481 L .7809 .34235 L .233 0 .28 r
F
.25 g
.77645 .51398 m
.77713 .51455 L
s
.77713 .51455 m
.7777 .51502 L
s
.7777 .51502 m
.79426 .52876 L
s
.79493 .36378 m
.79555 .36321 L
s
0 g
.006 w
.7809 .34235 m
.79664 .36222 L
s
.25 g
.5 Mabswid
.77925 .34406 m
.77985 .34343 L
s
.77985 .34343 m
.7809 .34235 L
s
1 0 0 r
.003 w
.46269 .60754 m
.46388 .60697 L
s
.25 g
.5 Mabswid
.8358 .51668 m
.8362 .52022 L
s
1 0 0 r
.003 w
.42293 .6259 m
.44459 .61614 L
s
0 g
.006 w
.39302 .92061 m
.41031 .91572 L
s
.25 g
.5 Mabswid
.35514 .91964 m
.3555 .92259 L
s
.35513 .91955 m
.35514 .91964 L
s
.33584 .76114 m
.35513 .91955 L
s
.76327 .32417 m .5965 .52109 L .60517 .52481 L .233 0 .28 r
F
.25 g
.60517 .52481 m
.60518 .5248 L
s
.60518 .5248 m
.60637 .52357 L
s
.60637 .52357 m
.60694 .52297 L
s
.58619 .5074 m
.58626 .50728 L
s
.68127 .52311 m
.68196 .52281 L
s
.67961 .52382 m
.68127 .52311 L
s
.74383 .30784 m .5965 .52109 L .76327 .32417 L .189 0 .307 r
F
1 0 0 r
.003 w
.58983 .51588 m
.5965 .52109 L
s
.25 g
.5 Mabswid
.75835 .51506 m
.7592 .51542 L
s
.7592 .51542 m
.75937 .5155 L
s
.70065 .52095 m
.70416 .51997 L
s
.70055 .52098 m
.70065 .52095 L
s
.69913 .52138 m
.70055 .52098 L
s
.72037 .5188 m
.74 .51687 L
s
.71914 .51893 m
.72037 .5188 L
s
.74011 .51688 m
.77236 .52101 L
s
.73907 .51675 m
.74011 .51688 L
s
.5869 .4321 m
.62489 .25989 L
s
.57873 .4822 m
.65042 .26551 L
s
.58026 .49114 m
.67519 .27335 L
s
.58267 .49962 m
.69893 .28339 L
s
.58626 .50728 m
.72138 .29558 L
s
.64598 .52612 m
.82072 .40742 L
s
.63089 .52634 m
.80876 .38496 L
s
.59133 .51386 m
.74235 .30984 L
s
.61785 .52535 m
.79493 .36378 L
s
.60694 .52297 m
.77922 .34409 L
s
.77922 .34409 m
.77925 .34406 L
s
0 g
.006 w
.76327 .32417 m
.7809 .34235 L
s
.25 g
.5 Mabswid
.59815 .51913 m
.76167 .32605 L
s
.59763 .51974 m
.59815 .51913 L
s
.76167 .32605 m
.76171 .32601 L
s
.59654 .52104 m
.59763 .51974 L
s
.5965 .52109 m
.59654 .52104 L
s
.76171 .32601 m
.76229 .32532 L
s
.76229 .32532 m
.76327 .32417 L
s
.74295 .30903 m
.74383 .30784 L
s
.7424 .30978 m
.74295 .30903 L
s
.74235 .30984 m
.7424 .30978 L
s
.59342 .30943 m
.5991 .25455 L
s
0 g
.006 w
.74383 .30784 m
.76327 .32417 L
s
1 0 0 r
.003 w
.41155 .63087 m
.42293 .6259 L
s
.5965 .52109 m
.60517 .52481 L
s
0 g
.006 w
.43719 .28615 m
.45093 .27885 L
s
.72271 .2935 m
.74383 .30784 L
s
.25 g
.5 Mabswid
.33588 .9165 m
.33588 .91944 L
s
.33588 .91643 m
.33588 .9165 L
s
.33584 .75878 m
.33588 .91643 L
s
.8552 .72412 m .84109 .51926 L .85305 .74346 L .589 .638 .867 r
F
0 g
.006 w
.8552 .72412 m
.85713 .70332 L
s
.70007 .28127 m
.72271 .2935 L
s
.45017 .27791 m
.47239 .26937 L
s
.37466 .92295 m
.39302 .92061 L
s
.25 g
.5 Mabswid
.31614 .91345 m
.31651 .91056 L
s
.31651 .91056 m
.31652 .91051 L
s
.31652 .91051 m
.33634 .75483 L
s
1 0 0 r
.003 w
.60517 .52481 m
.616 .52703 L
s
0 g
.006 w
.67612 .27123 m
.70007 .28127 L
s
.47239 .26937 m
.49605 .26253 L
s
.85305 .74346 m .83951 .52045 L .85073 .76114 L .662 .669 .847 r
F
.85305 .74346 m .84109 .51926 L .83951 .52045 L F
0 g
.85305 .74346 m
.8552 .72412 L
s
.25 g
.5 Mabswid
.85269 .73661 m
.85277 .73813 L
s
.85277 .73813 m
.85286 .73975 L
s
.85286 .73975 m
.85299 .74223 L
s
.85299 .74223 m
.85305 .74346 L
s
.70416 .51997 m
.84603 .48041 L
s
.83986 .51799 m
.84001 .52008 L
s
0 g
.006 w
.65112 .26342 m
.67612 .27123 L
s
.49605 .26253 m
.52087 .25752 L
s
.25 g
.5 Mabswid
.29666 .90461 m
.2974 .90182 L
s
.2974 .90182 m
.29741 .90178 L
s
.29741 .90178 m
.33768 .74977 L
s
0 g
.006 w
.62534 .25786 m
.65112 .26342 L
s
.3555 .92259 m
.37466 .92295 L
s
.52087 .25752 m
.54653 .25445 L
s
.5991 .25455 m
.62534 .25786 L
s
.54653 .25445 m
.57272 .25344 L
s
.57272 .25344 m
.5991 .25455 L
s
1 0 0 r
.003 w
.616 .52703 m
.62903 .52783 L
s
.25 g
.5 Mabswid
.27781 .89298 m
.27892 .89033 L
s
.27892 .89033 m
.27893 .89031 L
s
.27893 .89031 m
.34005 .74412 L
s
.85073 .76114 m .83951 .52045 L .83514 .52161 L .654 .64 .824 r
F
.25 g
.85059 .75825 m
.85073 .76114 L
s
.85026 .75108 m
.85059 .75825 L
s
0 g
.006 w
.85073 .76114 m
.85305 .74346 L
s
.25 g
.5 Mabswid
.84109 .51926 m
.84112 .51972 L
s
.84112 .51972 m
.84119 .52107 L
s
.8362 .52022 m
.83632 .52129 L
s
0 g
.006 w
.33588 .91944 m
.3555 .92259 L
s
.25 g
.5 Mabswid
.25999 .87865 m
.26145 .87621 L
s
.26145 .87621 m
.26146 .8762 L
s
.26146 .8762 m
.34347 .73836 L
s
1 0 0 r
.003 w
.62903 .52783 m
.64415 .52737 L
s
.84826 .77699 m .82805 .52283 L .84564 .79081 L .656 .62 .802 r
F
.84826 .77699 m .83514 .52161 L .82805 .52283 L F
.25 g
.5 Mabswid
.83951 .52045 m
.83955 .5213 L
s
.83955 .5213 m
.83963 .52311 L
s
.82959 .51901 m
.83021 .52246 L
s
0 g
.006 w
.84826 .77699 m
.85073 .76114 L
s
.25 g
.5 Mabswid
.83514 .52161 m
.83525 .52392 L
s
.84821 .77609 m
.84826 .77699 L
s
.68196 .52281 m
.83926 .45536 L
s
.84119 .52107 m
.84122 .5217 L
s
0 g
.006 w
.31614 .91345 m
.33588 .91944 L
s
.25 g
.5 Mabswid
.24357 .86182 m
.24535 .85961 L
s
.24535 .85961 m
.34786 .73293 L
s
1 0 0 r
.003 w
.41755 .65122 m
.4305 .65669 L
s
.64415 .52737 m
.66113 .52593 L
s
.84564 .79081 m .81836 .52433 L .84284 .80242 L .658 .602 .781 r
F
.25 g
.5 Mabswid
.84246 .74238 m
.84553 .78923 L
s
.84553 .78923 m
.84564 .79081 L
s
.82805 .52283 m
.82818 .52479 L
s
0 g
.006 w
.84564 .79081 m
.84826 .77699 L
s
.25 g
.5 Mabswid
.66289 .52494 m
.83086 .43096 L
s
0 g
.006 w
.29666 .90461 m
.31614 .91345 L
s
.25 g
.5 Mabswid
.2289 .84269 m
.23097 .84077 L
s
.23097 .84077 m
.35301 .72818 L
s
1 0 0 r
.003 w
.4305 .65669 m
.44483 .66547 L
s
.66113 .52593 m
.67961 .52382 L
s
0 g
.006 w
.27781 .89298 m
.29666 .90461 L
s
.25 g
.5 Mabswid
.81836 .52433 m
.8185 .52585 L
s
.84284 .80242 m .80622 .52636 L .83982 .81164 L .66 .585 .76 r
F
.25 g
.84142 .78627 m
.84267 .80047 L
s
.84267 .80047 m
.84284 .80242 L
s
0 g
.006 w
.84284 .80242 m
.84564 .79081 L
s
.25 g
.5 Mabswid
.84122 .5217 m
.85269 .73661 L
s
.2163 .82155 m
.21862 .81996 L
s
.21862 .81996 m
.35867 .72432 L
s
1 0 0 r
.003 w
.44483 .66547 m
.45141 .67106 L
s
.67961 .52382 m
.69913 .52138 L
s
0 g
.006 w
.25999 .87865 m
.27781 .89298 L
s
.25 g
.5 Mabswid
.20605 .79872 m
.20858 .79749 L
s
.20858 .79749 m
.36457 .72144 L
s
1 0 0 r
.003 w
.46508 .68508 m
.46735 .68773 L
s
.69913 .52138 m
.71914 .51893 L
s
.83982 .81164 m .79184 .52924 L .8365 .81829 L .66 .567 .739 r
F
.25 g
.5 Mabswid
.83377 .76025 m
.83956 .80943 L
s
.83956 .80943 m
.83961 .80984 L
s
.83961 .80984 m
.83975 .81106 L
s
.83975 .81106 m
.83982 .81164 L
s
0 g
.006 w
.83982 .81164 m
.84284 .80242 L
s
.25 g
.5 Mabswid
.83963 .52311 m
.85026 .75108 L
s
.83074 .66498 m
.84142 .78627 L
s
0 g
.006 w
.24357 .86182 m
.25999 .87865 L
s
1 0 0 r
.003 w
.71914 .51893 m
.73907 .51675 L
s
.80298 .79766 m .67554 .58117 L .65464 .59694 L .597 .383 .56 r
F
.81099 .80855 m .67554 .58117 L .80298 .79766 L .617 .421 .593 r
F
.81099 .80855 m .69665 .56741 L .67554 .58117 L F
.25 g
.5 Mabswid
.80622 .52636 m
.80623 .52644 L
s
.80298 .79766 m .65555 .59819 L .79358 .78397 L .597 .383 .56 r
F
.65555 .59819 m .65565 .59831 L .79358 .78397 L F
.65537 .59793 m .65586 .59859 L .79358 .78397 L F
.65531 .59785 m .65539 .59796 L .65537 .59793 L F
.65539 .59796 m .65586 .59859 L .65537 .59793 L F
.65555 .59819 m .65531 .59785 L .65565 .59831 L F
.65531 .59785 m .65464 .59694 L .65586 .59859 L F
.79358 .78397 m .65464 .59694 L .6343 .61449 L .571 .337 .523 r
F
.79358 .78397 m .63528 .61553 L .78264 .76767 L F
.63528 .61553 m .6343 .61449 L .63564 .61587 L F
.63528 .61553 m .63564 .61587 L .78264 .76767 L F
.61559 .63404 m .6343 .61449 L .61483 .63343 L .535 .283 .479 r
F
.78174 .76695 m .63563 .61587 L .61559 .63404 L F
.63563 .61587 m .6343 .61449 L .61559 .63404 L F
.78106 .76604 m .6343 .61449 L .78174 .76695 L F
.78264 .76767 m .78106 .76604 L .78174 .76695 L F
.78264 .76767 m .61585 .63425 L .76999 .74906 L F
.61585 .63425 m .61594 .63431 L .76999 .74906 L F
.6156 .63406 m .6162 .63446 L .76999 .74906 L F
.61559 .63404 m .61561 .63406 L .6156 .63406 L F
.61561 .63406 m .6162 .63446 L .6156 .63406 L F
.76874 .74837 m .6162 .63446 L .59644 .65333 L .488 .216 .427 r
F
.76833 .74783 m .61483 .63343 L .76874 .74837 L F
.76999 .74906 m .76833 .74783 L .76874 .74837 L F
.76999 .74906 m .59749 .65391 L .75553 .72852 L F
.59749 .65391 m .59644 .65333 L .59785 .65399 L F
.59749 .65391 m .59785 .65399 L .75553 .72852 L F
.75378 .72769 m .59785 .65399 L .75452 .72819 L .423 .131 .363 r
F
.59785 .65399 m .59644 .65333 L .59785 .654 L F
.59785 .65399 m .59785 .654 L .75452 .72819 L F
.75424 .72811 m .59644 .65333 L .57933 .67367 L F
.75412 .728 m .59644 .65333 L .75424 .72811 L F
.7544 .72798 m .75378 .72769 L .75459 .72822 L F
.75378 .72769 m .75452 .72819 L .75459 .72822 L F
.75459 .72822 m .75412 .728 L .75424 .72811 L F
.75553 .72852 m .7544 .72798 L .75459 .72822 L F
.75553 .72852 m .58037 .67399 L .73919 .70647 L F
.58037 .67399 m .58046 .67398 L .73919 .70647 L F
.58015 .67392 m .58071 .67395 L .73919 .70647 L F
.5801 .67391 m .58017 .67391 L .58015 .67392 L F
.58017 .67391 m .58071 .67395 L .58015 .67392 L F
.73787 .70638 m .58071 .67395 L .56357 .6939 L .334 .024 .282 r
F
.73741 .70611 m .57933 .67367 L .73787 .70638 L F
.73919 .70647 m .73741 .70611 L .73787 .70638 L F
.73919 .70647 m .5646 .69397 L .72092 .68342 L F
.5646 .69397 m .56357 .6939 L .56492 .69381 L F
.5646 .69397 m .56492 .69381 L .72092 .68342 L F
.71915 .68353 m .56492 .69381 L .71994 .68359 L .213 0 .178 r
F
.56492 .69381 m .56357 .6939 L .56492 .69381 L F
.56492 .69381 m .56492 .69381 L .71994 .68359 L F
.71961 .68365 m .56357 .6939 L .54921 .7135 L F
.71949 .68362 m .56357 .6939 L .71961 .68365 L F
.71975 .68349 m .71915 .68353 L .71994 .68359 L F
.71915 .68353 m .71994 .68359 L .71994 .68359 L F
.71994 .68359 m .71949 .68362 L .71961 .68365 L F
.72092 .68342 m .71975 .68349 L .71994 .68359 L F
.72092 .68342 m .5502 .71332 L .70077 .65988 L F
.5502 .71332 m .55029 .71325 L .70077 .65988 L F
.54993 .71337 m .55046 .71306 L .70077 .65988 L F
.69949 .66044 m .55046 .71306 L .53623 .73198 L .05 0 .047 r
F
.54993 .71337 m .54921 .7135 L .55046 .71306 L .213 0 .178 r
F
.69904 .66049 m .54921 .7135 L .69949 .66044 L .05 0 .047 r
F
.70077 .65988 m .69904 .66049 L .69949 .66044 L F
.70077 .65988 m .53623 .73198 L .67879 .6364 L F
.67785 .63708 m .53623 .73198 L .67786 .63707 L 0 0 0 r
F
.67716 .63749 m .53623 .73198 L .67785 .63708 L F
.67757 .63729 m .53623 .73198 L .52457 .74891 L F
.67746 .63734 m .53623 .73198 L .67757 .63729 L F
.67767 .63714 m .67716 .63749 L .67785 .63708 L F
.67786 .63707 m .67746 .63734 L .67757 .63729 L F
.67879 .6364 m .67767 .63714 L .67786 .63707 L F
.67879 .6364 m .52457 .74891 L .65511 .61352 L F
.65397 .61473 m .52457 .74891 L .51413 .76398 L F
.65511 .61352 m .65358 .61511 L .65397 .61473 L F
.65358 .61511 m .52457 .74891 L .65397 .61473 L F
.5502 .71332 m .54993 .71337 L .55029 .71325 L .213 0 .178 r
F
.55046 .71306 m .54921 .7135 L .53623 .73198 L .05 0 .047 r
F
.58037 .67399 m .5801 .67391 L .58046 .67398 L .423 .131 .363 r
F
.5801 .67391 m .57933 .67367 L .58071 .67395 L F
.58071 .67395 m .57933 .67367 L .56357 .6939 L .334 .024 .282 r
F
.61585 .63425 m .61559 .63404 L .61594 .63431 L .535 .283 .479 r
F
.61559 .63404 m .61483 .63343 L .6162 .63446 L F
.6162 .63446 m .61483 .63343 L .59644 .65333 L .488 .216 .427 r
F
.25 g
.65464 .59694 m
.65586 .59859 L
s
.65586 .59859 m
.65589 .59864 L
s
1 0 0 r
.003 w
.65464 .59694 m
.67554 .58117 L
s
.25 g
.5 Mabswid
.67554 .58117 m
.67664 .58305 L
s
.67664 .58305 m
.67669 .58313 L
s
1 0 0 r
.003 w
.6343 .61449 m
.65464 .59694 L
s
.8178 .81647 m .69665 .56741 L .81099 .80855 L .632 .453 .622 r
F
.8178 .81647 m .7176 .5558 L .69665 .56741 L F
.25 g
.5 Mabswid
.80623 .52644 m
.80641 .52793 L
s
1 0 0 r
.003 w
.67554 .58117 m
.69665 .56741 L
s
.25 g
.5 Mabswid
.65589 .59864 m
.70548 .66538 L
s
.69665 .56741 m
.69762 .56945 L
s
.69762 .56945 m
.69769 .56959 L
s
.19839 .77456 m
.20106 .77371 L
s
.20106 .77371 m
.3705 .71955 L
s
.6343 .61449 m
.63562 .61585 L
s
.63562 .61585 m
.63564 .61587 L
s
.63564 .61587 m
.64426 .62477 L
s
1 0 0 r
.003 w
.61483 .63343 m
.6343 .61449 L
s
.82358 .82139 m .7176 .5558 L .8178 .81647 L .643 .481 .648 r
F
.82358 .82139 m .73798 .54635 L .7176 .5558 L F
.25 g
.5 Mabswid
.8185 .52585 m
.81855 .5265 L
s
.80641 .52793 m
.8065 .52871 L
s
1 0 0 r
.003 w
.69665 .56741 m
.7176 .5558 L
s
.25 g
.5 Mabswid
.7176 .5558 m
.7185 .55815 L
s
1 0 0 r
.003 w
.73907 .51675 m
.75835 .51506 L
s
.82852 .82328 m .73798 .54635 L .82358 .82139 L .651 .506 .673 r
F
.82852 .82328 m .75739 .53892 L .73798 .54635 L F
.25 g
.5 Mabswid
.82818 .52479 m
.82822 .52548 L
s
.81855 .5265 m
.81859 .52691 L
s
.81679 .61611 m
.83377 .76025 L
s
.8065 .52871 m
.80652 .5289 L
s
1 0 0 r
.003 w
.7176 .5558 m
.73798 .54635 L
s
.25 g
.5 Mabswid
.73798 .54635 m
.73862 .54843 L
s
.73862 .54843 m
.73874 .5488 L
s
.61483 .63343 m
.6162 .63446 L
s
.6162 .63446 m
.61621 .63447 L
s
.61621 .63447 m
.62709 .64258 L
s
1 0 0 r
.003 w
.59644 .65333 m
.59702 .65271 L
s
.59702 .65271 m
.61483 .63343 L
s
0 g
.006 w
.2289 .84269 m
.24357 .86182 L
s
.83277 .82222 m .75739 .53892 L .82852 .82328 L .656 .528 .696 r
F
.83277 .82222 m .77546 .53332 L .75739 .53892 L F
.25 g
.5 Mabswid
.82822 .52548 m
.82823 .52555 L
s
.67669 .58313 m
.76278 .72937 L
s
.69769 .56959 m
.77042 .72298 L
s
.7185 .55815 m
.75889 .66323 L
s
.73874 .5488 m
.76338 .62798 L
s
1 0 0 r
.003 w
.73798 .54635 m
.75739 .53892 L
s
.25 g
.5 Mabswid
.75739 .53892 m
.75802 .54142 L
s
.75802 .54142 m
.76348 .56326 L
s
1 0 0 r
.003 w
.75739 .53892 m
.76212 .53746 L
s
.8365 .81829 m .77546 .53332 L .83277 .82222 L .659 .548 .718 r
F
.25 g
.5 Mabswid
.82787 .82071 m
.82852 .82328 L
s
.82283 .81897 m
.82358 .82139 L
s
.82278 .81881 m
.82283 .81897 L
s
.8365 .81829 m .79184 .52924 L .77546 .53332 L .659 .548 .718 r
F
.25 g
.83525 .52392 m
.83528 .52436 L
s
.83528 .52436 m
.84821 .77609 L
s
0 g
.006 w
.8365 .81829 m
.83982 .81164 L
s
.25 g
.5 Mabswid
.82823 .52555 m
.84246 .74238 L
s
.81859 .52691 m
.83074 .66498 L
s
.80652 .5289 m
.81679 .61611 L
s
.76278 .72937 m
.80168 .79546 L
s
.80168 .79546 m
.80172 .79553 L
s
.80172 .79553 m
.80221 .79636 L
s
.80221 .79636 m
.80298 .79766 L
s
.77042 .72298 m
.80985 .80615 L
s
.80985 .80615 m
.8099 .80625 L
s
.8099 .80625 m
.81034 .80717 L
s
.81034 .80717 m
.81099 .80855 L
s
.75889 .66323 m
.81683 .81395 L
s
.81683 .81395 m
.81688 .81408 L
s
.81688 .81408 m
.81726 .81508 L
s
.81726 .81508 m
.8178 .81647 L
s
.76338 .62798 m
.82278 .81881 L
s
.7858 .65249 m
.82787 .82071 L
s
.76348 .56326 m
.7858 .65249 L
s
1 0 0 r
.003 w
.76212 .53746 m
.77546 .53332 L
s
.25 g
.5 Mabswid
.83636 .81739 m
.8365 .81829 L
s
.83618 .81622 m
.83636 .81739 L
s
.83613 .8159 m
.83618 .81622 L
s
.82177 .72294 m
.83613 .8159 L
s
.80096 .58829 m
.82177 .72294 L
s
.79223 .53174 m
.80096 .58829 L
s
.79216 .53128 m
.79223 .53174 L
s
.79198 .53013 m
.79216 .53128 L
s
.79184 .52924 m
.79198 .53013 L
s
.75937 .5155 m
.75939 .5155 L
s
.75939 .5155 m
.79177 .52926 L
s
0 g
.006 w
.83277 .82222 m
.8365 .81829 L
s
1 0 0 r
.003 w
.75835 .51506 m
.77645 .51398 L
s
.25 g
.5 Mabswid
.80552 .68483 m
.83277 .82222 L
s
.7832 .57234 m
.80552 .68483 L
s
.77546 .53332 m
.7758 .535 L
s
.7758 .535 m
.77594 .53572 L
s
.77594 .53572 m
.77595 .5358 L
s
.77595 .5358 m
.7832 .57234 L
s
1 0 0 r
.003 w
.78004 .53218 m
.79184 .52924 L
s
.77546 .53332 m
.78004 .53218 L
s
.25 g
.5 Mabswid
.59644 .65333 m
.5965 .65336 L
s
.5965 .65336 m
.59784 .65399 L
s
.59784 .65399 m
.59785 .65399 L
s
.59785 .65399 m
.61038 .65992 L
s
1 0 0 r
.003 w
.57933 .67367 m
.58067 .67207 L
s
.58067 .67207 m
.59644 .65333 L
s
.79577 .52845 m
.80622 .52636 L
s
.79184 .52924 m
.79577 .52845 L
s
.77645 .51398 m
.7929 .51355 L
s
.80933 .52584 m
.81836 .52433 L
s
.80622 .52636 m
.80933 .52584 L
s
.82066 .52397 m
.82805 .52283 L
s
.81836 .52433 m
.82066 .52397 L
s
.25 g
.5 Mabswid
.57933 .67367 m
.57946 .67369 L
s
.57946 .67369 m
.5803 .67386 L
s
.5803 .67386 m
.58071 .67395 L
s
.58071 .67395 m
.58072 .67395 L
s
.58072 .67395 m
.59418 .67671 L
s
1 0 0 r
.003 w
.56357 .6939 m
.57933 .67367 L
s
.25 g
.5 Mabswid
.1935 .74945 m
.19626 .74899 L
s
.19626 .74899 m
.37633 .71856 L
s
1 0 0 r
.003 w
.47834 .70711 m
.481 .71352 L
s
0 g
.006 w
.2163 .82155 m
.2289 .84269 L
s
1 0 0 r
.003 w
.7929 .51355 m
.80732 .51373 L
s
.82964 .52256 m
.83514 .52161 L
s
.82805 .52283 m
.82964 .52256 L
s
.83612 .52135 m
.83951 .52045 L
s
.83514 .52161 m
.83612 .52135 L
s
.80732 .51373 m
.81941 .5144 L
s
.83997 .52011 m
.84109 .51926 L
s
.83951 .52045 m
.83997 .52011 L
s
.81941 .5144 m
.82895 .51544 L
s
.83986 .51799 m
.84109 .51926 L
s
.82895 .51544 m
.8358 .51668 L
s
.8358 .51668 m
.83986 .51799 L
s
.25 g
.5 Mabswid
.56357 .6939 m
.56455 .69383 L
s
.56455 .69383 m
.5649 .69381 L
s
.5649 .69381 m
.56492 .69381 L
s
.56492 .69381 m
.57858 .6929 L
s
1 0 0 r
.003 w
.54921 .7135 m
.56357 .6939 L
s
0 g
.006 w
.82852 .82328 m
.83277 .82222 L
s
.20605 .79872 m
.2163 .82155 L
s
.25 g
.5 Mabswid
.19149 .7238 m
.19428 .72372 L
s
.19428 .72372 m
.38206 .7184 L
s
.54921 .7135 m
.55046 .71306 L
s
.55046 .71306 m
.5505 .71304 L
s
.5505 .71304 m
.56363 .7084 L
s
1 0 0 r
.003 w
.53623 .73198 m
.54921 .7135 L
s
0 g
.006 w
.19839 .77456 m
.20605 .79872 L
s
.25 g
.5 Mabswid
.53623 .73198 m
.53737 .73122 L
s
.53737 .73122 m
.54943 .72313 L
s
1 0 0 r
.003 w
.52457 .74891 m
.53623 .73198 L
s
0 g
.006 w
.82358 .82139 m
.82852 .82328 L
s
.25 g
.5 Mabswid
.19243 .69801 m
.19519 .69831 L
s
.19519 .69831 m
.38777 .71901 L
s
0 g
.006 w
.1935 .74945 m
.19839 .77456 L
s
.19149 .7238 m
.1935 .74945 L
s
.25 g
.5 Mabswid
.19634 .67248 m
.19902 .67313 L
s
.19902 .67313 m
.39362 .72043 L
s
1 0 0 r
.003 w
.48578 .75569 m
.48632 .74517 L
s
0 g
.006 w
.8178 .81647 m
.82358 .82139 L
s
.62989 .59177 m .51413 .76398 L .50482 .77698 L .609 .826 .432 r
F
.25 g
.5 Mabswid
.52457 .74891 m
.52557 .74787 L
s
.65511 .61352 m .51413 .76398 L .62989 .59177 L 0 0 0 r
F
0 g
.006 w
.19149 .7238 m
.19243 .69801 L
s
.25 g
.5 Mabswid
.20318 .64759 m
.20574 .64857 L
s
.20574 .64857 m
.39982 .72281 L
s
1 0 0 r
.003 w
.48367 .76725 m
.48578 .75569 L
s
0 g
.006 w
.19243 .69801 m
.19634 .67248 L
s
.60335 .57162 m .50482 .77698 L .49653 .78781 L .777 .918 .538 r
F
.25 g
.5 Mabswid
.51413 .76398 m
.51498 .76272 L
s
.62989 .59177 m .50482 .77698 L .60335 .57162 L .609 .826 .432 r
F
1 0 0 r
.003 w
.50482 .77698 m
.51413 .76398 L
s
.25 g
.5 Mabswid
.62986 .59182 m
.62989 .59177 L
s
.62895 .59317 m
.62986 .59182 L
s
.62852 .5938 m
.62895 .59317 L
s
0 g
.006 w
.81099 .80855 m
.8178 .81647 L
s
.19634 .67248 m
.20318 .64759 L
s
.25 g
.5 Mabswid
.21288 .62372 m
.21527 .62498 L
s
.21527 .62498 m
.40656 .72638 L
s
1 0 0 r
.003 w
.48263 .7707 m
.48367 .76725 L
s
.57571 .55349 m .49653 .78781 L .4892 .79649 L .885 .95 .597 r
F
.25 g
.5 Mabswid
.50482 .77698 m
.50552 .77553 L
s
.51498 .76272 m
.5151 .76255 L
s
.60335 .57162 m .49653 .78781 L .57571 .55349 L .777 .918 .538 r
F
1 0 0 r
.003 w
.49653 .78781 m
.50482 .77698 L
s
.25 g
.5 Mabswid
.6033 .57171 m
.60335 .57162 L
s
.60253 .57332 m
.6033 .57171 L
s
.60217 .57407 m
.60253 .57332 L
s
0 g
.006 w
.20318 .64759 m
.21288 .62372 L
s
.25 g
.5 Mabswid
.22532 .60121 m
.2275 .60272 L
s
.2275 .60272 m
.41396 .73149 L
s
1 0 0 r
.003 w
.47695 .78631 m
.47823 .78318 L
s
0 g
.006 w
.80298 .79766 m
.81099 .80855 L
s
.54724 .53776 m .4892 .79649 L .48278 .80312 L .946 .944 .62 r
F
.25 g
.5 Mabswid
.49653 .78781 m
.49707 .78621 L
s
.50552 .77553 m
.50564 .77527 L
s
.57571 .55349 m .4892 .79649 L .54724 .53776 L .885 .95 .597 r
F
1 0 0 r
.003 w
.4892 .79649 m
.49653 .78781 L
s
.25 g
.5 Mabswid
.57566 .55365 m
.57571 .55349 L
s
.57504 .55549 m
.57566 .55365 L
s
.57475 .55633 m
.57504 .55549 L
s
0 g
.006 w
.21288 .62372 m
.22532 .60121 L
s
.25 g
.5 Mabswid
.24037 .58039 m
.2423 .58208 L
s
.2423 .58208 m
.42205 .73853 L
s
1 0 0 r
.003 w
.47364 .79293 m
.47695 .78631 L
s
.51821 .52471 m .48278 .80312 L .47725 .80788 L .977 .919 .622 r
F
.25 g
.5 Mabswid
.4892 .79649 m
.48959 .79477 L
s
.49707 .78621 m
.49721 .78582 L
s
.50564 .77527 m
.50568 .7752 L
s
.54724 .53776 m .48278 .80312 L .51821 .52471 L .946 .944 .62 r
F
.25 g
.5151 .76255 m
.62852 .5938 L
s
.50568 .7752 m
.60217 .57407 L
s
.49721 .78582 m
.57475 .55633 L
s
.48959 .79477 m
.54652 .54095 L
s
1 0 0 r
.003 w
.48278 .80312 m
.4892 .79649 L
s
.25 g
.5 Mabswid
.51776 .52822 m
.51789 .52723 L
s
.51789 .52723 m
.51817 .52502 L
s
.51817 .52502 m
.51821 .52471 L
s
.48278 .80312 m
.48371 .79581 L
s
.54719 .53798 m
.54724 .53776 L
s
.54673 .54002 m
.54719 .53798 L
s
.54652 .54095 m
.54673 .54002 L
s
0 g
.006 w
.22532 .60121 m
.24037 .58039 L
s
.79358 .78397 m
.80298 .79766 L
s
.25 g
.5 Mabswid
.25784 .56155 m
.2595 .56334 L
s
.2595 .56334 m
.27896 .58431 L
s
.27896 .58431 m
.43073 .74788 L
s
1 0 0 r
.003 w
.46988 .79975 m
.472 .79595 L
s
.4889 .51457 m .47725 .80788 L .47265 .81099 L .99 .885 .611 r
F
.25 g
.5 Mabswid
.47725 .80788 m
.47751 .8013 L
s
.48876 .5182 m
.4889 .51457 L
s
.47751 .8013 m
.48876 .5182 L
s
1 0 0 r
.003 w
.47725 .80788 m
.48278 .80312 L
s
.25 g
.5 Mabswid
.48371 .79581 m
.51776 .52822 L
s
0 g
.006 w
.24037 .58039 m
.25784 .56155 L
s
.25 g
.5 Mabswid
.27756 .54496 m
.27889 .54672 L
s
.27889 .54672 m
.28002 .54821 L
s
.4596 .5075 m .47265 .81099 L .46901 .81267 L .992 .847 .595 r
F
.25 g
.47241 .80552 m
.47265 .81099 L
s
1 0 0 r
.003 w
.46716 .80454 m
.46785 .80332 L
s
.47265 .81099 m
.47725 .80788 L
s
0 g
.006 w
.25784 .56155 m
.27756 .54496 L
s
.25 g
.5 Mabswid
.29932 .53084 m
.30023 .53234 L
s
.4306 .50358 m .46901 .81267 L .46642 .81311 L .987 .808 .577 r
F
.25 g
.4685 .80856 m
.46901 .81267 L
s
1 0 0 r
.003 w
.46534 .80821 m
.46576 .80737 L
s
.46901 .81267 m
.47265 .81099 L
s
0 g
.006 w
.78264 .76767 m
.79358 .78397 L
s
.25 g
.5 Mabswid
.32289 .51942 m
.3231 .51984 L
s
.3231 .51984 m
.32803 .52984 L
s
.40216 .50286 m .46642 .81311 L .46493 .81247 L .973 .768 .569 r
F
.4306 .50358 m .46642 .81311 L .40216 .50286 L .987 .808 .577 r
F
1 0 0 r
.003 w
.46642 .81311 m
.46901 .81267 L
s
.46457 .81083 m
.46459 .81078 L
s
.25 g
.5 Mabswid
.46568 .80953 m
.46642 .81311 L
s
.3511 .51872 m
.35425 .52683 L
s
.34805 .51086 m
.3511 .51872 L
s
.40216 .50286 m .46493 .81247 L .37456 .5053 L .973 .768 .569 r
F
.25 g
.46487 .81225 m
.46493 .81247 L
s
.46406 .80951 m
.46487 .81225 L
s
.37456 .5053 m
.37647 .5118 L
s
.37647 .5118 m
.37654 .51205 L
s
.37654 .51205 m
.46406 .80951 L
s
.46366 .80849 m
.46405 .8095 L
s
.35425 .52683 m
.46366 .80849 L
s
1 0 0 r
.003 w
.46493 .81247 m
.46642 .81311 L
s
.25 g
.5 Mabswid
.40216 .50286 m
.40316 .50769 L
s
.40316 .50769 m
.40322 .50796 L
s
.40322 .50796 m
.46568 .80953 L
s
.32803 .52984 m
.45692 .79114 L
s
.28002 .54821 m
.43972 .7598 L
s
.46181 .55872 m
.47241 .80552 L
s
.4596 .5075 m
.46181 .55872 L
s
.30023 .53234 m
.44862 .77432 L
s
.4306 .50358 m
.43168 .51226 L
s
.43168 .51226 m
.4685 .80856 L
s
0 g
.006 w
.27756 .54496 m
.29932 .53084 L
s
.29932 .53084 m
.32289 .51942 L
s
.76999 .74906 m
.78264 .76767 L
s
.32289 .51942 m
.34805 .51086 L
s
.75553 .72852 m
.76999 .74906 L
s
.34805 .51086 m
.37456 .5053 L
s
.37456 .5053 m
.40216 .50286 L
s
.73919 .70647 m
.75553 .72852 L
s
.40216 .50286 m
.4306 .50358 L
s
.72092 .68342 m
.73919 .70647 L
s
.4306 .50358 m
.4596 .5075 L
s
.4596 .5075 m
.4889 .51457 L
s
.70077 .65988 m
.72092 .68342 L
s
.4889 .51457 m
.51821 .52471 L
s
.67879 .6364 m
.70077 .65988 L
s
.51821 .52471 m
.54724 .53776 L
s
.65511 .61352 m
.67879 .6364 L
s
.54724 .53776 m
.57571 .55349 L
s
.62989 .59177 m
.65511 .61352 L
s
.57571 .55349 m
.60335 .57162 L
s
.60335 .57162 m
.62989 .59177 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.313, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[%, ViewPoint \[Rule] {\(-0.120\), \(-1.153\), 3.179}]\)], "Input",

  
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.08226 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.112363 1.17234 -0.0900796 1.17234 [
[ 0 0 0 0 ]
[ 1 1.08226 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15213 0 m
.04127 .1616 L
s
.04127 .1616 m
0 1.00512 L
s
0 1.00512 m
.11111 .65945 L
s
.11111 .65945 m
.15213 0 L
s
.86642 .07429 m
.76554 .72169 L
s
.76554 .72169 m
.8539 1.08226 L
s
.8539 1.08226 m
1 .2591 L
s
1 .2591 m
.86642 .07429 L
s
.15213 0 m
.04127 .1616 L
s
.04127 .1616 m
1 .2591 L
s
1 .2591 m
.86642 .07429 L
s
.86642 .07429 m
.15213 0 L
s
.11111 .65945 m
.76554 .72169 L
s
.76554 .72169 m
.8539 1.08226 L
s
.8539 1.08226 m
0 1.00512 L
s
0 1.00512 m
.11111 .65945 L
s
0 0 m
1 0 L
1 1.08226 L
0 1.08226 L
closepath
clip
newpath
.46752 .41783 m .47001 .44628 L .47933 .36118 L .985 .793 .393 r
F
.47152 .46347 m .47254 .47509 L .47847 .4472 L F
.47254 .47509 m .47762 .53297 L .4783 .46464 L F
.47254 .47509 m .4783 .46464 L .47847 .4472 L F
.47254 .47509 m .47744 .53499 L .47762 .53297 L F
.4644 .46468 m .46647 .47583 L .46557 .46095 L .975 .735 .315 r
F
.46647 .47583 m .47133 .46441 L .46985 .44727 L F
.46557 .46095 m .46985 .44727 L .4528 .25009 L F
.46647 .47583 m .46985 .44727 L .46557 .46095 L F
.51311 .30911 m .51092 .31622 L .51937 .28919 L 0 0 .098 r
F
.47001 .44628 m .47133 .46441 L .47152 .46347 L .985 .793 .393 r
F
.42561 .25554 m .4644 .46468 L .4528 .25009 L .975 .735 .315 r
F
.4644 .46468 m .46557 .46095 L .4528 .25009 L F
.46647 .47583 m .47714 .53793 L .47744 .53499 L F
.4644 .46468 m .46641 .47623 L .46647 .47583 L F
.46641 .47623 m .47714 .53793 L .46647 .47583 L F
.4574 .46852 m .46036 .47895 L .46115 .45032 L .974 .692 .29 r
F
.53237 .32108 m .52362 .34228 L .53979 .30372 L 0 0 .103 r
F
.46251 .48649 m .47714 .53793 L .46617 .47783 L .974 .692 .29 r
F
.46434 .46521 m .46635 .47664 L .4644 .46468 L .975 .735 .315 r
F
.46635 .47664 m .47714 .53793 L .46641 .47623 L F
.46635 .47664 m .46641 .47623 L .4644 .46468 L F
.45637 .46167 m .46009 .44451 L .45615 .42293 L .974 .692 .29 r
F
.45298 .45299 m .45404 .45696 L .45597 .46352 L F
.4535 .47814 m .45165 .48909 L .45475 .48122 L 0 0 .132 r
F
.45165 .48909 m .44496 .52861 L .45271 .4911 L F
.45165 .48909 m .45271 .4911 L .45475 .48122 L F
.45298 .45336 m .44795 .50057 L .45597 .46352 L F
.44795 .50057 m .44496 .52861 L .45597 .46352 L F
.44959 .48509 m .44471 .52898 L .44795 .50057 L F
.45725 .49126 m .4592 .49691 L .45924 .49642 L .966 .648 .269 r
F
.45717 .49249 m .4591 .49795 L .45725 .49126 L F
.4591 .49795 m .47606 .54592 L .4592 .49691 L F
.4591 .49795 m .4592 .49691 L .45725 .49126 L F
.45924 .49642 m .46603 .51639 L .4767 .54165 L F
.4592 .49691 m .47606 .54592 L .45924 .49642 L F
.45902 .49874 m .45659 .50463 L .45902 .49879 L 0 0 .103 r
F
.45707 .49383 m .4459 .53051 L .45902 .49874 L 0 0 .098 r
F
.45659 .50463 m .45658 .50471 L .45901 .49886 L 0 0 .103 r
F
.45659 .50463 m .45901 .49886 L .45902 .49879 L F
.45707 .49383 m .45486 .5005 L .45482 .50121 L 0 0 .098 r
F
.45717 .4924 m .44534 .52918 L .45707 .49383 L F
.46016 .48117 m .45731 .49041 L .45901 .48556 L F
.45725 .49126 m .4767 .54165 L .46008 .48209 L .966 .648 .269 r
F
.46008 .48209 m .45901 .48556 L .46003 .48265 L 0 0 .098 r
F
.46016 .48117 m .45901 .48556 L .46008 .48209 L F
.45731 .49041 m .44534 .52918 L .45717 .4924 L F
.45099 .47179 m .44956 .4844 L .44959 .48509 L 0 0 .132 r
F
.45298 .45299 m .45098 .47133 L .45099 .47179 L F
.45098 .47133 m .44956 .4844 L .45099 .47179 L F
.45597 .46352 m .4535 .47814 L .4574 .46837 L F
.4535 .47814 m .45475 .48122 L .4574 .46837 L F
.45298 .45237 m .45098 .47093 L .45298 .45299 L F
.45098 .47093 m .44471 .52898 L .45098 .47133 L F
.45098 .47093 m .45098 .47133 L .45298 .45299 L F
.45617 .42214 m .44954 .48393 L .45615 .42293 L F
.44954 .48393 m .44471 .52898 L .44955 .48413 L F
.44954 .48393 m .44955 .48413 L .45615 .42293 L F
.44956 .4844 m .44471 .52898 L .44959 .48509 L F
.45731 .49038 m .45499 .49792 L .45731 .49039 L 0 0 .098 r
F
.45726 .47097 m .44534 .52918 L .46018 .481 L 0 0 .096 r
F
.45499 .49792 m .45498 .49795 L .46016 .48117 L 0 0 .098 r
F
.46018 .481 m .46098 .48376 L .46025 .48018 L .974 .692 .29 r
F
.46008 .48209 m .46098 .48376 L .46018 .481 L F
.46215 .48951 m .46233 .48795 L .46025 .48018 L F
.46251 .48649 m .4767 .54165 L .47714 .53793 L F
.46245 .48696 m .4767 .54165 L .46251 .48649 L F
.46029 .47979 m .4767 .54165 L .46036 .47895 L F
.46215 .48951 m .4767 .54165 L .46233 .48795 L F
.46115 .45032 m .46416 .46678 L .46351 .46252 L .975 .735 .315 r
F
.46116 .45016 m .46351 .46252 L .46132 .4481 L F
.46115 .45032 m .46351 .46252 L .46116 .45016 L F
.46416 .46678 m .46434 .46521 L .46132 .4481 L F
.46036 .47895 m .46416 .46678 L .46115 .45032 L .974 .692 .29 r
F
.46132 .4481 m .46434 .46521 L .4644 .46468 L .975 .735 .315 r
F
.46712 .42134 m .4574 .46838 L .46674 .42467 L 0 0 .096 r
F
.45895 .49951 m .47606 .54592 L .4591 .49795 L .966 .648 .269 r
F
.46185 .49199 m .45901 .49886 L .4615 .49494 L 0 0 .103 r
F
.45648 .5061 m .45784 .50932 L .45787 .50893 L .951 .6 .244 r
F
.45886 .50037 m .46035 .50431 L .45895 .49951 L .966 .648 .269 r
F
.46035 .50431 m .47606 .54592 L .46044 .50356 L F
.46035 .50431 m .46044 .50356 L .45895 .49951 L F
.46025 .48018 m .4767 .54165 L .46029 .47979 L .974 .692 .29 r
F
.46416 .46678 m .47714 .53793 L .46434 .46521 L .975 .735 .315 r
F
.46647 .47583 m .47744 .53499 L .47133 .46441 L F
.45901 .49886 m .4459 .53051 L .45422 .51156 L 0 0 .103 r
F
.45901 .49886 m .45653 .50542 L .45886 .50037 L F
.45653 .50542 m .45422 .51156 L .45648 .5061 L F
.45653 .50542 m .45648 .5061 L .45886 .50037 L F
.45648 .5061 m .45787 .50893 L .45886 .50037 L .951 .6 .244 r
F
.45787 .50893 m .47606 .54592 L .46035 .50431 L F
.45787 .50893 m .46035 .50431 L .45886 .50037 L F
.55395 .32735 m .50209 .42655 L .56137 .31387 L 0 0 .105 r
F
.45638 .50755 m .45771 .51061 L .45645 .50657 L .951 .6 .244 r
F
.45771 .51061 m .47511 .55047 L .4578 .50973 L F
.45771 .51061 m .4578 .50973 L .45645 .50657 L F
.45787 .50893 m .46501 .52612 L .47606 .54592 L F
.45784 .50932 m .47511 .55047 L .45787 .50893 L F
.45645 .50657 m .4578 .50973 L .45648 .5061 L F
.4578 .50973 m .47511 .55047 L .45784 .50932 L F
.4578 .50973 m .45784 .50932 L .45648 .5061 L F
.45373 .52741 m .4737 .55495 L .45574 .52436 L .901 .487 .167 r
F
.45592 .52234 m .45382 .52564 L .45538 .52839 L 0 0 .099 r
F
.45184 .5361 m .46847 .56231 L .47158 .55902 L .865 .418 .11 r
F
.45184 .53616 m .46847 .56231 L .45184 .5361 L F
.45187 .53451 m .45012 .53679 L .45089 .53728 L 0 0 .083 r
F
.45184 .5361 m .45089 .53728 L .45181 .53786 L F
.45187 .53451 m .45089 .53728 L .45184 .5361 L F
.45166 .52901 m .44809 .53459 L .45167 .53155 L 0 0 .099 r
F
.45422 .52809 m .46235 .54257 L .4737 .55495 L .901 .487 .167 r
F
.4542 .52825 m .47158 .55902 L .45422 .52809 L F
.45353 .53134 m .45168 .5343 L .45392 .53183 L 0 0 .099 r
F
.45168 .5343 m .45012 .53679 L .45187 .53451 L F
.45168 .5343 m .45187 .53451 L .45392 .53183 L F
.45168 .5343 m .45015 .53284 L .45012 .53679 L F
.45184 .5361 m .47158 .55902 L .45377 .53371 L .865 .418 .11 r
F
.45392 .53183 m .45187 .53451 L .45341 .5384 L 0 0 .083 r
F
.45344 .53323 m .47158 .55902 L .45373 .52741 L .901 .487 .167 r
F
.45353 .53134 m .45167 .53155 L .45168 .5343 L 0 0 .099 r
F
.45538 .52839 m .4536 .5299 L .45353 .53134 L F
.4536 .5299 m .45167 .53155 L .45353 .53134 L F
.45167 .53155 m .45015 .53284 L .45168 .5343 L F
.45015 .53284 m .44809 .53459 L .44861 .53516 L F
.45015 .53284 m .44861 .53516 L .45012 .53679 L F
.45532 .51712 m .44676 .5324 L .45441 .51927 L 0 0 .105 r
F
.4554 .51594 m .44676 .5324 L .45532 .51712 L F
.45761 .51164 m .44676 .5324 L .45761 .51173 L F
.45627 .50902 m .44676 .5324 L .45761 .51164 L 0 0 .103 r
F
.45529 .51761 m .45618 .51943 L .45621 .51914 L .93 .547 .211 r
F
.45506 .521 m .44809 .53459 L .45592 .52234 L 0 0 .105 r
F
.45493 .52299 m .4737 .55495 L .4634 .53407 L .93 .547 .211 r
F
.45506 .521 m .4634 .53407 L .45529 .51761 L F
.45493 .52299 m .4634 .53407 L .45506 .521 L F
.45621 .51914 m .4737 .55495 L .47511 .55047 L F
.45618 .51943 m .4737 .55495 L .45621 .51914 L F
.45529 .51761 m .47511 .55047 L .45743 .51358 L F
.45761 .51173 m .4554 .51594 L .45532 .51712 L 0 0 .105 r
F
.45761 .51173 m .45441 .51927 L .45743 .51358 L F
.45886 .50037 m .45648 .5061 L .45879 .50112 L 0 0 .103 r
F
.45648 .5061 m .45422 .51156 L .45646 .50644 L F
.45648 .5061 m .45646 .50644 L .45879 .50112 L F
.45475 .48123 m .44496 .52861 L .45472 .48204 L 0 0 .096 r
F
.4615 .49494 m .45646 .50644 L .46141 .49571 L 0 0 .103 r
F
.45646 .50644 m .4459 .53051 L .45643 .5069 L F
.45646 .50644 m .45643 .5069 L .46141 .49571 L F
.45618 .51034 m .47511 .55047 L .45638 .50755 L .951 .6 .244 r
F
.45858 .50335 m .4459 .53051 L .44676 .5324 L 0 0 .103 r
F
.45874 .50171 m .4459 .53051 L .45858 .50335 L F
.45659 .50463 m .4459 .53051 L .45658 .50471 L F
.45452 .5075 m .45614 .51089 L .45455 .50688 L .951 .6 .244 r
F
.45614 .51089 m .47511 .55047 L .45618 .51034 L F
.45614 .51089 m .45618 .51034 L .45455 .50688 L F
.45499 .49792 m .44534 .52918 L .45498 .49795 L 0 0 .098 r
F
.45482 .50121 m .44534 .52918 L .4459 .53051 L F
.45486 .5005 m .44534 .52918 L .45482 .50121 L F
.45267 .49341 m .44615 .52298 L .44534 .52918 L 0 0 .096 r
F
.45735 .46933 m .46025 .48018 L .45737 .46896 L .974 .692 .29 r
F
.46025 .48018 m .46029 .47979 L .45738 .46882 L F
.4574 .46838 m .45475 .48123 L .45734 .46954 L 0 0 .096 r
F
.4574 .46852 m .46029 .47979 L .46036 .47895 L .974 .692 .29 r
F
.4574 .46837 m .45475 .48122 L .4574 .46838 L 0 0 .096 r
F
.45475 .48122 m .45271 .4911 L .45475 .48122 L F
.45475 .48122 m .45475 .48122 L .4574 .46838 L F
.45499 .49792 m .46016 .48117 L .46016 .48115 L 0 0 .098 r
F
.46036 .47895 m .46245 .48696 L .46251 .48649 L .974 .692 .29 r
F
.46036 .47895 m .46251 .48649 L .46416 .46678 L F
.46391 .46887 m .45732 .49029 L .46389 .46904 L 0 0 .098 r
F
.45732 .49029 m .44534 .52918 L .45731 .49037 L F
.45732 .49029 m .45731 .49037 L .46389 .46904 L F
.45895 .49951 m .4591 .49795 L .45717 .49249 L .966 .648 .269 r
F
.45731 .49037 m .45499 .49792 L .45731 .49037 L 0 0 .098 r
F
.46251 .48649 m .46617 .47783 L .46416 .46678 L .974 .692 .29 r
F
.46985 .44727 m .47133 .46441 L .47001 .44628 L .985 .793 .393 r
F
.47001 .44628 m .47152 .46347 L .47876 .41844 L F
.47152 .46347 m .47847 .4472 L .47876 .41844 L F
.45499 .49792 m .45499 .49792 L .51863 .29165 L 0 0 .098 r
F
.45708 .49375 m .4546 .48523 L .45457 .48603 L .966 .648 .269 r
F
.45895 .49951 m .4571 .49344 L .45708 .49375 L F
.4571 .49344 m .4546 .48523 L .45708 .49375 L F
.51799 .29366 m .45731 .49037 L .51863 .29165 L 0 0 .098 r
F
.45731 .49037 m .45731 .49037 L .51863 .29165 L F
.45499 .49792 m .44534 .52918 L .45499 .49792 L F
.45618 .51034 m .45638 .50755 L .4547 .50371 L .951 .6 .244 r
F
.45462 .50537 m .4547 .50371 L .45256 .49881 L F
.45618 .51034 m .4547 .50371 L .45462 .50537 L F
.4571 .49344 m .45717 .49249 L .4546 .48523 L .966 .648 .269 r
F
.45895 .49951 m .45717 .49249 L .4571 .49344 L F
.45463 .48446 m .45717 .49249 L .45725 .49126 L F
.45271 .4911 m .45271 .49111 L .4574 .46838 L 0 0 .096 r
F
.46752 .41783 m .46985 .44727 L .47001 .44628 L .985 .793 .393 r
F
.4674 .41888 m .46985 .44727 L .46752 .41783 L F
.47001 .44628 m .47876 .41844 L .47933 .36118 L F
.4574 .46838 m .4574 .46838 L .50202 .25232 L 0 0 .096 r
F
.45271 .4911 m .4574 .46838 L .4574 .46838 L F
.45731 .49038 m .45731 .49039 L .46016 .48115 L 0 0 .098 r
F
.45731 .49038 m .46016 .48115 L .46017 .48114 L F
.46017 .48113 m .45731 .49038 L .46017 .48114 L F
.45726 .47102 m .46008 .48209 L .45793 .47327 L .974 .692 .29 r
F
.45466 .48367 m .45269 .49203 L .45267 .49341 L 0 0 .096 r
F
.45726 .47097 m .45469 .48282 L .45466 .48367 L F
.45469 .48282 m .45269 .49203 L .45466 .48367 L F
.4573 .47022 m .4547 .48252 L .45726 .47097 L F
.4547 .48252 m .45269 .49203 L .45469 .48282 L F
.4547 .48252 m .45469 .48282 L .45726 .47097 L F
.45704 .49433 m .45708 .49375 L .45457 .48603 L .966 .648 .269 r
F
.45738 .46882 m .46029 .47979 L .4574 .46852 L .974 .692 .29 r
F
.46025 .48018 m .45738 .46882 L .45737 .46896 L F
.45734 .46954 m .44496 .52861 L .4573 .47022 L 0 0 .096 r
F
.45475 .48123 m .45472 .48204 L .45734 .46954 L F
.46008 .48209 m .46025 .48018 L .45298 .45299 L .974 .692 .29 r
F
.46103 .45194 m .45734 .46954 L .46095 .45296 L 0 0 .096 r
F
.45734 .46954 m .4573 .47022 L .46095 .45296 L F
.45298 .45629 m .45726 .47097 L .45298 .45299 L .974 .692 .29 r
F
.45726 .47097 m .45793 .47327 L .45728 .47061 L F
.45726 .47097 m .45728 .47061 L .45298 .45299 L F
.45456 .4864 m .45457 .48603 L .45106 .47522 L .966 .648 .269 r
F
.45704 .49433 m .45457 .48603 L .45456 .4864 L F
.45112 .47828 m .45452 .48749 L .45106 .47522 L F
.45452 .48749 m .45704 .49433 L .45456 .4864 L F
.45452 .48749 m .45456 .4864 L .45106 .47522 L F
.45298 .45667 m .45721 .47182 L .45726 .47102 L .974 .692 .29 r
F
.45721 .47182 m .46008 .48209 L .45726 .47102 L F
.45106 .47522 m .4546 .48523 L .45463 .48446 L .966 .648 .269 r
F
.4546 .48523 m .45717 .49249 L .45463 .48446 L F
.45597 .46352 m .45738 .46882 L .4574 .46852 L .974 .692 .29 r
F
.50121 .25622 m .4574 .46837 L .50202 .25232 L 0 0 .096 r
F
.4574 .46837 m .4574 .46838 L .50202 .25232 L F
.45271 .4911 m .44496 .52861 L .45271 .49111 L F
.45269 .49203 m .44615 .52298 L .45267 .49341 L F
.45254 .50012 m .45256 .49881 L .44987 .49264 L .951 .6 .244 r
F
.45618 .51034 m .45256 .49881 L .45254 .50012 L F
.45737 .46896 m .45738 .46882 L .45597 .46352 L .974 .692 .29 r
F
.46095 .45296 m .4573 .47022 L .45726 .47097 L 0 0 .096 r
F
.45004 .49734 m .45249 .50252 L .44987 .49264 L .951 .6 .244 r
F
.45249 .50252 m .45618 .51034 L .45254 .50012 L F
.45249 .50252 m .45254 .50012 L .44987 .49264 L F
.47233 .47597 m .47744 .53499 L .47254 .47509 L .985 .793 .393 r
F
.58207 .27354 m .4571 .51703 L .60612 .28752 L 0 0 .105 r
F
.4571 .51703 m .45506 .521 L .45733 .51749 L F
.4571 .51703 m .45733 .51749 L .60612 .28752 L F
.45506 .521 m .45592 .52234 L .60612 .28752 L F
.4571 .51703 m .44676 .5324 L .44809 .53459 L F
.45737 .51418 m .44676 .5324 L .4571 .51703 L F
.44795 .50057 m .44471 .52898 L .44496 .52861 L 0 0 .132 r
F
.44615 .52298 m .44496 .52861 L .44498 .52865 L 0 0 .096 r
F
.44615 .52298 m .44498 .52865 L .44534 .52918 L F
.43839 .52048 m .45171 .54221 L .45169 .53592 L .865 .418 .11 r
F
.28673 .34437 m .40213 .48276 L .43839 .52048 L F
.40213 .48276 m .45171 .54221 L .43839 .52048 L F
.60612 .28752 m .45353 .53134 L .62859 .30401 L 0 0 .099 r
F
.45353 .53134 m .45392 .53183 L .62859 .30401 L F
.46235 .54257 m .47158 .55902 L .47305 .5562 L .901 .487 .167 r
F
.46235 .54257 m .47305 .5562 L .4737 .55495 L F
.45373 .52741 m .4542 .52825 L .45422 .52809 L F
.45171 .54221 m .45171 .54221 L .45169 .53592 L .865 .418 .11 r
F
.45171 .54221 m .46847 .56231 L .45184 .53616 L F
.45171 .54221 m .45184 .53616 L .45169 .53592 L F
.45341 .5384 m .45187 .53451 L .45316 .53872 L 0 0 .083 r
F
.46603 .51639 m .47606 .54592 L .47652 .54283 L .966 .648 .269 r
F
.46603 .51639 m .47652 .54283 L .4767 .54165 L F
.62859 .30401 m .45392 .53183 L .45341 .5384 L 0 0 .083 r
F
.28673 .34437 m .45184 .5361 L .30594 .32359 L .865 .418 .11 r
F
.45187 .53451 m .45181 .53786 L .45316 .53872 L 0 0 .083 r
F
.45166 .52901 m .45167 .53155 L .4536 .5299 L 0 0 .099 r
F
.45184 .5361 m .45377 .53371 L .30594 .32359 L .865 .418 .11 r
F
.45169 .53592 m .45184 .53616 L .45184 .5361 L F
.45382 .52564 m .45166 .52901 L .4536 .5299 L 0 0 .099 r
F
.45382 .52564 m .4536 .5299 L .45538 .52839 L F
.30594 .32359 m .45344 .53323 L .45373 .52741 L .901 .487 .167 r
F
.30594 .32359 m .45373 .52741 L .32696 .30497 L F
.45373 .52741 m .45574 .52436 L .32696 .30497 L F
.60612 .28752 m .45592 .52234 L .45538 .52839 L 0 0 .099 r
F
.45743 .51358 m .45441 .51927 L .45737 .51418 L 0 0 .105 r
F
.32696 .30497 m .45493 .52299 L .45529 .51761 L .93 .547 .211 r
F
.32696 .30497 m .45529 .51761 L .34963 .28869 L F
.45615 .42293 m .45298 .45237 L .45298 .45299 L 0 0 .132 r
F
.39918 .26385 m .45597 .46352 L .42561 .25554 L .974 .692 .29 r
F
.45597 .46352 m .45637 .46167 L .42561 .25554 L F
.45637 .46167 m .45615 .42293 L .45385 .44475 L F
.45614 .42368 m .45298 .45336 L .46116 .45016 L 0 0 .132 r
F
.45298 .45336 m .4574 .46837 L .46116 .45016 L F
.4562 .42049 m .46115 .45032 L .46132 .4481 L .975 .735 .315 r
F
.45615 .42293 m .46115 .45032 L .4562 .42049 L F
.46223 .36647 m .46074 .37957 L .44795 .50057 L 0 0 .132 r
F
.46252 .36089 m .4674 .41888 L .46752 .41783 L .985 .793 .393 r
F
.46247 .36189 m .4674 .41888 L .46252 .36089 L F
.4528 .25009 m .46752 .41783 L .48046 .24758 L F
.46643 .32706 m .4623 .36513 L .46223 .36647 L 0 0 .132 r
F
.4623 .36513 m .46074 .37957 L .46223 .36647 L F
.4528 .25009 m .46247 .36189 L .46252 .36089 L .985 .793 .393 r
F
.45529 .51761 m .45743 .51358 L .34963 .28869 L .93 .547 .211 r
F
.46001 .50715 m .45761 .51173 L .45963 .5103 L 0 0 .105 r
F
.45761 .51173 m .45737 .51418 L .45963 .5103 L F
.50209 .42655 m .45761 .51164 L .51012 .41161 L F
.45761 .51164 m .45761 .51173 L .51012 .41161 L F
.50209 .42655 m .51012 .41161 L .56137 .31387 L F
.4547 .50371 m .45638 .50755 L .45476 .50259 L .951 .6 .244 r
F
.45638 .50755 m .45645 .50657 L .45476 .50259 L F
.34963 .28869 m .45648 .5061 L .37377 .27494 L F
.45648 .5061 m .45886 .50037 L .37377 .27494 L F
.46911 .48979 m .46001 .50715 L .46747 .49683 L 0 0 .105 r
F
.46001 .50715 m .45963 .5103 L .46747 .49683 L F
.47152 .46347 m .47233 .47597 L .47254 .47509 L .985 .793 .393 r
F
.47133 .46441 m .47233 .47597 L .47152 .46347 L F
.55668 .26221 m .45627 .50902 L .58207 .27354 L 0 0 .103 r
F
.45627 .50902 m .45761 .51164 L .58207 .27354 L F
.46501 .52612 m .47511 .55047 L .47579 .54722 L .951 .6 .244 r
F
.46501 .52612 m .47579 .54722 L .47606 .54592 L F
.46747 .49683 m .45737 .51418 L .4571 .51703 L 0 0 .105 r
F
.45901 .49886 m .45879 .50112 L .4615 .49494 L 0 0 .103 r
F
.45697 .49534 m .45886 .50037 L .45704 .49433 L .966 .648 .269 r
F
.45886 .50037 m .45895 .49951 L .45704 .49433 L F
.45457 .48603 m .4546 .48523 L .45106 .47522 L F
.4574 .46838 m .45734 .46954 L .46674 .42467 L 0 0 .096 r
F
.45404 .45696 m .45735 .46933 L .45597 .46352 L .974 .692 .29 r
F
.45735 .46933 m .45737 .46896 L .45597 .46352 L F
.46017 .48114 m .46016 .48115 L .51532 .3025 L 0 0 .098 r
F
.46956 .47338 m .46185 .49199 L .4684 .4792 L 0 0 .103 r
F
.46185 .49199 m .4615 .49494 L .4684 .4792 L F
.51062 .31758 m .46017 .48113 L .51532 .3025 L 0 0 .098 r
F
.46017 .48113 m .46017 .48114 L .51532 .3025 L F
.46016 .48115 m .46016 .48117 L .51532 .3025 L F
.45298 .45667 m .45793 .47327 L .45298 .45629 L .974 .692 .29 r
F
.50293 .24791 m .45726 .47097 L .5302 .25363 L 0 0 .096 r
F
.45726 .47097 m .46018 .481 L .5302 .25363 L F
.46008 .48209 m .46215 .48951 L .46098 .48376 L .974 .692 .29 r
F
.46476 .48752 m .4615 .49494 L .46461 .48853 L 0 0 .103 r
F
.4615 .49494 m .46141 .49571 L .46461 .48853 L F
.45115 .47995 m .45697 .49534 L .45112 .47828 L .966 .648 .269 r
F
.45697 .49534 m .45704 .49433 L .45112 .47828 L F
.45008 .49824 m .45452 .5075 L .45004 .49734 L .951 .6 .244 r
F
.45452 .5075 m .45455 .50688 L .45004 .49734 L F
.47516 .2451 m .46825 .30951 L .46643 .32706 L 0 0 .132 r
F
.46825 .30951 m .46074 .37957 L .46643 .32706 L F
.37377 .27494 m .45106 .47522 L .39918 .26385 L .966 .648 .269 r
F
.45106 .47522 m .45725 .49126 L .45167 .46938 L F
.45106 .47522 m .45167 .46938 L .39918 .26385 L F
.38536 .36323 m .45008 .49824 L .39889 .38893 L .951 .6 .244 r
F
.45008 .49824 m .45004 .49734 L .39889 .38893 L F
.4106 .37252 m .45115 .47995 L .42717 .4133 L .966 .648 .269 r
F
.45115 .47995 m .45112 .47828 L .42717 .4133 L F
.45731 .49041 m .45717 .4924 L .46345 .47288 L 0 0 .098 r
F
.45725 .49126 m .46008 .48209 L .39918 .26385 L .966 .648 .269 r
F
.46389 .46911 m .46016 .48117 L .46345 .47288 L 0 0 .098 r
F
.46016 .48117 m .46003 .48265 L .46345 .47288 L F
.45704 .49433 m .45895 .49951 L .45708 .49375 L .966 .648 .269 r
F
.45902 .49879 m .45901 .49886 L .46533 .48358 L 0 0 .103 r
F
.46536 .48338 m .45902 .49874 L .46533 .48358 L F
.45902 .49874 m .45902 .49879 L .46533 .48358 L F
.5302 .25363 m .45707 .49383 L .55668 .26221 L 0 0 .098 r
F
.45707 .49383 m .45902 .49874 L .55668 .26221 L F
.46461 .48853 m .45874 .50171 L .45858 .50335 L 0 0 .103 r
F
.45476 .50259 m .45645 .50657 L .45648 .5061 L .951 .6 .244 r
F
.44987 .49264 m .4547 .50371 L .45476 .50259 L F
.46345 .47288 m .45717 .4924 L .45707 .49383 L 0 0 .098 r
F
.42717 .4133 m .45112 .47828 L .45106 .47522 L .966 .648 .269 r
F
.39889 .38893 m .45004 .49734 L .44987 .49264 L .951 .6 .244 r
F
.34963 .28869 m .38536 .36323 L .39889 .38893 L F
.37377 .27494 m .4106 .37252 L .42717 .4133 L .966 .648 .269 r
F
.45597 .46352 m .4574 .46852 L .45637 .46167 L .974 .692 .29 r
F
.39918 .26385 m .45298 .45667 L .45298 .45299 L F
.46074 .37957 m .45617 .42214 L .45615 .42293 L 0 0 .132 r
F
.42561 .25554 m .45615 .42293 L .4562 .42049 L .975 .735 .315 r
F
.45385 .44475 m .45615 .42293 L .42561 .25554 L .974 .692 .29 r
F
.4574 .46852 m .46115 .45032 L .46009 .44451 L F
.4574 .46852 m .46009 .44451 L .45637 .46167 L F
.46752 .41783 m .47933 .36118 L .48046 .24758 L .985 .793 .393 r
F
.47516 .2451 m .45614 .42368 L .50152 .25319 L 0 0 .132 r
F
.50267 .24788 m .50152 .25319 L .50293 .24791 L F
.47516 .2451 m .50152 .25319 L .50267 .24788 L F
.45614 .42368 m .46116 .45016 L .50293 .24791 L F
.51532 .3025 m .46389 .46911 L .46345 .47288 L 0 0 .098 r
F
.52362 .34228 m .46536 .48338 L .53264 .32099 L 0 0 .103 r
F
.46536 .48338 m .46533 .48358 L .53264 .32099 L F
.52362 .34228 m .53264 .32099 L .53979 .30372 L F
.51863 .29165 m .51062 .31758 L .51532 .3025 L 0 0 .098 r
F
.4684 .4792 m .46476 .48752 L .46461 .48853 L 0 0 .103 r
F
.46908 .45208 m .46391 .46887 L .46904 .45235 L 0 0 .098 r
F
.46391 .46887 m .46389 .46904 L .46904 .45235 L F
.46674 .42467 m .46103 .45194 L .46095 .45296 L 0 0 .096 r
F
.50202 .25232 m .46712 .42134 L .46674 .42467 L F
.51092 .31622 m .46908 .45208 L .51799 .29366 L 0 0 .098 r
F
.46908 .45208 m .46904 .45235 L .51799 .29366 L F
.51092 .31622 m .51799 .29366 L .51937 .28919 L F
.51937 .28919 m .51799 .29366 L .51863 .29165 L F
.53896 .30576 m .46956 .47338 L .4684 .4792 L 0 0 .103 r
F
.53979 .30372 m .53845 .30694 L .53896 .30576 L F
.53845 .30694 m .46956 .47338 L .53896 .30576 L F
.56137 .31387 m .46911 .48979 L .46747 .49683 L 0 0 .105 r
F
.58207 .27354 m .55395 .32735 L .56137 .31387 L F
.55668 .26221 m .53237 .32108 L .53979 .30372 L 0 0 .103 r
F
.5302 .25363 m .51311 .30911 L .51937 .28919 L 0 0 .098 r
F
.50293 .24791 m .50121 .25622 L .50202 .25232 L 0 0 .096 r
F
.25 g
.5 Mabswid
.47762 .53297 m
.47789 .50564 L
s
1 0 0 r
.003 w
.47744 .53499 m
.47762 .53297 L
s
.25 g
.5 Mabswid
.4528 .25009 m
.4532 .25471 L
s
.4532 .25471 m
.45322 .25495 L
s
.47521 .50923 m
.47744 .53499 L
s
1 0 0 r
.003 w
.47714 .53793 m
.47744 .53499 L
s
.25 g
.5 Mabswid
.46116 .45016 m
.46712 .42131 L
s
.50121 .25622 m
.50293 .24791 L
s
.47652 .53453 m
.47714 .53793 L
s
.42561 .25554 m
.42574 .25625 L
s
.42574 .25625 m
.42618 .25866 L
s
.42618 .25866 m
.42637 .2597 L
s
.46009 .44451 m
.46115 .45032 L
s
.47255 .51279 m
.47652 .53453 L
s
1 0 0 r
.003 w
.4767 .54165 m
.47714 .53793 L
s
.25 g
.5 Mabswid
.46391 .46887 m
.46908 .45208 L
s
.46018 .481 m
.46391 .46887 L
s
.47608 .53946 m
.4767 .54165 L
s
.47531 .53667 m
.47608 .53946 L
s
.45298 .45667 m
.45721 .47182 L
s
.45721 .47182 m
.46008 .48209 L
s
.46971 .51659 m
.47531 .53667 L
s
.39918 .26385 m
.39933 .26437 L
s
.39933 .26437 m
.39995 .26662 L
s
.39995 .26662 m
.40023 .2676 L
s
1 0 0 r
.003 w
.47606 .54592 m
.4767 .54165 L
s
.25 g
.5 Mabswid
.46536 .48338 m
.46962 .47308 L
s
.45902 .49874 m
.46536 .48338 L
s
.47533 .54401 m
.47606 .54592 L
s
.47366 .53957 m
.47533 .54401 L
s
.45115 .47995 m
.45697 .49534 L
s
.45697 .49534 m
.45886 .50037 L
s
.46657 .52079 m
.47366 .53957 L
s
.37377 .27494 m
.37472 .27744 L
s
.37472 .27744 m
.37507 .27837 L
s
1 0 0 r
.003 w
.47511 .55047 m
.47606 .54592 L
s
.25 g
.5 Mabswid
.58103 .27554 m
.58207 .27354 L
s
.34963 .28869 m
.35114 .29185 L
s
.45614 .51089 m
.45743 .51358 L
s
.46311 .52542 m
.47511 .55047 L
s
1 0 0 r
.003 w
.4737 .55495 m
.47511 .55047 L
s
.21976 .47228 m .43936 .56236 L .22927 .44437 L .354 0 0 r
F
.21976 .47228 m .42636 .55851 L .43936 .56236 L F
.21205 .50081 m .42636 .55851 L .21976 .47228 L 0 .446 .742 r
F
.22927 .44437 m .44982 .56465 L .24068 .41735 L .533 0 0 r
F
.22927 .44437 m .43936 .56236 L .44982 .56465 L F
0 g
.006 w
.21976 .47228 m
.22927 .44437 L
s
.25 g
.5 Mabswid
.22927 .44437 m
.23129 .4455 L
s
.21341 .50117 m .41069 .5533 L .42636 .55851 L 0 .446 .742 r
F
.21308 .50108 m .21353 .5012 L .21341 .50117 L F
.21353 .5012 m .41069 .5533 L .21341 .50117 L F
.21389 .50129 m .41069 .5533 L .21308 .50108 L F
.21205 .50081 m .21389 .50129 L .21308 .50108 L F
.20602 .52966 m .41069 .5533 L .21205 .50081 L .106 .618 .892 r
F
.20728 .5298 m .39238 .54702 L .41069 .5533 L F
.20602 .52966 m .20771 .52981 L .20728 .5298 L F
.20771 .52981 m .39238 .54702 L .20728 .5298 L F
.2015 .55855 m .20238 .55849 L .20602 .52966 L .309 .73 .974 r
F
.20238 .55849 m .39135 .54708 L .20771 .52981 L F
.20238 .55849 m .20771 .52981 L .20602 .52966 L F
.39135 .54708 m .3904 .54684 L .20602 .52966 L F
.39135 .54708 m .39238 .54702 L .3904 .54684 L F
.20265 .55848 m .37161 .54007 L .39238 .54702 L F
.2015 .55855 m .20301 .55838 L .20265 .55848 L F
.20301 .55838 m .37161 .54007 L .20265 .55848 L F
.19832 .5872 m .19909 .58699 L .2015 .55855 L .459 .785 .999 r
F
.19909 .58699 m .37035 .54041 L .20301 .55838 L F
.19909 .58699 m .20301 .55838 L .2015 .55855 L F
.37035 .54041 m .36978 .54027 L .2015 .55855 L F
.37035 .54041 m .37161 .54007 L .36978 .54027 L F
.19933 .58693 m .34873 .53289 L .37161 .54007 L F
.19832 .5872 m .19962 .58673 L .19933 .58693 L F
.19962 .58673 m .34873 .53289 L .19933 .58693 L F
.19626 .61536 m .19693 .615 L .19832 .5872 L .559 .803 .99 r
F
.19693 .615 m .34762 .5335 L .19962 .58673 L F
.19693 .615 m .19962 .58673 L .19832 .5872 L F
.34762 .5335 m .3471 .53348 L .19832 .5872 L F
.34762 .5335 m .34873 .53289 L .3471 .53348 L F
.19713 .61489 m .32421 .52594 L .34873 .53289 L F
.19626 .61536 m .19735 .6146 L .19713 .61489 L F
.19735 .6146 m .32421 .52594 L .19713 .61489 L F
.19512 .64275 m .19567 .64225 L .19626 .61536 L .623 .799 .966 r
F
.19567 .64225 m .32327 .5268 L .19735 .6146 L F
.19567 .64225 m .19735 .6146 L .19626 .61536 L F
.32327 .5268 m .32282 .52692 L .19626 .61536 L F
.32327 .5268 m .32421 .52594 L .32282 .52692 L F
.19583 .6421 m .29863 .51965 L .32421 .52594 L F
.19512 .64275 m .19598 .64172 L .19583 .6421 L F
.19598 .64172 m .29863 .51965 L .19583 .6421 L F
.19467 .66913 m .19511 .6685 L .19512 .64275 L .664 .785 .938 r
F
.19511 .6685 m .29788 .52073 L .19598 .64173 L F
.19511 .6685 m .19598 .64173 L .19512 .64275 L F
.29788 .52073 m .29751 .52098 L .19512 .64275 L F
.29788 .52073 m .29863 .51965 L .29751 .52098 L F
.19523 .66833 m .27263 .51435 L .29863 .51965 L F
.19467 .66913 m .19531 .66787 L .19523 .66833 L F
.19531 .66787 m .27263 .51435 L .19523 .66833 L F
.19469 .69427 m .19501 .69353 L .19467 .66913 L .69 .766 .91 r
F
.19501 .69353 m .27207 .51564 L .19531 .66787 L F
.19501 .69353 m .19531 .66787 L .19467 .66913 L F
.27207 .51564 m .2718 .516 L .19467 .66913 L F
.27207 .51564 m .27263 .51435 L .2718 .516 L F
.1951 .69333 m .24686 .51028 L .27263 .51435 L F
.19469 .69427 m .19511 .6928 L .1951 .69333 L F
.19511 .6928 m .24686 .51028 L .1951 .69333 L F
.19496 .71794 m .19517 .7171 L .19469 .69427 L .706 .746 .883 r
F
.19517 .7171 m .2465 .51173 L .19511 .6928 L F
.19517 .7171 m .19511 .6928 L .19469 .69427 L F
.2465 .51173 m .24632 .5122 L .19469 .69427 L F
.2465 .51173 m .24686 .51028 L .24632 .5122 L F
.19496 .71794 m .22195 .50754 L .24686 .51028 L F
.19526 .73993 m .22177 .50911 L .19496 .71794 L .716 .726 .858 r
F
.22177 .50911 m .22168 .50967 L .19496 .71794 L F
.22177 .50911 m .22195 .50754 L .22168 .50967 L F
.19526 .73993 m .19845 .50608 L .22195 .50754 L F
.1954 .76004 m .19843 .50775 L .19526 .73993 L .721 .705 .835 r
F
.19843 .50775 m .19845 .50608 L .19842 .50837 L F
.19843 .50775 m .19842 .50837 L .19526 .73993 L F
.25 g
.21205 .50081 m
.21389 .50129 L
s
.23129 .4455 m
.23131 .44551 L
s
.21976 .47228 m
.22171 .4731 L
s
0 g
.006 w
.21205 .50081 m
.21976 .47228 L
s
.21079 .50685 m
.21164 .50278 L
s
.21164 .50278 m
.21205 .50081 L
s
.24068 .41735 m .45794 .56535 L .25405 .3915 L .662 .107 0 r
F
.24068 .41735 m .44982 .56465 L .45794 .56535 L F
.25 g
.5 Mabswid
.45761 .51164 m
.46917 .48953 L
s
.45008 .49824 m
.45614 .51089 L
s
0 g
.006 w
.22927 .44437 m
.24068 .41735 L
s
.25 g
.5 Mabswid
.21389 .50129 m
.24944 .51069 L
s
.24068 .41735 m
.24274 .4188 L
s
.60483 .28955 m
.60612 .28752 L
s
.25405 .3915 m .46405 .56451 L .26941 .36709 L .752 .235 0 r
F
.25405 .3915 m .45794 .56535 L .46405 .56451 L F
0 g
.006 w
.24068 .41735 m
.25405 .3915 L
s
.25 g
.5 Mabswid
.45592 .52234 m
.46792 .50358 L
s
.25405 .3915 m
.25614 .39327 L
s
.73369 .50209 m .55409 .52852 L .73704 .53151 L 0 0 0 r
F
.55409 .52852 m .55376 .52857 L .55426 .52857 L F
.55409 .52852 m .55426 .52857 L .73704 .53151 L F
.55379 .52857 m .55475 .52874 L .73704 .53151 L F
.55376 .52857 m .5538 .52857 L .55379 .52857 L F
.5538 .52857 m .55475 .52874 L .55379 .52857 L F
.60297 .52398 m .57664 .5259 L .60224 .52378 L .313 .769 .952 r
F
.55376 .52857 m .55278 .52871 L .55475 .52874 L 0 0 0 r
F
.73704 .53151 m .55278 .52871 L .57664 .5259 L .208 .73 .852 r
F
.73704 .53151 m .5778 .52594 L .73851 .56111 L F
.5778 .52594 m .57664 .5259 L .57837 .52628 L F
.5778 .52594 m .57837 .52628 L .73851 .56111 L F
.73789 .56094 m .57837 .52628 L .60297 .52398 L .313 .769 .952 r
F
.57837 .52628 m .57664 .5259 L .60297 .52398 L F
.73705 .56079 m .57664 .5259 L .73789 .56094 L F
.73851 .56111 m .73705 .56079 L .73789 .56094 L F
.73851 .56111 m .60323 .52405 L .73828 .59062 L F
.60323 .52405 m .60335 .52417 L .73828 .59062 L F
.60305 .52402 m .60368 .52449 L .73828 .59062 L F
.60297 .52398 m .60308 .52406 L .60305 .52402 L F
.60308 .52406 m .60368 .52449 L .60305 .52402 L F
.73761 .5902 m .60368 .52449 L .62897 .52269 L .399 .772 .993 r
F
.60323 .52405 m .60297 .52398 L .60335 .52417 L .313 .769 .952 r
F
.60297 .52398 m .60224 .52378 L .60368 .52449 L F
.60368 .52449 m .60224 .52378 L .62897 .52269 L .399 .772 .993 r
F
.73705 .59001 m .60224 .52378 L .73761 .5902 L F
.73828 .59062 m .73705 .59001 L .73761 .5902 L F
.73828 .59062 m .62975 .52318 L .73658 .6198 L F
.62975 .52318 m .62897 .52269 L .6301 .52372 L F
.62975 .52318 m .6301 .52372 L .73658 .6198 L F
.7362 .61934 m .62897 .52269 L .7362 .61934 L .462 .753 .993 r
F
.73559 .61891 m .62897 .52269 L .7362 .61934 L F
.73607 .61919 m .62897 .52269 L .65612 .52289 L F
.73595 .61912 m .62897 .52269 L .73607 .61919 L F
.73592 .6192 m .73559 .61891 L .7362 .61934 L F
.7362 .61934 m .73595 .61912 L .73607 .61919 L F
.73658 .6198 m .73592 .6192 L .7362 .61934 L F
.73658 .6198 m .65668 .52358 L .73362 .64841 L F
.65668 .52358 m .65675 .52375 L .73362 .64841 L F
.65664 .52358 m .65689 .52415 L .73362 .64841 L F
.65652 .52338 m .65669 .52374 L .65664 .52358 L F
.65669 .52374 m .65689 .52415 L .65664 .52358 L F
.7333 .64762 m .65689 .52415 L .68297 .52453 L .507 .728 .972 r
F
.7329 .64724 m .65612 .52289 L .7333 .64762 L F
.73362 .64841 m .7329 .64724 L .7333 .64762 L F
.73362 .64841 m .68332 .52539 L .72968 .67623 L F
.68332 .52539 m .68297 .52453 L .68345 .52609 L F
.68332 .52539 m .68345 .52609 L .72968 .67623 L F
.72956 .67547 m .68345 .52609 L .72958 .67549 L .54 .702 .944 r
F
.68345 .52609 m .68297 .52453 L .68345 .52609 L F
.68345 .52609 m .68345 .52609 L .72958 .67549 L F
.72924 .67481 m .68297 .52453 L .72956 .67547 L F
.72955 .67526 m .68297 .52453 L .70885 .52764 L F
.72947 .67514 m .68297 .52453 L .72955 .67526 L F
.72938 .67525 m .72924 .67481 L .72956 .67547 L F
.72958 .67549 m .72947 .67514 L .72955 .67526 L F
.72968 .67623 m .72938 .67525 L .72958 .67549 L F
.72968 .67623 m .70899 .52866 L .72501 .70304 L F
.70899 .52866 m .709 .5289 L .72501 .70304 L F
.70894 .52833 m .70899 .52924 L .72501 .70304 L F
.72507 .7019 m .709 .52924 L .73315 .5321 L .566 .679 .915 r
F
.72486 .70135 m .70885 .52764 L .72507 .7019 L F
.72501 .70304 m .72486 .70135 L .72507 .7019 L F
.72501 .70304 m .73315 .5321 L .71989 .72866 L F
.72006 .72759 m .73315 .5321 L .72008 .72764 L .587 .659 .887 r
F
.71998 .72732 m .72001 .72676 L .72006 .72759 L F
.72001 .72676 m .73315 .5321 L .72006 .72759 L F
.72013 .72734 m .73315 .5321 L .7554 .53772 L F
.72008 .72764 m .72011 .7272 L .72013 .72734 L F
.72011 .7272 m .73315 .5321 L .72013 .72734 L F
.71989 .72866 m .71998 .72732 L .72008 .72764 L F
.71989 .72866 m .7554 .53772 L .71457 .75289 L F
.715 .75141 m .7554 .53772 L .77523 .54417 L .605 .643 .862 r
F
.71457 .75289 m .71498 .75071 L .715 .75141 L F
.71498 .75071 m .7554 .53772 L .715 .75141 L F
.70899 .52866 m .70894 .52833 L .709 .5289 L .54 .702 .944 r
F
.70894 .52833 m .70885 .52764 L .70899 .52924 L F
.709 .52924 m .70885 .52764 L .73315 .5321 L .566 .679 .915 r
F
.65668 .52358 m .65652 .52338 L .65675 .52375 L .462 .753 .993 r
F
.65652 .52338 m .65612 .52289 L .65689 .52415 L F
.65689 .52415 m .65612 .52289 L .68297 .52453 L .507 .728 .972 r
F
.73369 .50209 m .53118 .53183 L .55278 .52871 L 0 0 0 r
F
.72829 .4731 m .53118 .53183 L .73369 .50209 L F
0 g
.006 w
.73369 .50209 m
.73704 .53151 L
s
.73704 .53151 m
.73712 .53311 L
s
.25 g
.5 Mabswid
.32696 .30497 m
.3286 .30776 L
s
1 0 0 r
.003 w
.47158 .55902 m
.4737 .55495 L
s
.72829 .4731 m .5122 .53487 L .53118 .53183 L 0 0 0 r
F
.72073 .4448 m .5122 .53487 L .72829 .4731 L .054 0 0 r
F
.25 g
.5 Mabswid
.73186 .50236 m
.73369 .50209 L
s
0 g
.006 w
.72829 .4731 m
.73369 .50209 L
s
.26941 .36709 m .46847 .56231 L .28673 .34437 L .817 .336 .035 r
F
.25 g
.5 Mabswid
.3286 .30776 m
.32866 .30787 L
s
.46247 .36189 m
.46254 .36274 L
s
.26941 .36709 m .46405 .56451 L .46847 .56231 L .817 .336 .035 r
F
.25 g
.37507 .27837 m
.4106 .37252 L
s
.46074 .37957 m
.46232 .36483 L
s
.40023 .2676 m
.43567 .39462 L
s
.45617 .42214 m
.46074 .37957 L
s
.43567 .39462 m
.45298 .45667 L
s
.35114 .29185 m
.45008 .49824 L
s
.4106 .37252 m
.45115 .47995 L
s
.4387 .56198 m
.43936 .56236 L
s
.43774 .56144 m
.4387 .56198 L
s
.43733 .56122 m
.43774 .56144 L
s
.43726 .56117 m
.43733 .56122 L
s
.23131 .44551 m
.43726 .56117 L
s
.42424 .55763 m
.42428 .55764 L
s
.22171 .4731 m
.42424 .55763 L
s
.42594 .55833 m
.42636 .55851 L
s
.42481 .55786 m
.42594 .55833 L
s
.42428 .55764 m
.42481 .55786 L
s
.44777 .56322 m
.44789 .5633 L
s
.29558 .45602 m
.44777 .56322 L
s
.24274 .4188 m
.29558 .45602 L
s
.31836 .44633 m
.45003 .55861 L
s
.25614 .39327 m
.31836 .44633 L
s
.45616 .56383 m
.45794 .56535 L
s
.45003 .55861 m
.45616 .56383 L
s
0 g
.006 w
.25405 .3915 m
.26941 .36709 L
s
.25 g
.5 Mabswid
.32866 .30787 m
.44952 .51377 L
s
.44952 .51377 m
.4526 .51901 L
s
.4526 .51901 m
.45574 .52436 L
s
.45933 .53047 m
.4737 .55495 L
s
.37127 .4704 m
.45046 .55073 L
s
.26941 .36709 m
.27082 .36852 L
s
.27082 .36852 m
.27145 .36916 L
s
.27145 .36916 m
.37127 .4704 L
s
.45046 .55073 m
.45079 .55106 L
s
.45079 .55106 m
.46405 .56451 L
s
.44789 .5633 m
.44812 .56346 L
s
.44812 .56346 m
.44982 .56465 L
s
0 g
.006 w
.26941 .36709 m
.28673 .34437 L
s
.72073 .4448 m .49601 .53751 L .5122 .53487 L .054 0 0 r
F
.71093 .41747 m .49601 .53751 L .72073 .4448 L .087 0 0 r
F
.25 g
.5 Mabswid
.72635 .47365 m
.72829 .4731 L
s
0 g
.006 w
.72073 .4448 m
.72829 .4731 L
s
.19626 .61536 m
.19712 .60363 L
s
.25 g
.5 Mabswid
.40213 .48276 m
.45171 .54221 L
s
.28673 .34437 m
.28681 .34447 L
s
.28681 .34447 m
.28809 .34601 L
s
.28809 .34601 m
.28869 .34673 L
s
.28869 .34673 m
.40213 .48276 L
s
.45171 .54221 m
.46847 .56231 L
s
0 g
.006 w
.28673 .34437 m
.30594 .32359 L
s
.71093 .41747 m .48264 .53947 L .49601 .53751 L .087 0 0 r
F
.69885 .39136 m .48264 .53947 L .71093 .41747 L .095 0 0 r
F
.25 g
.5 Mabswid
.71871 .44563 m
.72073 .4448 L
s
0 g
.006 w
.71093 .41747 m
.72073 .4448 L
s
.25 g
.5 Mabswid
.45392 .53183 m
.45591 .52924 L
s
.69885 .39136 m .47195 .54058 L .48264 .53947 L .095 0 0 r
F
.6845 .36673 m .47195 .54058 L .69885 .39136 L .085 0 0 r
F
.25 g
.70888 .41856 m
.71093 .41747 L
s
0 g
.006 w
.69885 .39136 m
.71093 .41747 L
s
.25 g
.5 Mabswid
.45591 .52924 m
.4975 .47499 L
s
.43977 .51381 m
.45377 .53371 L
s
.30594 .32359 m
.30605 .32374 L
s
.30605 .32374 m
.30724 .32544 L
s
.30724 .32544 m
.3078 .32623 L
s
.3078 .32623 m
.43977 .51381 L
s
.4553 .53587 m
.47158 .55902 L
s
0 g
.006 w
.30594 .32359 m
.32696 .30497 L
s
.25 g
.5 Mabswid
.19626 .61536 m
.19694 .61488 L
s
.19694 .61488 m
.19697 .61486 L
s
0 g
.006 w
.19512 .64275 m
.19606 .62016 L
s
.19606 .62016 m
.19626 .61536 L
s
1 0 0 r
.003 w
.46847 .56231 m
.47158 .55902 L
s
.6845 .36673 m .46371 .54079 L .47195 .54058 L .085 0 0 r
F
.66793 .34381 m .46371 .54079 L .6845 .36673 L .059 0 .017 r
F
.25 g
.5 Mabswid
.6812 .40296 m
.69682 .39269 L
s
.69682 .39269 m
.69885 .39136 L
s
0 g
.006 w
.6845 .36673 m
.69885 .39136 L
s
.25 g
.5 Mabswid
.66102 .38523 m
.6845 .36673 L
s
0 g
.006 w
.32696 .30497 m
.34963 .28869 L
s
.66793 .34381 m .45757 .54012 L .46371 .54079 L .059 0 .017 r
F
.25 g
.5 Mabswid
.47195 .54058 m
.47246 .54025 L
s
.64925 .32283 m .45757 .54012 L .66793 .34381 L .019 0 .057 r
F
0 g
.006 w
.66793 .34381 m
.6845 .36673 L
s
.25 g
.5 Mabswid
.65612 .52289 m
.65689 .52415 L
s
.64078 .36915 m
.66793 .34381 L
s
0 g
.006 w
.34963 .28869 m
.37377 .27494 L
s
.25 g
.5 Mabswid
.19512 .64275 m
.19565 .64212 L
s
.19565 .64212 m
.19598 .64172 L
s
.19598 .64172 m
.19601 .64169 L
s
.19601 .64169 m
.19661 .64098 L
s
0 g
.006 w
.19467 .66913 m
.19512 .64275 L
s
.64925 .32283 m .45316 .53872 L .45757 .54012 L .019 0 .057 r
F
.25 g
.5 Mabswid
.46371 .54079 m
.46582 .53912 L
s
.47246 .54025 m
.4737 .53943 L
s
.4737 .53943 m
.4742 .53911 L
s
.48264 .53947 m
.48295 .5393 L
s
.62859 .30401 m .45316 .53872 L .64925 .32283 L 0 0 .083 r
F
.25 g
.42637 .2597 m
.45615 .42293 L
s
1 0 0 r
.003 w
.45181 .53786 m
.45316 .53872 L
s
.25 g
.5 Mabswid
.45322 .25495 m
.46247 .36189 L
s
.46908 .45208 m
.51092 .31622 L
s
.53118 .53183 m
.53334 .53151 L
s
.53334 .53151 m
.73186 .50236 L
s
.46917 .48953 m
.55248 .33016 L
s
.55278 .52871 m
.55475 .52874 L
s
.55475 .52874 m
.59231 .52931 L
s
.5122 .53487 m
.51377 .53442 L
s
.51377 .53442 m
.51448 .53422 L
s
.51448 .53422 m
.72635 .47365 L
s
.46962 .47308 m
.53057 .32545 L
s
.57664 .5259 m
.57837 .52628 L
s
.57837 .52628 m
.57837 .52628 L
s
.57837 .52628 m
.57837 .52628 L
s
.57837 .52628 m
.63032 .53758 L
s
.46792 .50358 m
.57048 .34325 L
s
.49601 .53751 m
.49617 .53744 L
s
.49617 .53744 m
.49766 .53682 L
s
.49834 .53654 m
.71871 .44563 L
s
.49766 .53682 m
.49834 .53654 L
s
.46712 .42131 m
.50121 .25622 L
s
.60224 .52378 m
.60368 .52449 L
s
.60368 .52449 m
.60368 .52449 L
s
.60368 .52449 m
.60369 .5245 L
s
.60369 .5245 m
.66356 .55391 L
s
.48496 .53823 m
.70888 .41856 L
s
.48436 .53855 m
.48496 .53823 L
s
.48295 .5393 m
.48436 .53855 L
s
.62897 .52269 m
.63008 .5237 L
s
.63008 .5237 m
.6301 .52372 L
s
.6301 .52372 m
.69 .57777 L
s
.4975 .47499 m
.59752 .34453 L
s
.4742 .53911 m
.6812 .40296 L
s
.46582 .53912 m
.48793 .52169 L
s
.48793 .52169 m
.66102 .38523 L
s
.59752 .34453 m
.59868 .34302 L
s
.46232 .36483 m
.47516 .2451 L
s
.4595 .53832 m
.49086 .50905 L
s
.45928 .53853 m
.4595 .53832 L
s
.45757 .54012 m
.45928 .53853 L
s
.49086 .50905 m
.61631 .39198 L
s
.61631 .39198 m
.64078 .36915 L
s
.59868 .34302 m
.62707 .30599 L
s
.5763 .33416 m
.60483 .28955 L
s
.57503 .33613 m
.5763 .33416 L
s
.57048 .34325 m
.57503 .33613 L
s
.55395 .32735 m
.58103 .27554 L
s
.55248 .33016 m
.55395 .32735 L
s
.53057 .32545 m
.53237 .32108 L
s
0 g
.006 w
.64925 .32283 m
.66793 .34381 L
s
.25 g
.5 Mabswid
.46321 .52766 m
.61556 .35992 L
s
.4546 .53714 m
.46321 .52766 L
s
.45316 .53872 m
.4546 .53714 L
s
.61556 .35992 m
.61953 .35555 L
s
.61953 .35555 m
.64754 .32471 L
s
.64754 .32471 m
.64925 .32283 L
s
.62707 .30599 m
.62859 .30401 L
s
.53237 .32108 m
.55668 .26221 L
s
.51311 .30911 m
.5302 .25363 L
s
.51092 .31622 m
.51311 .30911 L
s
1 0 0 r
.003 w
.45435 .5391 m
.45757 .54012 L
s
.45316 .53872 m
.45435 .5391 L
s
0 g
.006 w
.62859 .30401 m
.64925 .32283 L
s
.25 g
.5 Mabswid
.68297 .52453 m
.68342 .52599 L
s
0 g
.006 w
.37377 .27494 m
.39918 .26385 L
s
.60612 .28752 m
.62859 .30401 L
s
1 0 0 r
.003 w
.46405 .56451 m
.46847 .56231 L
s
0 g
.006 w
.39918 .26385 m
.42561 .25554 L
s
.58207 .27354 m
.60612 .28752 L
s
.25 g
.5 Mabswid
.70885 .52764 m
.70899 .52924 L
s
.70899 .52924 m
.70901 .52941 L
s
.19467 .66913 m
.19505 .66837 L
s
.19505 .66837 m
.19531 .66787 L
s
.19531 .66787 m
.19533 .66782 L
s
.19533 .66782 m
.19627 .66596 L
s
0 g
.006 w
.19467 .66913 m
.19469 .69427 L
s
.42561 .25554 m
.4528 .25009 L
s
.55668 .26221 m
.58207 .27354 L
s
.4528 .25009 m
.47464 .24811 L
s
.47464 .24811 m
.47484 .24809 L
s
.5302 .25363 m
.55668 .26221 L
s
1 0 0 r
.003 w
.45968 .54035 m
.46371 .54079 L
s
.45757 .54012 m
.45968 .54035 L
s
0 g
.006 w
.50293 .24791 m
.5302 .25363 L
s
.47516 .2451 m
.50293 .24791 L
s
1 0 0 r
.003 w
.45794 .56535 m
.46405 .56451 L
s
.25 g
.5 Mabswid
.73304 .53382 m
.73315 .5321 L
s
.19469 .69427 m
.19513 .69272 L
s
.19513 .69272 m
.19594 .68985 L
s
0 g
.006 w
.19469 .69427 m
.19496 .71794 L
s
1 0 0 r
.003 w
.46371 .54079 m
.47195 .54058 L
s
.71457 .75289 m .77523 .54417 L .70931 .77557 L .605 .643 .862 r
F
.25 g
.5 Mabswid
.71457 .75289 m
.71458 .7528 L
s
.71458 .7528 m
.71485 .75137 L
s
.71485 .75137 m
.71498 .75071 L
s
.19496 .71794 m
.19518 .7162 L
s
.19518 .7162 m
.19563 .71269 L
s
0 g
.006 w
.19496 .71794 m
.19526 .73993 L
s
1 0 0 r
.003 w
.44982 .56465 m
.45794 .56535 L
s
.47195 .54058 m
.48264 .53947 L
s
.70931 .77557 m .79239 .55108 L .70437 .79652 L .62 .63 .839 r
F
.70931 .77557 m .77523 .54417 L .79239 .55108 L F
.25 g
.5 Mabswid
.75507 .5395 m
.7554 .53772 L
s
.73302 .53407 m
.73304 .53382 L
s
0 g
.006 w
.70931 .77557 m
.71457 .75289 L
s
.25 g
.5 Mabswid
.7098 .77387 m
.71 .77315 L
s
.70935 .77542 m
.7098 .77387 L
s
.70931 .77557 m
.70935 .77542 L
s
1 0 0 r
.003 w
.43936 .56236 m
.44982 .56465 L
s
.48264 .53947 m
.49601 .53751 L
s
.70437 .79652 m .80676 .55804 L .69999 .81559 L .634 .619 .817 r
F
.70437 .79652 m .79239 .55108 L .80676 .55804 L F
.25 g
.5 Mabswid
.755 .53986 m
.75507 .5395 L
s
.77471 .54599 m
.77523 .54417 L
s
0 g
.006 w
.70437 .79652 m
.70931 .77557 L
s
.25 g
.5 Mabswid
.70505 .79463 m
.70533 .79386 L
s
.70445 .79631 m
.70505 .79463 L
s
.70437 .79652 m
.70445 .79631 L
s
.1954 .76004 m .17682 .50577 L .19845 .50608 L .721 .705 .835 r
F
.19518 .77807 m .17682 .50577 L .1954 .76004 L .722 .685 .813 r
F
1 0 0 r
.003 w
.42636 .55851 m
.43936 .56236 L
s
.49601 .53751 m
.5122 .53487 L
s
.69636 .83262 m .82592 .5726 L .69371 .84747 L .658 .601 .779 r
F
.82592 .5726 m .82695 .57052 L .82573 .57307 L F
.82592 .5726 m .82573 .57307 L .69371 .84747 L F
.69371 .84747 m .83243 .57613 L .69218 .85998 L .669 .592 .761 r
F
.83243 .57613 m .83282 .57536 L .83231 .5764 L F
.83243 .57613 m .83231 .5764 L .69218 .85998 L F
.69371 .84747 m .82695 .57052 L .83282 .57536 L F
.69218 .85998 m .83595 .5789 L .69194 .87001 L .677 .583 .742 r
F
.69218 .85998 m .83282 .57536 L .83595 .5789 L F
.69194 .87001 m .83636 .581 L .69308 .87741 L .671 .557 .717 r
F
.69194 .87001 m .83595 .5789 L .83636 .581 L F
.69308 .87741 m .83609 .58156 L .83409 .58161 L .722 .599 .719 r
F
.83609 .58156 m .83636 .581 L .83409 .58161 L F
.82993 .58172 m .83409 .58161 L .83026 .58098 L .721 .58 .696 r
F
.76954 .71702 m .83321 .58347 L .70194 .86848 L .722 .599 .719 r
F
.83321 .58347 m .83312 .58369 L .70194 .86848 L F
.76954 .71702 m .70194 .86848 L .69569 .88203 L F
.69308 .87741 m .76954 .71702 L .69569 .88203 L F
.83321 .58347 m .83354 .58277 L .83312 .58369 L F
.83354 .58277 m .83386 .58211 L .8334 .58309 L F
.83354 .58277 m .8334 .58309 L .69569 .88203 L F
.83386 .58211 m .83409 .58161 L .83364 .58259 L F
.83386 .58211 m .83364 .58259 L .8333 .58333 L F
.8334 .58309 m .8333 .58333 L .69569 .88203 L F
.83386 .58211 m .8333 .58333 L .8334 .58309 L F
.82988 .58184 m .83409 .58161 L .82993 .58172 L .721 .58 .696 r
F
.70191 .86854 m .8333 .58333 L .82988 .58184 L F
.8333 .58333 m .83409 .58161 L .82988 .58184 L F
.69569 .88203 m .70191 .86854 L .82915 .58079 L F
.70191 .86854 m .83026 .58098 L .82915 .58079 L F
.69569 .88203 m .82828 .58275 L .69982 .88373 L F
.82828 .58275 m .82857 .58209 L .82821 .58295 L F
.82828 .58275 m .82821 .58295 L .69982 .88373 L F
.82857 .58209 m .82845 .58242 L .69982 .88373 L F
.82888 .58141 m .82863 .582 L .82833 .58271 L F
.82845 .58242 m .82833 .58271 L .69982 .88373 L F
.82888 .58141 m .82833 .58271 L .82845 .58242 L F
.82314 .57943 m .82915 .58079 L .82325 .57916 L .728 .57 .676 r
F
.70002 .88322 m .82863 .582 L .82314 .57943 L F
.82857 .58209 m .82888 .58141 L .82845 .58242 L .721 .58 .696 r
F
.82888 .58141 m .82915 .58079 L .82863 .582 L F
.82863 .582 m .82915 .58079 L .82314 .57943 L .728 .57 .676 r
F
.7003 .88259 m .82915 .58079 L .70002 .88322 L F
.69636 .83262 m .81827 .56465 L .82695 .57052 L .658 .601 .779 r
F
.70504 .87065 m .82325 .57916 L .82155 .57868 L .728 .57 .676 r
F
.69982 .88373 m .82325 .57916 L .70504 .87065 L F
.69982 .88373 m .7003 .88259 L .70002 .88322 L F
.69982 .88373 m .82075 .58068 L .70545 .88237 L F
.82075 .58068 m .82069 .58085 L .70545 .88237 L F
.82098 .5801 m .82076 .58074 L .70545 .88237 L F
.70573 .88154 m .81373 .57628 L .74748 .76053 L .736 .56 .654 r
F
.70562 .88188 m .70575 .88149 L .70573 .88154 L F
.70575 .88149 m .81373 .57628 L .70573 .88154 L F
.70545 .88237 m .70564 .88182 L .70562 .88188 L F
.70564 .88182 m .81373 .57628 L .70562 .88188 L F
.82075 .58068 m .82098 .5801 L .82069 .58085 L .728 .57 .676 r
F
.82098 .5801 m .82155 .57868 L .82076 .58074 L F
.70564 .88182 m .82155 .57868 L .81373 .57628 L .736 .56 .654 r
F
.70545 .88237 m .70579 .88148 L .70564 .88182 L F
.70579 .88148 m .82155 .57868 L .70564 .88182 L F
.69999 .81559 m .81676 .56785 L .69636 .83262 L .647 .609 .797 r
F
.81676 .56785 m .81657 .5684 L .69636 .83262 L F
.69999 .81559 m .80676 .55804 L .81827 .56465 L F
.74748 .76053 m .81373 .57628 L .81129 .57553 L .736 .56 .654 r
F
.70545 .88237 m .8106 .57752 L .71254 .87782 L F
.8106 .57752 m .81057 .57766 L .71254 .87782 L F
.81077 .57702 m .81069 .57733 L .71254 .87782 L F
.81102 .57632 m .81079 .57706 L .81059 .57769 L F
.81069 .57733 m .81059 .57769 L .71254 .87782 L F
.81102 .57632 m .81059 .57769 L .81069 .57733 L F
.71307 .87618 m .81129 .57553 L .71306 .87621 L .744 .549 .631 r
F
.8106 .57752 m .81077 .57702 L .81057 .57766 L .736 .56 .654 r
F
.71281 .87685 m .81079 .57706 L .79843 .57162 L .744 .549 .631 r
F
.81077 .57702 m .81102 .57632 L .81069 .57733 L .736 .56 .654 r
F
.81102 .57632 m .81129 .57553 L .81079 .57706 L F
.81079 .57706 m .81129 .57553 L .79843 .57162 L .744 .549 .631 r
F
.71306 .87621 m .81129 .57553 L .71281 .87685 L F
.71256 .87775 m .71307 .87618 L .71255 .87777 L F
.71307 .87618 m .71306 .87621 L .71255 .87777 L F
.71255 .87777 m .71306 .87621 L .71281 .87685 L F
.71254 .87782 m .71256 .87775 L .71255 .87777 L F
.71254 .87782 m .79788 .57358 L .72099 .86998 L F
.79788 .57358 m .79799 .57318 L .79786 .57368 L F
.79788 .57358 m .79786 .57368 L .72099 .86998 L F
.79799 .57318 m .79793 .57348 L .72099 .86998 L F
.79818 .57249 m .79799 .57329 L .79785 .57385 L F
.79793 .57348 m .79785 .57385 L .72099 .86998 L F
.79818 .57249 m .79785 .57385 L .79793 .57348 L F
.72124 .86874 m .79799 .57329 L .78304 .56732 L .75 .536 .605 r
F
.72122 .86883 m .72126 .86869 L .72124 .86874 L F
.72126 .86869 m .79843 .57162 L .72124 .86874 L F
.72108 .86954 m .72148 .868 L .72122 .86883 L F
.72148 .868 m .79843 .57162 L .72122 .86883 L F
.72099 .86998 m .72116 .86933 L .72108 .86954 L F
.72116 .86933 m .79843 .57162 L .72108 .86954 L F
.72099 .86998 m .78265 .5692 L .73064 .85878 L F
.78265 .5692 m .78265 .56927 L .73064 .85878 L F
.78271 .56892 m .78268 .5692 L .73064 .85878 L F
.78285 .56826 m .78272 .56909 L .78263 .56958 L F
.78268 .5692 m .78263 .56958 L .73064 .85878 L F
.78285 .56826 m .78263 .56958 L .78268 .5692 L F
.73093 .85694 m .78272 .56909 L .73093 .85694 L .756 .519 .574 r
F
.73105 .85654 m .73111 .85619 L .73093 .85694 L F
.73111 .85619 m .78304 .56732 L .73093 .85694 L F
.73082 .8578 m .73105 .85654 L .73072 .8581 L F
.73105 .85654 m .73093 .85694 L .73072 .8581 L F
.78265 .5692 m .78271 .56892 L .78265 .56927 L .75 .536 .605 r
F
.78271 .56892 m .78285 .56826 L .78268 .5692 L F
.78285 .56826 m .78304 .56732 L .78272 .56909 L F
.73081 .85737 m .78304 .56732 L .76527 .56298 L .756 .519 .574 r
F
.73072 .8581 m .73093 .85694 L .73081 .85737 L F
.73093 .85694 m .78304 .56732 L .73081 .85737 L F
.73064 .85878 m .73082 .8578 L .73072 .8581 L F
.73064 .85878 m .76506 .56476 L .7413 .84416 L F
.76506 .56476 m .76507 .56479 L .7413 .84416 L F
.76508 .5646 m .76508 .56485 L .7413 .84416 L F
.76516 .56397 m .76511 .56483 L .76508 .56524 L F
.76508 .56485 m .76508 .56524 L .7413 .84416 L F
.76516 .56397 m .76508 .56524 L .76508 .56485 L F
.75143 .72507 m .76527 .56298 L .75143 .72502 L .759 .498 .538 r
F
.75143 .72507 m .75143 .72502 L .75029 .73834 L F
.75029 .73846 m .75143 .72507 L .75029 .73834 L F
.75029 .73846 m .75029 .73834 L .7414 .84229 L F
.74144 .84212 m .75029 .73846 L .7414 .84229 L F
.7415 .84182 m .74153 .84155 L .74144 .84212 L F
.74153 .84155 m .76527 .56298 L .74144 .84212 L F
.7414 .843 m .7415 .84182 L .74131 .84333 L F
.7415 .84182 m .7414 .84229 L .74131 .84333 L F
.76506 .56476 m .76508 .5646 L .76507 .56479 L .756 .519 .574 r
F
.76508 .5646 m .76516 .56397 L .76508 .56485 L F
.76516 .56397 m .76527 .56298 L .76511 .56483 L F
.74132 .84267 m .76527 .56298 L .74533 .56057 L .759 .498 .538 r
F
.74533 .56057 m .76527 .56298 L .74535 .55897 L F
.74131 .84333 m .7414 .84229 L .74132 .84267 L F
.7414 .84229 m .76527 .56298 L .74132 .84267 L F
.7413 .84416 m .7414 .843 L .74131 .84333 L F
.7413 .84416 m .74533 .56061 L .7527 .82614 L F
.74533 .56061 m .74533 .56062 L .7527 .82614 L F
.74533 .56057 m .74541 .56117 L .7527 .82614 L F
.74533 .56061 m .74533 .56057 L .74533 .56062 L F
.74533 .56057 m .74535 .55897 L .74541 .56117 L F
.75254 .82462 m .74535 .55897 L .72359 .55559 L .759 .471 .495 r
F
.73421 .65434 m .72375 .55715 L .74517 .68712 L F
.72375 .55715 m .72382 .55733 L .74517 .68712 L F
.75258 .82428 m .74535 .55897 L .75256 .82447 L F
.75256 .82447 m .74535 .55897 L .75254 .82462 L F
.75267 .82488 m .74535 .55897 L .7526 .82523 L F
.73421 .65434 m .74517 .68712 L .76453 .80477 L F
.75259 .82453 m .75258 .82428 L .75257 .82489 L F
.75258 .82428 m .75256 .82447 L .75257 .82489 L F
.75257 .82489 m .75256 .82447 L .75254 .82462 L F
.7526 .82523 m .75259 .82453 L .75257 .82489 L F
.7527 .82614 m .75267 .82488 L .7526 .82523 L F
.7527 .82614 m .73421 .65434 L .76453 .80477 L F
.7237 .55662 m .72389 .55744 L .72393 .55769 L F
.72382 .55733 m .72393 .55769 L .76453 .80477 L F
.7237 .55662 m .72393 .55769 L .72382 .55733 L F
.76415 .80327 m .72389 .55744 L .70037 .55308 L .755 .435 .443 r
F
.72375 .55715 m .7237 .55662 L .72382 .55733 L .759 .471 .495 r
F
.7237 .55662 m .72359 .55559 L .72389 .55744 L F
.72389 .55744 m .72359 .55559 L .70037 .55308 L .755 .435 .443 r
F
.76432 .80347 m .76415 .80247 L .76429 .80383 L F
.76415 .80247 m .72359 .55559 L .76415 .80297 L F
.76415 .80247 m .76415 .80297 L .76429 .80383 L F
.76429 .80383 m .76415 .80297 L .76415 .80327 L F
.76415 .80297 m .72359 .55559 L .76415 .80327 L F
.76453 .80477 m .76432 .80347 L .76429 .80383 L F
.76453 .80477 m .70075 .55456 L .77642 .78018 L F
.70075 .55456 m .70084 .55471 L .77642 .78018 L F
.70075 .55447 m .70096 .55486 L .77642 .78018 L F
.70063 .55409 m .70084 .55458 L .70075 .55447 L F
.70084 .55458 m .70096 .55486 L .70075 .55447 L F
.77593 .77905 m .77578 .7786 L .7758 .77876 L .744 .388 .378 r
F
.70063 .55409 m .70037 .55308 L .70096 .55486 L .755 .435 .443 r
F
.77578 .7786 m .70037 .55308 L .7758 .77876 L .744 .388 .378 r
F
.77602 .77925 m .77588 .77884 L .77593 .77905 L F
.77588 .77884 m .70037 .55308 L .77593 .77905 L F
.77642 .78018 m .776 .77891 L .77602 .77925 L F
.776 .77891 m .70037 .55308 L .77602 .77925 L F
.77642 .78018 m .67677 .55297 L .78799 .75255 L F
.67677 .55297 m .67617 .55161 L .67715 .55336 L F
.67677 .55297 m .67715 .55336 L .78799 .75255 L F
.78692 .75066 m .67715 .55336 L .78704 .75102 L .722 .325 .296 r
F
.67715 .55336 m .67617 .55161 L .67714 .55336 L F
.67715 .55336 m .67714 .55336 L .78704 .75102 L F
.78684 .75048 m .67617 .55161 L .78692 .75066 L F
.70075 .55456 m .70063 .55409 L .70084 .55471 L .755 .435 .443 r
F
.73553 .65828 m .70037 .55308 L .67617 .55161 L .744 .388 .378 r
F
.78711 .75125 m .67617 .55161 L .65152 .55121 L .722 .325 .296 r
F
.78704 .75102 m .67617 .55161 L .78711 .75125 L F
.78689 .75057 m .78684 .75048 L .78692 .75066 L F
.78733 .75136 m .78689 .75057 L .7874 .75168 L F
.78689 .75057 m .78704 .75102 L .7874 .75168 L F
.7874 .75168 m .78704 .75102 L .78711 .75125 L F
.78799 .75255 m .78733 .75136 L .7874 .75168 L F
.78799 .75255 m .65234 .55242 L .79881 .72215 L F
.65234 .55242 m .65247 .5525 L .79881 .72215 L F
.65221 .5522 m .65276 .55265 L .79881 .72215 L F
.6521 .55207 m .65228 .55223 L .65221 .5522 L F
.65228 .55223 m .65276 .55265 L .65221 .5522 L F
.79766 .72102 m .65276 .55265 L .62698 .55182 L .683 .239 .191 r
F
.6521 .55207 m .65152 .55121 L .65276 .55265 L .722 .325 .296 r
F
.79732 .72042 m .65152 .55121 L .79766 .72102 L .683 .239 .191 r
F
.79881 .72215 m .79732 .72042 L .79766 .72102 L F
.79881 .72215 m .62802 .55285 L .80844 .68931 L F
.62802 .55285 m .62698 .55182 L .62859 .55305 L F
.62802 .55285 m .62859 .55305 L .80844 .68931 L F
.80652 .68785 m .62859 .55305 L .80729 .68853 L .619 .126 .058 r
F
.62859 .55305 m .62698 .55182 L .62859 .55305 L F
.62859 .55305 m .62859 .55305 L .80729 .68853 L F
.80704 .68838 m .62698 .55182 L .60313 .55329 L F
.8069 .68824 m .62698 .55182 L .80704 .68838 L F
.80728 .68843 m .80652 .68785 L .80746 .68866 L F
.80652 .68785 m .80729 .68853 L .80746 .68866 L F
.80746 .68866 m .8069 .68824 L .80704 .68838 L F
.80844 .68931 m .80728 .68843 L .80746 .68866 L F
.80844 .68931 m .60438 .55411 L .81647 .65442 L F
.60438 .55411 m .60455 .55413 L .81647 .65442 L F
.6041 .55392 m .60501 .55418 L .81647 .65442 L F
.60405 .5539 m .60412 .55392 L .6041 .55392 L F
.60412 .55392 m .60501 .55418 L .6041 .55392 L F
.81483 .65373 m .60501 .55418 L .58053 .55534 L .52 0 0 r
F
.60405 .5539 m .60313 .55329 L .60501 .55418 L .619 .126 .058 r
F
.81424 .65336 m .60313 .55329 L .81483 .65373 L .52 0 0 r
F
.81647 .65442 m .81424 .65336 L .81483 .65373 L F
.81647 .65442 m .58197 .55594 L .82249 .61794 L F
.58197 .55594 m .58053 .55534 L .58271 .5559 L F
.58197 .55594 m .58271 .5559 L .82249 .61794 L F
.81989 .61727 m .58271 .5559 L .82101 .6176 L .375 0 0 r
F
.58271 .5559 m .58053 .55534 L .58271 .5559 L F
.58271 .5559 m .58271 .5559 L .82101 .6176 L F
.82063 .61751 m .58053 .55534 L .55969 .55764 L F
.82043 .61745 m .58053 .55534 L .82063 .61751 L F
.82084 .61751 m .81989 .61727 L .82115 .61763 L F
.81989 .61727 m .82101 .6176 L .82115 .61763 L F
.82115 .61763 m .82043 .61745 L .82063 .61751 L F
.82249 .61794 m .82084 .61751 L .82115 .61763 L F
.82249 .61794 m .56089 .55792 L .82614 .58034 L F
.56089 .55792 m .55969 .55764 L .56208 .55785 L F
.56089 .55792 m .56208 .55785 L .82614 .58034 L F
.8241 .5802 m .56208 .55785 L .54104 .55984 L .19 0 0 r
F
.82614 .58034 m .82329 .5801 L .8241 .5802 L F
.82329 .5801 m .55969 .55764 L .8241 .5802 L F
.79799 .57318 m .79818 .57249 L .79793 .57348 L .744 .549 .631 r
F
.79818 .57249 m .79843 .57162 L .79799 .57329 L F
.79799 .57329 m .79843 .57162 L .78304 .56732 L .75 .536 .605 r
F
.81676 .56785 m .81827 .56465 L .81657 .5684 L .647 .609 .797 r
F
.82614 .58034 m .54104 .55984 L .82711 .54215 L .19 0 0 r
F
.82509 .54227 m .82402 .54234 L .8255 .54225 L 0 0 0 r
F
.82402 .54234 m .54104 .55984 L .82544 .54226 L F
.82402 .54234 m .82544 .54226 L .8255 .54225 L F
.56208 .55785 m .55969 .55764 L .54104 .55984 L .19 0 0 r
F
.82492 .54229 m .54104 .55984 L .52487 .56153 L 0 0 0 r
F
.8255 .54225 m .82469 .5423 L .82492 .54229 L F
.82469 .5423 m .54104 .55984 L .82492 .54229 L F
.82711 .54215 m .82509 .54227 L .8255 .54225 L F
.60438 .55411 m .60405 .5539 L .60455 .55413 L .619 .126 .058 r
F
.60501 .55418 m .60313 .55329 L .58053 .55534 L .52 0 0 r
F
.65234 .55242 m .6521 .55207 L .65247 .5525 L .722 .325 .296 r
F
.65276 .55265 m .65152 .55121 L .62698 .55182 L .683 .239 .191 r
F
.25 g
.5 Mabswid
.69999 .81559 m
.7001 .81531 L
s
.7001 .81531 m
.70086 .81349 L
s
.73916 .7211 m
.74094 .71681 L
s
.70956 .7925 m
.73916 .7211 L
s
.70119 .81267 m
.70956 .7925 L
s
.70086 .81349 m
.70119 .81267 L
s
0 g
.006 w
.69999 .81559 m
.70437 .79652 L
s
.25 g
.5 Mabswid
.72204 .74727 m
.73831 .7019 L
s
.70856 .78485 m
.72204 .74727 L
s
.70533 .79386 m
.70856 .78485 L
s
.73096 .69958 m
.73452 .68706 L
s
.71787 .74553 m
.73096 .69958 L
s
.71057 .77114 m
.71787 .74553 L
s
.71 .77315 m
.71057 .77114 L
s
.68342 .52599 m
.68456 .52969 L
s
.68456 .52969 m
.68562 .53316 L
s
.68562 .53316 m
.6894 .54541 L
s
.6894 .54541 m
.69098 .55057 L
s
.70901 .52941 m
.70959 .53574 L
s
.70959 .53574 m
.70966 .53647 L
s
.70966 .53647 m
.70995 .53957 L
s
.70995 .53957 m
.70995 .53957 L
s
.70995 .53957 m
.7102 .54231 L
s
.7102 .54231 m
.71036 .54411 L
s
.71036 .54411 m
.71085 .54934 L
s
.72038 .65281 m
.72067 .6559 L
s
.72067 .6559 m
.72299 .68111 L
s
.72299 .68111 m
.72305 .68176 L
s
.733 .53445 m
.73302 .53407 L
s
.73246 .54245 m
.733 .53445 L
s
.73244 .54268 m
.73246 .54245 L
s
.73237 .54373 m
.73244 .54268 L
s
.73223 .54575 m
.73237 .54373 L
s
.73223 .54575 m
.73223 .54575 L
s
.73214 .54712 m
.73223 .54575 L
s
.73212 .54743 m
.73214 .54712 L
s
.73212 .54743 m
.73212 .54743 L
s
.73208 .54802 m
.73212 .54743 L
s
.72216 .69501 m
.72441 .6616 L
s
.72055 .71879 m
.72216 .69501 L
s
.72028 .72276 m
.72055 .71879 L
s
.75489 .54041 m
.755 .53986 L
s
.75468 .54152 m
.75489 .54041 L
s
.7537 .54669 m
.75468 .54152 L
s
.72405 .70292 m
.72963 .6735 L
s
.71804 .73459 m
.72405 .70292 L
s
.71498 .75071 m
.71804 .73459 L
s
.65689 .52415 m
.65726 .52474 L
s
.65726 .52474 m
.67068 .54648 L
s
.67068 .54648 m
.67382 .55157 L
s
0 g
.006 w
.69878 .82126 m
.69999 .81559 L
s
.69636 .83262 m
.69878 .82126 L
s
.19518 .77807 m .15743 .50633 L .17682 .50577 L .722 .685 .813 r
F
.19445 .79384 m .15743 .50633 L .19518 .77807 L .722 .665 .793 r
F
.25 g
.5 Mabswid
.19525 .758 m
.1954 .76004 L
s
0 g
.006 w
.19518 .77807 m
.1954 .76004 L
s
1 0 0 r
.003 w
.41069 .5533 m
.42636 .55851 L
s
.5122 .53487 m
.53118 .53183 L
s
.25 g
.5 Mabswid
.69654 .83224 m
.69743 .83028 L
s
.69743 .83028 m
.69782 .82942 L
s
.71981 .78107 m
.74249 .73123 L
s
.69821 .82856 m
.71981 .78107 L
s
.69782 .82942 m
.69821 .82856 L
s
.69636 .83262 m
.69654 .83224 L
s
0 g
.006 w
.69371 .84747 m
.69636 .83262 L
s
.19445 .79384 m .14054 .50744 L .15743 .50633 L .722 .665 .793 r
F
.25 g
.5 Mabswid
.17682 .50577 m
.17693 .50732 L
s
.19306 .80716 m .14054 .50744 L .19445 .79384 L .72 .645 .773 r
F
.25 g
.19488 .77594 m
.19518 .77807 L
s
0 g
.006 w
.19445 .79384 m
.19518 .77807 L
s
1 0 0 r
.003 w
.39238 .54702 m
.41069 .5533 L
s
.53118 .53183 m
.55278 .52871 L
s
.25 g
.5 Mabswid
.69371 .84747 m
.69396 .84695 L
s
.69396 .84695 m
.69498 .84483 L
s
.69498 .84483 m
.69542 .84391 L
s
.82636 .57176 m
.82695 .57052 L
s
.70097 .83236 m
.7427 .74563 L
s
.69542 .84391 m
.70097 .83236 L
s
0 g
.006 w
.69218 .85998 m
.69371 .84747 L
s
1 0 0 r
.003 w
.37161 .54007 m
.39238 .54702 L
s
.19306 .80716 m .12635 .50876 L .14054 .50744 L .72 .645 .773 r
F
.25 g
.5 Mabswid
.15743 .50633 m
.1577 .50831 L
s
.17693 .50732 m
.17699 .50805 L
s
.17699 .50805 m
.17699 .50815 L
s
.19089 .81785 m .12635 .50876 L .19306 .80716 L .716 .625 .754 r
F
.25 g
.19404 .79167 m
.19445 .79384 L
s
0 g
.006 w
.19306 .80716 m
.19445 .79384 L
s
1 0 0 r
.003 w
.55278 .52871 m
.57664 .5259 L
s
.34873 .53289 m
.37161 .54007 L
s
.25 g
.5 Mabswid
.69218 .85998 m
.69254 .85926 L
s
.69254 .85926 m
.69369 .85693 L
s
.69369 .85693 m
.69419 .85591 L
s
.83231 .5764 m
.83282 .57536 L
s
.69419 .85591 m
.7424 .75835 L
s
.83041 .58025 m
.83231 .5764 L
s
.83006 .58094 m
.83041 .58025 L
s
0 g
.006 w
.69194 .87001 m
.69218 .85998 L
s
1 0 0 r
.003 w
.57664 .5259 m
.60224 .52378 L
s
.19089 .81785 m .11496 .50993 L .11975 .50943 L .716 .625 .754 r
F
.18786 .82576 m .11496 .50993 L .19089 .81785 L .712 .605 .735 r
F
.18786 .82576 m .10645 .51063 L .11009 .51033 L F
.1871 .82248 m .11009 .51033 L .11496 .50993 L F
.18786 .82576 m .11009 .51033 L .1871 .82248 L F
.18391 .83072 m .10645 .51063 L .18786 .82576 L .709 .586 .716 r
F
.18391 .83072 m .1782 .80872 L .10645 .51063 L F
.1782 .80872 m .10085 .51062 L .10318 .51062 L F
.1782 .80872 m .10318 .51062 L .10645 .51063 L F
.17904 .83258 m .1745 .81389 L .18391 .83072 L .71 .569 .694 r
F
.1745 .81389 m .10085 .51062 L .1782 .80872 L F
.1745 .81389 m .1782 .80872 L .18391 .83072 L F
.17904 .83258 m .09821 .50973 L .10085 .51062 L F
.17325 .83119 m .09821 .50973 L .17904 .83258 L .641 .508 .685 r
F
.17195 .82564 m .09855 .50789 L .09821 .50973 L F
.17212 .82635 m .17194 .82559 L .17195 .82564 L F
.17194 .82559 m .09855 .50789 L .17195 .82564 L F
.17196 .82564 m .17189 .82533 L .17212 .82635 L F
.17189 .82533 m .09855 .50789 L .17194 .82559 L F
.17189 .82533 m .17194 .82559 L .17212 .82635 L F
.17295 .82988 m .17191 .82539 L .17295 .82991 L F
.17191 .82539 m .09855 .50789 L .17196 .82564 L F
.17191 .82539 m .17196 .82564 L .17295 .82991 L F
.17295 .82991 m .17196 .82564 L .17212 .82635 L F
.17325 .83119 m .17295 .82988 L .17295 .82991 L F
.16662 .82645 m .09855 .50789 L .17325 .83119 L .672 .509 .656 r
F
.16591 .82315 m .10187 .50514 L .09855 .50789 L F
.10204 .50611 m .10213 .50646 L .10334 .51245 L .667 .486 .631 r
F
.16587 .82271 m .10187 .50514 L .16591 .82315 L .672 .509 .656 r
F
.10213 .50646 m .10213 .50647 L .10334 .51245 L .667 .486 .631 r
F
.10334 .51245 m .10213 .50647 L .10341 .5128 L F
.10319 .51182 m .10341 .5128 L .16662 .82645 L F
.10204 .50611 m .10341 .5128 L .10319 .51182 L F
.16662 .82645 m .16587 .82271 L .16591 .82315 L .672 .509 .656 r
F
.15926 .81825 m .13648 .67704 L .16637 .82523 L .667 .486 .631 r
F
.10256 .50891 m .10204 .50611 L .10319 .51182 L F
.10256 .50891 m .10319 .51182 L .16637 .82523 L F
.10204 .50611 m .10187 .50514 L .10213 .50647 L F
.15874 .81545 m .10818 .50163 L .10187 .50514 L F
.15872 .81493 m .10818 .50163 L .15874 .81545 L F
.15926 .81825 m .15872 .81493 L .15874 .81545 L F
.10973 .5115 m .10997 .51271 L .15926 .81825 L .659 .459 .603 r
F
.15132 .80654 m .1092 .50882 L .15926 .81825 L F
.1092 .50882 m .10973 .5115 L .15926 .81825 L F
.10851 .50393 m .10864 .50446 L .10997 .51271 L F
.10851 .50393 m .10997 .51271 L .10973 .5115 L F
.1092 .50882 m .10851 .50393 L .10973 .5115 L F
.10851 .50393 m .10818 .50163 L .10864 .50446 L F
.15096 .80406 m .11747 .49757 L .10818 .50163 L F
.15132 .80654 m .15098 .80352 L .15096 .80406 L F
.15098 .80352 m .11747 .49757 L .15096 .80406 L F
.143 .79131 m .14276 .78854 L .15132 .80654 L .649 .43 .572 r
F
.14276 .78854 m .11777 .50103 L .15098 .80351 L F
.14276 .78854 m .15098 .80351 L .15132 .80654 L F
.13457 .77259 m .13454 .77075 L .143 .79131 L .639 .396 .535 r
F
.11777 .50103 m .11792 .50165 L .15132 .80654 L .649 .43 .572 r
F
.17914 .76157 m .11975 .50943 L .12635 .50876 L .716 .625 .754 r
F
.19089 .81785 m .11975 .50943 L .17914 .76157 L F
.11777 .50103 m .11747 .49757 L .11792 .50165 L .649 .43 .572 r
F
.14281 .78908 m .12967 .49327 L .11747 .49757 L F
.143 .79131 m .14288 .78853 L .14281 .78908 L F
.14288 .78853 m .12967 .49327 L .14281 .78908 L F
.13454 .77075 m .12989 .50581 L .14283 .78746 L .639 .396 .535 r
F
.13454 .77075 m .14283 .78746 L .143 .79131 L F
.12989 .50581 m .13027 .50869 L .143 .79131 L F
.12973 .4966 m .12988 .49798 L .143 .79131 L F
.12989 .50581 m .12973 .4966 L .13027 .50869 L F
.12973 .4966 m .12967 .49327 L .12988 .49798 L F
.13453 .77057 m .14467 .48907 L .12967 .49327 L F
.13457 .77259 m .13466 .77005 L .13453 .77057 L F
.13466 .77005 m .14467 .48907 L .13453 .77057 L F
.12631 .75048 m .12647 .74819 L .13457 .77259 L .626 .358 .492 r
F
.12647 .74819 m .14451 .49144 L .13466 .77004 L F
.12647 .74819 m .13466 .77004 L .13457 .77259 L F
.11854 .72515 m .11881 .72364 L .12631 .75048 L .612 .314 .44 r
F
.14451 .49144 m .14455 .49247 L .13457 .77259 L .626 .358 .492 r
F
.14451 .49144 m .14467 .48907 L .14455 .49247 L F
.12643 .74867 m .1623 .48533 L .14467 .48907 L F
.12631 .75048 m .12662 .74817 L .12643 .74867 L F
.12662 .74817 m .1623 .48533 L .12643 .74867 L F
.11881 .72364 m .16196 .4872 L .12675 .74721 L .612 .314 .44 r
F
.11881 .72364 m .12675 .74721 L .12631 .75048 L F
.16196 .4872 m .16193 .48806 L .12631 .75048 L F
.16196 .4872 m .1623 .48533 L .16193 .48806 L F
.11891 .72309 m .18229 .48241 L .1623 .48533 L F
.11854 .72515 m .11931 .7222 L .11891 .72309 L F
.11931 .7222 m .18229 .48241 L .11891 .72309 L F
.11161 .69683 m .11205 .69551 L .11854 .72515 L .596 .263 .377 r
F
.11205 .69551 m .1818 .48389 L .11931 .7222 L F
.11205 .69551 m .11931 .7222 L .11854 .72515 L F
.1818 .48389 m .18171 .48463 L .11854 .72515 L F
.1818 .48389 m .18229 .48241 L .18171 .48463 L F
.1122 .69503 m .20431 .48058 L .18229 .48241 L F
.11161 .69683 m .11272 .69424 L .1122 .69503 L F
.11272 .69424 m .20431 .48058 L .1122 .69503 L F
.1059 .66584 m .2037 .48175 L .11269 .6943 L .575 .202 .297 r
F
.2037 .48175 m .20354 .48238 L .11161 .69683 L F
.2037 .48175 m .20431 .48058 L .20354 .48238 L F
.10671 .66432 m .22795 .48009 L .20431 .48058 L F
.1059 .66584 m .10734 .66365 L .10671 .66432 L F
.10734 .66365 m .22795 .48009 L .10671 .66432 L F
.22722 .48097 m .22715 .48116 L .10734 .66365 L .549 .129 .197 r
F
.10734 .66365 m .10734 .66365 L .1059 .66584 L F
.22722 .48097 m .10734 .66365 L .10734 .66365 L F
.22715 .48116 m .22694 .48162 L .1059 .66584 L F
.10176 .63257 m .22722 .48097 L .1059 .66584 L F
.22715 .48116 m .22702 .48151 L .22694 .48162 L F
.22722 .48097 m .22795 .48009 L .22702 .48151 L F
.10278 .63134 m .25272 .48103 L .22795 .48009 L F
.10176 .63257 m .10352 .6308 L .10278 .63134 L F
.10352 .6308 m .25272 .48103 L .10278 .63134 L F
.09954 .59745 m .10045 .59677 L .10176 .63257 L .513 .041 .072 r
F
.10045 .59677 m .25186 .48168 L .10352 .6308 L F
.10045 .59677 m .10352 .6308 L .10176 .63257 L F
.25186 .48168 m .25146 .48229 L .10176 .63257 L F
.25186 .48168 m .25272 .48103 L .25146 .48229 L F
.10076 .59653 m .2781 .48342 L .25272 .48103 L F
.09954 .59745 m .10159 .59614 L .10076 .59653 L F
.10159 .59614 m .2781 .48342 L .10076 .59653 L F
.09957 .56099 m .10061 .56054 L .09954 .59745 L .465 0 0 r
F
.10061 .56054 m .27708 .48386 L .10159 .59614 L F
.10061 .56054 m .10159 .59614 L .09954 .59745 L F
.27708 .48386 m .27659 .48438 L .09954 .59745 L F
.27708 .48386 m .2781 .48342 L .27659 .48438 L F
.10096 .56039 m .30352 .48715 L .2781 .48342 L F
.09957 .56099 m .10188 .56016 L .10096 .56039 L F
.10188 .56016 m .30352 .48715 L .10096 .56039 L F
.10212 .52372 m .10327 .52351 L .09957 .56099 L .401 0 0 r
F
.10327 .52351 m .30235 .48736 L .10188 .56015 L F
.10327 .52351 m .10188 .56015 L .09957 .56099 L F
.30235 .48736 m .30176 .48778 L .09957 .56099 L F
.30235 .48736 m .30352 .48715 L .30176 .48778 L F
.10365 .52344 m .32842 .49199 L .30352 .48715 L F
.10212 .52372 m .10463 .52337 L .10365 .52344 L F
.10463 .52337 m .32842 .49199 L .10365 .52344 L F
.1074 .48619 m .10864 .48622 L .10212 .52372 L .32 0 0 r
F
.10864 .48622 m .32712 .49196 L .10463 .52336 L F
.10864 .48622 m .10463 .52336 L .10212 .52372 L F
.32712 .49196 m .32645 .49227 L .10212 .52372 L F
.32712 .49196 m .32842 .49199 L .32645 .49227 L F
.1074 .48619 m .35229 .49763 L .32842 .49199 L F
.11557 .44894 m .35087 .49734 L .1074 .48619 L .233 0 0 r
F
.35087 .49734 m .35229 .49763 L .35011 .49753 L F
.35087 .49734 m .35011 .49753 L .1074 .48619 L F
.11557 .44894 m .37463 .50369 L .35229 .49763 L F
.1267 .41252 m .37312 .50313 L .11557 .44894 L 0 .42 .738 r
F
.37312 .50313 m .37463 .50369 L .37229 .50319 L F
.37312 .50313 m .37229 .50319 L .11557 .44894 L F
.1059 .66584 m .11269 .6943 L .11161 .69683 L .575 .202 .297 r
F
.166 .82575 m .16637 .82523 L .16662 .82645 L .667 .486 .631 r
F
.15926 .81825 m .16637 .82523 L .166 .82575 L F
.25 g
.5 Mabswid
.14406 .62796 m
.18605 .79823 L
s
.18605 .79823 m
.19042 .81595 L
s
.19042 .81595 m
.19089 .81785 L
s
0 g
.006 w
.19089 .81785 m
.19306 .80716 L
s
.25 g
.5 Mabswid
.14893 .60978 m
.17592 .7305 L
s
.17592 .7305 m
.19258 .80505 L
s
.19258 .80505 m
.19306 .80716 L
s
.15649 .59215 m
.17017 .66485 L
s
.17017 .66485 m
.18743 .75655 L
s
.18743 .75655 m
.19404 .79167 L
s
.16673 .57326 m
.19442 .77257 L
s
.19442 .77257 m
.19488 .77594 L
s
.18032 .5537 m
.19525 .758 L
s
0 g
.006 w
.18786 .82576 m
.19089 .81785 L
s
1 0 0 r
.003 w
.32421 .52594 m
.34873 .53289 L
s
.60224 .52378 m
.62897 .52269 L
s
.25 g
.5 Mabswid
.69194 .87001 m
.69246 .86895 L
s
.69246 .86895 m
.69379 .86627 L
s
.69379 .86627 m
.69439 .86504 L
s
.83554 .57972 m
.83595 .5789 L
s
.69439 .86504 m
.74092 .77099 L
s
.83468 .58145 m
.83554 .57972 L
s
0 g
.006 w
.69194 .87001 m
.69308 .87741 L
s
1 0 0 r
.003 w
.29863 .51965 m
.32421 .52594 L
s
.62897 .52269 m
.65612 .52289 L
s
.25 g
.5 Mabswid
.14081 .64364 m
.18752 .82443 L
s
.18752 .82443 m
.18786 .82576 L
s
0 g
.006 w
.18391 .83072 m
.18786 .82576 L
s
1 0 0 r
.003 w
.65612 .52289 m
.68297 .52453 L
s
.27263 .51435 m
.29863 .51965 L
s
.68297 .52453 m
.70885 .52764 L
s
.26968 .51388 m
.27263 .51435 L
s
.24686 .51028 m
.26968 .51388 L
s
.70885 .52764 m
.73315 .5321 L
s
.25 g
.5 Mabswid
.83609 .58156 m
.83636 .581 L
s
.83568 .58242 m
.83609 .58156 L
s
.83528 .58323 m
.83568 .58242 L
s
.83491 .58401 m
.83528 .58323 L
s
.83457 .5847 m
.83491 .58401 L
s
.82349 .60763 m
.83457 .5847 L
s
0 g
.006 w
.69308 .87741 m
.69569 .88203 L
s
1 0 0 r
.003 w
.73315 .5321 m
.7554 .53772 L
s
.7554 .53772 m
.76409 .54055 L
s
.76409 .54055 m
.77523 .54417 L
s
.24132 .50967 m
.24686 .51028 L
s
.83409 .58161 m
.83475 .58144 L
s
.83475 .58144 m
.83636 .581 L
s
.83595 .5789 m
.83636 .581 L
s
.83282 .57536 m
.83595 .5789 L
s
.25 g
.5 Mabswid
.83364 .58259 m
.83409 .58161 L
s
.8333 .58333 m
.83364 .58259 L
s
.83297 .58405 m
.8333 .58333 L
s
.83267 .5847 m
.83297 .58405 L
s
.83245 .58518 m
.83267 .5847 L
s
.83234 .58542 m
.83245 .58518 L
s
.82386 .60382 m
.83234 .58542 L
s
1 0 0 r
.003 w
.82915 .58079 m
.83409 .58161 L
s
.82695 .57052 m
.83282 .57536 L
s
.25 g
.5 Mabswid
.82833 .58271 m
.82915 .58079 L
s
.82806 .58334 m
.82833 .58271 L
s
.82786 .58382 m
.82806 .58334 L
s
.82776 .58405 m
.82786 .58382 L
s
.8252 .59006 m
.82776 .58405 L
s
1 0 0 r
.003 w
.82615 .57996 m
.82915 .58079 L
s
.8264 .57015 m
.82695 .57052 L
s
.77523 .54417 m
.77779 .5452 L
s
.25 g
.5 Mabswid
.18261 .82571 m
.18391 .83072 L
s
.1782 .80872 m
.18261 .82571 L
s
.13894 .6574 m
.1782 .80872 L
s
0 g
.006 w
.17904 .83258 m
.18391 .83072 L
s
.25 g
.5 Mabswid
.15089 .80262 m
.15132 .80654 L
s
.15086 .80241 m
.15089 .80262 L
s
.13842 .68881 m
.15086 .80241 L
s
.15858 .81403 m
.15926 .81825 L
s
.15853 .81378 m
.15858 .81403 L
s
.13851 .68964 m
.15853 .81378 L
s
1 0 0 r
.003 w
.10187 .50514 m
.10498 .50341 L
s
.25 g
.5 Mabswid
.14284 .78764 m
.143 .79131 L
s
.14283 .78747 m
.14284 .78764 L
s
.13794 .67808 m
.14283 .78747 L
s
.16568 .82177 m
.16637 .82523 L
s
.16562 .82148 m
.16568 .82177 L
s
.13829 .68586 m
.16562 .82148 L
s
.16637 .82523 m
.16662 .82645 L
s
1 0 0 r
.003 w
.09855 .50789 m
.10187 .50514 L
s
.25 g
.5 Mabswid
.17191 .82539 m
.17325 .83119 L
s
.17188 .82524 m
.17191 .82539 L
s
.13795 .67844 m
.17188 .82524 L
s
1 0 0 r
.003 w
.09821 .50973 m
.09855 .50789 L
s
.25 g
.5 Mabswid
.17514 .81703 m
.17904 .83258 L
s
.13824 .66962 m
.17514 .81703 L
s
.13457 .77259 m
.13469 .76916 L
s
.13469 .76916 m
.1347 .76903 L
s
.1347 .76903 m
.13858 .66006 L
s
.12631 .75048 m
.12673 .74732 L
s
.12673 .74732 m
.12675 .74721 L
s
.12675 .74721 m
.14174 .63682 L
s
.11854 .72515 m
.11929 .72228 L
s
.11929 .72228 m
.11931 .7222 L
s
.11931 .7222 m
.14869 .61033 L
s
0 g
.006 w
.69569 .88203 m
.69982 .88373 L
s
.25 g
.5 Mabswid
.11161 .69683 m
.1127 .6943 L
s
.1127 .6943 m
.11272 .69424 L
s
.11272 .69424 m
.16056 .58265 L
s
.1059 .66584 m
.10731 .66369 L
s
.10731 .66369 m
.10734 .66365 L
s
.10734 .66365 m
.17814 .5559 L
s
1 0 0 r
.003 w
.65152 .55121 m
.67455 .55158 L
s
0 g
.006 w
.17325 .83119 m
.17904 .83258 L
s
.25 g
.5 Mabswid
.10176 .63257 m
.10349 .63083 L
s
.10349 .63083 m
.10352 .6308 L
s
.10352 .6308 m
.2018 .53215 L
s
.65152 .55121 m
.65276 .55265 L
s
.65276 .55265 m
.65282 .55272 L
s
.65282 .55272 m
.65299 .55291 L
s
1 0 0 r
.003 w
.62698 .55182 m
.62782 .5518 L
s
.62782 .5518 m
.65152 .55121 L
s
.25 g
.5 Mabswid
.09954 .59745 m
.10158 .59616 L
s
.10158 .59616 m
.10159 .59614 L
s
0 g
.006 w
.69982 .88373 m
.70545 .88237 L
s
.25 g
.5 Mabswid
.09957 .56099 m
.10187 .56016 L
s
.62698 .55182 m
.62704 .55187 L
s
.62704 .55187 m
.62855 .55301 L
s
.62855 .55301 m
.62859 .55305 L
s
.62859 .55305 m
.62859 .55305 L
s
.62859 .55305 m
.63027 .55432 L
s
1 0 0 r
.003 w
.60313 .55329 m
.62698 .55182 L
s
0 g
.006 w
.16662 .82645 m
.17325 .83119 L
s
.25 g
.5 Mabswid
.10212 .52372 m
.10463 .52337 L
s
.60313 .55329 m
.60443 .5539 L
s
.60443 .5539 m
.60501 .55418 L
s
.60501 .55418 m
.60504 .55419 L
s
.60504 .55419 m
.60819 .55568 L
s
1 0 0 r
.003 w
.58053 .55534 m
.60313 .55329 L
s
0 g
.006 w
.70545 .88237 m
.71254 .87782 L
s
.25 g
.5 Mabswid
.1074 .48619 m
.11008 .48631 L
s
0 g
.006 w
.15926 .81825 m
.16662 .82645 L
s
.25 g
.5 Mabswid
.58053 .55534 m
.58269 .5559 L
s
.58269 .5559 m
.58271 .5559 L
s
.58271 .5559 m
.58695 .557 L
s
1 0 0 r
.003 w
.55969 .55764 m
.58053 .55534 L
s
.1267 .41252 m .39505 .50972 L .37463 .50369 L 0 .42 .738 r
F
.25 g
.5 Mabswid
.37457 .50367 m
.37463 .50369 L
s
.37305 .50335 m
.37457 .50367 L
s
.37229 .50319 m
.37305 .50335 L
s
0 g
.006 w
.71254 .87782 m
.72099 .86998 L
s
.25 g
.5 Mabswid
.55969 .55764 m
.56208 .55785 L
s
.56208 .55785 m
.56676 .55825 L
s
.55969 .55764 m
.55969 .55764 L
s
1 0 0 r
.003 w
.54104 .55984 m
.55969 .55764 L
s
0 g
.006 w
.15132 .80654 m
.15926 .81825 L
s
.14082 .37741 m .39505 .50972 L .1267 .41252 L 0 .435 .808 r
F
.25 g
.5 Mabswid
.11557 .44894 m
.11835 .44953 L
s
.14082 .37741 m .41326 .51529 L .39505 .50972 L 0 .435 .808 r
F
1 0 0 r
.003 w
.37463 .50369 m
.39505 .50972 L
s
.25 g
.5 Mabswid
.3926 .50883 m
.3934 .50912 L
s
.3934 .50912 m
.39503 .50971 L
s
.39503 .50971 m
.39505 .50972 L
s
0 g
.006 w
.72099 .86998 m
.73064 .85878 L
s
.143 .79131 m
.15132 .80654 L
s
.15786 .34406 m .41326 .51529 L .14082 .37741 L 0 .422 .838 r
F
.25 g
.5 Mabswid
.1267 .41252 m
.12953 .41354 L
s
.15786 .34406 m .42908 .52002 L .41326 .51529 L 0 .422 .838 r
F
1 0 0 r
.003 w
.39505 .50972 m
.41326 .51529 L
s
.25 g
.5 Mabswid
.41075 .51402 m
.41154 .51442 L
s
.41154 .51442 m
.41321 .51527 L
s
.41321 .51527 m
.41326 .51529 L
s
.82517 .50387 m .52487 .56153 L .51139 .56237 L .211 .736 .79 r
F
.25 g
.54104 .55984 m
.54359 .55968 L
s
.82711 .54215 m .52487 .56153 L .82517 .50387 L 0 0 0 r
F
0 g
.006 w
.73064 .85878 m
.7413 .84416 L
s
.13457 .77259 m
.143 .79131 L
s
.17771 .31285 m .42908 .52002 L .15786 .34406 L 0 .389 .838 r
F
.25 g
.5 Mabswid
.14082 .37741 m
.14363 .37883 L
s
.17771 .31285 m .44244 .52357 L .42908 .52002 L 0 .389 .838 r
F
1 0 0 r
.003 w
.41326 .51529 m
.42908 .52002 L
s
.25 g
.5 Mabswid
.42655 .51838 m
.4273 .51887 L
s
.4273 .51887 m
.42893 .51993 L
s
.42893 .51993 m
.42908 .52002 L
s
.82014 .46602 m .51139 .56237 L .50063 .56208 L .376 .842 .862 r
F
.25 g
.52487 .56153 m
.52752 .56102 L
s
.82517 .50387 m .51139 .56237 L .82014 .46602 L .211 .736 .79 r
F
1 0 0 r
.003 w
.51139 .56237 m
.52487 .56153 L
s
.25 g
.5 Mabswid
.82302 .50429 m
.82517 .50387 L
s
.82192 .5045 m
.82302 .50429 L
s
0 g
.006 w
.7413 .84416 m
.7527 .82614 L
s
.12631 .75048 m
.13457 .77259 L
s
.20019 .28411 m .44244 .52357 L .17771 .31285 L 0 .342 .819 r
F
.25 g
.5 Mabswid
.15786 .34406 m
.16059 .34583 L
s
.20019 .28411 m .4534 .52573 L .44244 .52357 L 0 .342 .819 r
F
1 0 0 r
.003 w
.42908 .52002 m
.44244 .52357 L
s
.25 g
.5 Mabswid
.44062 .52213 m
.44214 .52333 L
s
.43997 .52161 m
.44062 .52213 L
s
.44214 .52333 m
.44244 .52357 L
s
0 g
.006 w
.7527 .82614 m
.76453 .80477 L
s
.81195 .42907 m .50063 .56208 L .49251 .56045 L .507 .91 .894 r
F
.25 g
.5 Mabswid
.51139 .56237 m
.51407 .56154 L
s
.52752 .56102 m
.52757 .56101 L
s
.82014 .46602 m .50063 .56208 L .81195 .42907 L .376 .842 .862 r
F
1 0 0 r
.003 w
.50063 .56208 m
.51139 .56237 L
s
.25 g
.5 Mabswid
.81791 .46672 m
.82014 .46602 L
s
.8168 .46707 m
.81791 .46672 L
s
0 g
.006 w
.11854 .72515 m
.12631 .75048 L
s
.2251 .2581 m .4534 .52573 L .20019 .28411 L 0 .285 .785 r
F
.25 g
.5 Mabswid
.17771 .31285 m
.18031 .31492 L
s
.2251 .2581 m .46212 .52639 L .4534 .52573 L 0 .285 .785 r
F
1 0 0 r
.003 w
.44244 .52357 m
.4534 .52573 L
s
.25 g
.5 Mabswid
.45291 .52526 m
.4534 .52573 L
s
.45158 .52399 m
.45291 .52526 L
s
.45104 .52348 m
.45158 .52399 L
s
0 g
.006 w
.76453 .80477 m
.77642 .78018 L
s
.11161 .69683 m
.11854 .72515 L
s
.80058 .39346 m .49251 .56045 L .48681 .55742 L .609 .953 .898 r
F
.25 g
.5 Mabswid
.50063 .56208 m
.50327 .56095 L
s
.51407 .56154 m
.51415 .56151 L
s
.81195 .42907 m .49251 .56045 L .80058 .39346 L .507 .91 .894 r
F
1 0 0 r
.003 w
.49251 .56045 m
.50063 .56208 L
s
.25 g
.5 Mabswid
.80967 .43005 m
.81195 .42907 L
s
.80857 .43052 m
.80967 .43005 L
s
.25218 .23501 m .46212 .52639 L .2251 .2581 L 0 .218 .741 r
F
.25 g
.20019 .28411 m
.20261 .28642 L
s
.10159 .59614 m
.23134 .51328 L
s
.25218 .23501 m .46886 .52562 L .46212 .52639 L 0 .218 .741 r
F
1 0 0 r
.003 w
.4534 .52573 m
.46212 .52639 L
s
.25 g
.5 Mabswid
.46143 .52561 m
.46212 .52639 L
s
.46033 .52437 m
.46143 .52561 L
s
.45994 .52392 m
.46033 .52437 L
s
0 g
.006 w
.77642 .78018 m
.78799 .75255 L
s
.1059 .66584 m
.11161 .69683 L
s
.47898 .1627 m .48412 .50749 L .44463 .16328 L 0 0 .111 r
F
.47898 .1627 m .4846 .50608 L .48412 .50749 L F
.5132 .16534 m .4846 .50608 L .47898 .1627 L 0 0 .003 r
F
.5132 .16534 m .48477 .50607 L .4846 .50608 L F
.54702 .17118 m .48477 .50607 L .5132 .16534 L 0 0 .21 r
F
0 g
.47898 .1627 m
.5132 .16534 L
s
.44463 .16328 m .48329 .51004 L .41045 .1671 L 0 0 .231 r
F
.44463 .16328 m .48412 .50749 L .48329 .51004 L F
0 g
.44463 .16328 m
.47898 .1627 L
s
.25 g
.5 Mabswid
.44463 .16328 m
.44484 .16505 L
s
.54702 .17118 m .48464 .5076 L .48477 .50607 L 0 0 .21 r
F
.58013 .1802 m .48464 .5076 L .54702 .17118 L .893 .853 .401 r
F
0 g
.006 w
.5132 .16534 m
.54702 .17118 L
s
.78608 .35958 m .48681 .55742 L .4832 .55304 L .687 .979 .884 r
F
.25 g
.5 Mabswid
.50327 .56095 m
.50342 .56089 L
s
.49251 .56045 m
.49504 .55908 L
s
.80058 .39346 m .48681 .55742 L .78608 .35958 L .609 .953 .898 r
F
1 0 0 r
.003 w
.48681 .55742 m
.49251 .56045 L
s
.25 g
.5 Mabswid
.80054 .39348 m
.80058 .39346 L
s
.79829 .3947 m
.80054 .39348 L
s
.79722 .39528 m
.79829 .3947 L
s
.41045 .1671 m .48204 .51336 L .37672 .17419 L 0 0 .346 r
F
.41045 .1671 m .48329 .51004 L .48204 .51336 L F
0 g
.006 w
.41045 .1671 m
.44463 .16328 L
s
.25 g
.5 Mabswid
.41045 .1671 m
.41093 .16936 L
s
.58013 .1802 m .48421 .51067 L .48464 .5076 L .893 .853 .401 r
F
.25 g
.48681 .55742 m
.49208 .55393 L
s
.61227 .19235 m .48421 .51067 L .58013 .1802 L .883 .895 .474 r
F
0 g
.006 w
.54702 .17118 m
.58013 .1802 L
s
.25 g
.5 Mabswid
.51179 .18227 m
.5132 .16534 L
s
.54575 .17803 m
.54702 .17118 L
s
.37672 .17419 m .48021 .51703 L .34374 .18454 L 0 0 .45 r
F
.37672 .17419 m .48204 .51336 L .48021 .51703 L F
0 g
.006 w
.37672 .17419 m
.41045 .1671 L
s
.25 g
.5 Mabswid
.37672 .17419 m
.37733 .17615 L
s
.37733 .17615 m
.3775 .17669 L
s
.61227 .19235 m .48351 .51517 L .48421 .51067 L .883 .895 .474 r
F
.64314 .20761 m .48351 .51517 L .61227 .19235 L .884 .936 .563 r
F
.25 g
.57876 .18494 m
.58013 .1802 L
s
0 g
.006 w
.58013 .1802 m
.61227 .19235 L
s
.25 g
.5 Mabswid
.47898 .1627 m
.47917 .17431 L
s
.60894 .20069 m
.61227 .19235 L
s
0 g
.006 w
.10176 .63257 m
.1059 .66584 L
s
.78799 .75255 m
.79881 .72215 L
s
.34374 .18454 m .47759 .52059 L .31179 .19816 L 0 0 .542 r
F
.25 g
.5 Mabswid
.2251 .2581 m
.22629 .25945 L
s
.34374 .18454 m .48021 .51703 L .47759 .52059 L 0 0 .542 r
F
0 g
.006 w
.34374 .18454 m
.37672 .17419 L
s
.25 g
.5 Mabswid
.34374 .18454 m
.3441 .18543 L
s
.3441 .18543 m
.34465 .18677 L
s
.34465 .18677 m
.34481 .18717 L
s
.47899 .51406 m
.47916 .51447 L
s
.47916 .51447 m
.47964 .51564 L
s
.47964 .51564 m
.48021 .51703 L
s
.28117 .215 m .46886 .52562 L .25218 .23501 L 0 .141 .686 r
F
.25 g
.25318 .23635 m
.25399 .23744 L
s
.25218 .23501 m
.25318 .23635 L
s
.22629 .25945 m
.2273 .26059 L
s
.10187 .56016 m
.26594 .50075 L
s
.28117 .215 m .47391 .52358 L .46886 .52562 L 0 .141 .686 r
F
1 0 0 r
.003 w
.46212 .52639 m
.46886 .52562 L
s
.25 g
.5 Mabswid
.46799 .52444 m
.46886 .52562 L
s
.46714 .52331 m
.46799 .52444 L
s
.46689 .52297 m
.46714 .52331 L
s
.64314 .20761 m .48262 .52084 L .48351 .51517 L .884 .936 .563 r
F
.67245 .22592 m .48262 .52084 L .64314 .20761 L .877 .967 .644 r
F
.25 g
.57868 .18521 m
.57876 .18494 L
s
0 g
.006 w
.61227 .19235 m
.64314 .20761 L
s
.31179 .19816 m .47391 .52358 L .28117 .215 L 0 .056 .62 r
F
.25 g
.5 Mabswid
.25399 .23744 m
.25413 .23762 L
s
.10463 .52337 m
.30421 .49539 L
s
.31179 .19816 m .47759 .52059 L .47391 .52358 L 0 .056 .62 r
F
0 g
.006 w
.31179 .19816 m
.34374 .18454 L
s
.25 g
.5 Mabswid
.11008 .48631 m
.3442 .49726 L
s
.11835 .44953 m
.37229 .50319 L
s
.12953 .41354 m
.3926 .50883 L
s
.18031 .31492 m
.43997 .52161 L
s
.16059 .34583 m
.42655 .51838 L
s
.14363 .37883 m
.41075 .51402 L
s
.2273 .26059 m
.45994 .52392 L
s
.20261 .28642 m
.45104 .52348 L
s
.34481 .18717 m
.47899 .51406 L
s
.25413 .23762 m
.46689 .52297 L
s
1 0 0 r
.003 w
.46886 .52562 m
.47391 .52358 L
s
.25 g
.5 Mabswid
.31179 .19816 m
.31237 .19929 L
s
.31237 .19929 m
.31301 .20054 L
s
.31301 .20054 m
.31317 .20084 L
s
.31317 .20084 m
.47615 .51779 L
s
.47615 .51779 m
.47616 .5178 L
s
.47616 .5178 m
.47651 .51849 L
s
.47651 .51849 m
.47731 .52004 L
s
.47731 .52004 m
.47759 .52059 L
s
0 g
.006 w
.28117 .215 m
.31179 .19816 L
s
.67245 .22592 m .48168 .52733 L .48262 .52084 L .877 .967 .644 r
F
.69991 .24721 m .48168 .52733 L .67245 .22592 L .86 .987 .713 r
F
.25 g
.5 Mabswid
.64125 .2113 m
.64314 .20761 L
s
0 g
.006 w
.64314 .20761 m
.67245 .22592 L
s
.25 g
.5 Mabswid
.66065 .24456 m
.67245 .22592 L
s
.4729 .52196 m
.47391 .52358 L
s
.47231 .52101 m
.4729 .52196 L
s
.47219 .52083 m
.47231 .52101 L
s
.28117 .215 m
.28197 .21627 L
s
.28197 .21627 m
.2827 .21744 L
s
.2827 .21744 m
.28284 .21768 L
s
.28284 .21768 m
.47219 .52083 L
s
0 g
.006 w
.25218 .23501 m
.28117 .215 L
s
.09954 .59745 m
.10176 .63257 L
s
.69991 .24721 m .48094 .53424 L .48168 .52733 L .86 .987 .713 r
F
.72526 .27138 m .48094 .53424 L .69991 .24721 L .833 .997 .771 r
F
.25 g
.5 Mabswid
.61799 .25669 m
.64114 .21151 L
s
.64114 .21151 m
.64125 .2113 L
s
0 g
.006 w
.67245 .22592 m
.69991 .24721 L
s
.25 g
.5 Mabswid
.69394 .25504 m
.69991 .24721 L
s
0 g
.006 w
.79881 .72215 m
.80844 .68931 L
s
.2251 .2581 m
.25218 .23501 L
s
.76857 .32776 m .4832 .55304 L .4813 .5475 L .748 .994 .857 r
F
.25 g
.5 Mabswid
.49504 .55908 m
.49527 .55896 L
s
.78608 .35958 m .4832 .55304 L .76857 .32776 L .687 .979 .884 r
F
1 0 0 r
.003 w
.4832 .55304 m
.48681 .55742 L
s
.25 g
.5 Mabswid
.4832 .55304 m
.49013 .54757 L
s
.786 .35963 m
.78608 .35958 L
s
.78383 .36107 m
.786 .35963 L
s
.7828 .36174 m
.78383 .36107 L
s
.72526 .27138 m .48068 .54111 L .48094 .53424 L .833 .997 .771 r
F
.74823 .29828 m .48068 .54111 L .72526 .27138 L .796 .999 .819 r
F
.25 g
.66251 .29624 m
.69394 .25504 L
s
0 g
.006 w
.69991 .24721 m
.72526 .27138 L
s
.25 g
.5 Mabswid
.72453 .27219 m
.72507 .27159 L
s
.6995 .29979 m
.72453 .27219 L
s
.72507 .27159 m
.72526 .27138 L
s
0 g
.006 w
.20019 .28411 m
.2251 .2581 L
s
.09954 .59745 m
.09957 .56099 L
s
1 0 0 r
.003 w
.47391 .52358 m
.47759 .52059 L
s
0 g
.006 w
.17771 .31285 m
.20019 .28411 L
s
.80844 .68931 m
.81647 .65442 L
s
.74823 .29828 m .4813 .5475 L .48068 .54111 L .796 .999 .819 r
F
.25 g
.5 Mabswid
.48068 .54111 m
.481 .54075 L
s
.3775 .17669 m
.48108 .51026 L
s
.48108 .51026 m
.48111 .51037 L
s
.76857 .32776 m .4813 .5475 L .74823 .29828 L .748 .994 .857 r
F
1 0 0 r
.003 w
.4813 .5475 m
.4832 .55304 L
s
.25 g
.5 Mabswid
.48213 .53267 m
.4832 .53127 L
s
.48094 .53424 m
.48213 .53267 L
s
.48168 .52733 m
.48308 .52512 L
s
.41093 .16936 m
.48258 .50669 L
s
.48258 .50669 m
.48265 .50702 L
s
.48265 .50702 m
.48286 .50802 L
s
.48183 .51269 m
.48204 .51336 L
s
.48134 .51112 m
.48183 .51269 L
s
.48111 .51037 m
.48134 .51112 L
s
.48286 .50802 m
.48326 .50988 L
s
.48326 .50988 m
.48329 .51004 L
s
.48411 .50748 m
.48412 .50749 L
s
.48388 .50543 m
.48411 .50748 L
s
.48375 .50428 m
.48388 .50543 L
s
.48464 .5076 m
.48469 .50734 L
s
.48458 .50471 m
.4846 .50608 L
s
.49527 .55896 m
.79722 .39528 L
s
.50342 .56089 m
.80857 .43052 L
s
.48477 .50607 m
.51179 .18227 L
s
.51415 .56151 m
.8168 .46707 L
s
.52757 .56101 m
.82192 .5045 L
s
.48469 .50734 m
.54575 .17803 L
s
.49208 .55393 m
.7828 .36174 L
s
.48456 .50384 m
.48458 .50471 L
s
.48421 .51067 m
.48476 .50878 L
s
.48476 .50878 m
.57868 .18521 L
s
.48455 .50303 m
.48456 .50384 L
s
.48351 .51517 m
.4844 .51294 L
s
.48499 .51146 m
.60894 .20069 L
s
.4844 .51294 m
.48499 .51146 L
s
.48454 .50235 m
.48455 .50303 L
s
.47917 .17431 m
.48454 .50235 L
s
.4837 .50382 m
.48375 .50428 L
s
.48262 .52084 m
.48384 .51846 L
s
.48384 .51846 m
.48454 .51709 L
s
.48533 .51555 m
.61799 .25669 L
s
.48454 .51709 m
.48533 .51555 L
s
.44484 .16505 m
.4837 .50382 L
s
.60591 .33105 m
.66065 .24456 L
s
.48308 .52512 m
.48397 .52372 L
s
.48582 .5208 m
.60591 .33105 L
s
.48397 .52372 m
.48582 .5208 L
s
.4832 .53127 m
.48415 .53002 L
s
.48649 .52695 m
.66251 .29624 L
s
.48415 .53002 m
.48649 .52695 L
s
.49013 .54757 m
.75938 .33501 L
s
.481 .54075 m
.4822 .53943 L
s
.4822 .53943 m
.48328 .53824 L
s
.4874 .5337 m
.6995 .29979 L
s
.48328 .53824 m
.4874 .5337 L
s
0 g
.006 w
.72526 .27138 m
.74823 .29828 L
s
.25 g
.5 Mabswid
.73094 .31443 m
.74615 .30023 L
s
.69169 .35107 m
.73094 .31443 L
s
.4813 .5475 m
.4821 .54676 L
s
.48859 .5407 m
.69169 .35107 L
s
.48328 .54565 m
.48859 .5407 L
s
.4821 .54676 m
.48328 .54565 L
s
.74615 .30023 m
.74807 .29843 L
s
.74807 .29843 m
.74823 .29828 L
s
.76845 .32786 m
.76857 .32776 L
s
.76639 .32948 m
.76845 .32786 L
s
.76543 .33024 m
.76639 .32948 L
s
.75938 .33501 m
.76543 .33024 L
s
0 g
.006 w
.74823 .29828 m
.76857 .32776 L
s
.09957 .56099 m
.10212 .52372 L
s
.15786 .34406 m
.17771 .31285 L
s
.76857 .32776 m
.78608 .35958 L
s
.14082 .37741 m
.15786 .34406 L
s
1 0 0 r
.003 w
.48068 .54111 m
.4813 .5475 L
s
0 g
.006 w
.10212 .52372 m
.1074 .48619 L
s
.81647 .65442 m
.82249 .61794 L
s
.78608 .35958 m
.80058 .39346 L
s
.1267 .41252 m
.14082 .37741 L
s
.1074 .48619 m
.11557 .44894 L
s
.11557 .44894 m
.1267 .41252 L
s
1 0 0 r
.003 w
.47759 .52059 m
.48021 .51703 L
s
0 g
.006 w
.82249 .61794 m
.82614 .58034 L
s
.80058 .39346 m
.81195 .42907 L
s
.81195 .42907 m
.82014 .46602 L
s
.82614 .58034 m
.82711 .54215 L
s
.82014 .46602 m
.82517 .50387 L
s
.82517 .50387 m
.82711 .54215 L
s
1 0 0 r
.003 w
.48068 .54111 m
.48094 .53424 L
s
.481 .51544 m
.48204 .51336 L
s
.48021 .51703 m
.481 .51544 L
s
.48094 .53424 m
.48168 .52733 L
s
.48256 .51197 m
.48329 .51004 L
s
.48204 .51336 m
.48256 .51197 L
s
.48168 .52733 m
.48262 .52084 L
s
.48363 .50901 m
.48412 .50749 L
s
.48329 .51004 m
.48363 .50901 L
s
.48262 .52084 m
.48351 .51517 L
s
.48431 .50692 m
.4846 .50608 L
s
.48412 .50749 m
.48431 .50692 L
s
.48351 .51517 m
.48421 .51067 L
s
.48467 .50608 m
.48477 .50607 L
s
.4846 .50608 m
.48467 .50608 L
s
.48421 .51067 m
.48464 .5076 L
s
.48464 .5076 m
.48477 .50607 L
s
0 g
.25 Mabswid
.15213 0 m
.04127 .1616 L
s
.04127 .1616 m
1 .2591 L
s
1 .2591 m
.86642 .07429 L
s
.86642 .07429 m
.15213 0 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.063, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004:000181000`40O003h00Oogoo2goo000XOol5
003MOol002Moo`8000Aoo`X00==oo`009goo0P003Woo2P00bGoo000VOol00`00Ool0000HOol:002o
Ool002Eoo`04001oogoo000ROol:002eOol002Aoo`05001oogooOol0000/Ool:002[Ool002Aoo`05
001oogooOol0000fOol:002QOol002=oo`03001oogoo009oo`03001oogoo03ioo`X009Moo`008Woo
00<007ooOol00Woo00<007ooOol0BGoo2P00SGoo000ROol00`00Oomoo`02Ool00`00Oomoo`1COol:
0023Ool0025oo`03001oogoo00=oo`03001oogoo05eoo`X007Uoo`0087oo00<007ooOol017oo00<0
07ooOol0Igoo2P00Kgoo000OOol00`00Oomoo`05Ool00`00Oomoo`1aOol:001UOol001moo`03001o
ogoo00Eoo`03001oogoo07]oo`X005]oo`007Woo00<007ooOol01Woo00<007ooOol0QGoo2P00DGoo
000MOol00`00Oomoo`07Ool00`00Oomoo`2?Ool:0017Ool001eoo`03001oogoo00Moo`03001oogoo
09Uoo`X003eoo`0077oo00<007ooOol027oo00<007ooOol0Xgoo2P00<goo000KOol00`00Oomoo`09
Ool00`00Oomoo`2]Ool:000YOol001Yoo`03001oogoo00Yoo`03001oogoo0;Moo`D002Aoo`006Woo
00<007ooOol02Woo00<007ooOol0^goo0P008goo000IOol00`00Oomoo`0;Ool00`00Oomoo`2kOol2
000SOol001Qoo`03001oogoo00aoo`03001oogoo0;]oo`03001oo`00029oo`0067oo00<007ooOol0
37oo00<007ooOol0^Woo00D007ooOomoo`00025oo`005goo00<007ooOol037oo00<007ooOol0^goo
00<007ooOol00Woo00<007ooOol07Woo000FOol00`00Oomoo`0=Ool00`00Oomoo`2kOol00`00Oomo
o`02Ool00`00Oomoo`0NOol001Eoo`03001oogoo00ioo`03001oogoo0;]oo`03001oogoo00=oo`03
001oogoo01eoo`005Goo00<007ooOol03Woo00<007ooOol0^goo00<007ooOol017oo00<007ooOol0
77oo000DOol00`00Oomoo`0?Ool00`00Oomoo`2kOol00`00Oomoo`05Ool00`00Oomoo`0KOol001=o
o`03001oogoo011oo`03001oogoo0;Yoo`03001oogoo00Ioo`03001oogoo01]oo`004goo00<007oo
Ool047oo00<007ooOol0^Woo00<007ooOol01goo00<007ooOol06Woo000BOol00`00Oomoo`0AOol0
0`00Oomoo`2jOol00`00Oomoo`08Ool00`00Oomoo`0IOol0015oo`03001oogoo019oo`03001oogoo
0;Yoo`03001oogoo00Uoo`03001oogoo01Qoo`0047oo00<007ooOol04goo00<007ooOol0^Woo00<0
07ooOol02Goo00<007ooOol067oo000@Ool00`00Oomoo`0COol00`00Oomoo`2jOol00`00Oomoo`0:
Ool00`00Oomoo`0GOol000moo`03001oogoo01Aoo`03001oogoo0;Uoo`03001oogoo00aoo`03001o
ogoo01Ioo`003Woo00<007ooOol05Goo00<007ooOol0^Goo00<007ooOol037oo00<007ooOol05Woo
000>Ool00`00Oomoo`0EOol00`00Oomoo`2iOol00`00Oomoo`0=Ool00`00Oomoo`0EOol000eoo`03
001oogoo01Ioo`03001oogoo0;Uoo`03001oogoo00ioo`03001oogoo01Aoo`0037oo00<007ooOol0
5goo00<007ooOol0^Goo00<007ooOol03goo00<007ooOol04goo000;Ool00`00Oomoo`0GOol00`00
Oomoo`2jOol00`00Oomoo`0?Ool00`00Oomoo`0COol000]oo`03001oogoo01Moo`03001oogoo0;Yo
o`03001oogoo011oo`03001oogoo019oo`002Woo1@005Woo00<007ooOol0^Goo00<007ooOol04Woo
00<007ooOol04Goo000:Ool00`00Oomoo`02Ool:000<Ool00`00Oomoo`19Ool400000acW00000006
00000acW0000000700000acW001oo`1FOol00`00Oomoo`0COol00`00Oomoo`0@Ool000Yoo`03001o
ogoo00aoo`X0009oo`03001oogoo049oo`8000037>L000000080000>00H01`0600LLi`0300800`02
00<00P03008Li`T000037>L01@0000<005=oo`03001oogoo01=oo`03001oogoo011oo`002Woo00<0
07ooOol05Woo2P00>Goo10000P0:00<Li`0700H00P0600l01`0600H01QcW00800`0200<00P030080
0`007>L0200000<Li`0600D00`060P0000<Li`000000CWoo00<007ooOol057oo00<007ooOol03goo
000:Ool00`00Oomoo`0HOol00`00Oomoo`05Ool:000[Ool200000acW00002P0500X051cW00H01`06
00L01P0700H01acW00<00P0300800`0200<00P007>L7000031cW00H01@0600D01P0500H01AcWKd]c
K0@004Yoo`03001oogoo01Eoo`03001oogoo00ioo`002Woo00<007ooOol067oo00<007ooOol03goo
2@007Woo100000<03@0:7>L0200:00<Li`0600L00`0600d01`067>L00P0300800`0200<00P03000L
i`0700000acW00D01P0200H02`0500H01P067>McK6m<Lfa_C7=/Kd`01000AWoo00<007ooOol05Woo
00<007ooOol03Goo000:Ool00`00Oomoo`0HOol00`00Oomoo`0HOol:000@Ool40000200>00d03P0=
00h03@0:7>L700X04acW00L01P0700H01`0600L01QcW00800`0200<00P03008001cW00L0000D7>L0
1P0500H01@0600D01Vm;7>M_Bg=/Kd]cK6m;Lfa_Bg=/7>McS`8004=oo`03001oogoo01Moo`03001o
ogoo00eoo`002Woo00<007ooOol067oo00<007ooOol08Woo2P0017oo0P0000@041cW00d03P<03@05
00h03@0=00XLi`0700X01AcW00H01P0600L00`0600/01acW00<00P0300800`0200<001cW00L00004
7>L01P0600D300H03005Lf`Lig=/KdacK6m<Lfa_C7=/KhhLi`=_SP80045oo`03001oogoo01Qoo`03
001oogoo00aoo`002Woo00<007ooOol067oo00<007ooOol0;7oo2P0000P03P0=00h03@0>00d02QcW
1`0:01<Li`0700H01`0600L01P0700HLi`0200<00P0300800`02000Li`07000061cW00H01@0600D0
1P0500HLig=/Kd]cK6m;Lfa_Bg=/Kd]cSacWLhi_SW>?KhicSP8003moo`03001oogoo01Uoo`03001o
ogoo00]oo`002Woo00<007ooOol067oo00<007ooOol0;7oo0P001P0@00<Li`0=00002@001@0:00<L
i`0600L00`0600d01`0600HLi`0300800`0200<00P03000Li`0700000acW00D01P0200H03@0500H0
1QcWKdacK6m<Lfa_C7=/KdacK1cW00Q_SP8003eoo`03001oogoo01Yoo`03001oogoo00Yoo`002Woo
00<007ooOol067oo00<007ooOol0:Woo0P0001@04@0@0140400A01004@0@7>L03@0>00d03P0=00h0
3@0>00XLi`0:2@0000l01P0700H01`067>L00P0300800`0200<00P007>L01`0001`Li`0600D01P05
00H01@067>McK6m;Lfa_Bg=/Kd]cK6m;7>M_SW>?KhicSVn>Lhm_SW>>7>Mc/@8003]oo`03001oogoo
01Yoo`03001oogoo00Yoo`002Woo00<007ooOol067oo00<007ooOol0:7oo0P000QcW2@0@00DLi`0=
00d03@0>00<03@0300XLi`0:00H02P037>L01P0600X0000500<00P03000Li`07000011cW00H01P05
0`0600/01AcWKdacK6m<Lfa_C7=/Kda_SQcW00Q_SP047>M_/FnaKk42000iOol00`00Oomoo`0KOol0
0`00Oomoo`09Ool000Uoo`03001oogoo01Uoo`03001oogoo02Moo`0H0000<`0b03<041cW01004@0@
0140400A01004AcW00h03@0>00d03P0=00h02QcW1`0:00dLi`0600L01P0700H01`067>L00P030080
0`0<000081cW00H01@0600D01P05Lf`Lig=/Kd]cK6m;Lfa_Bg=/KhhLifn>Lhi_SW>?KhicSVn>LhlL
ig>aKk5c/FnaLk42000gOol00`00Oomoo`0LOol00`00Oomoo`08Ool000Uoo`03001oogoo01Uoo`03
001oogoo02Eoo`8000D0<`037>L0400@00H040037>L03@0>00<03@0500h03@0=00XLi`0600X00acW
00L01P0200H03@0700H01QcW00<00P0300800`0200<001cW00l000097>M_C7=/KdacK6m<Lfa_C1cW
00Q_SP037>M_/Fna00I_/@8003Aoo`03001oogoo01eoo`03001oogoo00Qoo`002Goo00<007ooOol0
67oo00<007ooOol097oo0P0001/0<P0c0380<`0b03<0<P0A7>L04@0@0140400A01004@0@7>L03@0>
00d03P0=00h03@0:7>L01`0:014Li`0700H01`0600L01P077>L00`0200<00P03008001cW00H00009
7>L01@0600D01P0500H01AcW00X0000BKhicSfn>Lhi_SW>?KhhLifnaLk5_/G>aKk5c/FnaLk4LifoD
0P00<Woo00<007ooOol07Woo00<007ooOol01goo0009Ool00`00Oomoo`0HOol00`00Oomoo`0SOol0
0`0003<0<`0803<00acW01004006010011cW00d03@0>0`0=00<03P0:7>L01`0:00<Li`0600L00`06
00/01`067>L00P0300800`0200<001cW00H000057>L01P0600H01@0300H02acWLfa_C7=/KdacK6m<
Lfa_SQcWKhh02P001Fna00DLifoDKm=_e6oC0080031oo`03001oogoo01moo`03001oogoo00Ioo`00
2Goo00<007ooOol067oo00<007ooOol08Goo0P0001l0UAcW03<0<P0c0380<`0b03<0<P0c010Li`0@
0140400A01004@0@014Li`0>00d03P0=00h03@0>00XLi`0600X04AcW00L01P0700H01`0600LLi`03
00800`0200<00P007>L01P0001dLi`0500H01@0600D01P057>M_Bg=/Kd]cK6m;Lfa_BacWKhicSfn>
Lhi_SW>?KhicSQcWLk5_/G>a00T00003KmA_dfoD008002ioo`03001oogoo021oo`03001oogoo00Eo
o`002Goo00<007ooOol067oo00<007ooOol087oo00D0002E09D0UAcW00X0<`037>L0400@00H04005
7>L03@0=00d03P0300d00`0:7>L02P0500X01AcW00H01P0600L00`0600TLi`0200<00P0300800`00
7>L01P0000<Li`0600D00`0600/01G=/7>McK6m<Lfa_C7=/KdacK1cW00Q_SP037>M_/Fna00E_/@05
7>M_dfoDKm=_e00:000YOol00`00Oomoo`0POol00`00Oomoo`05Ool000Uoo`03001oogoo01Qoo`03
001oogoo01ioo`800080U@0P09@0U@2E7>L0<P0c0380<`0b03<0<P0c03804AcW0140400A01004@0@
014Li`0>00d03P0=00h03@0>00XLi`H02P0A7>L01`0600L01P0700H01acW00<00P0300800`02000L
i`060000;QcW00D01P0500H01@06Kd/Lifm;Lfa_Bg=/Kd]cK6n>7>M_SW>>KhicSfn>Lhi_SQcWKk5c
/FnaLk5_/G>aKk5c/AcWKmA_dfoDKm=_e6oCKmA_dfoD7>M_mP000Woo2P007goo00<007ooOol08Goo
00<007ooOol017oo0009Ool00`00Oomoo`0HOol00`00Oomoo`0LOol2000809D00acW03<0<`0703<0
0acW0100400601000acW00h03@0200d01@0>00d03@0:7>L01P0:00<Li`0700H00P0600/01`067>L0
0P0300800`0200<001cW00H000057>L01P0600H01@0200H02AcWKdacK6m<Lfa_C7=/Kd`Li`08Khh0
0acWKk5_/@05Kk403acWKmA_dfoDKm=_e6oCKmA_dfoDKm<Lif_fKoH0000;Ool:000DOol00`00Oomo
o`0SOol00`00Oomoo`03Ool000Uoo`03001oogoo01Qoo`03001oogoo01]oo`03000Li`2E0080U@0S
09@0U@2E09D0U02E7>L0<`0b03<0<P0c0380<`0b03<041cW01004@0@0140400A010Li`0=00h03@0>
00d03P0=00XLi`0600X041cW00H01`0600L01P077>L00`0200<00P03008001cW1P0002lLi`0500H0
1@0600D01QcWLfa_Bg=/Kd]cK6m;Lf`Lig>>KhicSfn>Lhi_SW>?7>Mc/FnaLk5_/G>aKk5c/Fna7>M_
dfoDKm=_e6oCKmA_dfoDKm<Lif_eKoI[mFof008001=oo`X000Yoo`03001oogoo02Aoo`03001oogoo
009oo`002Goo00<007ooOol067oo00<007ooOol06Woo00<0003G7>L02P2E00<Li`0c03<01`0c00<L
i`0@01001P0@00<Li`0=00h00`0=00<03P0:7>L01P0:00@Li`0600H01`<01P097>L00P0300800`02
00<001cW00H000037>L01P0500<01P0:00DLifm<Lfa_C7=/KdacK6n>7>L7Khh00acWKk5_/@05Kk40
4acWKm=_e6oCKmA_dfoDKm=_e6oCKoHLifofJoI_mV_fKoI[mP0001aoo`T00003Ool007oo02Eoo`03
001oogoo009oo`002Goo00<007ooOol067oo00<007ooOol06Goo00H0003F0=L0eQcW09@309D08@2D
09D0U@2E09@Li`0b03<0<P0c0380<`0b03<0<P0A7>L04@0@0140400A01004AcW00h03@0>00d03P0=
00hLi`0600X041cW00H01`0600L01P0700HLi`0200<00P03008001cW1P0003<Li`0500H01@0600D0
1QcWLfa_Bg=/Kd]cK6m;LhhLig>?KhicSVn>Lhm_SW>>7>Mc/FnaLk5_/G>aKk5c/AcWKmA_dfoDKm=_
e6oCKmA_dfoD7>M_mV_eKoI[mFofJoE_mV_e000097oo2P007goo00<007ooOol00Goo0009Ool00`00
Oomoo`0HOol00`00Oomoo`0GOol200020=L00`3F0=LLi`0:09D00acW03<0<`0703<00acW01004005
01001AcW00d03@0=00h00`0=00<02QcW00X0100:00<Li`0700H00P0600/01`0600HLi`0300800`02
00<001cW00H0000?7>L01P0600H01@06Kd`Lifm<Lfa_C7=/KdacK1cW00M_SP037>M_/Fna00E_/@0F
7>M_e6oCKmA_dfoDKm=_e6oCKm@LifofJoI_mV_fKoI[mVofJoI_mV_f000TOol00`00Oomoo`06Ool:
000FOol10001Ool1Ool000Uoo`03001oogoo01Qoo`03001oogoo01Ioo`0;0000e`3F0=L0eP3G0=H0
eacW09D0U00309D0802D09D0U@2E09@Li`0b03<0<P0c0380<`0b03<041cW01004@0@0140400A010L
i`0=00h03@0>00d03P0:7>L600X03acW00L01P0700H01`067>L00P0300800`0200<Li`060000=AcW
00D01P0500H01G=/7>McK6m;Lfa_Bg=/Kd/Lifn>Lhi_SW>?KhicSVn>7>M_/G>aKk5c/FnaLk5_/AcW
Km=_e6oCKmA_dfoDKm=_e6oC7>M[mFofJoE_mV_eKoI[mFofJoDLifOg00008goo00<007ooOol047oo
2P003Goo0@000Goo0009Ool00`00Oomoo`0HOol00`00Oomoo`0EOol01@000=L0e`3G0=H00`3G00<0
eP3G7>L02@2E00<Li`0c03<01`0c00<Li`0@01001@0@00<Li`0>00d00P0=00@03P0=00dLi`H02P03
7>L01P0700<01P0900LLi`0300800`0200<00QcW00D000047>L01P0600D300H02AcWLfa_C7=/Kdac
K6m<KhhLi`06Khh00acWKk5_/@05Kk405QcWKm=_e6oCKmA_dfoDKm=_e6oC7>M[mVofJoI_mV_fKoI[
mVofJoHLifOg0V_h00<007ooOol07goo00<007ooOol06goo2P000goo0@000Goo0009Ool00`00Oomo
o`0HOol00`00Oomoo`0DOol03`000=L0eP3G0=H0e`3F0=L0eP3G0=H0eacW09D0U00309D07`2D09D0
U@2E7>L0<`0b03<0<P0c0380<`0b014Li`0A01004@0@0140400A7>L03P0=00h03@0>00d02QcW00D0
2P0?7>L01`0600L01P0700HLi`0200<00P0300800acW00D0000g7>L01P0500H01@0600DLifm;Lfa_
Bg=/Kd]cK1cWLhi_SW>?KhicSVn>LhlLig>aKk5c/FnaLk5_/G>a7>M_e6oCKmA_dfoDKm=_e6oC7>M[
mFofJoE_mV_eKoI[mFofJoDLifOgJoQWmf_hIoL00P007goo00<007ooOol09Goo1@000009Ool00`00
Oomoo`0HOol00`00Oomoo`0COol01@000APLi`3G0=H00`3G00H0eP3G0=L0e`3F7>L:09D00acW03<0
<`0603<00acW0100400501000acW00d03P0300d00`0>00XLi`0500X01AcW00H01P0600L00P0600PL
i`0300800`0200<00QcW1@0000<Li`0500H00P0600X01@067>McK6m<Lfa_C7=/Kd`Li`M_SP037>M_
/Fna00A_/@0E7>M_e6oCKmA_dfoDKm=_e6oCKm@LifofJoI_mV_fKoI[mVofJoI_mQcW00=[n005IoM[
n6_hJoP0000NOol00`00Oomoo`0YOol1000000Uoo`03001oogoo01Qoo`03001oogoo019oo`0@0001
604H0APLi`3G0=H0e`3F0=L0eP3G0=H0e`3F7>L209D01@2D09D0U@2E09@00P2E01XLi`0b03<0<P0c
0380<`0b03<041cW01004@0@0140400A7>L03P0=00h03@0>00d02QcW1@0:00lLi`0700H01`0600L0
1QcW00800`0200<00P037>L01@0003/Li`0600D01P0500H01AcWKd]cK6m;Lfa_Bg>>7>McSfn>Lhi_
SW>?KhhLifnaLk5_/G>aKk5c/Fna7>M_dfoDKm=_e6oCKmA_dfoD7>M_mV_eKoI[mFofJoE_mV_eKoHL
if_hIoM[n6OgJoQWmf_hIoM[n00001eoo`03001oogoo02Uoo`4000002Goo00<007ooOol067oo00<0
07ooOol04Goo00<0004H0AP00`4H00<Li`3G0=H00`3G00H0eP3G0=L0e`3F7>L909D00acW03<0<`06
03<00acW01004005010011cW00d03@0>0`0=00<02QcW00X0100:00<Li`0700H00P0600T01acW00<0
0P0300800`027>L01@0000@Li`0600H01@801P09Lf`Lig=/KdacK6m<Lfa_SQcW00I_SP037>M_/Fna
00A_/@0D7>M_dfoDKm=_e6oCKmA_dfoD7>M_mV_fKoI[mVofJoI_mV_fKoHLi`=[n005IoM[n6_hJoQW
m`03JoP00`00Oomoo`0JOol00`00Oomoo`0XOol10001Ool000Uoo`03001oogoo01Moo`03001oogoo
019oo`030001604H00@1600<7>L0e`3F0=L0eP3G0=H0e`3F0=L0eQcW0P2E0200U02E09D0U@2D09DL
i`0c0380<`0b03<0<P0c03804AcW0140400A01004@0@7>L03@0>00d03P0=00h02QcW1@0:00hLi`06
00L01P0700H01acW00<00P0300800acW1@0003dLi`0600D01P0500HLig=/Kd]cK6m;Lfa_BacWKhic
SVn>Lhm_SW>>7>Mc/FnaLk5_/G>aKk5c/AcWKmA_dfoDKm=_e6oCKmA_dacWJoE_mV_eKoI[mFofJoE_
mQcWJoQWmf_hIoM[n6OgJoQWmf_hIoM[n6?i7>L0000KOol00`00Oomoo`0XOol10001Ool000Uoo`03
001oogoo01Moo`03001oogoo015oo`030001604H00D160040=LLi`3G0=H30=L01@3F0=L0e`3G7>L0
2@2E00<Li`0c03<01P0c00<Li`0@01001@0@00PLi`0=00d03@0>00d02QcW1@0:00@Li`0600H01`<0
1P077>L00P0300800`027>L01@0000<Li`0500H00P0600T01AcWKdacK6m<Lfa_C7=/7>L01Vn>00<L
ifnaKk4016na01@LifoDKm=_e6oCKmA_dfoDKm<Lif_fKoI[mVofJoI_mV_fKoI[mQcW0V_h00EWmf_h
JoQ[n6Og00=[n005HoTLif?iIoT0000JOol00`00Oomoo`0XOol10001Ool000Uoo`03001oogoo01Mo
o`03001oogoo011oo`030001604H00L1600<7>L0eP3G0=H0e`3F0=L0eP3G0=H0eacW0`2E01h0U02E
09D0U@2D09DLi`0c0380<`0b03<0<P0c010Li`0@0140400A01004AcW00h03@0>00d03P0=7>L500X0
3QcW00H01`0600L01P077>L00`0200<00P037>L50000?QcW00H01@0600D01QcWLfa_Bg=/Kd]cK6n>
7>M_SW>?KhicSVn>LhlLig>aKk5c/FnaLk5_/AcWKm=_e6oCKmA_dfoDKm<Lif_eKoI[mFofJoE_mV_e
KoI[mAcWIoM[n6OgJoQWmf_hIoM[n6OgJoQSnAcWHoUWnV?i000IOol00`00Oomoo`0YOol10001Ool0
00Uoo`03001oogoo01Moo`03001oogoo00moo`030001604H00T160047>L0e`3G0=H30=L01@3F0=L0
e`3G7>L0202E00<Li`0c03<01P0c00<Li`0@0100100@00<Li`0=00h00`0=00<03P0:7>L01@0:00dL
i`0600H01P0700HLi`0200<00P03008Li`05000011cW00H01P050P0600LLifm<Lfa_C7=/Kd`Li`06
Khh00acWKk5_/@04Kk404acWKm=_e6oCKmA_dfoDKm=_e1cWKoI[mVofJoI_mV_fKoI[mQcW009[n005
IoM[n6_hJoQWm`03JoP016?i7>MSnFOi0f?i00<007ooOol05Woo00<007ooOol0:Goo0@000Goo0008
Ool00`00Oomoo`0HOol00`00Oomoo`0>Ool00`000ETLi`0;0AP031cW0=H0e`3F0=L0eP3G0=H0e`3F
0=LLi`<0U@0M09@0U@2E09D0U1cW0380<`0b03<0<P0c03804AcW0140400A01004@0@7>L03@0>00d0
3P0=00XLi`0500X03AcW00L01P0700H01acW00<00P0300800acW00D000107>L01P0500H01G=/7>Mc
K6m;Lfa_Bg=/7>McSfn>Lhi_SW>?KhhLifnaLk5_/G>aKk5c/AcWKmA_dfoDKm=_e6oCKm@LifofJoE_
mV_eKoI[mFofJoDLifOgJoQWmf_hIoM[n6OgJoQWmf_hHoTLif?iIoYSnFOiHoUWnV?i000GOol00`00
Oomoo`0YOol10001Ool000Qoo`03001oogoo01Qoo`03001oogoo00eoo`050001F@5I0ETLi`0;0AP0
11cW0=L0e`3F0`3G00@0eP3G0=LLi`T0U@037>L0<`0c00D0<`037>L0400@00@040047>L03@0=00h3
00d00acW00X02P0300X00acW00H01`0300H01acW00800`0200<00QcW00D000037>L01@0600801P08
7>McK6m<Lfa_C7=/KhhLi`E_SP037>M_/Fna00A_/@0E7>M_e6oCKmA_dfoDKm=_e6oC7>M[mVofJoI_
mV_fKoI[mVof7>M[n6Og00=[n008IoM[n6_hJoQWmacWHoUWn@=Sn@05IoUSnF?iHoT0000FOol00`00
Oomoo`0XOol10001Ool1Ool000Qoo`03001oogoo01Qoo`03001oogoo00aoo`030001F@5J00<1F@03
7>L1604H00T1600<7>L0eP3G0=H0e`3F0=L0eP3G0=HLi`2D0`2E01`0U02E09D0UAcW03<0<P0c0380
<`0b03<041cW01004@0@0140400A7>L03P0=00h03@0>00XLi`@02P0=7>L01`0600L01P077>L00`02
00<00P037>L01@00044Li`0600D01P057>M_Bg=/Kd]cK6m;7>M_SW>>KhicSfn>LhhLig>aKk5c/Fna
Lk5_/AcWKm=_e6oCKmA_dfoDKm<Lif_eKoI[mFofJoE_mV_eKoHLif_hIoM[n6OgJoQWmf_hIoM[n6Og
7>MSnFOjHoUWnF?iIoYSnFOiHoUWnP0001Ioo`03001oogoo02Qoo`40005oo`5oo`0027oo00<007oo
Ool067oo00<007ooOol037oo00<0005I0ET0105I00<Li`4H0AP02@4H00@Li`3G0=L0eP<0e`040=H0
e`3G7>L809D00acW03<0<`0503<00acW01004004010021cW00d03@0=00h03@0:7>L400X03AcW00H0
1P0600L01QcW00800`0200<00QcW00@0000=7>L01P0600H01@067>McK6m<Lfa_C7=/7>L01Vn>00<L
ifnaKk400fna01@LifoCKmA_dfoDKm=_e6oC7>M[mVofJoI_mV_fKoI[mVof7>M[n6Og0f_h00QWmf_h
JoQ[n6Og7>MSnFOi0f?i00QWnF?iHoUSnFOiHoTLi`005Goo00<007ooOol0:7oo0@000Goo0Goo0008
Ool00`00Oomoo`0HOol00`00Oomoo`0;Ool00`000EX1F@020ET01@5J0ET1F@5I7>L02`4H00`Li`3F
0=L0eP3G0=H0e`3F0=L0eQcW09@309D06P2D09D0UAcW0380<`0b03<0<P0c03804AcW0140400A0100
4AcW00h03@0>00d03P0=7>L500X031cW00H01`0600L00QcW00800`0200<Li`@000147>L01@0600D0
1P057>M_Bg=/Kd]cK6m;7>M_SW>?KhicSVn>7>M_/G>aKk5c/FnaLk4LifoDKm=_e6oCKmA_dfoD7>M_
mV_eKoI[mFofJoE_mQcWJoQWmf_hIoM[n6OgJoQWmf_hIoLLif?iIoYSnFOiHoUWnV?iIoUSnFOjHoTL
ie_jGo/001=oo`03001oogoo02Uoo`40005oo`5oo`0027oo00<007ooOol067oo00<007ooOol02Woo
00<0005I0ET0205I00<Li`4H0AP02@4H00@Li`3G0=L0eP<0e`030=H0eacW00P0U@037>L0<`0c00D0
<`037>L0400@00@040037>L03P0=00803@0300h02QcW00@02P037>L01`0600801P0700LLi`030080
0`027>L0100000<Li`0600D00`0600LLig=/KdacK6m<KhhLi`05Khh00acWKk5_/@03Kk404acWKmA_
dfoDKm=_e6oCKm@LifofJoI_mV_fKoI[mVofJoHLifOg00=[n008IoM[n6_hJoQWmacWHoUWn@=Sn@0;
IoUSnF?iHoUWnF?i7>MOnUokGoX0000COol00`00Oomoo`0YOol10001Ool1Ool000Qoo`03001oogoo
01Qoo`03001oogoo00Uoo`030001FP5I0081F@050EX1F@5I0ET1FP030ET00acW0AP160080AP03AcW
0=L0eP3G0=H0e`3F0=L0eP3G7>L0U@2D00<0U@0I09@0U@2E7>L0<P0c0380<`0b03<041cW01004@0@
014041cW00d03P0=00h03@0:7>L0100:00`Li`0600L01P0700HLi`0200<00P037>L40000AAcW00D0
1P0500I_BacWKd]cK6m;Lf`Lig>?KhicSVn>LhlLig>aKk5c/FnaLk5_/AcWKm=_e6oCKmA_dfoD7>M_
mV_eKoI[mFofJoE_mV_e7>MWmf_hIoM[n6OgJoQWmf_hIoLLif?iIoYSnFOiHoUWnV?iIoUSnFOjHoTL
ie_jGo]OnUokFoX0000BOol00`00Oomoo`0XOol00`00Oomoo`01Ool000Qoo`03001oogoo01Qoo`03
001oogoo00Qoo`03000Li`5I00`1F@037>L1604H00P160057>L0e`3G0=L0eP030=L00`3F0=LLi`07
09D00acW03<0<`0503<00acW0100400401000acW00d03P0300d00acW00X02P0200X011cW00H01P07
0P0600HLi`0300800`027>L4000031cW00H01P0600DLifm<Lfa_C7=/Kd`Li`E_SP037>M_/Fna00=_
/@0B7>M_dfoDKm=_e6oCKmA_dacWJoI_mV_fKoI[mVofJoHLifOg0f_h00QWmf_hJoQ[n6Og7>MSnFOi
0f?i00UWnF?iHoUSnFOiHoTLieojGo/00eoj00=Oneoj00004Goo00<007ooOol0:7oo00<007ooOol0
0Goo0008Ool00`00Oomoo`0HOol00`00Oomoo`08Ool01@000GTLi`5I0EX00`5I00D1FP5I0ET1F@5J
00<1F@037>L1604H00P1600=7>L0e`3F0=L0eP3G0=H0e`3F0=LLi`2E09@00`2E01P0U02E7>L0<`0b
03<0<P0c03804AcW0140400A01004AcW00h03@0>00d03P0:7>L300X031cW00H01`0600L01QcW0080
0`0200<Li`@000177>L01@0600D01QcWLfa_Bg=/Kd]cSacWLhi_SW>?KhicSQcWLk5_/G>aKk5c/AcW
KmA_dfoDKm=_e6oC7>M[mFofJoE_mV_eKoI[mAcWIoM[n6OgJoQWmf_hIoM[n6Og7>MSnFOjHoUWnF?i
IoYSnFOiHoUWnV?i7>MKnUokGoYOne_jGo]OnUokFoX0000@Ool00`00Oomoo`0XOol00`00Oomoo`01
Ool000Qoo`03001oogoo01Qoo`03001oogoo00Moo`040001VP6J0IX27>L<0ET00acW0AP160080AP0
1AcW0=L0e`3G0=H00`3G00<0eQcW09D01`2E00<Li`0c03<0100c00<Li`0@01000`0@00PLi`0=00d0
3@0>00d02QcW100:00/Li`0600H01P077>L00`0200<00QcW00@000037>L01P0500801P067>M_C7=/
KdacK1cW1Fn>00<LifnaKk400fna014LifoDKm=_e6oCKmA_dacWJoI_mV_fKoI[mVofJoI_mQcW00=[
n008IoM[n6_hJoQWmf?i7>MWn@=Sn@09IoUSnF?iHoUWnF?i7>MOnUok00=OnP06Go]OnUojGoYOn`00
47oo00<007ooOol0:7oo00<007ooOol00Goo0008Ool00`00Oomoo`0HOol00`00Oomoo`06Ool02@00
0GT1VP5i0IX1N@6J7>L1FP030ET01@5J0ET1F@5I0EX00`5I0QcW2@4H00XLi`3G0=H0e`3F0=L0eP3G
0=HLi`80U@0J09@0U@2E09D0U1cW0380<`0b03<0<P0c010Li`0@0140400A010Li`0=00h03@0>00XL
i`@02P0;7>L01`0600L01QcW00800`0200<Li`040000B1cW00D01P0500HLig=/Kd]cK6m;7>M_SW>?
KhicSVn>7>M_/G>aKk5c/Fna7>M_dfoDKm=_e6oCKm@LifofJoE_mV_eKoI[mFof7>M[n6OgJoQWmf_h
IoM[n6OgIoTLifOjHoUWnF?iIoYSnFOiHoUWnV?i7>MKnUokGoYOne_jGo]OnUokFoYOneojGo/000io
o`03001oogoo02Uoo`03001oogoo005oo`0027oo00<007ooOol05goo00<007ooOol01goo00<0006J
0IX01@6J00<Li`5I0ET02`5I00<Li`4H0AP01`4H00DLi`3G0=L0e`3F00<0e`030=HLi`2E00H0U@03
7>L0<`0c00@0<`037>L0400@00<040037>L03P0=00803@0300hLi`0:00<02P037>L01P0700801P06
7>L00`0200<00QcW100000/Li`0600H01Vm<7>M_C7=/KdacK1cW00A_SP037>M_/Fna00=_/@0@7>M_
dfoDKm=_e6oCKm@LifofJoI_mV_fKoI[mVof7>L3JoP026OgJoQ[n6_hIoM[n1cWIoT3HoT02FOiHoUS
nF?iIoUSnAcWGoYOn`03GoX01EokGoYOnUojGo/00Uoj0QcW00<007ooOol02goo00<007ooOol0:Goo
00<007ooOol00Goo0008Ool00`00Oomoo`0GOol00`00Oomoo`06Ool030000IX1N@6J0GT1VP5i0IX1
N@6J7>L1FP<1F@050EX1F@5I0ET1FP030ET00`5J7>L160080AP02QcW0=L0eP3G0=H0e`3F0=L0eQcW
0P2E01T0U02E09D0U@2D7>L0<P0c0380<`0b014Li`0A01004@0@014Li`0>00d03P0=00XLi`0300X0
2acW00L01P0700H00acW00<00P037>L0100004TLi`0500H01AcWKd]cK6m;Lfa_SQcWKhicSVn>LhlL
ig>aKk5c/FnaLk4LifoDKm=_e6oCKm@LifofJoE_mV_eKoI[mFof7>M[n6OgJoQWmf_hIoM[n6OgJoPL
ifOjHoUWnF?iIoYSnFOiHoUWnV?i7>MKnUokGoYOne_jGo]OnUokFoYOneojGo/LieOlEm/0000=Ool0
0`00Oomoo`0XOol00`00Oomoo`02Ool000Qoo`03001oogoo01Moo`03001oogoo00Eoo`030001VP6J
00T1VP8Li``1F@037>L1604H00L160057>L0e`3G0=L0eP030=L00acW09D0U@0509D00acW03<0<`04
03<00acW0100400301000acW00d03P0200d00`0:7>L02P0300X02QcW00H01P0700HLi`0200<00QcW
100000XLi`0600D01QcWLfa_C7=/Kd`Li`E_SP037>M_/Fna009_/@0@7>M_e6oCKmA_dfoDKm<Lif_f
KoI[mVofJoI_mV_f7>L2JoP026OgJoQ[n6_hIoM[n1cWIoT3HoT02FOiHoUSnF?iIoUSnAcWGoYOn`03
GoX03EokGoYOnUojGo]OnUOk7>MGneOKEo]Gf`0000aoo`03001oogoo02Qoo`03001oogoo009oo`00
27oo00<007ooOol05goo00<007ooOol01Goo00l0005i0IX1N@6J0GT1VP5i0IX1N@6J0GT1VP5i7>L0
0`5I00D1FP5I0ET1F@5J00<1F@030EXLi`4H00P160097>L0e`3F0=L0eP3G0=H0eacW00<0U@0G09@0
U@2E09DLi`0c0380<`0b03<041cW01004@0@014Li`0>00d03P0=00hLi`0400X02acW00H01`0600LL
i`0300800`007>L00`00048Li`0500H01AcWKd]cK6m;Lf`Lig>>KhicSfn>7>M_/G>aKk5c/Fna7>M_
dfoDKm=_e6oC7>M[mFofJoE_mV_eKoI[mAcWIoM[n6OgJoQWmf_hIoM[n1cWIoYSnFOiHoUWnV?iIoUS
nFOjHoTLie_jGo]OnUokFoYOneojGo]KnUokGoX27>L01UOlEm]Go5?KEo`000aoo`03001oogoo02Qo
o`03001oogoo009oo`0027oo00<007ooOol05goo00<007ooOol017oo00<001cW0IX03@6J00<Li`5I
0ET02P5I00<Li`4H0AP01P4H00<Li`3F0=L00P3G00D0eP3G0=L0eacW00H0U@037>L0<`0c00@0<`03
7>L0400@00<040077>L03@0=00h03@0:7>L00`0:00<Li`0700H00P0600HLi`0200<00P007>L20000
0acW00D01P0200H01QcWLfa_C7=/Kd`Li`A_SP037>M_/Fna009_/@0?7>M_dfoDKm=_e6oC7>M[mVof
JoI_mV_fKoI[mQcW009[n008IoM[n6_hJoQWmf_h7>MWn@=Sn@09IoUSnF?iHoUWnF?i7>MOnUok00=O
nP0@Go]OnUojGoYOneoj7>MGfeOkEm]GneOKEo]GfeOk000;Ool00`00Oomoo`0XOol00`00Oomoo`02
Ool000Qoo`03001oogoo01Moo`03001oogoo00Aoo`0B0001VQcW7>L1N@6J0GT1VP5i0IX1N@6J0GT1
VP5i0IX1NAcW0`5I00D1FP5I0ET1F@5J00<1F@030EXLi`4H00L1600:7>L0eP3G0=H0e`3F0=L0eP3G
7>L309D05P2D09D0UAcW0380<`0b03<0<P0A7>L04@0@014041cW00d03P0=00h02QcW0`0:00/Li`06
00L01P077>L00`0200<001cW0080001<7>L01P0500H01AcWKd]cK6m;7>M_SW>?KhicSQcWLk5_/G>a
Kk5c/AcWKmA_dfoDKm=_e1cWKoI[mFofJoE_mV_e7>MWmf_hIoM[n6OgJoQWmf_h7>MWnV?iIoUSnFOj
HoUWnF?iIoYSnAcWFoYOneojGo]KnUokGoYOne_jGo]OnQcWDm]Go5OKEoaCfeOlEm]Go5?K000;Ool0
0`00Oomoo`0XOol00`00Oomoo`02Ool000Qoo`03001oogoo01Moo`03001oogoo00=oo`060001^P6j
0KX1VQcW3@6J0QcW2`5I00<Li`4H0AP01P4H00<Li`3F0=L00P3G00@0eP3G0=LLi`L0U@037>L0<`0c
00<0<`037>L0400@00<040067>L03@0=00d03QcW0`0:00/Li`0600H01`067>L00P03008001cW0080
000:7>L01P0600EcK1cWLfa_C7=/7>L4Khh00acWKk5_/@02Kk403QcWKmA_dfoDKm=_e1cWKoI[mVof
JoI_mV_f7>L2JoP026OgJoQ[n6_hIoM[n1cWIoT3HoT02FOiHoUSnF?iIoUSnAcWGoYOn`03GoX04eok
GoYOnUojGo]GfacWEm]GneOKEo]GfeOkEm]GneOKEo]Gf`0000Uoo`03001oogoo02Uoo`03001oogoo
009oo`0027oo00<007ooOol05goo00<007ooOol00goo00H0006i0KX1^@6j0GT27>L03P6J0GT1VP5i
0IX1N@6J0GT1VP5i0IX1N@6J7>L20ET01@5J0ET1F@5I0EX00`5I00<1FQcW0AP01`4H00XLi`3F0=L0
eP3G0=H0e`3F7>L0U0<0U@0E09@0UAcW03<0<P0c0380<`0@7>L0400A01004AcW00h03@0>00d02QcW
00<02P0:7>L01`0600LLi`0300800`007>L20000?QcW00H01@067>McK6m;Lfa_BacWKhicSVn>7>M_
/G>aKk5c/Fna7>M_dfoDKm=_e6oC7>M[mFofJoE_mV_eKoHLif_hIoM[n6OgJoQWmf_h7>MWnV?iIoUS
nFOjHoUWnF?iIoYSnAcWFoYOneojGo]KnUokGoYOne_jGo/27>L03E?KEoaGfeOlDm]Go5OKEoaCfeOl
Em]Go00000Uoo`03001oogoo02Qoo`03001oogoo00=oo`0027oo00<007ooOol05goo00<007ooOol0
0Woo00<0006j0KX01@6j00<1VQcW0IX0306J00<Li`5I0ET02@5I00<Li`4H0AP01P4H00<Li`3F0=L0
0P3G00@0eP3G0=LLi`H0U@037>L0<`0c00<0<`03010Li`0@00<040067>L03P0=00d02QcW0`0:00XL
i`0600H01QcW00800`02000Li`8000097>L01@0600HLifm<Lfa_C1cW00A_SP037>M_/Fna009_/@0@
7>M_dfoDKm=_e6oC7>M[mVofJoI_mV_fKoHLif_hIoL3JoP016OgJoQSnAcW0f?i00UWnF?iHoUSnFOi
HoTLieojGo/00eoj01IOneojGoYOnUok7>MGneOKEo]GfeOkEm]GneOKEo]GfeOkEm]GneOK7>L000Qo
o`03001oogoo02Qoo`03001oogoo00=oo`0027oo00<007ooOol05goo00<007ooOol00Woo00X0006j
0KT1^P6i0KX1^@6j0KT1^P8Li`0=0GT1VP5i0IX1N@6J0GT1VP5i0IX1N@6J7>L00P5I00D1FP5I0ET1
F@5J00<1F@030EXLi`4H00L1600:7>L0eP3G0=H0e`3F0=L0eQcW09@309D04`2D09DLi`0c0380<`0b
03<Li`0A01004@0@7>L03@0>00d03QcW00<02P0:7>L01`0600LLi`0300800`007>L20000BQcW00H0
1@067>McK6m;Lf`Lig>>KhicSfn>7>M_/G>aKk5c/AcWKmA_dfoDKm<Lif_eKoI[mFofJoE_mQcWJoQW
mf_hIoM[n6OgJoQSnAcWHoUWnF?iIoYSnFOiHoUWnV?i7>MKnUokGoYOne_jGo]OnUokFoYOnacWEoaC
feOlEm]Go5?KEoaGfeOlDm]Go5OKEo`27>L00d^k001oo`07Ool00`00Oomoo`0XOol00`00Oomoo`03
Ool000Qoo`03001oogoo01Moo`05001oogooOol0000;0KX00`6J7>LLi`0;0IX27>L:0ET00acW0AP1
60060AP00acW0=H0e`020=L00`3F0=LLi`0609D00acW03<0<`0303<00`0@7>L0400201001QcW00d0
3@0>00dLi`<02P037>L01P0700801P057>L00`02000Li`0200002AcW00H01P057>M_C7=/Kd`Li`03
Khh00acWKk5_/@02Kk403acWKmA_dfoDKm=_e1cWKoI[mVofJoI_mQcWJoQWm`03JoP016OgJoQ[n1cW
0f?i00UWnF?iHoUSnFOiHoTLieojGo/00eoj01IOneojGoYOnUOk7>MGneOKEo]GfeOkEm]GneOKEo]G
feOkEm]GnacWCma;f`9;g003001oogoo00Eoo`03001oogoo02Qoo`03001oogoo00=oo`001goo00<0
07ooOol067oo02<007ooOomoo`000KT1^P6i0KX1^@6j0KT1^P6i0KX1^@6j0KT1VQcW0IX1N@6J0GT1
VP5i0IX1N@6J0GT1VP5i7>L1F@5J00<1F@060EX1F@5I0ET1FQcW204H00XLi`3F0=L0eP3G0=H0eacW
09D0U0<0U@0B09@Li`0b03<0<P0c038Li`0@0140400A7>L03P0=00h02QcW0P0:00XLi`0700H01`06
7>L00P03000Li`80000i7>L01P05Lf`Lig=/Kd]cK1cWLhm_SW>>7>Mc/FnaLk5_/AcWKm=_e6oCKm@L
ifofJoE_mV_eKoI[mAcWIoM[n6OgJoQWmf_hIoLLif?iIoUSnFOjHoUWnF?iIoYSnAcWFoYOneojGo]K
nUokGoYOne_j008Li`0<EoaCfeOlEm]Go5?KEoaGfeOlDm]Go5OK0QcW00I?g4^kCma;^doL0007Ool0
0`00Oomoo`0XOol00`00Oomoo`03Ool000Moo`03001oogoo01Qoo`04001oogoo000?0KX00`6J7>LL
i`0;0IX00acW0ET1F@080ET00acW0AP160060AP00acW0=H0e`020=L00`3F0=LLi`0509D00acW03<0
<`0303<00`0@7>L0400201001QcW00d03@0=00XLi`<02P097>L01P0600LLi`03008001cW00800008
7>L01@067>McK6m<Lf`Li`=_SP037>M_/Fna009_/@0>7>M_dfoDKm=_e1cWKoI[mVofJoI_mV_f7>MW
m`=[n004IoM[n6_h7>L3HoT01FOiHoUSnF?iIoT00QcW00=OnUokGoX00Uoj01IOneojGoYOnQcWEm]G
neOKEo]GfeOkEm]GneOKEo]GfeOkEm/Lid_LCma;f`9;g004Cma;fd_L0005Ool00`00Oomoo`0XOol0
0`00Oomoo`04Ool000Moo`03001oogoo01Qoo`0U001oogoo000Li`6i0KX1^@6j0KT1^P6i0KX1^@6j
0KT1^P6i0KX1^@6j0GTLi`5i0IX1N@6J0GT1VP5i0IX1N@6J0GTLi`5I0EX00`5I00H1FP5I0ET1F@5J
7>L70AP02acW0=L0eP3G0=H0e`3F0=LLi`2E09@00`2E010Li`0c0380<`0b03<Li`0A01004@0@7>L0
3@0>00dLi`<02P097>L01P0700HLi`0200<001cW008000147>L01P057>M_Bg=/Kd/Lifn>Lhi_SQcW
Kk5c/FnaLk4LifoDKm=_e6oC7>M[mFofJoE_mV_e7>MWmf_hIoM[n6OgJoQWmacWHoUWnF?iIoYSnFOi
HoUWnQcWGo]KnUokGoYOne_jGo]OnUokFoXLieOKEoaCfeOlEm]Go5?KEoaGfeOlDm]Go08Li`0:Bk]?
g4^kCma;^doLBk]?g4^k0005Ool00`00Oomoo`0XOol00`00Oomoo`04Ool000Moo`03001oogoo01Qo
o`05001oogoo0001^@027>L?0KX00`6J7>LLi`0:0IX27>L90ET00acW0AP160050AP00acW0=L0eP03
0=L00`3F7>L0U@0509D00acW03<0<`0203<00`0@7>L0400201001QcW00h03@0=00XLi`802P097>L0
1`0600HLi`03008001cW008000087>L01P067>McK6m<Lf`Li`=_SP0A7>M_/FnaKk4LifoDKm=_e6oC
7>M[mVofJoI_mV_f7>MWm`03JoP016OgJoQ[n1cW0f?i00IWnF?iHoUSnFOi7>L2GoX01EokGoYOnUoj
Go/00Uoj0QcW00eGfeOkEm]GneOKEo]GfeOkEm]GneOKEo/Li`02Bm`01ToLBm];g4_LCma;f`9;g003
Cma;f`0000Aoo`03001oogoo02Qoo`03001oogoo00Aoo`001goo00<007ooOol067oo00L007oo0001
^06i0KP1^@027>L07P6i0KX1^@6j0KT1^P6i0KX1^@6j0KT1^P6i0KX1^@6J7>L1VP5i0IX1N@6J0GT1
VP5i0IX1N@6J7>L1FP<1F@060EX1F@5I0ET1FQcW1`4H00PLi`3G0=H0e`3F0=L0eQcW0P2E01<0U02E
09DLi`0b03<0<P0c038Li`0@014041cW00d03P0=00XLi`0200X02AcW00H01`067>L00P03000Li`02
0000@AcW00H01AcWKd]cK1cWLhi_SW>?7>Mc/FnaLk4LifoDKm=_e6oCKm@LifofJoE_mV_eKoHLif_h
IoM[n6OgJoQWmacWHoUWnF?iIoYSnFOiHoUWnQcWGo]KnUokGoYOne_jGo]OnUok7>MGo5OKEoaCfeOl
Em]Go5?KEoaGfeOlDm/00QcW00i?g4^kCma;^doLBk]?g4^kCma;^doLBk]?g00017oo00<007ooOol0
:7oo00<007ooOol017oo0007Ool00`00Oomoo`0GOol01000Oomoo`001P6i0QcW3`6j0QcW2P6J00<L
i`5I0ET01`5I00<Li`4H0AP01@4H00<Li`3G0=H00`3G00<0eQcW09D0102E00<Li`0c03<00P0c00<0
41cW01000P0@00DLi`0=00h03AcW00802P097>L01P0600LLi`03008001cW008000077>L01@067>Mc
K6m<7>L00fn>010LifnaKk5_/AcWKm=_e6oCKm@LifofJoI_mV_fKoHLi`=[n004IoM[n6_h7>L3HoT0
1VOiHoUSnF?iIoTLi`9OnP05Go]OnUojGoYOn`02GoX03acWEo]GfeOkEm]GneOKEo]GfeOkEm]GneOK
7>M;f`02Bm`01ToLBm];g4_LCma;f`9;g006Cma;fd_LBma?g0000goo00<007ooOol0:7oo00<007oo
Ool017oo0007Ool00`00Oomoo`0GOol03000Ool0006i0KP1^@6h0KT1^06i0KP1^@8Li`0L0KT1^P6i
0KX1^@6j0KT1^P6i0KX1^@6j0KT1^P5i7>L1N@6J0GT1VP5i0IX1N@6J0GT1VQcW0EX30ET01P5J0ET1
F@5I0EXLi`L160087>L0e`3F0=L0eP3G0=HLi`80U@0B09@0U@2E7>L0<P0c0380<acW0140400A7>L0
3P0=00h02QcW0P0:04PLi`0700HLi`0200<001cW000Li`0500I_BacWKd]cK1cWLhm_SQcWKk5c/Fna
7>M_dfoDKm=_e1cWKoI[mFofJoE_mQcWJoQWmf_hIoM[n6Og7>MSnFOiHoUWnV?iIoUSnFOj7>MOne_j
Go]OnUokFoYOneojGo/LieOlEm]Go5?KEoaGfeOlDm]Go5OKEo`27>L04T^kCma;^doLBk]?g4^kCma;
^doLBk]?g4^kCma;^doL7>L000=oo`03001oogoo02Qoo`03001oogoo00Aoo`001goo00<007ooOol0
5goo00<007oo00002`6i0QcW3P6j0QcW2@6J0QcW205I00<Li`4H0AP01@4H00<Li`3G0=H00`3G00<L
i`2E09D00`2E00<Li`0c03<00P0c00<041cW01000P0@00DLi`0=00d02QcW00802P0:7>L01P06008L
i`02000Li`007>L200H01AcWKdacK6m<7>L00Vn>00lLifnaKk5_/AcWKmA_dfoDKm<Lif_fKoI[mVof
7>L00f_h00EWmf_hJoQWnAcW009Sn@06IoUSnF?iHoUWnAcW0Uoj00IOneojGoYOnUokGoX27>L03UOk
Em]GneOKEo]GfeOkEm]GneOKEo/LidoLBm/2Bm`01ToLBm];g4_LCma;f`9;g004Cma;fd_LBm`27>L0
1CnL001oogoo0000:Woo00<007ooOol01Goo0007Ool00`00Oomoo`0GOol200003P6h0KT1^06i0KP1
^@6h0KT1^06i0KP1^@6h0KT27>L06P6i0KX1^@6j0KT1^P6i0KX1^@6j0KT1^P6i0IXLi`6J0GT1VP5i
0IX1N@6J0GT1VP5i7>L30ET01P5J0ET1F@5I0EXLi`L160077>L0e`3F0=L0eP3G7>L00`2E0100U02E
7>L0<`0b03<0<QcW01004@0@7>L03@0>00dLi`802P157>L01`0600LLi`03000Li`007>L01@067>Mc
K6m;7>M_SW>>KhhLifnaLk4LifoDKm=_e6oC7>M[mFofJoE_mQcWJoQWmf_hIoM[n6OgIoXLifOiHoUW
nV?iIoUSnFOj7>MOne_jGo]OnUokFoYOneoj7>MCfeOlEm]Go5?KEoaGfeOlDm]Go5OK008Li`0?Cma;
^doLBk]?g4^kCma;^doLBk]?g4^kCma;^doL008Li`07?i/oW3nK@i`007oo0000:Woo00<007ooOol0
1Goo0007Ool00`00Oomoo`0GOol2000@0KT27>L=0KX27>L90IX00acW0ET1F@060ET27>L60AP00acW
0=L0eP030=L00acW09D0U@0209D00acW03<0<`0203<01P0@7>L0400@7>L03P803@0C00XLi`0:7>L0
1P0700HLi`02000Li`007>L01P057>M_C7=/7>L00Vn>00lLifnaKk5_/AcWKm=_e6oC7>M[mVofJoI_
mV_f7>L00V_h00EWmf_hJoQ[n1cW009Sn@06IoUSnF?iHoUWnAcW0Uoj01IOneojGoYOnUokGoXLieOK
Eo]GfeOkEm]GneOKEo]GfeOkEm/Lid_LCma;f`9;g006Cma;fd_LBma?g4_K0T_L00e?g4_K7>LLicnL
?i/oW3nK?i`oV`00Ool0000ZOol00`00Oomoo`05Ool000Moo`03001oogoo01Moo`0D0001^@6h0KT1
^06i0KP1^@6h0KT1^06i0KP1^@6h0KT1^06i0KP1^@8Li`0=0KT1^P6i0KX1^@6j0KT1^P6i0KX1^@6j
0GT00QcW00T1VP5i0IX1N@6J0GT1VP5i7>L00`5I00L1FP5I0ET1F@5J0ETLi`050AP021cW0=H0e`3F
0=L0eP3G7>L309D03`2D7>L0<P0c0380<acW0140400A7>L03P0=00XLi`0200X0@AcW00H01acW00<0
01cW000Li`0500HLig=/Kd/Lifn>LhlLig>aKk4LifoCKmA_dfoD7>M_mV_eKoI[mAcWIoM[n6OgJoQW
mf_h7>MWnF?iIoYSnFOiHoUWnQcWGo]KnUokGoYOne_jGo]OnQcWDm]Go5OKEoaCfeOlEm]Go5?KEo`0
0QcW00i;^doLBk]?g4^kCma;^doLBk]?g4^kCma;^doL0QcW00/oVd>L?i/oW3nK@i`oVcnL001oo`00
02Yoo`03001oogoo00Eoo`001goo00<007ooOol05goo00<001cW7>L04`6i0QcW306j00<1VQcW0IX0
1`6J0QcW205I00<Li`4H0AP00`4H00@Li`3G0=L0eP80e`037>L0U@2E00<0U@067>L0<`0c03<041cW
0P0@00DLi`0=00h03AcW00802P0>7>L01P067>L00P007>L001cW00I_C1cWKd`Li`9_SP0>7>M_/Fna
Kk4LifoDKm=_e1cWKoI[mVofJoHLi`9[n005IoM[n6_hJoPLi`02HoT01VOiHoUSnF?iIoTLi`9OnP05
Go]OnUojGoYOn`027>L02eOKEo]GfeOkEm]GneOKEo]GfeOk7>L00T_L00I?g4_KBma;g4oLBm/2Bm`0
4DoLBm];g4_LCm`LicnL?i/oW3nK?i`oVcnL?i/oW3nK?i`00P00:Woo00<007ooOol01Goo0007Ool0
0`00Oomoo`0GOol00`000KL1^0037>L04P6h0KT1^06i0KP1^@6h0KT1^06i0KP1^@6h0KT1^06i0KP1
^@8Li`0<0KT1^P6i0KX1^@6j0KT1^P6i0KX1^@6J0QcW00T1N@6J0GT1VP5i0IX1N@6J7>L00P5I00L1
FP5I0ET1F@5J0ETLi`050AP021cW0=H0e`3F0=L0eQcW09@309D03AcW03<0<P0c038Li`0@014041cW
00d03QcW00802P0n7>L01P077>L00`007>L001cW00DLifm;Lf`Lig>?KhhLifnaLk4LifoDKm=_e6_e
7>M[mFofJoDLifOgJoQWmf_hIoM[n1cWIoUSnFOjHoUWnF?iIoXLieokFoYOneojGo]KnUok7>MGo5?K
EoaGfeOlDm]Go5OKEoaCf`8Li`0>Cma;^doLBk]?g4^kCma;^doLBk]?g4^kCma;^`8Li`0<?i`oVd>L
?i/oW3nK@i`oVcnL?i]3W3nK0P00:Goo00<007ooOol01Woo0007Ool00`00Oomoo`0FOol01`000KL1
]P6g0KH1]`6i008Lia81^@8Li`/1^P030IXLi`6J00L1VP037>L1F@5I00H1F@037>L1604H00<16004
7>L0e`3G0=H20=L00acW09D0U@0209D01QcW03<0<`0c010Li`80400D7>L03@0=00XLi`0:7>L01`06
7>L00P007>L001cW00HLig=/Kd`Li`9_SP0?7>M_/Fna7>M_dfoDKm<Lif_fKoI[mVof7>M[n6Og00=[
n0047>MSnF?iIoT3HoT01FOi7>MOnUojGo/00eoj00iOnacWEo]GfeOkEm]GneOKEo]GfeOkEm/Lid_K
0T_L00I?g4_KBma;g4oLBm/2Bm`00doLBm];g0027>L03SnK?i`oVcnL?i/oW3nK?i`oVcnL?i/oW3nK
?i`2000YOol00`00Oomoo`06Ool000Moo`03001oogoo01Ioo`090001UP6g0IH1]`6F0KL1UP6i00<L
i`0A0KT1^06i0KP1^@6h0KT1^06i0KP1^@6h0KT1^06i0KP1^@027>L02`6i0KX1^@6j0KT1^P6i0KX1
^@6j0KT00QcW00L1VP5i0IX1N@6J0GT1VP027>L00`5I0EX1F@020ET00`5J0ETLi`050AP021cW0=H0
e`3F0=L0eQcW09@309D0=AcW03<0<P0c7>L04@0@7>L03@0>00dLi`0:7>L01P077>L00`027>L001cW
00DLifm;7>M_SW>>7>Mc/Fna7>M_dfoDKm<Lif_eKoI[mFof7>M[n6OgJoQWmf_h7>MWnF?iIoYSnFOi
HoT00QcW015One_jGo]OnUokFoYOnacWEoaCfeOlEm]Go5?KEoaGfeOl008Li`0=Bk]?g4^kCma;^doL
Bk]?g4^kCma;^doLBk/00QcW0193W3nK?i`oVd>L?i/oW3nK@i`oVcnL?i]3W3nK?i`oVd>L000YOol0
0`00Oomoo`06Ool000Moo`03001oogoo01Ioo`0<0001]`6f0KL1]P6g0KH1]`6f0KL1]P6i0acW406i
0QcW2P6j00<1VQcW0IX01`6J00<Li`5I0ET01@5I00<Li`4H0AP00`4H00HLi`3G0=L0eP3G7>L409D0
1QcW03<0<`0c010Li`8040047>L03@0=7>L200X031cW00H00acW00<Li`007>L01QcWLf`Li`9_SP0>
7>M_/Fna7>M_e6oCKm@LifofJoI_mQcWJoQWm`=[n0047>MSnF?iIoT3HoT01AcWGoYOnUojGo/00eoj
0QcW00aGneOKEo]GfeOkEm]GneOKEo/LidoLBm/2Bm`01ToLBm];g4_LCma;f`9;g00GCm`LiacW?i/o
W3nK?i`oVcnL?i/oW3nK?i`oVcnL?i/oW3nK?i`oVcnL?i/0000YOol00`00Oomoo`06Ool000Moo`03
001oogoo01Eoo`0@0001]`6F0KL1UP6g0IH1]`6F0KL1UP6g0IH1]`6F0KT37>L03`6i0KP1^@6h0KT1
^06i0KP1^@6h0KT1^06i0KP1^@027>L02P6i0KX1^@6j0KT1^P6i0KX1^@6j0QcW00X1N@6J0GT1VP5i
0IX1NAcW0ET1FP<1F@030EX1FAcW00D160087>L0eP3G0=H0eacW09D0U080U@147>L0<P0c038Li`0@
014Li`0>00d02QcW00XLi`0700HLi`027>L001cW00DLifm;7>M_SQcWKk5c/AcWKmA_dfoD7>M_mV_e
KoHLif_hIoM[n6OgJoPLifOiHoUWnV?iIoUSnAcWGoYOne_jGo]OnUokFoXLieOKEoaCfeOlEm]Go5?K
EoaGf`8Li`0<Cma;^doLBk]?g4^kCma;^doLBk]?g4^k0QcW01<oW3nK@i`oVcnL?i]3W3nK?i`oVd>L
?i/oW3nK@i`oVcnL?i]3W0027>L00`00Oomoo`0WOol00`00Oomoo`06Ool000Moo`03001oogoo01Eo
o`0C0001]P6g0KH1]`6f0KL1]P6g0KH1]`6f0KL1]P6g0KH1]goo0KT00acW3P6i0QcW2@6j00<1VQcW
0IX01P6J00<Li`5I0ET01@5I00<Li`4H0AP00`4H00HLi`3G0=L0eP3G7>L409D01AcW03<0<`0@7>L0
0P0@00HLi`0>00XLi`0:7>L200H011cW00<Li`000QcW00E_C7=/7>M_SQcW009_/@0:7>M_dfoD7>M_
mV_fKoHLif_hIoL3JoP011cWHoUSnFOi0f?i00DLieojGoYOnUok00=OnP0>7>MGfeOkEm]GneOKEo]G
feOkEm/Lid_LCma;f`9;g006Cma;fd_LBma?g4_K0T_L01@LicnK?i`oVcnL?i/oW3nK?i`oVcnL?i/o
W3nK?i`oVcnL?i/oW3nK0QcW00<_FbmJ0000:Goo00<007ooOol01Woo0007Ool00`00Oomoo`0EOol0
5P000KL1UP6g0IH1]`6F0KL1UP6g0IH1]`6F0KL1UP6g0IH1]`6F0KL1^06i0QcW00h1^06i0KP1^@6h
0KT1^06i0KP1^@6h0KT1^06i0QcW00T1^@6j0KT1^P6i0KX1^@6j0KT00QcW00H1VP5i0IX1N@6J0GT2
7>L01`5J0ET1F@5I0EX1FAcW00D1600J7>L0eP3G0=H0eacW09D0U02E7>L0<`0b03<Li`0A010Li`0=
00hLi`0:7>L01`067>L00P8Li`0]00HLig=/7>McSfn>7>M_/AcWKm=_e6oC7>M[mFofJoDLifOgJoQW
mf_hHoTLif?iIoYSnFOiHoTLieojGo]KnUokGoYOne_j7>MGfeOlDm]Go5OKEoaCfeOl008Li`0<Bk]?
g4^kCma;^doLBk]?g4^kCma;^doL0QcW018oVcnL?i]3W3nK?i`oVd>L?i/oW3nK@i`oVcnL?i]3W3nK
?i`27>L01RmJ;e/_FRmK;eX002Moo`03001oogoo00Moo`001goo00<007ooOol05Goo01P0006f0KL1
]P6g0KH1]`6f0KL1]P6g0KH1]`6f0KL1]P6g0KH1]`6f0KL1]P6g0KT37>L=0KT27>L80KX00`6J7>L1
VP060IX00acW0ET1F@040ET00acW0AP160020AP01QcW0=L0e`3G0=HLi`@0U@077>L0<`0c010Li`0@
7>L00P0=00L02QcW7>L01P077>L00`027>L01P057>M_C1cWKhhLi`9_/@097>M_e6oC7>M[mVofJoHL
ifOg00=[n004HoTLif?iIoT3HoT01AcWGoYOnUojGo/00Uoj0QcW00UGfeOkEm]GneOKEo]GfeOk7>L0
0T_L00I?g4_KBma;g4oLBm/2Bm`05DoLBm/LiacW?i`oVcnL?i/oW3nK?i`oVcnL?i/oW3nK?i`oVcnL
?i/oW0037>L022mK;eX_FbmJ;e/_FRmK000WOol00`00Oomoo`07Ool000Moo`03001oogoo01Aoo`0L
0001UP6g0IH1]`6F0KL1UP6g0IH1]`6F0KL1UP6g0IH1]`6F0KL1UP6g0IH1]`6F0KL1UP6g0KP37>L0
5P6h0KT1^06i0KP1^@6h0KT1^06i0KP1^AcW0KX1^@6j0KT1^P6i0KX1^@6j0QcW00P1N@6J0GT1VP5i
0IXLi`5J0`5I00<1FP5I7>L0104H00HLi`3G0=H0e`3F7>L209D04@2D7>L0<P0c038Li`0@014Li`0>
00XLi`0:7>L01QcW00800QcW02X01QcWLf`Lig>>7>Mc/AcWKmA_dfof7>M_mV_e7>MWmf_hIoM[n6Og
7>MSnFOjHoUWnF?i7>MOnUokFoYOneojGo/LieOlEm]Go5?KEoaGfeOlDm/27>L02doLBk]?g4^kCma;
^doLBk]?g4^kCm`00QcW014oVd>L?i/oW3nK@i`oVcnL?i]3W3nK?i`oVd>L?i/oW3nK008Li`0;;e/_
FRmK;eX_FbmJ;e/_FRmK;eX0000WOol00`00Oomoo`07Ool000Moo`03001oogoo01Aoo`0M000LiacW
7>L1]P6g0KH1]`6f0KL1]P6g0KH1]`6f0KL1]P6g0KH1]`6f0KL1]P6g0KH1]`6f0KL1]P020KT37>L:
0KT27>L90KX00acW0IX1VP040IX00acW0ET1F@040ET00acW0AP160020AP01QcW0=L0e`3G0=HLi`<0
U@077>L0<`0c010Li`0@7>L00P0=00HLi`0:7>L01QcW00<27>L01@067>LLifn>7>L00Vna00PLifoC
Km@LifofJoHLifOg0f_h00AWmacWHoUWn@=Sn@057>MOnUojGoYOn`02GoX02acWEo]GfeOkEm]GneOK
Eo]GfacWBm/00T_L00I?g4_KBma;g4oLBm/2Bm`27>L043nL?i/oW3nK?i`oVcnL?i/oW3nK?i`oVcnL
?i/oW3nK0acW00d_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/0000WOol00`00Oomoo`07Ool000Moo`03
001oogoo01Aoo`04000H01`00IH57>L06@6F0KL1UP6g0IH1]`6F0KL1UP6g0IH1]`6F0KL1UP6g0IH1
]`6F0KL1UP6g0IH1^@6h00<Li`090KP1^@6h0KT1^06i0KP1^@6h008Li`080KX1^@6j0KT1^P6i0KX1
^@8Li`050IX1N@6J0GT1VP027>L30ET00`5J0ETLi`040AP01QcW0=L0eP3G0=HLi`80U@0?09@Li`0b
03<Li`0A010Li`0=7>L02QcW00HLi`02008Li`0N00HLiacWKhhLifna7>M_dfoD7>M_mV_eKoHLif_h
IoM[n6Og7>MSnFOjHoUWnF?i7>MOnUokFoYOneoj0QcW00MGo5OKEoaCfeOlEm]Go0027>L074^kCma;
^doLBk]?g4^kCma;^doLBk/LicnK?i`oVd>L?i/oW3nK@i`oVcnL?i]3W3nK?i`oVd>L0QcW010_FRmK
;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FRmK;eX002Moo`03001oogoo00Moo`001Woo00<007ooOol05Goo
00@001P0600L00<H00037001]QcW00<Li`0F0KL1]P6g0KH1]`6f0KL1]P6g0KH1]`6f0KL1]P6g0KH1
]`6f0KL1]P6g0KH20KT27>L90KT27>L80KX27>L50IX00acW0ET1F@030ET00acW0AP160020AP01AcW
0=L0e`3G7>L00`2E00TLi`0c03<041cW010Li`0>00X00QcW00<01`027>L00acW00acK1cWKhhLifna
7>M_e6_f7>M[mVof7>L3JoP016Og7>MSnFOi0f?i00hLieojGoYOnUokGoXLieOKEo]GfeOkEm]GneOK
0QcW00I?g4_KBma;g4oLBm/2Bm`00doLBm];g0027>L03cnK?i`oVcnL?i/oW3nK?i`oVcnL?i/oW3nK
?i`oV`027>L04bmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FP0002Ioo`03001oogoo
00Moo`001Woo00<007ooOol057oo00h001`0600L01P0700H01`0600L01P0700H01`01AcW01D1]`6F
0KL1UP6g0IH1]`6F0KL1UP6g0IH1]`6F0KL1UP6g0IH1]bP00KT00acW00P1^@6h0KT1^06i0KP1^@6h
0QcW00l1^P6i0KX1^@6j0KT1^P5i7>L1N@6J0GT1VP5i7>L00`5I00<1FP5I7>L0104H00DLi`3G0=H0
eacW00<0U@087>L0<`0b7>L041cW00d03P8Li`0300H01acW00<Li`0_Kd/LiacWLk4LifoDKm<Lif_e
KoHLif_hIoM[n6Og7>MSnFOjHoUWnF?i7>MOnUokFoYOneoj7>MCfeOlEm]Go5?KEoaGfacWBk]?g4^k
Cma;^doLBk]?g4^kCma;^`027>L03T>L?i/oW3nK@i`oVcnL?i]3W3nK?i`oVd>L?i/37>L05BmJ;e/_
FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/0000UOol00`00Oomoo`08Ool000Ioo`03
001oogoo01Aoo`03000H01`000<H0005700H01P0600L000360001A`0600H01P070001AcW0141]`6f
0KL1]P6g0KH1]`6f0KL1]P6g0KH1]`6f0KL1]P6g0081^@<Li`L1^@8Li`L1^P8Li`@1VP037>L1F@5I
00<1F@037>L1604H008160057>L0e`3G0=LLi`0309D02acW03<041cW010Li`0=7>L02QcW00H01AcW
00U_SQcWKk4LifoC7>M[mVof7>L00f_h00AWmacWHoUWn@=Sn@0=7>MOnUojGoYOneoj7>MGfeOkEm]G
neOKEo/00QcW00=;g4oLBm/00T_L00E?g4_KBma;g4oL008Li`0>?i/oW3nK?i`oVcnL?i/oW3nK?i`o
VcnL?i/oW08Li`0E;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ008Li`03
001oogoo02=oo`03001oogoo00Qoo`001Woo00<007ooOol057oo01P001`0600L01P0700H01`0600L
01P0700H01`0600L01P0700H01`0600L01P00KL57>L04@6g0IH1]`6F0KL1UP6g0IH1]`6F0KL1UP6g
0IH1]`6h0KT00acW00H1^@6h0KT1^06i0KP27>L0306j0KT1^P6i0KX1^@6J7>L1VP5i0IX1N@8Li`81
F@030EX1FAcW00@160057>L0e`3F0=LLi`0209D021cW0380<acW014Li`0>00X27>L00`077>LLi`04
7>L046na7>M_dfoD7>M_mV_e7>MWmf_hIoLLif?iIoYSnFOi0QcW00AOnUokFoYOn`8Li`0ADm]Go5OK
EoaCfeOl7>M?g4^kCma;^doLBk]?g4^kCma;^`027>L03CnL?i]3W3nK?i`oVd>L?i/oW3nK@i`oVcnL
00<Li`0D;e/_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FP<Li`035_PJn@0002Eo
o`03001oogoo00Qoo`001Woo00<007ooOol057oo00D001P0600H01`000<H0005700H01P0600L0003
60001A`0600H01P070000aP000DL01P0600H006g00DLi`0=0KL1]P6g0KH1]`6f0KL1]P6g0KH1]`6f
@0000P6i0acW1@6i0QcW1P6j0QcW106J00<Li`5I0ET00P5I00<Li`4H0AP00P4H00@Li`3G0=LLi`<0
U@077>L0<`0@7>L041cW00d00QcW00<01QcW7>L011cW00M_/AcWKm@LifofJoHLi`02JoP016Og7>MS
nFOi0V?i00<LieokGoX00Uoj00QOnacWEo]GfeOkEm]GneOK0QcW0T_L00M?g4_KBma;g4oLBm];g002
7>L03CnK?i`oVcnL?i/oW3nK?i`oVcnL?i/oW3nK008Li`0D;e/_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ
;e/_FRmK;eX_FbmJ;e/_FP<Li`DJn003001oogoo02=oo`03001oogoo00Qoo`001Woo00<007ooOol0
4goo02<001P0700H01`0600L01P0700H01`0600L01P0700H01`0600L01P0700H01`0600L01P0700H
01`0600L01P0700H006g00@Li`0>0IH1]`6F0KL1UP6g0IH1]`6F0KL1UT000KP1^@8Li`050KP1^@6h
0KT1^0027>L0306j0KT1^P6i0KX1^AcW0GT1VP5i0IXLi`81F@030EX1FAcW00<1600>7>L0eP3G0=HL
i`2D09DLi`0c038Li`0@7>L03@8Li`0300LLiacW008Li`0fKhhLiacWKmA[mAcWJoDLifOgJoQWmfOi
7>MWnV?iIoTLieokGoYOne_jGo/LieOlDm]Go5OKEoaCfacWBk]?g4^kCma;^doLBk]?g4^kCm`Lid>L
?i/oW3nK@i`oVcnL?i]3W3nK?i`oVd>L0QcW018_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FRmK;eX_
FbmJ;e/47>L02AKh6_TFn1[i5_PJnAKh6_T0000UOol00`00Oomoo`08Ool000Ioo`03001oogoo01=o
o`04000H01P0700360001A`0600H01P070000aP000DL01P0600H01`000<H0005700H01P0600L0003
60001A`0600H01P070000aP01AcW00T1]P6g0KH1]`6f0KL1]P6g0KH00P6i0acW106i0QcW1@6j0QcW
0`6J00<Li`5I0ET00P5I00HLi`4H0AP161cW0=H20=L01QcW09D0UAcW03<0408Li`0300h02QcW00HL
i`06Kk4LifoC7>M[mQcW0V_h00AWmf?i7>MWn@9Sn@037>MOneoj009OnP07Go/LieOkEm]GneOKEo/0
0QcW00E;fd_LBma?g4_K009;g00?Cma;facW7>LoW3nK?i`oVcnL?i/oW3nK?i`oVcnL00<Li`0A;e/_
FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FRmK;eX_F`037>L<6_P00`00Oomoo`0ROol00`00Oomoo`09
Ool000Ioo`03001oogoo01=oo`03000LiacW00TLi`0P700H01`0600L01P0700H01`0600L01P0700H
01`0600L01P0700H01`0600L01P0700H01`0600L01P0700H00DLi`090IH1]`6F0KL1UP6g0IH1^@6h
00<Li`030KP1^@6h008Li`090KX1^@6j0KT1^QcW0IX1N@6J008Li`030ET1FP5I008Li`81600=7>L0
eP3G0=HLi`2D09DLi`0c7>L04AcW00h021cW015_dacWJoDLifOgJoQWmf_h7>MWnV?iIoTLieokGoYO
ne_j008Li`0?EoaCfeOlEm]Go1cWCma;^doLBk]?g4^kCma;^doL008Li`0;?i]3W3nK?i`oVd>L?i/o
W3nK@i`oV`027>L04BmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/00acW014JnAKh6_TF
n1[i5_PJnAKh6_TFn1[i5_PJnAKh6_TFn00002=oo`03001oogoo00Uoo`001Woo00<007ooOol04goo
00<002@0900022@000<H01cW7>L04QcW00<H01`060000QP000DL01P0600H01`000<H0004700H01P0
60057>L01@6f0KL1]P6g@0000P6i0acW0P6i0QcW106j0QcW0`6J00<Li`5I0ET00P5I00LLi`4H0APL
i`3F0=LLi`0209D00acW03<040027>L0100=7>LLi`030acW00]_/AcWKoHLifof7>M[n6OgJoPLifOi
009Sn@037>MOneoj009OnP067>MGfeOkEm]GneOK0QcW00I?g4_KBma;g4oLBm/2Bm`27>L02cnL?i/o
W3nK?i`oVcnL?i/oW3nK?i`00QcW010_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FRmK;eX_F`<Lia<J
n003001oogoo025oo`03001oogoo00Uoo`001Woo00<007ooOol04goo00D002@0900T02P000<T0005
:00T02@0900X000390001BP0900T02@0:0000b@000DX02@0900T02P000<T01DLi`03600LiacW00<L
i`050IH1]`6h0KT1^0037>L03P6h7>LLi`6j0KT1^P6i7>L1N@6J0GTLi`5I0EX20ET03AcW0AP161cW
0=H0eacW09D0U1cW038Li`0@00<Li`0300HLiacW008Li`0OKm@Lifof7>M[n6OgJoPLifOjHoUWnAcW
Go]OnUokFoXLieOKEoaCfeOlEm/Lid^kCma;^doLBk]?g4^kCm`00QcW00XoVcnL?i]3W3nK?i`oVd>L
?i/oW0<Li`0?;e/_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FRmK00<Li`0G6_TFn1[i5_PJnAKh6_TF
n1[i5_PJnAKh6_TFn1[i5_PJnAKh6_TFn1[i5_P0000SOol00`00Oomoo`09Ool000Ioo`03001oogoo
01=oo`03000T02@002hT00lLi`<1^@8Li`030KTLiacW00<1^P8Li`81VP037>L1F@5I0081F@077>L1
604H7>L0eP3G7>L00P2E00LLi`0@7>LLi`0:7>L01`057>L01fof7>M[n6OgJoPLifOi009Sn@037>MO
neoj009OnP057>MGfeOkEm]Gn`027>L00d_LCma;f`02Bm`03ToLBm];g1cW?i`oVcnL?i/oW3nK?i`o
VcnL?i/27>L03RmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FRmK;eX47>LI6_P00`00Oomoo`0QOol00`00
Oomoo`09Ool000Ioo`03001oogoo01=oo`03000T02P000<T0005:00T02@0900X000390001BP0900T
02@0:0000b@000DX02@0900T02P000<T0005:00T02@0900X000390000bP0900T00087>L02BP0;00X
02`0:00/02P0;00X00027>L3@0057>L00`6i7>LLi`037>L00`6j0KT1^P027>L0105i7>LLi`5J0P5I
00XLi`4H0APLi`3F0=LLi`2E7>L0<`8Li`0300dLiacW00<Li`0>JoDLiacWJoQWmf_h7>MWnV?iIoTL
ieokGoYOn`8Li`0=Em]Go5?KEo`LidoLBk]?g4^kCma;^doLBk/00QcW00Q3W3nK?i`oVd>L?i/oW3nK
0acW00d_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FP037>L07RmJ6_TFn1[i5_PJnAKh6_TFn1[i5_PJ
nAKh6_TFn1[i5_PJnAKh6_TFn1[i5_PJnAKh6_TFn1[i5_P002=oo`03001oogoo00Uoo`001Woo00<0
07ooOol04Woo00<002@0900082@01acW00P`006f0ML1]`7G0KH1ebP00QcW2BP000<Lid00@0001D00
0acW00=l01cW7>L00QcW0P6j00D1VQcW0IX1VQcW00<1F@067>L1604H7>L0eQcW0P2E00<Li`0@7>L0
1acW00I[mQcWIoM[n1cWIoT2HoT02AcWGo]OnUoj7>MGneOKEo]Gf`027>L2Bm`01DoLBm];g4_LCm`0
0QcW00PoVcnL?i/oW3nK?i`oVcnL0QcW00d_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ;e/_FP037>L00bmJ
6_PJn00J6_P37>L00`00Oomoo`0POol00`00Oomoo`0:Ool000Ioo`03001oogoo015oo`03O00002P0
00<T0005:00T02@0900X000390001BP0900T02@0:0000b@000HX02@0900T02P090087>L04C00;00L
iacW<001]P7G0KH1e`6f0ML1]P7G0KH1e`6f0ML00acW00L/02P0;00X02`0:00/00027>L6@00011cW
D61@@06i0W`00acW00L1^P6i7>LLi`6J7>L1FP020ET02AcW0APLi`3G0=HLi`2E7>L0<P027>L01@0:
7>Ml01cWKoH00QcW01MWmf_h7>MWnV?iIoTLieokGoYOnacWEoaGfeOlDm/Lid^kCma;^doLBk]?g4^k
008Li`08?i`oVd>L?i/oW3nK@i`oV`8Li`0<;e/_FRmK;eX_FbmJ;e/_FRmK;eX_FbmJ0acW01/Fn1[i
5_PJnAKh6_TFn1[i5_PJnAKh6_TFn1[i5_PJnAKh6_TFn1[i5_PJnAKh6_TFn1[i5_P01AcW10008Woo
00<007ooOol02Woo0006Ool00`00Oomoo`0AOol00g`0000T000A90087>L7<0037>L4O0003P6f0ML1
]`7G0KH1e`6g0ML1]P7G0KL1e`6f:0027>L7:0027>L5@0027>L3D603O0027>L20KX00acW0IXLi`03
0ET02AcW0APLi`3G0=HLi`2E7>L040027>L2O0037>L016OgJoPLifOi0V?i00PLieokGoYOnQcWEo]G
feOk0QcW00I;fd_LBma?g4_KBm`27>L01cnK?i`oVcnL?i/oW3nK00<Li`0;;eX_FbmJ;e/_FRmK;eX_
FbmJ;e/_FP037>LI6_P57>L9000ROol00`00Oomoo`0:Ool000Ioo`03001oogoo015oo`05EQ@002@0
900X000390001BP0900T02@0:0001acW00``02`0<00/0300;00`02`0<00/0300;0047>L00e[lE_]J
o003Ea`8O000207G0KH1e`6f0ML1]P7G0KH37>L01RP0;00X02`0:00/008Li`E000097>M@@5APD41@
H1cWG>1l01cW009l00@Li`81F@077>L161cW0=L0eQcW09D00acW0W`00QcW00UWmf_hHoTLif?iIoTL
ieokGoX00QcW00YGo5OKEo`LidoLBk]?g4^kCma;^`8Li`07@i`oVcnL?i]3W3nK?i`00QcW00X_FRmK
;eX_FbmJ;e/_FRmK;eX_F`@Li`0F5_PJnAKh6_TFn1[i5_PJnAKh6_TFn1[i5_PJnAKh6_TFn1[i5_PJ
nAKh6_T67>L>000ROol00`00Oomoo`0:Ool000Ioo`03001oogoo015oo`03COD002@0008T00PLia4`
008Li`06<00LiacWF_]Fne[k25LL15<M1G`000H1e`6f0ML1]`7G:0027>L6:0027>L4@0027>L3D600
1AcWG>1Lh5cP7>L00W`000<Lig`07>L00P5I00XLi`4H7>L0eacW09DLi`0@7>Ml00<Li`04JoQSnAcW
HoT27>L01UokGoXLieOKEo]Gf`8Li`0>Cma;fd_LBma?g4_K7>LoVcnL?i/oW3nK?i`oV`8Li`09;e/_
FRmK;eX_FbmJ;e/_FRmK00<Li`03;e/Jn1[h018Jn0DLia@0029oo`03001oogoo00Yoo`001Woo00<0
07ooOol04Woo01X001cW7>LLib`0<00/0300;00`02`0<00/0300;00`02`0<00/0300;00`02`0<00/
03000acW0SP000HLieKkF_aFne[lE_/7Ea`00e<MEaeC7@02Dad01ELMDae??T/mCch00g`000D1e`6f
0ML1]R`000<Li`06;00X02`0:01001cW1D0000DLieAPD41@H1cW00=Lh0067>MY@FE1ID5l01cW0W`0
00HLi`4H7>L0eacW09D3O0027>L04f_hIoLLif?i7>MKnUokGoXLie?KEoaGfacWBk]?g4^kCma;^doL
008Li`05?i]3W3nK?i`oV`037>L022mJ;e/_FRmK;eX_FbmJ;e/37>L04bmK5_PJnAKh6_TFn1[i5_PJ
nAKh6_TFn1[i5_PJnAKh6_TFn1[i00DLiaX0021oo`03001oogoo00]oo`001Woo00<007ooOol04Woo
00<00300<00053000acW0cP00QcW00IFne[kE_]JneKkF_/7Ea`7Dad6Cch3O0001@7G0KH1e`6g:000
0QcW12P00QcW140000@Lie1PD61@H08Li`9Lh0077>MU@FE1ID4LiffS7>L01W`000@40@@0O00Li`9[
n0057>MSnAcWGoYOn`027>L01eOKEo/LiacWBma?g4_K009;g08Li`05?i`oVcnL?i/oW0027>L022mJ
;e/_FRmK;eX_FbmJ;e/37>L00bmK6_PJn00>6_P57>LO000POol00`00Oomoo`0;Ool000Ioo`03001o
ogoo019oo`0E000`02`0<00/0300;00`02`0<00/0300;00`02`0<00/0300;00`02`0008Li`<h000;
=00LiacWF_]Fne[lE_]Jo5KkF_aFn`06Ea`01ELMDaeC7E<MEad00U<M00E;?DlnCci??T/m009??P03
Acm3?TLo00Al00030KH1ebP000<Li`03:00/02P0008Li`=0008Li`04D41@H5107>L2G>001QcWJD5U
@AcWJH9]X`<Li`0G104Li`@1100Lig`07>MWmacWHoTLie_jGo/LieOlDm]Go1cWCma;^doLBk]?g002
7>L013nK?i`oVd>L0acW00L_FbmJ;e/_FRmK;eX_F`037>L03a[i5_PJnAKh6_TFn1[i5_PJnAKh6_TF
n1[i5_PJn@057>LT000POol00`00Oomoo`0;Ool000Ioo`03001oogoo019oo`03000`030000l`00<L
i`Dh000:7>MJfU[JF]YJneKkF_]Fne[kE_/7Ea`6Dad7Cch3Acl01DLnAcm7?dLoAch00g`000<1]P7G
:0000QcW0bP00QcW0d0000DLie1PD61@H1cW009Lh0067>MU@FE17>MYXVfS0acW00h40AcW7>LLig`0
JoPLif?i7>MOnUok7>MGneOK0QcW0T_L00Q?g4_K7>LLicnL?i/oW3nK0QcW00H_FbmJ;e/_FRmK;eX4
7>L<6_P67>LY000POol00`00Oomoo`0;Ool000Ioo`03001oogoo019oo`0?000`02`0<00/0300;00`
02`0<00/0300;00`02`000<Li`8h0004=00h03P0>0027>L02U[JF_]FfU[kE_]Jo5KkF_aFne[l1ULL
0e<M00AG7E<MDaeC7@=??P0?Bce??TlnAcm3?TLoAci7?d<nAcm7?TLo=alk7cLO00=l00070KH/01cW
7>LX02`0@0000QcW0T000QcW00=@H5107>L00UcP00@LifU1ID4Li`9l000J7>L40AcW200Li`P0O00L
if?i7>MKnUok7>MGo5?K7>M;^doLBk]?g4^k7>LoVd>L?i/oW08Li`05;eX_FbmJ;e/_FP037>L02bmJ
6_TFn1[i5_PJnAKh6_TFn1[i5_P01AcW;`0087oo00<007ooOol02goo0005Ool00`00Oomoo`0BOol0
0`00<00`000;<0027>L8>0027>L3F]X025[KF]YJneKkF_]Fne[kE_/6Ea`6Dad6Cch3Acl01DLnAcm7
?dLoAch00c/O00Dg7c/O>alk7cLO00=l0007:00LiacW7>LX04007>L00d0000@Lie1PD60Li`9Lh005
7>MU@FE17>MYXP07O0000f?i7>MOnP027>L015Ok7>LLid_K0T_L00E?g1cW7>LoVcnL00<Li`04;e/_
FRmK;eX37>L00bmJ6_PJn0066_P57>Ld000POol00`00Oomoo`0;Ool000Eoo`03001oogoo019oo`0;
000/0300;00`02`0<00/0300;00`00037>L00cP0=00h0002>0000c@0>00h00037>L035[IF_]FfU[k
F]YJneKkF_aFne[lE_]Jo0EG709C7@04EaeC7E<MDad3Cch05d/mCci??TLo@ci7?dLnAcm3?TLo=alk
7cLO>alg7c/O=alk7cLO9_hRgRKo9]h00g`000@X01cW7>L/008Li`9000047>M@H5107>L2G>001AcW
JD5U@AcWJH800QcW00if9QcWO01l01cWFoXLieOKEo`LidoLBk]?g4^k0QcW00PoW3nK7>LLibmK;eX_
FbmJ0acW00L_FQ[i5_PJnAKh6_TFn0057>L_00000goo500D000650000`00Oomoo`0MOol00`00Oomo
o`0<Ool000Eoo`03001oogoo019oo`03000`030000D`00<Li`Th008Li`03F]XLie[I009JfP09F]]J
fU[JF]YJneKkF_]Fne[k00IG70EC7@E??P05Aci7?dLoAcm7?P02Acl00c/O=alk7`02>al03CLO>alV
gRKn9]hVoRKN9_hVgRKn9]hVoRKN00=l00DLi`04@00LiacWD6027>L01UcP7>MU@FE17>MYXP8Li`06
O01oog`0GoXLieOK0QcW00=?g4_KBm`00QcW00LoVacW7>LLibmJ;e/_FP037>L00bmJ6_PJn0026_P5
7>LT00000acWBY/D000F50000`00Oomoo`0MOol00`00Oomoo`0<Ool000Eoo`03001oogoo019oo`06
000/0300;00`02`00QcW00<h03@0>0000SP000Pd03P0>00h03@0>00Lid0R0QcW00eJfE[JF]UJne[J
F_]FfU[kE_]Jo5KkF_aFn`06Ea`01ELMDaeC7E<MEad00Tln01A;?DlnAci7?d<nAcm7?TLo=alk7cLO
>alg7bKo9]hVoR;N9_lVgRKn2Woo00<1]W`0O0000W`00acW00U001cWD41DH1cWG>0LifU1ID400acW
00Ul07ooOoml05OK7>M;^doLBk/00QcW00E3W1cW7>LoVbmK00@Li`03;eXJnAcW00DLiaT00003O000
01@0008D00037>LD01@0024D0003001oogoo01eoo`03001oogoo00aoo`001Goo00<007ooOol04Woo
00<00300<0000acW2cP00QcW00@l8C`17>MJf@IJfP07F]]JfU[kE_]JneKkF_/01ELL1E<M14ln00E7
?TLoAcm7?dLn00<k7aQoo`040KH1eg`0O0047>L2D6001QcWG>0LifE17>M]X`8Li`=oo`03O01;g4oL
008Li`04?i/LiacW;e/37>L00bmK7>LLi`037>LB000f50000`00Oomoo`0MOol00`00Oomoo`0<Ool0
00Eoo`03001oogoo019oo`04000LiacW=003>0001C@0>00h03P0=0000cP000Dd01cW?0508S`1008L
i`0>F]YJfE[JF]UJneKJF_]JfU[kE_]Jo5KkF_aFn`EG70=C7@0:Eae??TlnBce??TLnAcm3?TLoAchP
Ool3O0037>L00eAP7>MLh0037>L00ffSO01oo`03Ool00g`07>LoW0027>L012mJ7>LLig`00acW00@0
01cW7>Ml00<D008Lid<D0003001oogoo01ioo`03001oogoo00aoo`001Goo00<007ooOol04Woo00<0
03P0>0002cP00QcW00<l0C`Q?0400acW0U[J00AJfE[JF]YJf`9JfP05E_]JneKkF_]Fn`05Ea`5Dad3
Cch014LnAcm7?dLo9Goo2W`01Woo1g`03Goo@a@000<007ooOol07Woo00<007ooOol037oo0005Ool0
0`00Oomoo`0BOol00`00=00h0002>0001C@0>00h03P0=0000SP00QcW00A08S`1@28l0@8Li`0?F[TL
ie[JF]UJfU[IF_]JfU[kE]YJo5KkF_aFne[l00EG709C7@08EaeC7DlnBce??TLnAcm3?U=oo`05:00/
02`0;00X0002;00d50000`00Oomoo`0MOol00`00Oomoo`0=Ool000Eoo`03001oogoo019oo`03000h
03P000Ph00067>Ll0D0Q?04l8C`10QcW0UZi00<Lie[IF]X01E[J00IJfeKkF_]Fne[kE_/4Ea`4Dad3
Cch00dLnAcmoo`1GOol2@00A;00U50000`00O01oo`0MOol00`00Oomoo`0=Ool000Eoo`03001oogoo
019oo`04000h03P0=003>00033@0>00LiacW?0508S`1@28l0AcW@6DLi`9J^@0>7>MJfU[IF]YJfE[k
E]YJne[JF_aFne[lE_]Jo0AG7007DaeG7E<MDae;?DlnAch0G7oo00I003`0@00l02`0:003;0001BP0
;00/02`0:0000b`000DX02`0;00/02P000</0005:00/02`0;00X0002;00F50000`00DUMl000MOol0
0`00Oomoo`0=Ool000Eoo`03001oogoo019oo`03000h03P000Dh00097>Ll8C`1@24l0C`Q?04Lid1U
008Li`9J^@04F]XLie[JF]T2F]X01e[KF]YJfUKkF_]Fne[k00AG70AC7@9??P03Acioogoo05ioo`=0
0003?01002`002d/0004001BEacWO00LOol00`00Oomoo`0=Ool000Eoo`03001oogoo019oo`03000d
03P0008h000>=00LiacW@28l0D0R?0508S`17>M0IAcWFYPLi`9J^@0=F]TLie[IF]YJfE[kF]YJneKJ
F_aFne[lE_/015LL00EG7E<MDae;?Dln06Aoo`08?01003`0@00l0400?010008/0005:00/02`0;00X
0003;0001BP0;00/02`0:0000b`000DX02`0;00/02P000</0005:00/02`0;00X0003;0001BP0;00/
02`0:0000R`000@007`0O01l01aoo`03001oogoo00eoo`001Goo00<007ooOol04Woo00@003P0>00h
008Li`0=?04l8C`1@24l0C`Q?04Lid1UA6DLieZi7>L00eZi00<Lie[JF]X015[J00EJfeKkF_]Fne[k
00AG709C7@03Ccioogoo06Ioo`03@00l040000900005?0100400@00l000U;0001000FUDLiacW6goo
00<007ooOol03Woo0005Ool00`00Oomoo`0BOol05000>00h01cW@28l0D0R?0508S`1@28l0AcW@6E4
QQcWF[UJV5Zi7>L2F[T031cWF]UJfU[IF_]FfU[kF]YJo5KkF_aFn`=G70=C7Faoo`0<@00l0400?010
03`0@00l0400?01002P00b`000DX02`0;00/02P000</0005:00/02`0;00X0003;0001BP0;00/02`0
:0000b`000PX02`0;00/02P0001BEQcW77oo00<007ooOol03Woo0005Ool00`00Oomoo`0BOol03P00
7>LLid0Q?04l8C`1@24l0C`Q?04Lid1UA6D27>L015ZHF[QJ^AcW0UZi00<Lie[JF]T00U[J00IJfe[J
F_]Fne[kE_/4Ea`2Dae^Ool014aQ@01003`00d0000Dl0400@01003`0009001d/0003000LiacW01ao
o`03001oogoo00ioo`001Goo00<007ooOol04Woo00h003`1@28l0D0R?0508S`1@28l0AcW@6E4QT1U
0QcW00AJ^EZHF[TLi`9J^@0;7>MJfE[JF]UJne[JF_]Fne[lE_]Jo003Ea`2DaeaOol04dQQC64l0400
?01003`0@00l0400?01003`0@00l0400?00/02P000</0005:00/02`0;00X0003;0001BP0;00/02`0
:0000b`000DX02`0;00001cW01eoo`03001oogoo00ioo`001Goo00<007ooOol04Woo00d0040Q?04l
8C`1@24l0C`Q?04Lid1UA6E0I@037>L015ZHF[UJ^AcW0UZi00<Lie[JF]X015[J00AJneKkF_]Fn`=G
709C7G9oo`=<H@=00005?0100400@00l0003@0001S`0@0100400?01001@/0003000Ligoo01aoo`03
001oogoo00ioo`001Goo00<007ooOol04Woo00`003`1@28l0D0R?0508S`17>M0IDB6@6D27>L01UZH
FYLLieZHF[TLi`9J^@0;7>MJfE[JF]T005KJF_]Fne[lE_]Jo002Ea`00e<MEaeoo`1dOol05TaQB65<
HC`0@00l0400?01003`0@00l0400?01003`0@00l0400?01003`00b`000DX02`0;00/02P000</0006
:00/02`0;00X00007Woo00<007ooOol03Woo0005Ool00`00Oomoo`0BOol03P00?24l0D0Q?04l8C`1
7>M0IDAU@6DLidC87>L2FYP011cWF[QJV1cW0UZi00XLie[JF]UJfP00F]]JfU[kE_]Jn`=G7003Daeo
ogoo07Eoo`E<H@05?0100400@00l0003@0001C`0@0100400?0000d0000Dl0400@01003`000//0003
001oogoo01]oo`03001oogoo00moo`001Goo00<007ooOol04Woo01@003`1@28l0D0R?04Lid1UA8I0
IDB67>M92acWFYQJUacWFYQJ^AcW0UZi00XLie[IF]YJfAcWF]YJneKkF_aFn`9G7003EaeC7Goo07Mo
o`0NE>E8HDaQB65<HDQQ@00l0400?01003`0@00l0400?01003`0@00l0400?01003`0@00l0400?010
02P00b`000@X02`0;00001eoo`03001oogoo00moo`001Goo00<007ooOol04Woo00`0040Q?04l8C`1
7>M0IDAU@6E4IAcWA<T27>L01UZGFYPLieZiFYPLi`9J^@057>MJfU[JF]X00002F]X00e[kE_]Jn`02
Ea`00e<MOomoo`1hOol00eCUC65<H@04C642@0001C`0@0100400?0000d0000Dl0400@01003`000=0
0005?0100400@00l0003@0000c`0@000000MOol00`00Oomoo`0?Ool000Eoo`03001oogoo019oo`0B
000l0D0R?04Lid1UA8I0IDB67>M8bDS[7>MJMacWFYLLieZH0UZi00hLieZi7>MJfE[JF]UJneKJF_]F
ne[lE_]G75<MO7oo02=DiE3UC658HDaQB65<HDQQC64l0400?01003`0@00l0400?01003`0@00l0400
?01003`0@00l0400?01003`0@00l000001eoo`03001oogoo00moo`001Goo00<007ooOol04Woo00/0
03`Q?04Lid1UA6E0IDAU@6DLidC8008Li`0<FWLLieZHFYLLieZHF[TLieZi7>MJfU[I0U[J00AJfe[J
F_]Fn`9G77ioo`9Di@Q<H@=00005?0100400@00l0003@0001C`0@0100400?0000d0000Dl0400@010
000001eoo`03001oogoo00moo`0017oo00<007ooOol04goo00/003`17>M0IDB6@6E4QT1U7>M4Z4S9
008Li`05EWLLieZGFYPLi`02F[T02acWF[TLie[IF]YJfE[kF]YJo5KkF_`00ULLOgoo021DiE3UE>E8
HDaQB65<HDQQC658HDaQB65003`0@00l0400?01003`0@00l0400?01003`0@00l0400?01000007Goo
00<007ooOol047oo0004Ool00`00Oomoo`0COol02P007>M0IDAU@6E4ID1U7>M4b4S90acW00]JMacW
FYQJV1cWFYQJ^1cWF[UJfAcW00AJfP04E_]JneKkEab0Ool015U8E>EDiECU2TaQ00Dl0400@01003`0
00=00005?0100400@00l0003@0000c`0001oo`0LOol00`00Oomoo`0@Ool000Aoo`03001oogoo01=o
o`0:0010IDB6@6E4QT1UA8HLidS9A:P37>L2FWL01QcWFYPLieZiFYPLi`9J^@097>MJfP00F_]FfU[l
E_]Jo5LL085oo`0OFBQDiE3UE>E@iDaQB65<HDQQC658HDaQB65<HDQQ@00l0400?01003`0@00l0400
?01003`0@00l040000007Goo00<007ooOol047oo0004Ool00`00Oomoo`0COol05@00A6E0IDAU@6E4
IAcWB<U4b1cWB@/LieYg7>MJMacWFYMJ^1cWF[TLi`02F[T021cWF]T001cWF]]Fne[kEab3Ool00eU8
E>EDi@02E>D<C6400d00?0100002@0001C`0@0100400?0000T0000<007ooOol06goo00<007ooOol0
47oo0004Ool00`00Oomoo`0DOol05000A8I0IDB67>M8bDBXB<TLidT;7>MJMacWFWPLieZHFYLLieZH
7>L2F[T021cWF]X005[kF]YJo5KkEab3Ool07UU9FBQDiE3UE>E@iECUB65<HDQQC658HDaQB65<HDQQ
C658HDaQ?01003`0@00l0400?01003`0@00001eoo`03001oogoo011oo`0017oo00<007ooOol057oo
00P0041UA6E0IAcWA<Q4bDT;0acW00AJEQcWFWLLi`9JV0087>MJ^5Zi7>MJ^AcWF]X0009JfP03E_]J
ngoo08Aoo`9IB0EDi@m<H@03@00l040000900003001oogoo01aoo`03001oogoo011oo`0017oo00<0
07ooOol057oo00/004B6@6DLidBXB<U4Z1cWB>/LieIF008Li`0@FWLLieZHFYLLieZHF[TLieZi7>MJ
fP00F_]FfU[lE_^6Ool06eU9FBQDiE3UE>E@iECUD>E<HDQQC658HDaQB65<HDQQC658HDaQB65<HDQQ
C64l0400?000000MOol00`00Oomoo`0AOol000Aoo`03001oogoo01Aoo`0B0010IAcWA<Q4bDC8B<TL
idT;7>MJEQcWFWLLieYg7>MJV1cW0UZi00PLieZi7>MJf@00F]YJfeKkQgoo0QcW00=IB5CUE>D015CU
4DaQ00<007ooOol06goo00<007ooOol04Goo0004Ool00`00Oomoo`0EOol06`007>M8bDBXB<TLidT;
B>/LieIF7>MFEQcWFWLLieZGF[TLieZi7>MJ^AcWF]X005[kF]YJo028Ool06QcWFDUI:5CUD>EDiE3U
E>E@iECUB65<HDQQC658HDaQB65<HDQQC658HDaQB65<HDQQ000MOol00`00Oomoo`0AOol000Aoo`03
001oogoo01Eoo`070014bDC8B<U4b1cWB@/00QcW019JEQcWFWLLieYg7>MJV5ZG7>MJV1cWF[TLie[J
001JfU[kE_^8Ool27>L2FDP7E>D>C6400`00Oomoo`0KOol00`00Oomoo`0AOol000Aoo`03001oogoo
01Eoo`070014Z4S9A:PLidS[B@/00acW015JMacW7>MFMacWFYMJV1cWF[TLieZi7>MJfP007>MFne[l
08Qoo`8Li`0GFBQIBETXE>E@iECUD>EDiE3UE>E@iDaQB65<HDQQC658HDaQB65<HDQQC640000NOol0
0`00Oomoo`0AOol000Aoo`03001oogoo01Eoo`050018bDC8A<TLi`02B@/37>L04EIF7>MJMacWFWLL
ieZH7>MJV1cWF[TLie[I001JfU[kOol02P00OWoo0QcW00AIBEU8FDQIB0QDi@Y<H@03001oogoo01]o
o`03001oogoo019oo`0017oo00<007ooOol05Goo00P004BXB<U4Z1cWB>/LidT]0QcW00QJEQcWFWLL
ieYg7>MJV1cW0UZi0QcW00AJfP00F_]Fn`]oo`X007Aoo`<Li`0FFDUI:5U9FBQDiE3UE>E@iECUD>ED
iE3UE>E8HDaQB65<HDQQC658HDaQ000MOol00`00Oomoo`0BOol000Aoo`03001oogoo01Aoo`800003
A<U4b1cW00992`0>7>M=KacW7>MJEQcWFUHLieYg7>MJUeZh7>MJ^@8Li`04F]X005[JF_/EOol:001Z
Ool37>L00eU8FDUIB002FDP9E>D7C6400`00Oomoo`0KOol00`00Oomoo`0BOol000Aoo`03001oogoo
01Aoo`07001oo`00B<TLidT;B>/01AcW00EFEQcW7>MJN1cW009JV0087>MJ^AcWF]TLi`00F_]Fnamo
o`/005moo`8Li`0FBYYMReTXFDUI:5U9FBQDiE3UE>E@iECUD>EDiE3UE>E@iECUB65<HDQQ000NOol0
0`00Oomoo`0BOol000Aoo`03001oogoo01Aoo`04001oo`007>L3B@/57>L00eYF7>MJM`027>L2FYP0
1acWF[PLieZi7>L005[J02]oo`X005Eoo`8Li`05BY]MRef;FDQIB@03FDP:E>D3C6400`00Oomoo`0L
Ool00`00Oomoo`0BOol000Aoo`03001oogoo01=oo`09001oogoo000LidS[B@/Lidd]00@Li`0;EUDL
ieIF7>MFMacWFYLLieZH7>MJ^@027>L00e[kOomoo`0cOol:001;Ool27>L05TZJ7>MIJeU9FBQIBETX
FDUI:5CUD>EDiE3UE>E@iECUD>EDiE3UE>E@i@007Woo00<007ooOol04Woo0004Ool00`00Oomoo`0C
Ool01@00Oomoo`007>L00TT;00<LidT]7>L00acW00]JEQcWFWLLieYg7>MJV1cWF[TLieZi008Li`03
E_]oogoo03eoo`X0045oo`8Li`04BY/Lief;GH/2FDP015U9FDQIB5U82eCU00<007ooOol06goo00<0
07ooOol04goo0004Ool00`00Oomoo`0COol02@00Oomoo`00B@]8jdT;7>M=;@057>L03EYg7>LLieYg
7>MJUacWFYPLieZi7>L005[l04Uoo`X003Moo`0G7>M>VacWCYYIJef;FF]IBETXFDUI:5U9FBQDiE3U
E>E@iECUD>EDiE3UE>D0000NOol00`00Oomoo`0COol000Aoo`03001oogoo01=oo`04001oogoo0003
B@/00acWBBdLi`047>L00eYF7>MJM`027>L2FYP27>L00eZi7>L0001DOol;000/Ool01AcWBYXLidij
GJd00Uf;0eU800AIBEU8FDQIB0QDi@03001oogoo01aoo`03001oogoo01=oo`0017oo00<007ooOol0
4Woo00<007ooOol00Woo00D004S[7>M9;Dd]00DLi`03FUHLieYg008Li`04FYMJV1cWF[T27>L00`00
Oomoo`1MOol:000QOol064ZL7>M>VacWCYXLief;FF]MReTXFDUI:5U9FBQIBETXE>E@iECUD>EDiE3U
E>D001ioo`03001oogoo01=oo`0017oo00<007ooOol04Woo00<007ooOol00Woo00H004T;7>M=;AcW
CFl67>L01eYF7>MJMacWFYPLieZi008Li`03001oogoo06Moo`X001Moo`<Li`9>NP037>MM[Ef;009M
R`=IB004FDUIB5U8FDP5E>D00`00Oomoo`0MOol00`00Oomoo`0COol000=oo`03001oogoo01=oo`03
001oogoo009oo`060018jacWBBdLide>1AcW00QFEQcW7>MJMacWFYPLieZi0acWLgoo2P003Goo0acW
01A:NAcWCWUM[EU[GH]IJef;FBQIBETXFDUI:5U9FBQDiE3UE>E@i@007goo00<007ooOol04goo0003
Ool00`00Oomoo`0BOol00`00Oomoo`03Ool01000B@/Lidd]1acW00=JEQcWFWL00QcW00=JUacWFYP0
0acWOGoo2P000goo0acW00=>NQcWCWT00Uf]0ef;00EIBEU8FDQIB5U900=IB0=Di@03001oogoo01ao
o`03001oogoo01Aoo`000goo00<007ooOol04Woo00<007ooOol017oo00<004d]BBd01acW00=FEQcW
EUH00QcW00=JV1cWF[T00QcW00<007ooOol0QGoo0`0001HLidZJ7>M:NAcWCWTLief]GH]IJef;FF]I
BETXFDUI:5U9FBQIBETXE>D001moo`03001oogoo01Aoo`000goo00<007ooOol04Woo00<007ooOol0
17oo00<004T]CBd02AcW00EJMacWFWLLieZH00<Li`03001oogoo08Qoo`8Li`04CWXLidii7>L3GJd4
GH/01EU9FDQIB5U8FDT00eU800<007ooOol07Goo00<007ooOol057oo0003Ool00`00Oomoo`0AOol0
0`00Oomoo`05Ool00`00CBe9;@087>L01UYg7>LLieIg7>MJU`<Li`03001oogoo08Qoo`8Li`0DCYXL
ie9j7>MQcef]HJiIJef;FF]MReTXFDUI:5U9FBQIBETXFDT001moo`03001oogoo01Aoo`000goo00<0
07ooOol04Goo00<007ooOol01Goo00<004T]CBd021cW00=FEQcWFWL00QcW00EJV1cWF[TLi`0008Yo
o`8Li`05CWXLiacWDWTLi`02GJd5GH/00eU8FDUIB002FDP00eU9001oo`0OOol00`00Oomoo`0DOol0
00=oo`03001oogoo015oo`03001oogoo00Ioo`050019;AcW7>MA/P047>L015He7>LLieYg0QcW00=J
UacWF[T00QcWRWoo0acW00A>NAcWCUPLi`=M[@0;GH]IJef;FF]MReTXFDUI:5U9FBP0000OOol00`00
Oomoo`0EOol000=oo`03001oogoo011oo`03001oogoo00Moo`05000Lide_7>MA/@077>L00eYF7>MJ
M`027>L00eZi7>LLi`2:Ool011cWCWXLidii0QcW00AMcef]GJeM[@EMR`9IB003FDUIB000021oo`03
001oogoo01Eoo`000goo00<007ooOol047oo00<007ooOol01goo00L001cWCFlLie6@7>MAd`047>L0
15IF7>LLieYh0QcW00=JV1cW7>L0RWoo00TLidYi7>LLie9i7>L005g>HJh00Uf]00UIJef;FF]MReU[
FDUI:5U9000087oo00<007ooOol05Goo0003Ool00`00Oomoo`0@Ool00`00Oomoo`08Ool01000CFhL
idf@1QcW00=JEQcWFWL00QcW00AJV1cW7>LLihUoo`<Li`06CWTLiacWDUPLieg?0ef]1Uf;0UU800<0
07ooOol07Woo00<007ooOol05Goo0003Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool01000CFlLie6@
1AcW00AJEAcW7>MFEP8Li`04FYPLiacW7>N9Ool47>L01DiH7>MooacWGLh00Uf]00UQ[Uf]GH]IJef;
FF]MReTX00008Goo00<007ooOol05Goo0003Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool01000CFlL
idf@21cW00=JMacWFWL011cWRGoo00<Lidii7>L00QcW00ABF1cW001Mc`AM[@IMR`03001oogoo01mo
o`03001oogoo01Eoo`000goo00<007ooOol03goo00<007ooOol02Woo00<001cWDI001acW00AJMacW
7>MJM`@LihUoo`8Li`08CUPLiacWDWPLi`00GLiQc`=M[@07GH]IJef;FF]MReU[000087oo00<007oo
Ool05Woo0003Ool00`00Oomoo`0>Ool00`00Oomoo`0;Ool00`007>M=T0077>L00eYF7>MJM`037>L0
0eZi7>Moo`28Ool37>L01E9h7>LLie9G7>L00Ug?15f]15f;00<007ooOol07goo00<007ooOol05Woo
0003Ool00`00Oomoo`0>Ool00`00Oomoo`0;Ool00`007>MAT0027>L01E7B7>LLiacWESD00QcW00IJ
MacW7>LLieZi7>N8Ool00`007>MBN@027>L0259H7>MBEacWGLiQcef]HJh2GJd01EU[GH]IJef;0000
8Goo00<007ooOol05Woo0003Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool01`00CI0LiacWDM8Lie8E
00@Li`03FUHLieYg00<LihQoo`8Li`07DWPLiacW7>MBEacW00000Ug?1Ef]0Uf;00<007ooOol087oo
00<007ooOol05Woo0003Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool01`00DI0LiacWDM8Lidgd00<L
i`04EUHLiacWFWL37>N8Ool47>L00e9h7>MFF0027>L00eg>HLmMcP02GJd01F6^GJeMReU[00008Woo
00<007ooOol05Woo0003Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool01@00CI0LiacWDM8011cW00AJ
=AcW7>MJM`@LihQoo`037>MBNAcW008Li`04EULLie8f7>L3GLl5GJd2000QOol00`00Oomoo`0GOol0
00=oo`03001oogoo00eoo`03001oogoo00ioo`04000LiacWDM847>L015YF7>LLieIF0acW00<007oo
Ool0QWoo0acW00=BEacWDUL00QcW0P0000=Qceg>HJh00ef]00=Q[P0000008Goo00<007ooOol05goo
0003Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01@007>MA/AcWDM800QcW00MB5AcW7>LLieYg7>MJ
V0027>N7Ool00acWCWTLi`027>L0159G7>MB=QcW0P000Ug?1Ef]0P008Goo00<007ooOol05goo0003
Ool00`00Oomoo`0<Ool00`00Oomoo`0@Ool01P00DK8Lie7C7>MB5@<Li`04FWLLiacWEWL27>N7Ool0
0acWDWTLi`027>L015IH7>LLiehA0P0000UQceg>HLmM[F6^GJd007oo00008Goo00<007ooOol05goo
0003Ool00`00Oomoo`0<Ool00`00Oomoo`0@Ool01P00DK4Lie7B7>MAm08Li`04FSDLiacWFWL37>N6
Ool00acW000Li`027>L01E9G7>MF=QcWGQ400P000eg?0ef]00@007ooOol0021oo`03001oogoo01Mo
o`000Woo00<007ooOol03Goo00<007ooOol04Goo00<001cWDM<011cW00AF=AcW7>MJM`8Li`03001o
ogoo08Aoo`037>M>F1cW008Li`05DULLiacW001N4@0200000f7?GLiQc`02GJd01@00Oomoogoo0000
87oo00<007ooOol05goo0002Ool00`00Oomoo`0<Ool00`00Oomoo`0COol00`00DM8Li`027>L024ge
7>LLiacWFUHLieZH7>N6Ool02P007>LLiacWDULLie8f7>L005hA0P000eg?0Uf]00D007ooOomoo`00
01moo`03001oogoo01Qoo`000Woo00<007ooOol037oo00<007ooOol04goo00D001cW7>LLidge00<L
i`05EUHLiacWFWPLi`26Ool01@007>LLiacWEUP00QcW00=J<`00GQ400P0000EQceg>HLmMcP0000Ao
o`03001oogoo01eoo`03001oogoo01Qoo`000Woo00<007ooOol037oo00<007ooOol057oo00@0057B
7>MB5@8Li`06ESDLiacW7>MJMacWQWoo00X001cW7>MFEacWDSHLi`00GQ9N4@8000AMc`03001oogoo
00=oo`03001oogoo01aoo`03001oogoo01Qoo`000Woo00<007ooOol02goo00<007ooOol05Woo00<0
01cWDO<00QcW00AJEAcW7>MFEP8LihEoo`05000LiacW7>MBE`027>L015iE001N<ehA0P0000AQceg>
HLl000Ioo`03001oogoo01aoo`03001oogoo01Qoo`000Woo00<007ooOol02goo00<007ooOol05Woo
00D001cW7>LLie8E00<Li`03FWL007oo08Eoo`09001BF1cWDULLie8f7>MJ=000009N4@<0009Mc`03
001oogoo00Aoo`03001oogoo01aoo`03001oogoo01Qoo`000Woo00<007ooOol02goo00<007ooOol0
5goo00<001cWDQD00QcW00AFEQcW7>L008Ioo`04000LiacWEUP27>L01EYFGS@0068BGQ400`0000=M
cP00Ool01Woo00<007ooOol077oo00<007ooOol067oo0002Ool00`00Oomoo`0:Ool00`00Oomoo`0I
Ool01@00CODLiacWFSD00QcWQgoo00L001cWDULLieHf7>MJ=@020002GQ4300000eg?001oo`07Ool0
0`00Oomoo`0JOol00`00Oomoo`0IOol0009oo`03001oogoo00Yoo`03001oogoo01Uoo`04000LiacW
DQD27>L00`00Oomoo`25Ool27>L01U9G7>LLieYfFS<0009N4P03GQ400000008000Uoo`03001oogoo
01Yoo`03001oogoo01Uoo`000Woo00<007ooOol02Woo00<007ooOol06Woo00<001cWCOD00QcWQgoo
0QcW00QBEacWDSHLieXeGS@005hB0UhA10002Goo00<007ooOol06Woo00<007ooOol06Goo0002Ool0
0`00Oomoo`09Ool00`00Oomoo`0LOol40027Ool00`007>MFF0027>L01eYFGUD00000FQ9R4UhA00<0
00Yoo`03001oogoo01Yoo`03001oogoo01Uoo`000Woo00<007ooOol02Goo00<007ooOol0Ygoo00L0
01cW7>MB=QcWFUEJ=00200000ehBGQ5N4@02000<Ool00`00Oomoo`0IOol00`00Oomoo`0IOol0009o
o`03001oogoo00Uoo`03001oogoo0:Ioo`03000Lie9G008Li`03FWIJ=5hd0080009N4P03GQ400000
00aoo`03001oogoo01Qoo`03001oogoo01Yoo`000Woo00<007ooOol02Goo00<007ooOol0YWoo00X0
01cW7>MB=QcWFUEJ=EXd001N4P=N4@03001oogoo00]oo`03001oogoo01Qoo`03001oogoo01Yoo`00
0Woo00<007ooOol027oo00<007ooOol0Ygoo00L005IH7>LLieYFGUEJ<`02000015hcGQ5R4P003Woo
00<007ooOol067oo00<007ooOol06Woo0002Ool00`00Oomoo`08Ool00`00Oomoo`2WOol01`007>MF
=QcWFUIJ=Ehd00800003GQ9N4@00011oo`03001oogoo01Moo`03001oogoo01Yoo`000Woo00<007oo
Ool027oo00<007ooOol0Ygoo00L001cW7>MJMUYEGSAJ=00200000ehcGQ40000@Ool00`00Oomoo`0G
Ool00`00Oomoo`0JOol0009oo`03001oogoo00Moo`03001oogoo0:Qoo`067>MB=QcWFUIJ=EXd0`00
00=N4P00Ool047oo00<007ooOol05goo00<007ooOol06Woo0002Ool00`00Oomoo`07Ool00`00Oomo
o`2XOol01P007>MJEUYFFSAN=0800003GQ8007oo015oo`03001oogoo01Ioo`03001oogoo01]oo`00
0Woo00<007ooOol01goo00<007ooOol0Z7oo0QcW00AJEUXdGSAJ=0800003GQ8007oo019oo`03001o
ogoo01Eoo`03001oogoo01]oo`000Woo00<007ooOol01Woo00<007ooOol0ZGoo00H005YfFUENEEXc
GS@3000DOol00`00Oomoo`0EOol00`00Oomoo`0KOol0009oo`03001oogoo00Ioo`03001oogoo0:Uo
o`05001JEUYEFSEN=003000EOol00`00Oomoo`0EOol00`00Oomoo`0KOol0009oo`03001oogoo00Io
o`03001oogoo0:Uoo`06001JEUYEGSAJ=0005goo00<007ooOol05Goo00<007ooOol06goo00000goo
001oo`07Ool00`00Oomoo`2[Ool01000FSD000006Goo00<007ooOol04goo00<007ooOol077oo0000
0goo001oo`07Ool00`00Oomoo`2/Ool00`00Oomoo`0IOol00`00Oomoo`0COol00`00Oomoo`0LOol0
0003Ool007oo00Moo`03001oogoo0<Qoo`03001oogoo01=oo`03001oogoo01aoo`0000=oo`00Ool0
1Woo00<007ooOol0bGoo00<007ooOol04goo00<007ooOol077oo00000goo001oo`06Ool00`00Oomo
o`3:Ool00`00Oomoo`0BOol00`00Oomoo`0LOol00003Ool007oo00Ioo`03001oogoo0<Yoo`03001o
ogoo019oo`03001oogoo01aoo`0000=oo`00Ool01Woo00<007ooOol0bWoo00<007ooOol04Goo00<0
07ooOol07Goo00000goo001oo`05Ool00`00Oomoo`3;Ool00`00Oomoo`0AOol00`00Oomoo`0MOol0
0003Ool007oo00Eoo`03001oogoo0<aoo`03001oogoo011oo`03001oogoo01eoo`0000=oo`00Ool0
1Goo00<007ooOol0c7oo00<007ooOol047oo00<007ooOol07Goo00000goo001oo`04Ool00`00Oomo
o`3=Ool00`00Oomoo`0@Ool00`00Oomoo`0MOol00003Ool007oo00Aoo`03001oogoo0<eoo`03001o
ogoo011oo`03001oogoo01eoo`0000=oo`00Ool017oo00<007ooOol0cWoo00<007ooOol03Woo00<0
07ooOol07Woo00000goo001oo`03Ool00`00Oomoo`3?Ool00`00Oomoo`0>Ool00`00Oomoo`0NOol0
0003Ool007oo00=oo`03001oogoo0<moo`03001oogoo00ioo`03001oogoo01ioo`0000=oo`00Ool0
0goo00<007ooOol0cgoo00<007ooOol03Woo00<007ooOol07Woo00000goo001oo`02Ool00`00Oomo
o`3AOol00`00Oomoo`0=Ool00`00Oomoo`0NOol00003Ool007oo009oo`03001oogoo0=5oo`03001o
ogoo00aoo`03001oogoo01moo`0000=oo`00Ool00Woo00<007ooOol0dGoo00<007ooOol037oo00<0
07ooOol07goo00001Goo001oogoo0000e7oo00<007ooOol037oo00<007ooOol07goo00001Goo001o
ogoo0000eGoo00<007ooOol02goo00<007ooOol07goo00001Goo001oogoo0000eGoo00<007ooOol0
2goo00<007ooOol07goo00001000Oomoo`00eWoo00<007ooOol02goo00<007ooOol07goo00001000
Oomoo`00eWoo00<007ooOol02Woo00<007ooOol087oo00001000Oomoo`00egoo00<007ooOol02Goo
00<007ooOol087oo00001000Oomoo`00egoo00<007ooOol02Goo00<007ooOol087oo00000`00Ool0
003HOol00`00Oomoo`09Ool00`00Oomoo`0POol00003001oo`000=Qoo`03001oogoo00Uoo`03001o
ogoo021oo`0000<007oo0000fGoo00<007ooOol01goo00<007ooOol08Goo0002003JOol00`00Oomo
o`07Ool00`00Oomoo`0QOol000800=Yoo`03001oogoo00Moo`03001oogoo025oo`000P00fWoo00<0
07ooOol01goo00<007ooOol08Goo00000`00Oomoo`3JOol00`00Oomoo`06Ool00`00Oomoo`0QOol0
00H00=Moo`03001oogoo00Ioo`03001oogoo025oo`001Woo2`00c7oo00<007ooOol01Goo00<007oo
Ool08Woo000AOol<0030Ool00`00Oomoo`05Ool00`00Oomoo`0ROol001eoo`/00;Ioo`03001oogoo
00Aoo`03001oogoo029oo`00:7oo2`00Zgoo00<007ooOol017oo00<007ooOol08Woo000cOol<002O
Ool00`00Oomoo`04Ool00`00Oomoo`0ROol003moo`/009Aoo`03001oogoo00Aoo`03001oogoo029o
o`00BWoo2`00RWoo00<007ooOol00Woo00<007ooOol08goo001EOol<001nOol00`00Oomoo`02Ool0
0`00Oomoo`0SOol0065oo`/007=oo`03001oogoo009oo`03001oogoo02=oo`00K7oo2`00J7oo00<0
07ooOol00Woo00<007ooOol08goo001gOol;001NOol01@00Oomoogoo00009Goo0022Ool<001BOol0
1000Oomoo`009Woo002>Ool;0017Ool01000Oomoo`009Woo002IOol;000lOol01000Oomoo`009Woo
002TOol<000aOol00`00Ool0000VOol00;1oo`/002Ioo`03001oo`0002Ioo`00^goo2`006goo00<0
07oo00009Woo0036Ool<000?Ool2000WOol00=9oo`/000Eoo`03001oogoo02Eoo`00gGoo1P009goo
0000
\>"],
  ImageRangeCache->{{{0, 265.063}, {287, 0}} -> {0.0958408, 0.0766181, 
  0.00321812, 0.00321812}}]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell["If you use Cos instead of Sine it doesn't work out.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(clear; top = 125; kappa[s_] = 1; tau[s_] := Cos[s]; width = .5; 
    ds = .1; \), 
    \(pribbonfrenet\)}], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-016 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.53102 .6777 m .54036 .70497 L .55238 .68083 L .253 0 .076 r
F
.53102 .6777 m .52712 .71206 L .54036 .70497 L F
.50966 .67538 m .52712 .71206 L .53102 .6777 L .391 .042 .248 r
F
.50966 .67538 m .51415 .71881 L .52712 .71206 L F
.25 g
.5 Mabswid
.52712 .71206 m
.53102 .6777 L
s
.48843 .67403 m .51415 .71881 L .50966 .67538 L .478 .163 .354 r
F
0 g
.006 w
.50966 .67538 m
.53102 .6777 L
s
.55238 .68083 m .55383 .69756 L .57363 .68462 L .023 0 0 r
F
.55238 .68083 m .54036 .70497 L .55383 .69756 L F
0 g
.53102 .6777 m
.55238 .68083 L
s
.25 g
.5 Mabswid
.54036 .70497 m
.55238 .68083 L
s
.48843 .67403 m .50148 .72523 L .51415 .71881 L .478 .163 .354 r
F
.25 g
.50966 .67538 m
.51415 .71881 L
s
.46747 .67378 m .50148 .72523 L .48843 .67403 L .537 .247 .421 r
F
0 g
.006 w
.48843 .67403 m
.50966 .67538 L
s
.57363 .68462 m .56753 .6899 L .59464 .68886 L 0 0 0 r
F
.57363 .68462 m .55383 .69756 L .56753 .6899 L F
0 g
.55238 .68083 m
.57363 .68462 L
s
.46747 .67378 m .48918 .73134 L .50148 .72523 L .537 .247 .421 r
F
.44691 .67472 m .48918 .73134 L .46747 .67378 L .581 .307 .466 r
F
.25 g
.5 Mabswid
.48843 .67403 m
.48865 .67488 L
s
0 g
.006 w
.46747 .67378 m
.48843 .67403 L
s
.59464 .68886 m .58144 .68205 L .6153 .69336 L .593 .949 .858 r
F
.59464 .68886 m .56753 .6899 L .58144 .68205 L F
0 g
.57363 .68462 m
.57603 .6851 L
s
.25 g
.5 Mabswid
.59415 .68888 m
.59464 .68886 L
s
.55383 .69756 m
.57363 .68462 L
s
.44691 .67472 m .47732 .73718 L .48918 .73134 L .581 .307 .466 r
F
.25 g
.50105 .72354 m
.50148 .72523 L
s
.48865 .67488 m
.50105 .72354 L
s
.4269 .67695 m .47732 .73718 L .44691 .67472 L .616 .351 .494 r
F
.25 g
.46747 .67378 m
.46782 .6747 L
s
0 g
.006 w
.44691 .67472 m
.46747 .67378 L
s
.6153 .69336 m .59555 .67412 L .63551 .6979 L .721 .956 .948 r
F
.6153 .69336 m .58144 .68205 L .59555 .67412 L F
0 g
.59464 .68886 m
.6153 .69336 L
s
.25 g
.5 Mabswid
.61468 .69315 m
.6153 .69336 L
s
.56753 .6899 m
.56762 .68989 L
s
.56762 .68989 m
.59415 .68888 L
s
.4269 .67695 m .46599 .74282 L .47732 .73718 L .616 .351 .494 r
F
.25 g
.48825 .72887 m
.48918 .73134 L
s
.46782 .6747 m
.48825 .72887 L
s
.40757 .68051 m .46599 .74282 L .4269 .67695 L .645 .384 .509 r
F
.25 g
.44691 .67472 m
.44738 .67568 L
s
0 g
.006 w
.4269 .67695 m
.44691 .67472 L
s
.63551 .6979 m .60982 .6662 L .65516 .70223 L .752 .895 .942 r
F
.63551 .6979 m .59555 .67412 L .60982 .6662 L F
.25 g
.5 Mabswid
.58144 .68205 m
.58173 .68215 L
s
0 g
.006 w
.6153 .69336 m
.63551 .6979 L
s
.25 g
.5 Mabswid
.63476 .69745 m
.63551 .6979 L
s
.40757 .68051 m .4553 .7483 L .46599 .74282 L .645 .384 .509 r
F
.25 g
.4756 .73365 m
.47732 .73718 L
s
.38907 .68544 m .4553 .7483 L .40757 .68051 L .67 .407 .514 r
F
.25 g
.4269 .67695 m
.42746 .67789 L
s
0 g
.006 w
.40757 .68051 m
.4269 .67695 L
s
.65516 .70223 m .62423 .65841 L .67417 .70614 L .75 .828 .912 r
F
.65516 .70223 m .60982 .6662 L .62423 .65841 L F
.25 g
.5 Mabswid
.59555 .67412 m
.5961 .67444 L
s
0 g
.006 w
.63551 .6979 m
.65516 .70223 L
s
.25 g
.5 Mabswid
.65432 .70156 m
.65516 .70223 L
s
.65431 .70155 m
.65432 .70156 L
s
.58173 .68215 m
.58207 .68226 L
s
.58207 .68226 m
.61468 .69315 L
s
.38907 .68544 m .44535 .75365 L .4553 .7483 L .67 .407 .514 r
F
.25 g
.46294 .73768 m
.46599 .74282 L
s
.47289 .72808 m
.4756 .73365 L
s
.44738 .67568 m
.47289 .72808 L
s
.37157 .69175 m .44535 .75365 L .38907 .68544 L .692 .421 .509 r
F
.25 g
.40757 .68051 m
.40817 .68137 L
s
0 g
.006 w
.38907 .68544 m
.40757 .68051 L
s
.67417 .70614 m .6387 .65081 L .69244 .70937 L .736 .77 .88 r
F
.67417 .70614 m .62423 .65841 L .6387 .65081 L F
.25 g
.5 Mabswid
.60982 .6662 m
.61068 .66688 L
s
0 g
.006 w
.65516 .70223 m
.67417 .70614 L
s
.25 g
.5 Mabswid
.67322 .70523 m
.67417 .70614 L
s
.67321 .70522 m
.67322 .70523 L
s
.5961 .67444 m
.59659 .67474 L
s
.59659 .67474 m
.63476 .69745 L
s
.37157 .69175 m .43627 .75892 L .44535 .75365 L .692 .421 .509 r
F
.25 g
.44966 .7403 m
.4553 .7483 L
s
.45768 .72881 m
.46294 .73768 L
s
.35522 .69942 m .43627 .75892 L .37157 .69175 L .709 .425 .492 r
F
.25 g
.38907 .68544 m
.38958 .68606 L
s
0 g
.006 w
.37157 .69175 m
.38907 .68544 L
s
.69244 .70937 m .65317 .64346 L .7099 .7117 L .72 .721 .85 r
F
.69244 .70937 m .6387 .65081 L .65317 .64346 L F
.25 g
.5 Mabswid
.61068 .66688 m
.61136 .66742 L
s
.62423 .65841 m
.62543 .65955 L
s
0 g
.006 w
.67417 .70614 m
.69244 .70937 L
s
.25 g
.5 Mabswid
.6914 .70824 m
.69244 .70937 L
s
.6914 .70824 m
.6914 .70824 L
s
.35522 .69942 m .42817 .76408 L .43627 .75892 L .709 .425 .492 r
F
.25 g
.43263 .73823 m
.44535 .75365 L
s
.4376 .72316 m
.44966 .7403 L
s
.44747 .71162 m
.45768 .72881 L
s
.42746 .67789 m
.44747 .71162 L
s
.34018 .70841 m .42817 .76408 L .35522 .69942 L .722 .417 .461 r
F
.25 g
.40817 .68137 m
.4376 .72316 L
s
0 g
.006 w
.35522 .69942 m
.37157 .69175 L
s
.34018 .70841 m .42113 .76911 L .42817 .76408 L .722 .417 .461 r
F
.32662 .71864 m .42113 .76911 L .34018 .70841 L .728 .394 .414 r
F
.25 g
.5 Mabswid
.38958 .68606 m
.43263 .73823 L
s
.35522 .69942 m
.3671 .70995 L
s
0 g
.006 w
.34018 .70841 m
.35522 .69942 L
s
.7099 .7117 m .66752 .63639 L .72648 .71291 L .703 .679 .824 r
F
.7099 .7117 m .65317 .64346 L .66752 .63639 L F
.25 g
.5 Mabswid
.62543 .65955 m
.62631 .6604 L
s
.6387 .65081 m
.64027 .65252 L
s
0 g
.006 w
.69244 .70937 m
.7099 .7117 L
s
.25 g
.5 Mabswid
.70916 .71081 m
.7099 .7117 L
s
.70878 .71035 m
.70916 .71081 L
s
.61136 .66742 m
.61223 .66812 L
s
.61223 .66812 m
.65431 .70155 L
s
.32662 .71864 m .41523 .77395 L .42113 .76911 L .728 .394 .414 r
F
.31469 .73002 m .41523 .77395 L .32662 .71864 L .721 .35 .346 r
F
.25 g
.37157 .69175 m
.38753 .70832 L
s
.34018 .70841 m
.34311 .71061 L
s
0 g
.006 w
.32662 .71864 m
.34018 .70841 L
s
.25 g
.5 Mabswid
.33187 .72192 m
.34233 .72845 L
s
.32662 .71864 m
.33187 .72192 L
s
.72648 .71291 m .68163 .62956 L .74213 .71277 L .685 .641 .8 r
F
.72648 .71291 m .66752 .63639 L .68163 .62956 L F
.25 g
.64027 .65252 m
.64139 .65374 L
s
.65317 .64346 m
.65513 .64582 L
s
0 g
.006 w
.7099 .7117 m
.72648 .71291 L
s
.25 g
.5 Mabswid
.72569 .71187 m
.72648 .71291 L
s
.72529 .71136 m
.72569 .71187 L
s
.62631 .6604 m
.62744 .66148 L
s
.62744 .66148 m
.67321 .70522 L
s
1 0 0 r
.003 w
.48918 .73134 m
.50148 .72523 L
s
.47732 .73718 m
.48918 .73134 L
s
.50148 .72523 m
.51415 .71881 L
s
.46599 .74282 m
.47732 .73718 L
s
.51415 .71881 m
.52712 .71206 L
s
.4553 .7483 m
.46599 .74282 L
s
.52712 .71206 m
.54036 .70497 L
s
.54036 .70497 m
.55383 .69756 L
s
.44535 .75365 m
.4553 .7483 L
s
.55383 .69756 m
.56753 .6899 L
s
.43627 .75892 m
.44535 .75365 L
s
.56753 .6899 m
.58144 .68205 L
s
.31469 .73002 m .41052 .77852 L .41523 .77395 L .721 .35 .346 r
F
.30455 .74241 m .41052 .77852 L .31469 .73002 L .697 .28 .251 r
F
.25 g
.5 Mabswid
.38753 .70832 m
.43627 .75892 L
s
.3671 .70995 m
.42817 .76408 L
s
.34311 .71061 m
.34315 .71064 L
s
0 g
.006 w
.31469 .73002 m
.32662 .71864 L
s
.25 g
.5 Mabswid
.31469 .73002 m
.32508 .73528 L
s
1 0 0 r
.003 w
.58144 .68205 m
.59555 .67412 L
s
.42817 .76408 m
.43627 .75892 L
s
.59555 .67412 m
.60982 .6662 L
s
.74213 .71277 m .69536 .62292 L .75678 .71111 L .667 .607 .778 r
F
.74213 .71277 m .68163 .62956 L .69536 .62292 L F
.25 g
.5 Mabswid
.65513 .64582 m
.65651 .64748 L
s
.65651 .64748 m
.70878 .71035 L
s
.66752 .63639 m
.66989 .63946 L
s
.66989 .63946 m
.72529 .71136 L
s
0 g
.006 w
.72648 .71291 m
.74213 .71277 L
s
.25 g
.5 Mabswid
.74128 .71161 m
.74213 .71277 L
s
.74088 .71106 m
.74128 .71161 L
s
.64139 .65374 m
.64281 .65528 L
s
.64281 .65528 m
.6914 .70824 L
s
1 0 0 r
.003 w
.60982 .6662 m
.62423 .65841 L
s
.42113 .76911 m
.42817 .76408 L
s
.62423 .65841 m
.6387 .65081 L
s
.6387 .65081 m
.65317 .64346 L
s
.30455 .74241 m .40699 .78271 L .41052 .77852 L .697 .28 .251 r
F
.29635 .75566 m .40699 .78271 L .30455 .74241 L .644 .176 .127 r
F
.25 g
.5 Mabswid
.34315 .71064 m
.42113 .76911 L
s
.34233 .72845 m
.41523 .77395 L
s
.32508 .73528 m
.37946 .7628 L
s
0 g
.006 w
.30455 .74241 m
.31469 .73002 L
s
.25 g
.5 Mabswid
.31078 .74486 m
.36323 .76549 L
s
.30455 .74241 m
.31078 .74486 L
s
1 0 0 r
.003 w
.41523 .77395 m
.42113 .76911 L
s
.65317 .64346 m
.66752 .63639 L
s
.66752 .63639 m
.68163 .62956 L
s
.75678 .71111 m .70857 .61639 L .77039 .70777 L .648 .574 .758 r
F
.75678 .71111 m .69536 .62292 L .70857 .61639 L F
.25 g
.5 Mabswid
.68163 .62956 m
.68444 .63343 L
s
.68444 .63343 m
.74088 .71106 L
s
0 g
.006 w
.74213 .71277 m
.75678 .71111 L
s
.25 g
.5 Mabswid
.7555 .70928 m
.75678 .71111 L
s
.69536 .62292 m
.7555 .70928 L
s
1 0 0 r
.003 w
.41052 .77852 m
.41523 .77395 L
s
.68163 .62956 m
.69536 .62292 L
s
.29635 .75566 m .40461 .78641 L .40699 .78271 L .644 .176 .127 r
F
.29022 .76958 m .40461 .78641 L .29635 .75566 L .553 .034 0 r
F
.25 g
.5 Mabswid
.37946 .7628 m
.41052 .77852 L
s
.38623 .77454 m
.40699 .78271 L
s
.36323 .76549 m
.38623 .77454 L
s
0 g
.006 w
.29635 .75566 m
.30455 .74241 L
s
.25 g
.5 Mabswid
.29635 .75566 m
.37406 .77773 L
s
1 0 0 r
.003 w
.40699 .78271 m
.41052 .77852 L
s
.77039 .70777 m .70857 .61639 L .72109 .60985 L .627 .543 .74 r
F
1 0 0 r
.69536 .62292 m
.70857 .61639 L
s
.48613 .30904 m .49442 .32317 L .46382 .3163 L .348 0 0 r
F
.48613 .30904 m .50766 .32463 L .49442 .32317 L F
.50877 .30222 m .50766 .32463 L .48613 .30904 L .527 0 0 r
F
.50877 .30222 m .5212 .32726 L .50766 .32463 L F
.5316 .29604 m .5212 .32726 L .50877 .30222 L .653 .159 .064 r
F
0 g
.006 w
.48613 .30904 m
.50877 .30222 L
s
.46382 .3163 m .48158 .32288 L .44197 .32384 L .153 0 0 r
F
.46382 .3163 m .49442 .32317 L .48158 .32288 L F
0 g
.46382 .3163 m
.48613 .30904 L
s
.25 g
.5 Mabswid
.46382 .3163 m
.4645 .31645 L
s
.48613 .30904 m
.505 .3227 L
s
.505 .3227 m
.50766 .32463 L
s
.77039 .70777 m .72109 .60985 L .78294 .7026 L .627 .543 .74 r
F
0 g
.006 w
.75678 .71111 m
.77039 .70777 L
s
.25 g
.5 Mabswid
.70857 .61639 m
.77039 .70777 L
s
.78294 .7026 m .72109 .60985 L .73277 .60319 L .604 .512 .723 r
F
1 0 0 r
.003 w
.70857 .61639 m
.72109 .60985 L
s
.5316 .29604 m .53491 .33107 L .5212 .32726 L .653 .159 .064 r
F
.25 g
.5 Mabswid
.50877 .30222 m
.5212 .32726 L
s
.5545 .29067 m .53491 .33107 L .5316 .29604 L .725 .299 .238 r
F
0 g
.006 w
.50877 .30222 m
.5316 .29604 L
s
.44197 .32384 m .46929 .32372 L .42071 .33151 L 0 0 0 r
F
.44197 .32384 m .48158 .32288 L .46929 .32372 L F
0 g
.44197 .32384 m
.46382 .3163 L
s
.25 g
.5 Mabswid
.44197 .32384 m
.44289 .32382 L
s
.4645 .31645 m
.48955 .32207 L
s
.48955 .32207 m
.49442 .32317 L
s
.79438 .69551 m .73277 .60319 L .74345 .59627 L .578 .48 .707 r
F
.25 g
.72109 .60985 m
.72555 .61654 L
s
.78294 .7026 m .73277 .60319 L .79438 .69551 L .604 .512 .723 r
F
1 0 0 r
.003 w
.72109 .60985 m
.73277 .60319 L
s
0 g
.006 w
.77039 .70777 m
.78294 .7026 L
s
.5545 .29067 m .5487 .336 L .53491 .33107 L .725 .299 .238 r
F
.25 g
.5 Mabswid
.5316 .29604 m
.53491 .33107 L
s
.57733 .28632 m .5487 .336 L .5545 .29067 L .76 .397 .367 r
F
0 g
.006 w
.5316 .29604 m
.5545 .29067 L
s
.42071 .33151 m .45767 .32564 L .40017 .33917 L 0 0 0 r
F
.42071 .33151 m .46929 .32372 L .45767 .32564 L F
0 g
.42071 .33151 m
.44197 .32384 L
s
.25 g
.5 Mabswid
.42071 .33151 m
.42192 .33131 L
s
.44289 .32382 m
.47278 .32309 L
s
.47278 .32309 m
.48158 .32288 L
s
.29022 .76958 m .40331 .78951 L .40461 .78641 L .553 .034 0 r
F
1 0 0 r
.003 w
.40461 .78641 m
.40699 .78271 L
s
.28629 .78395 m .40331 .78951 L .29022 .76958 L .418 0 0 r
F
.25 g
.5 Mabswid
.37406 .77773 m
.40461 .78641 L
s
0 g
.006 w
.29022 .76958 m
.29635 .75566 L
s
.25 g
.5 Mabswid
.29022 .76958 m
.39032 .78722 L
s
.8047 .68645 m .74345 .59627 L .75299 .589 L .547 .447 .692 r
F
.25 g
.73277 .60319 m
.73801 .61104 L
s
.72555 .61654 m
.72887 .62152 L
s
.79438 .69551 m .74345 .59627 L .8047 .68645 L .578 .48 .707 r
F
.25 g
.72887 .62152 m
.78294 .7026 L
s
1 0 0 r
.003 w
.73277 .60319 m
.74345 .59627 L
s
.25 g
.5 Mabswid
.79302 .69347 m
.79438 .69551 L
s
.57733 .28632 m .56252 .34197 L .5487 .336 L .76 .397 .367 r
F
.25 g
.5487 .336 m
.5545 .29067 L
s
.59996 .28319 m .56252 .34197 L .57733 .28632 L .774 .463 .461 r
F
0 g
.006 w
.5545 .29067 m
.57733 .28632 L
s
.40017 .33917 m .44684 .32858 L .38049 .34671 L 0 0 0 r
F
.40017 .33917 m .45767 .32564 L .44684 .32858 L F
.25 g
.5 Mabswid
.45143 .32658 m
.46929 .32372 L
s
0 g
.006 w
.40017 .33917 m
.42071 .33151 L
s
.25 g
.5 Mabswid
.40017 .33917 m
.40179 .33879 L
s
0 g
.006 w
.78294 .7026 m
.79438 .69551 L
s
.81388 .67538 m .75299 .589 L .76125 .5813 L .512 .413 .68 r
F
.25 g
.5 Mabswid
.74345 .59627 m
.74973 .60552 L
s
.73801 .61104 m
.74205 .61709 L
s
.8047 .68645 m .75299 .589 L .81388 .67538 L .547 .447 .692 r
F
1 0 0 r
.003 w
.74345 .59627 m
.75299 .589 L
s
.25 g
.5 Mabswid
.80326 .68432 m
.8047 .68645 L
s
.59996 .28319 m .5763 .34886 L .56252 .34197 L .774 .463 .461 r
F
.62225 .28147 m .5763 .34886 L .59996 .28319 L .776 .508 .531 r
F
.25 g
.57703 .28744 m
.57733 .28632 L
s
0 g
.006 w
.57733 .28632 m
.59996 .28319 L
s
.38049 .34671 m .43692 .33251 L .36181 .35403 L 0 0 0 r
F
.38049 .34671 m .44684 .32858 L .43692 .33251 L F
0 g
.38049 .34671 m
.40017 .33917 L
s
.25 g
.5 Mabswid
.383 .34603 m
.38303 .34602 L
s
.38049 .34671 m
.383 .34603 L
s
.42192 .33131 m
.45143 .32658 L
s
.28629 .78395 m .40297 .79192 L .40331 .78951 L .418 0 0 r
F
1 0 0 r
.003 w
.40331 .78951 m
.40461 .78641 L
s
.25 g
.5 Mabswid
.39032 .78722 m
.40331 .78951 L
s
.28464 .79854 m .40297 .79192 L .28629 .78395 L .245 0 0 r
F
0 g
.006 w
.28629 .78395 m
.29022 .76958 L
s
.82188 .66234 m .76125 .5813 L .76813 .5731 L .47 .378 .67 r
F
.25 g
.5 Mabswid
.75299 .589 m
.76078 .60006 L
s
.74973 .60552 m
.75483 .61303 L
s
.74205 .61709 m
.74762 .62544 L
s
.81388 .67538 m .76125 .5813 L .82188 .66234 L .512 .413 .68 r
F
1 0 0 r
.003 w
.75299 .589 m
.76125 .5813 L
s
.25 g
.5 Mabswid
.81239 .67327 m
.81388 .67538 L
s
.62225 .28147 m .59001 .35654 L .5763 .34886 L .776 .508 .531 r
F
.25 g
.5763 .34886 m
.57753 .34545 L
s
.56252 .34197 m
.57703 .28744 L
s
.64406 .28135 m .59001 .35654 L .62225 .28147 L .772 .541 .585 r
F
.25 g
.59948 .2845 m
.59996 .28319 L
s
0 g
.006 w
.59996 .28319 m
.62225 .28147 L
s
.82871 .64738 m .76813 .5731 L .77351 .5644 L .421 .344 .664 r
F
.25 g
.5 Mabswid
.76078 .60006 m
.76766 .60982 L
s
.75483 .61303 m
.76227 .62397 L
s
.74762 .62544 m
.75555 .63732 L
s
.82188 .66234 m .76813 .5731 L .82871 .64738 L .47 .378 .67 r
F
.25 g
.75555 .63732 m
.79302 .69347 L
s
.76125 .5813 m
.77152 .59502 L
s
1 0 0 r
.003 w
.76125 .5813 m
.76813 .5731 L
s
.25 g
.5 Mabswid
.82033 .66026 m
.82075 .66082 L
s
.82075 .66082 m
.82188 .66234 L
s
.36181 .35403 m .42798 .33736 L .34428 .36106 L .005 0 0 r
F
.36181 .35403 m .43692 .33251 L .42798 .33736 L F
0 g
.006 w
.36181 .35403 m
.38049 .34671 L
s
.25 g
.5 Mabswid
.36181 .35403 m
.36775 .35233 L
s
0 g
.006 w
.79438 .69551 m
.8047 .68645 L
s
.28464 .79854 m .40344 .79354 L .40297 .79192 L .245 0 0 r
F
1 0 0 r
.003 w
.40297 .79192 m
.40331 .78951 L
s
.25 g
.5 Mabswid
.28629 .78395 m
.40297 .79192 L
s
.83433 .6306 m .77351 .5644 L .77734 .55522 L .368 .313 .664 r
F
.25 g
.76227 .62397 m
.77379 .64093 L
s
.82871 .64738 m .77351 .5644 L .83433 .6306 L .421 .344 .664 r
F
.25 g
.77379 .64093 m
.80326 .68432 L
s
.76766 .60982 m
.77873 .62553 L
s
1 0 0 r
.003 w
.76813 .5731 m
.77351 .5644 L
s
.25 g
.5 Mabswid
.82705 .64534 m
.82748 .64587 L
s
.82748 .64587 m
.82847 .64709 L
s
.82847 .64709 m
.82871 .64738 L
s
.64406 .28135 m .60366 .36484 L .59001 .35654 L .772 .541 .585 r
F
.25 g
.59001 .35654 m
.59145 .35319 L
s
.57753 .34545 m
.59948 .2845 L
s
.66527 .28301 m .60366 .36484 L .64406 .28135 L .764 .564 .628 r
F
.25 g
.62161 .28296 m
.62225 .28147 L
s
0 g
.006 w
.62225 .28147 m
.64406 .28135 L
s
.28533 .81307 m .40344 .79354 L .28464 .79854 L .056 0 0 r
F
0 g
.28464 .79854 m
.28629 .78395 L
s
.83873 .61216 m .77734 .55522 L .77956 .54562 L .315 .291 .673 r
F
.25 g
.5 Mabswid
.80289 .63694 m
.82033 .66026 L
s
.83433 .6306 m .77734 .55522 L .83873 .61216 L .368 .313 .664 r
F
.25 g
.77152 .59502 m
.78202 .60906 L
s
.80454 .61774 m
.82705 .64534 L
s
.76813 .5731 m
.78329 .59169 L
s
1 0 0 r
.003 w
.77351 .5644 m
.77734 .55522 L
s
.25 g
.5 Mabswid
.83251 .62862 m
.83296 .62911 L
s
.83296 .62911 m
.83401 .63026 L
s
.83401 .63026 m
.83433 .6306 L
s
.77873 .62553 m
.81239 .67327 L
s
.34428 .36106 m .4201 .34313 L .32806 .36772 L .143 0 0 r
F
.34428 .36106 m .42798 .33736 L .4201 .34313 L F
0 g
.006 w
.34428 .36106 m
.36181 .35403 L
s
.25 g
.5 Mabswid
.34428 .36106 m
.34435 .36104 L
s
.34435 .36104 m
.35642 .35762 L
s
.40179 .33879 m
.45767 .32564 L
s
.28533 .81307 m .40454 .79433 L .40344 .79354 L .056 0 0 r
F
1 0 0 r
.003 w
.40297 .79192 m
.40344 .79354 L
s
.25 g
.5 Mabswid
.28464 .79854 m
.40344 .79354 L
s
.84188 .59223 m .77956 .54562 L .78014 .53568 L .272 .285 .692 r
F
.83873 .61216 m .77956 .54562 L .84188 .59223 L .315 .291 .673 r
F
1 0 0 r
.003 w
.77734 .55522 m
.77956 .54562 L
s
.25 g
.5 Mabswid
.83658 .61016 m
.83711 .61066 L
s
.83711 .61066 m
.83828 .61174 L
s
.83828 .61174 m
.83873 .61216 L
s
.80312 .59663 m
.83251 .62862 L
s
.78202 .60906 m
.80289 .63694 L
s
.66527 .28301 m .61722 .37359 L .60366 .36484 L .764 .564 .628 r
F
.25 g
.60366 .36484 m
.6052 .36166 L
s
.68573 .28658 m .61722 .37359 L .66527 .28301 L .754 .582 .663 r
F
.25 g
.6216 .28298 m
.62161 .28296 L
s
.64326 .283 m
.64406 .28135 L
s
0 g
.006 w
.64406 .28135 m
.66527 .28301 L
s
.8047 .68645 m
.81388 .67538 L
s
.84377 .57103 m .78014 .53568 L .77909 .5255 L .248 .301 .721 r
F
.84188 .59223 m .78014 .53568 L .84377 .57103 L .272 .285 .692 r
F
1 0 0 r
.003 w
.77956 .54562 m
.78014 .53568 L
s
.25 g
.5 Mabswid
.8383 .58954 m
.83881 .58993 L
s
.83881 .58993 m
.83969 .59059 L
s
.83969 .59059 m
.84117 .59169 L
s
.84117 .59169 m
.84188 .59223 L
s
.78329 .59169 m
.80454 .61774 L
s
.84435 .5488 m .77909 .5255 L .77644 .51521 L .253 .338 .757 r
F
.84377 .57103 m .77909 .5255 L .84435 .5488 L .248 .301 .721 r
F
1 0 0 r
.003 w
.77909 .5255 m
.78014 .53568 L
s
.25 g
.5 Mabswid
.80675 .55046 m
.83899 .56838 L
s
.83899 .56838 m
.84377 .57103 L
s
.77734 .55522 m
.83658 .61016 L
s
.77351 .5644 m
.78788 .58004 L
s
.78788 .58004 m
.80312 .59663 L
s
.32806 .36772 m .41329 .34977 L .3133 .37399 L .275 0 .087 r
F
.32806 .36772 m .4201 .34313 L .41329 .34977 L F
0 g
.006 w
.32806 .36772 m
.34428 .36106 L
s
.25 g
.5 Mabswid
.32806 .36772 m
.32811 .36771 L
s
.32811 .36771 m
.33525 .3658 L
s
.40198 .34797 m
.4201 .34313 L
s
.38303 .34602 m
.44684 .32858 L
s
.2884 .82726 m .40454 .79433 L .28533 .81307 L 0 0 0 r
F
0 g
.006 w
.28464 .79854 m
.28533 .81307 L
s
.2884 .82726 m .40609 .7943 L .40454 .79433 L 0 0 0 r
F
1 0 0 r
.003 w
.40344 .79354 m
.40454 .79433 L
s
.25 g
.5 Mabswid
.28533 .81307 m
.40454 .79433 L
s
.84359 .52583 m .77644 .51521 L .77223 .50491 L .286 .39 .795 r
F
.84435 .5488 m .77644 .51521 L .84359 .52583 L .253 .338 .757 r
F
1 0 0 r
.003 w
.77644 .51521 m
.77909 .5255 L
s
.25 g
.5 Mabswid
.84392 .54865 m
.84435 .5488 L
s
.80137 .53346 m
.84392 .54865 L
s
.78014 .53568 m
.80675 .55046 L
s
.77956 .54562 m
.8383 .58954 L
s
.68573 .28658 m .6307 .38263 L .61722 .37359 L .754 .582 .663 r
F
.25 g
.61722 .37359 m
.61986 .36862 L
s
.59145 .35319 m
.6216 .28298 L
s
.70532 .29219 m .6307 .38263 L .68573 .28658 L .743 .596 .693 r
F
.25 g
.64326 .28301 m
.64326 .283 L
s
.66432 .28479 m
.66527 .28301 L
s
0 g
.006 w
.66527 .28301 m
.68573 .28658 L
s
.84147 .5024 m .77223 .50491 L .76655 .4947 L .339 .448 .826 r
F
.84359 .52583 m .77223 .50491 L .84147 .5024 L .286 .39 .795 r
F
1 0 0 r
.003 w
.77223 .50491 m
.77644 .51521 L
s
.25 g
.5 Mabswid
.84276 .5257 m
.84359 .52583 L
s
.78571 .51668 m
.84276 .5257 L
s
.77644 .51521 m
.78571 .51668 L
s
.77909 .5255 m
.80137 .53346 L
s
.83796 .47884 m .76655 .4947 L .7595 .48465 L .401 .502 .847 r
F
.84147 .5024 m .76655 .4947 L .83796 .47884 L .339 .448 .826 r
F
1 0 0 r
.003 w
.76655 .4947 m
.77223 .50491 L
s
.25 g
.5 Mabswid
.77223 .50491 m
.84147 .5024 L
s
0 g
.006 w
.81388 .67538 m
.82188 .66234 L
s
.83302 .45546 m .7595 .48465 L .75121 .47482 L .461 .545 .856 r
F
.83796 .47884 m .7595 .48465 L .83302 .45546 L .401 .502 .847 r
F
.25 g
.5 Mabswid
.76655 .4947 m
.83796 .47884 L
s
1 0 0 r
.003 w
.7595 .48465 m
.76655 .4947 L
s
.29383 .84082 m .40609 .7943 L .2884 .82726 L .286 .766 .667 r
F
0 g
.006 w
.28533 .81307 m
.2884 .82726 L
s
.29383 .84082 m .40789 .79345 L .40609 .7943 L .286 .766 .667 r
F
1 0 0 r
.003 w
.40454 .79433 m
.40584 .7943 L
s
.25 g
.5 Mabswid
.2884 .82726 m
.40538 .79449 L
s
.82662 .43258 m .75121 .47482 L .74181 .46522 L .516 .577 .855 r
F
.83302 .45546 m .75121 .47482 L .82662 .43258 L .461 .545 .856 r
F
1 0 0 r
.003 w
.75121 .47482 m
.7595 .48465 L
s
.25 g
.5 Mabswid
.83175 .45596 m
.83302 .45546 L
s
.3133 .37399 m .40754 .35727 L .30018 .37985 L .382 .027 .233 r
F
.3133 .37399 m .41329 .34977 L .40754 .35727 L F
0 g
.006 w
.3133 .37399 m
.32806 .36772 L
s
.25 g
.5 Mabswid
.3133 .37399 m
.31411 .37379 L
s
.31411 .37379 m
.31461 .37367 L
s
.40244 .35239 m
.41329 .34977 L
s
.36775 .35233 m
.43692 .33251 L
s
.81876 .41051 m .74181 .46522 L .73147 .45583 L .562 .599 .848 r
F
.82662 .43258 m .74181 .46522 L .81876 .41051 L .516 .577 .855 r
F
.25 g
.7595 .48465 m
.83175 .45596 L
s
1 0 0 r
.003 w
.74181 .46522 m
.75121 .47482 L
s
.25 g
.5 Mabswid
.74181 .46522 m
.74383 .46379 L
s
.82528 .43333 m
.82662 .43258 L
s
.70532 .29219 m .6441 .39182 L .6307 .38263 L .743 .596 .693 r
F
.25 g
.6307 .38263 m
.63323 .37822 L
s
.6052 .36166 m
.64326 .28301 L
s
.72392 .29992 m .6441 .39182 L .70532 .29219 L .73 .606 .719 r
F
.25 g
.66432 .28479 m
.66432 .28479 L
s
.68465 .28846 m
.68573 .28658 L
s
0 g
.006 w
.68573 .28658 m
.70532 .29219 L
s
.80943 .38957 m .73147 .45583 L .72032 .44661 L .6 .613 .836 r
F
.81876 .41051 m .73147 .45583 L .80943 .38957 L .562 .599 .848 r
F
1 0 0 r
.003 w
.73147 .45583 m
.74181 .46522 L
s
.25 g
.5 Mabswid
.73147 .45583 m
.73542 .45247 L
s
.81747 .41143 m
.81876 .41051 L
s
.81735 .41151 m
.81747 .41143 L
s
.79863 .37 m .72032 .44661 L .70852 .43751 L .632 .62 .82 r
F
.80943 .38957 m .72032 .44661 L .79863 .37 L .6 .613 .836 r
F
1 0 0 r
.003 w
.72032 .44661 m
.73147 .45583 L
s
.25 g
.5 Mabswid
.72032 .44661 m
.72335 .44365 L
s
.80807 .39072 m
.80943 .38957 L
s
.80798 .3908 m
.80807 .39072 L
s
.78638 .35207 m .70852 .43751 L .69621 .42844 L .658 .623 .803 r
F
.79863 .37 m .70852 .43751 L .78638 .35207 L .632 .62 .82 r
F
.25 g
.75121 .47482 m
.82528 .43333 L
s
1 0 0 r
.003 w
.70852 .43751 m
.72032 .44661 L
s
.25 g
.5 Mabswid
.70852 .43751 m
.71287 .43273 L
s
.79782 .3708 m
.79863 .37 L
s
.79723 .37137 m
.79782 .3708 L
s
.79715 .37145 m
.79723 .37137 L
s
.77273 .33596 m .69621 .42844 L .68353 .41936 L .68 .623 .784 r
F
.78638 .35207 m .69621 .42844 L .77273 .33596 L .658 .623 .803 r
F
1 0 0 r
.003 w
.69621 .42844 m
.70852 .43751 L
s
.25 g
.5 Mabswid
.69621 .42844 m
.69933 .42468 L
s
.78554 .353 m
.78638 .35207 L
s
.78496 .35363 m
.78554 .353 L
s
.7849 .3537 m
.78496 .35363 L
s
.75772 .32184 m .68353 .41936 L .67056 .41023 L .699 .62 .764 r
F
.77273 .33596 m .68353 .41936 L .75772 .32184 L .68 .623 .784 r
F
.25 g
.70456 .29344 m
.70532 .29219 L
s
.74383 .46379 m
.81735 .41151 L
s
1 0 0 r
.003 w
.68353 .41936 m
.69621 .42844 L
s
.25 g
.5 Mabswid
.68665 .41526 m
.68733 .41436 L
s
.68353 .41936 m
.68665 .41526 L
s
.77186 .33701 m
.77273 .33596 L
s
.77131 .33768 m
.77186 .33701 L
s
.77126 .33774 m
.77131 .33768 L
s
0 g
.006 w
.82188 .66234 m
.82871 .64738 L
s
.30155 .85344 m .40789 .79345 L .29383 .84082 L .419 .84 .68 r
F
0 g
.2884 .82726 m
.29383 .84082 L
s
.30155 .85344 m .40978 .79187 L .40789 .79345 L .419 .84 .68 r
F
.25 g
.5 Mabswid
.29383 .84082 m
.40459 .79482 L
s
.74142 .30981 m .67056 .41023 L .6574 .40104 L .715 .614 .743 r
F
.75772 .32184 m .67056 .41023 L .74142 .30981 L .699 .62 .764 r
F
.25 g
.70414 .29412 m
.70456 .29344 L
s
1 0 0 r
.003 w
.67056 .41023 m
.68353 .41936 L
s
.25 g
.5 Mabswid
.67056 .41023 m
.67314 .40658 L
s
.75685 .32298 m
.75772 .32184 L
s
.75632 .32367 m
.75685 .32298 L
s
.75629 .32372 m
.75632 .32367 L
s
.72392 .29992 m .6574 .40104 L .6441 .39182 L .73 .606 .719 r
F
.25 g
.6441 .39182 m
.6464 .38808 L
s
.74142 .30981 m .6574 .40104 L .72392 .29992 L .715 .614 .743 r
F
0 g
.006 w
.70532 .29219 m
.72392 .29992 L
s
.25 g
.5 Mabswid
.61986 .36862 m
.66432 .28479 L
s
.63323 .37822 m
.68465 .28846 L
s
.6464 .38808 m
.70413 .29414 L
s
.70413 .29414 m
.70414 .29412 L
s
.72335 .44365 m
.79715 .37145 L
s
.71287 .43273 m
.7849 .3537 L
s
.69933 .42468 m
.77126 .33774 L
s
.68733 .41436 m
.75629 .32372 L
s
.67314 .40658 m
.74005 .31175 L
s
1 0 0 r
.003 w
.6574 .40104 m
.67056 .41023 L
s
.25 g
.5 Mabswid
.66052 .3963 m
.72263 .30189 L
s
.72263 .30189 m
.72265 .30186 L
s
.72265 .30186 m
.72311 .30116 L
s
.72311 .30116 m
.72392 .29992 L
s
.6574 .40104 m
.66052 .3963 L
s
.74057 .31101 m
.74142 .30981 L
s
.74007 .31171 m
.74057 .31101 L
s
.74005 .31175 m
.74007 .31171 L
s
.73542 .45247 m
.80798 .3908 L
s
0 g
.006 w
.72392 .29992 m
.74142 .30981 L
s
1 0 0 r
.003 w
.6441 .39182 m
.6574 .40104 L
s
.30018 .37985 m .40279 .36564 L .28886 .3853 L .465 .143 .335 r
F
.30018 .37985 m .40754 .35727 L .40279 .36564 L F
0 g
.006 w
.30018 .37985 m
.3133 .37399 L
s
.25 g
.5 Mabswid
.30018 .37985 m
.30044 .37979 L
s
.30044 .37979 m
.3014 .37959 L
s
.3014 .37959 m
.30177 .37951 L
s
.39973 .35892 m
.40754 .35727 L
s
.38647 .3617 m
.39973 .35892 L
s
.38034 .35775 m
.40244 .35239 L
s
.35642 .35762 m
.42798 .33736 L
s
1 0 0 r
.003 w
.6307 .38263 m
.6441 .39182 L
s
.61722 .37359 m
.6307 .38263 L
s
.60366 .36484 m
.61722 .37359 L
s
.59001 .35654 m
.60366 .36484 L
s
.5763 .34886 m
.59001 .35654 L
s
.56252 .34197 m
.5763 .34886 L
s
.5487 .336 m
.56252 .34197 L
s
.53491 .33107 m
.5487 .336 L
s
.5212 .32726 m
.53491 .33107 L
s
.50766 .32463 m
.5212 .32726 L
s
.49442 .32317 m
.50766 .32463 L
s
.48158 .32288 m
.49442 .32317 L
s
.46929 .32372 m
.48158 .32288 L
s
.31147 .86484 m .40978 .79187 L .30155 .85344 L .525 .884 .659 r
F
0 g
.006 w
.29383 .84082 m
.30155 .85344 L
s
.31251 .86407 m .41161 .78965 L .40978 .79187 L .525 .884 .659 r
F
.31351 .86331 m .41161 .78965 L .31251 .86407 L F
.31147 .86484 m .31351 .86331 L .31251 .86407 L F
.32343 .87472 m .41161 .78965 L .31147 .86484 L .607 .9 .611 r
F
.32435 .87383 m .41327 .78691 L .41161 .78965 L F
.32343 .87472 m .32524 .87295 L .32435 .87383 L F
.32524 .87295 m .41327 .78691 L .32435 .87383 L F
.33721 .88282 m .41209 .7884 L .32343 .87472 L .667 .892 .538 r
F
.41209 .7884 m .41327 .78691 L .41054 .78957 L F
.41209 .7884 m .41054 .78957 L .32343 .87472 L F
.338 .88183 m .4147 .78378 L .41327 .78691 L F
.33721 .88282 m .33876 .88083 L .338 .88183 L F
.33876 .88083 m .4147 .78378 L .338 .88183 L F
.35259 .8889 m .41391 .78513 L .33721 .88282 L .703 .858 .443 r
F
.41391 .78513 m .4147 .78378 L .41276 .78627 L F
.41391 .78513 m .41276 .78627 L .33721 .88282 L F
.35322 .88783 m .4159 .78037 L .4147 .78378 L F
.35259 .8889 m .35384 .88674 L .35322 .88783 L F
.35384 .88674 m .4159 .78037 L .35322 .88783 L F
.36926 .89276 m .41542 .78153 L .35259 .8889 L .715 .799 .326 r
F
.41542 .78153 m .4159 .78037 L .41463 .78256 L F
.41542 .78153 m .41463 .78256 L .35259 .8889 L F
.36973 .89163 m .41688 .77679 L .4159 .78037 L F
.36926 .89276 m .3702 .89048 L .36973 .89163 L F
.3702 .89048 m .41688 .77679 L .36973 .89163 L F
.38692 .89425 m .41665 .77769 L .36926 .89276 L .7 .713 .187 r
F
.41665 .77769 m .41688 .77679 L .41616 .77855 L F
.41665 .77769 m .41616 .77855 L .36926 .89276 L F
.38692 .89425 m .41772 .77308 L .41688 .77679 L F
.40522 .89326 m .41765 .77371 L .38692 .89425 L 0 0 0 r
F
.41765 .77371 m .41772 .77308 L .4174 .77432 L F
.41765 .77371 m .4174 .77432 L .38692 .89425 L F
.25 g
.5 Mabswid
.30155 .85344 m
.3038 .85217 L
s
.3038 .85217 m
.40512 .79452 L
s
0 g
.006 w
.74142 .30981 m
.75772 .32184 L
s
.82871 .64738 m
.83433 .6306 L
s
1 0 0 r
.003 w
.45767 .32564 m
.46929 .32372 L
s
.44684 .32858 m
.45767 .32564 L
s
.28886 .3853 m .39896 .37485 L .2795 .39039 L .53 .231 .404 r
F
.28886 .3853 m .40279 .36564 L .39896 .37485 L F
0 g
.006 w
.28886 .3853 m
.30018 .37985 L
s
.25 g
.5 Mabswid
.28886 .3853 m
.28944 .3852 L
s
.28944 .3852 m
.29038 .38504 L
s
.29038 .38504 m
.29066 .38499 L
s
.38731 .36831 m
.40279 .36564 L
s
.31461 .37367 m
.38034 .35775 L
s
.33525 .3658 m
.40198 .34797 L
s
1 0 0 r
.003 w
.43692 .33251 m
.44684 .32858 L
s
0 g
.006 w
.30155 .85344 m
.31147 .86484 L
s
.75772 .32184 m
.77273 .33596 L
s
.25 g
.5 Mabswid
.31147 .86484 m
.31351 .86331 L
s
.31351 .86331 m
.31352 .8633 L
s
.31352 .8633 m
.40668 .79334 L
s
0 g
.006 w
.83433 .6306 m
.83873 .61216 L
s
1 0 0 r
.003 w
.42798 .33736 m
.43692 .33251 L
s
.4201 .34313 m
.42798 .33736 L
s
0 g
.006 w
.77273 .33596 m
.78638 .35207 L
s
.83873 .61216 m
.84188 .59223 L
s
1 0 0 r
.003 w
.41329 .34977 m
.4201 .34313 L
s
.2795 .39039 m .39593 .38489 L .27228 .39516 L .582 .299 .452 r
F
.2795 .39039 m .39896 .37485 L .39593 .38489 L F
.25 g
.5 Mabswid
.29066 .38499 m
.38731 .36831 L
s
0 g
.006 w
.2795 .39039 m
.28886 .3853 L
s
.25 g
.5 Mabswid
.2795 .39039 m
.28126 .39016 L
s
.28126 .39016 m
.28149 .39013 L
s
.39418 .37547 m
.39896 .37485 L
s
.30177 .37951 m
.38647 .3617 L
s
.32343 .87472 m
.32524 .87295 L
s
.32524 .87295 m
.32524 .87294 L
s
.32524 .87294 m
.40896 .79112 L
s
0 g
.006 w
.31147 .86484 m
.32343 .87472 L
s
.78638 .35207 m
.79863 .37 L
s
1 0 0 r
.003 w
.40754 .35727 m
.41329 .34977 L
s
0 g
.006 w
.84188 .59223 m
.84377 .57103 L
s
1 0 0 r
.003 w
.40279 .36564 m
.40754 .35727 L
s
.25 g
.5 Mabswid
.33721 .88282 m
.33876 .88083 L
s
.33876 .88083 m
.41159 .78776 L
s
0 g
.006 w
.79863 .37 m
.80943 .38957 L
s
.32343 .87472 m
.33721 .88282 L
s
.84377 .57103 m
.84435 .5488 L
s
.27228 .39516 m .39355 .39573 L .26733 .39969 L .626 .353 .485 r
F
.27228 .39516 m .39593 .38489 L .39355 .39573 L F
0 g
.27228 .39516 m
.2795 .39039 L
s
.25 g
.5 Mabswid
.27228 .39516 m
.27421 .39499 L
s
.39214 .38521 m
.39593 .38489 L
s
.27441 .39498 m
.39214 .38521 L
s
.27421 .39499 m
.27441 .39498 L
s
.28149 .39013 m
.39418 .37547 L
s
1 0 0 r
.003 w
.39896 .37485 m
.40279 .36564 L
s
0 g
.006 w
.80943 .38957 m
.81876 .41051 L
s
.84359 .52583 m
.84435 .5488 L
s
.25 g
.5 Mabswid
.35259 .8889 m
.35384 .88674 L
s
.35384 .88674 m
.41425 .7832 L
s
0 g
.006 w
.81876 .41051 m
.82662 .43258 L
s
1 0 0 r
.003 w
.39593 .38489 m
.39896 .37485 L
s
0 g
.006 w
.84147 .5024 m
.84359 .52583 L
s
.82662 .43258 m
.83302 .45546 L
s
.83796 .47884 m
.84147 .5024 L
s
.33721 .88282 m
.35259 .8889 L
s
.83302 .45546 m
.83796 .47884 L
s
.26733 .39969 m .39169 .40733 L .26479 .40408 L .665 .398 .507 r
F
.26733 .39969 m .39355 .39573 L .39169 .40733 L F
0 g
.26733 .39969 m
.27228 .39516 L
s
.25 g
.5 Mabswid
.26733 .39969 m
.39355 .39573 L
s
1 0 0 r
.003 w
.39355 .39573 m
.39593 .38489 L
s
.25 g
.5 Mabswid
.36926 .89276 m
.3702 .89048 L
s
.41616 .77855 m
.4166 .77747 L
s
0 g
.006 w
.35259 .8889 m
.36926 .89276 L
s
.26479 .40408 m .39169 .40733 L .39018 .41961 L .701 .437 .522 r
F
1 0 0 r
.003 w
.39169 .40733 m
.39355 .39573 L
s
.40522 .89326 m .41848 .76928 L .41772 .77308 L 0 0 0 r
F
.25 g
.5 Mabswid
.4174 .77432 m
.41772 .77308 L
s
.3702 .89048 m
.41616 .77855 L
s
.26479 .40408 m .39018 .41961 L .26477 .40847 L .701 .437 .522 r
F
0 g
.006 w
.26479 .40408 m
.26733 .39969 L
s
.25 g
.5 Mabswid
.26479 .40408 m
.39169 .40733 L
s
.26477 .40847 m .39018 .41961 L .38892 .4325 L .735 .472 .532 r
F
1 0 0 r
.003 w
.39018 .41961 m
.39169 .40733 L
s
0 g
.006 w
.36926 .89276 m
.38692 .89425 L
s
.42382 .88972 m .41848 .76928 L .40522 .89326 L 0 0 .138 r
F
.25 g
.5 Mabswid
.40522 .89326 m
.41842 .76991 L
s
.38692 .89425 m
.38752 .89189 L
s
.38752 .89189 m
.4174 .77432 L
s
.42382 .88972 m .41927 .76534 L .41848 .76928 L 0 0 .138 r
F
1 0 0 r
.003 w
.41772 .77308 m
.41848 .76928 L
s
.25 g
.5 Mabswid
.41842 .76991 m
.41848 .76928 L
s
.26733 .41299 m .38892 .4325 L .38781 .44588 L .769 .506 .536 r
F
.26477 .40847 m .38892 .4325 L .26733 .41299 L .735 .472 .532 r
F
.25 g
.26477 .40847 m
.39018 .41961 L
s
1 0 0 r
.003 w
.38892 .4325 m
.39018 .41961 L
s
0 g
.006 w
.26477 .40847 m
.26479 .40408 L
s
.2725 .41781 m .38781 .44588 L .3868 .45964 L .804 .538 .537 r
F
.31488 .42597 m .38781 .44588 L .32394 .43033 L .769 .506 .536 r
F
.28026 .4231 m .3868 .45964 L .38588 .47367 L .84 .571 .531 r
F
.2725 .41781 m .33586 .441 L .28026 .4231 L .804 .538 .537 r
F
.33586 .441 m .3868 .45964 L .34278 .44455 L F
.33586 .441 m .34278 .44455 L .28026 .4231 L F
.29052 .42906 m .38588 .47367 L .3851 .48785 L .879 .605 .519 r
F
.28026 .4231 m .36055 .46154 L .29052 .42906 L .84 .571 .531 r
F
.36055 .46154 m .38588 .47367 L .36441 .46362 L F
.36055 .46154 m .36441 .46362 L .29052 .42906 L F
.33326 .40777 m .39714 .47616 L .39613 .48947 L .965 .683 .449 r
F
.37379 .46044 m .38464 .47454 L .37948 .46336 L F
.38464 .47454 m .39527 .48835 L .38765 .47617 L F
.38464 .47454 m .38765 .47617 L .37948 .46336 L F
.37379 .46044 m .37948 .46336 L .3737 .45429 L F
.39527 .48835 m .39613 .48947 L .39489 .48753 L F
.39527 .48835 m .39489 .48753 L .38765 .47617 L F
.36632 .45074 m .37379 .46044 L .3737 .45429 L F
.36632 .45074 m .3737 .45429 L .34922 .41588 L F
.34922 .41588 m .39613 .48947 L .39552 .50275 L .987 .713 .379 r
F
.34922 .41588 m .39476 .50132 L .36668 .42551 L F
.39476 .50132 m .39552 .50275 L .39461 .50031 L F
.39476 .50132 m .39461 .50031 L .36668 .42551 L F
.36698 .42648 m .39552 .50275 L .39541 .51595 L .953 .705 .248 r
F
.36728 .42713 m .39552 .50275 L .36698 .42648 L F
.36668 .42551 m .36728 .42713 L .36698 .42648 L F
.36668 .42551 m .39541 .51595 L .38527 .43676 L F
.38538 .43777 m .39541 .51595 L .3959 .52909 L .79 .603 .039 r
F
.38527 .43676 m .38548 .43844 L .38538 .43777 L F
.38548 .43844 m .39541 .51595 L .38538 .43777 L F
.33326 .40777 m .36632 .45074 L .34922 .41588 L .965 .683 .449 r
F
.26733 .41299 m .31488 .42597 L .2725 .41781 L .769 .506 .536 r
F
.31488 .42597 m .32394 .43033 L .2725 .41781 L F
.25 g
.5 Mabswid
.26964 .41336 m
.30702 .41935 L
s
.30702 .41935 m
.34712 .42579 L
s
.38848 .43242 m
.38892 .4325 L
s
.3874 .43225 m
.38848 .43242 L
s
.37436 .43016 m
.3874 .43225 L
s
1 0 0 r
.003 w
.38781 .44588 m
.38892 .4325 L
s
.25 g
.5 Mabswid
.2725 .41781 m
.27473 .41835 L
s
.32394 .43033 m
.35677 .43832 L
s
.38738 .44577 m
.38781 .44588 L
s
.38652 .44556 m
.38738 .44577 L
s
.38639 .44553 m
.38652 .44556 L
s
0 g
.006 w
.26477 .40847 m
.26733 .41299 L
s
.25 g
.5 Mabswid
.26733 .41299 m
.26964 .41336 L
s
1 0 0 r
.003 w
.38731 .45271 m
.38781 .44588 L
s
0 g
.006 w
.38692 .89425 m
.40522 .89326 L
s
.44234 .88362 m .41927 .76534 L .42382 .88972 L 0 0 .31 r
F
.44234 .88362 m .42014 .76121 L .41927 .76534 L F
1 0 0 r
.003 w
.41848 .76928 m
.41927 .76534 L
s
.25 g
.5 Mabswid
.28026 .4231 m
.2823 .42381 L
s
.2823 .42381 m
.28235 .42382 L
s
.46043 .87499 m .42014 .76121 L .44234 .88362 L 0 0 .472 r
F
.25 g
.42373 .88735 m
.42382 .88972 L
s
.46043 .87499 m .42116 .75677 L .42014 .76121 L 0 0 .472 r
F
.25 g
.41927 .76534 m
.4193 .76627 L
s
1 0 0 r
.003 w
.41927 .76534 m
.42014 .76121 L
s
.38525 .48513 m
.38531 .48415 L
s
0 g
.006 w
.40522 .89326 m
.42382 .88972 L
s
.26733 .41299 m
.2725 .41781 L
s
.29052 .42906 m .3851 .48785 L .30313 .43586 L .879 .605 .519 r
F
.25 g
.5 Mabswid
.36608 .47579 m
.3851 .48785 L
s
.3048 .43691 m
.36608 .47579 L
s
.30478 .4369 m
.3048 .43691 L
s
.30419 .43653 m
.30478 .4369 L
s
.30313 .43586 m
.30419 .43653 L
s
1 0 0 r
.003 w
.3851 .48785 m
.38525 .48513 L
s
.25 g
.5 Mabswid
.36441 .46362 m
.37807 .47002 L
s
.3462 .45511 m
.36441 .46362 L
s
.29242 .42995 m
.3462 .45511 L
s
.29239 .42994 m
.29242 .42995 L
s
.29171 .42962 m
.29239 .42994 L
s
.29052 .42906 m
.29171 .42962 L
s
.34278 .44455 m
.36829 .45329 L
s
.28235 .42382 m
.34278 .44455 L
s
.27473 .41835 m
.32394 .43033 L
s
.39576 .47468 m
.39714 .47616 L
s
.39473 .47358 m
.39576 .47468 L
s
.39341 .47217 m
.39473 .47358 L
s
.38923 .46769 m
.39341 .47217 L
s
1 0 0 r
.003 w
.39613 .48947 m
.39714 .47616 L
s
.47776 .86392 m .42116 .75677 L .46043 .87499 L 0 .052 .612 r
F
.25 g
.5 Mabswid
.44192 .88131 m
.44234 .88362 L
s
.47776 .86392 m .42233 .75191 L .42116 .75677 L 0 .052 .612 r
F
.25 g
.41936 .768 m
.42373 .88735 L
s
.4193 .76627 m
.41936 .768 L
s
.42014 .76121 m
.4204 .76261 L
s
1 0 0 r
.003 w
.42014 .76121 m
.42116 .75677 L
s
0 g
.006 w
.42382 .88972 m
.44234 .88362 L
s
.25 g
.5 Mabswid
.39489 .48753 m
.39613 .48947 L
s
.39399 .48612 m
.39489 .48753 L
s
.39098 .4814 m
.39399 .48612 L
s
1 0 0 r
.003 w
.39552 .50275 m
.39613 .48947 L
s
0 g
.006 w
.2725 .41781 m
.28026 .4231 L
s
.49398 .85053 m .42233 .75191 L .47776 .86392 L 0 .205 .721 r
F
.25 g
.5 Mabswid
.45971 .8728 m
.46043 .87499 L
s
.49398 .85053 m .42363 .74647 L .42233 .75191 L 0 .205 .721 r
F
.25 g
.42082 .76495 m
.44192 .88131 L
s
.4204 .76261 m
.42082 .76495 L
s
.42116 .75677 m
.42179 .75867 L
s
1 0 0 r
.003 w
.42116 .75677 m
.42233 .75191 L
s
0 g
.006 w
.44234 .88362 m
.46043 .87499 L
s
.25 g
.5 Mabswid
.39461 .50031 m
.39552 .50275 L
s
.39278 .49542 m
.39461 .50031 L
s
1 0 0 r
.003 w
.39541 .51595 m
.39552 .50275 L
s
.50879 .83495 m .42363 .74647 L .49398 .85053 L .132 .332 .797 r
F
.25 g
.5 Mabswid
.47675 .86188 m
.47776 .86392 L
s
.50879 .83495 m .42499 .74034 L .42363 .74647 L .132 .332 .797 r
F
.25 g
.42278 .76165 m
.45971 .8728 L
s
.42179 .75867 m
.42278 .76165 L
s
.42233 .75191 m
.42352 .75431 L
s
1 0 0 r
.003 w
.42233 .75191 m
.42363 .74647 L
s
0 g
.006 w
.28026 .4231 m
.29052 .42906 L
s
.46043 .87499 m
.47776 .86392 L
s
.52193 .81739 m .42499 .74034 L .50879 .83495 L .257 .43 .842 r
F
.25 g
.5 Mabswid
.49272 .84867 m
.49398 .85053 L
s
.52193 .81739 m .42632 .73341 L .42499 .74034 L .257 .43 .842 r
F
.25 g
.42533 .75796 m
.47675 .86188 L
s
.42352 .75431 m
.42533 .75796 L
s
.42363 .74647 m
.4256 .74939 L
s
1 0 0 r
.003 w
.42363 .74647 m
.42499 .74034 L
s
.40459 .44972 m .3959 .52909 L .39706 .54219 L 0 0 .2 r
F
.38527 .43676 m .3959 .52909 L .40459 .44972 L .79 .603 .039 r
F
0 g
.006 w
.47776 .86392 m
.49398 .85053 L
s
.53314 .79804 m .42632 .73341 L .52193 .81739 L .36 .498 .862 r
F
.25 g
.5 Mabswid
.50734 .83331 m
.50879 .83495 L
s
.53314 .79804 m .42748 .7256 L .42632 .73341 L .36 .498 .862 r
F
.25 g
.4256 .74939 m
.42856 .75376 L
s
.42499 .74034 m
.42804 .74378 L
s
1 0 0 r
.003 w
.42499 .74034 m
.42632 .73341 L
s
.42422 .4644 m .39706 .54219 L .39888 .55528 L 0 0 .382 r
F
.25 g
.5 Mabswid
.3959 .52909 m
.39628 .52568 L
s
.40459 .44972 m .39706 .54219 L .42422 .4644 L 0 0 .2 r
F
1 0 0 r
.003 w
.3959 .52909 m
.39706 .54219 L
s
0 g
.006 w
.29052 .42906 m
.30313 .43586 L
s
.54221 .77714 m .42748 .7256 L .53314 .79804 L .44 .541 .863 r
F
.25 g
.5 Mabswid
.52034 .81599 m
.52193 .81739 L
s
.54221 .77714 m .42834 .71686 L .42748 .7256 L .44 .541 .863 r
F
.25 g
.43288 .76016 m
.49272 .84867 L
s
.42856 .75376 m
.43288 .76016 L
s
.42804 .74378 m
.43263 .74897 L
s
.42632 .73341 m
.43087 .73741 L
s
1 0 0 r
.003 w
.42632 .73341 m
.42748 .7256 L
s
.44372 .48079 m .39888 .55528 L .40133 .5684 L .064 .021 .492 r
F
.25 g
.5 Mabswid
.39706 .54219 m
.39841 .53831 L
s
.39628 .52568 m
.39654 .52326 L
s
.42422 .4644 m .39888 .55528 L .44372 .48079 L 0 0 .382 r
F
1 0 0 r
.003 w
.39706 .54219 m
.39888 .55528 L
s
.25 g
.5 Mabswid
.42363 .46609 m
.42422 .4644 L
s
0 g
.006 w
.49398 .85053 m
.50879 .83495 L
s
.46267 .49884 m .40133 .5684 L .40432 .58158 L .227 .151 .557 r
F
.25 g
.5 Mabswid
.39888 .55528 m
.40148 .55096 L
s
.39841 .53831 m
.39938 .53553 L
s
.39654 .52326 m
.39688 .52018 L
s
.44372 .48079 m .40133 .5684 L .46267 .49884 L .064 .021 .492 r
F
1 0 0 r
.003 w
.39888 .55528 m
.40133 .5684 L
s
.25 g
.5 Mabswid
.44271 .48247 m
.44372 .48079 L
s
.54898 .75493 m .42834 .71686 L .54221 .77714 L .5 .564 .852 r
F
.25 g
.53148 .79691 m
.53314 .79804 L
s
.54898 .75493 m .42877 .70722 L .42834 .71686 L .5 .564 .852 r
F
.25 g
.43953 .75676 m
.50734 .83331 L
s
.43263 .74897 m
.43953 .75676 L
s
.43087 .73741 m
.43794 .74362 L
s
.42748 .7256 m
.43428 .73026 L
s
1 0 0 r
.003 w
.42748 .7256 m
.42834 .71686 L
s
0 g
.006 w
.50879 .83495 m
.52193 .81739 L
s
.48066 .51842 m .40432 .58158 L .40772 .59484 L .34 .246 .6 r
F
.25 g
.5 Mabswid
.40133 .5684 m
.4055 .56368 L
s
.40148 .55096 m
.40337 .54782 L
s
.39938 .53553 m
.40063 .53196 L
s
.39688 .52018 m
.39731 .51622 L
s
.46267 .49884 m .40432 .58158 L .48066 .51842 L .227 .151 .557 r
F
.25 g
.39731 .51622 m
.40459 .44972 L
s
1 0 0 r
.003 w
.40133 .5684 m
.40432 .58158 L
s
.25 g
.5 Mabswid
.46169 .49994 m
.46267 .49884 L
s
.46127 .50042 m
.46169 .49994 L
s
0 g
.006 w
.33326 .40777 m
.34922 .41588 L
s
.55329 .73167 m .42877 .70722 L .54898 .75493 L .541 .57 .833 r
F
.25 g
.5 Mabswid
.54059 .77629 m
.54221 .77714 L
s
.43794 .74362 m
.52034 .81599 L
s
.55329 .73167 m .42865 .6967 L .42877 .70722 L .541 .57 .833 r
F
.25 g
.44559 .73801 m
.53148 .79691 L
s
.43428 .73026 m
.44559 .73801 L
s
.42834 .71686 m
.43894 .72247 L
s
1 0 0 r
.003 w
.42834 .71686 m
.42877 .70722 L
s
.49733 .5394 m .40772 .59484 L .41135 .60817 L .419 .317 .633 r
F
.25 g
.5 Mabswid
.4055 .56368 m
.40859 .56016 L
s
.40337 .54782 m
.40584 .54372 L
s
.48066 .51842 m .40772 .59484 L .49733 .5394 L .34 .246 .6 r
F
.25 g
.40432 .58158 m
.41047 .5765 L
s
1 0 0 r
.003 w
.40432 .58158 m
.40772 .59484 L
s
.25 g
.5 Mabswid
.48056 .5185 m
.48066 .51842 L
s
.47941 .51945 m
.48056 .5185 L
s
.47888 .51989 m
.47941 .51945 L
s
.40063 .53196 m
.42363 .46609 L
s
.55507 .70761 m .42865 .6967 L .55329 .73167 L .566 .564 .81 r
F
.25 g
.54759 .75438 m
.54898 .75493 L
s
.43894 .72247 m
.54059 .77629 L
s
.55507 .70761 m .4279 .6854 L .42865 .6967 L .566 .564 .81 r
F
.25 g
.44769 .71473 m
.54759 .75438 L
s
.42877 .70722 m
.44769 .71473 L
s
1 0 0 r
.003 w
.42865 .6967 m
.42877 .70722 L
s
0 g
.006 w
.52193 .81739 m
.53314 .79804 L
s
.51234 .5616 m .41135 .60817 L .41502 .62152 L .477 .375 .66 r
F
.49733 .5394 m .41135 .60817 L .51234 .5616 L .419 .317 .633 r
F
.25 g
.5 Mabswid
.41047 .5765 m
.41519 .57259 L
s
.40772 .59484 m
.41644 .58945 L
s
1 0 0 r
.003 w
.40772 .59484 m
.41135 .60817 L
s
.25 g
.5 Mabswid
.49717 .5395 m
.49733 .5394 L
s
.49581 .54034 m
.49717 .5395 L
s
.49519 .54073 m
.49581 .54034 L
s
.40859 .56016 m
.46127 .50042 L
s
.40584 .54372 m
.44271 .48247 L
s
.55424 .68302 m .4279 .6854 L .55507 .70761 L .578 .549 .785 r
F
.25 g
.55272 .73151 m
.55329 .73167 L
s
.42865 .6967 m
.55272 .73151 L
s
.55424 .68302 m .42647 .67343 L .4279 .6854 L .578 .549 .785 r
F
1 0 0 r
.003 w
.4279 .6854 m
.42865 .6967 L
s
.25 g
.5 Mabswid
.4279 .6854 m
.55507 .70761 L
s
.5254 .58482 m .41502 .62152 L .41853 .63484 L .519 .423 .685 r
F
.51234 .5616 m .41502 .62152 L .5254 .58482 L .477 .375 .66 r
F
1 0 0 r
.003 w
.41135 .60817 m
.41502 .62152 L
s
.25 g
.5 Mabswid
.51055 .56243 m
.51234 .5616 L
s
.50985 .56275 m
.51055 .56243 L
s
.41519 .57259 m
.47888 .51989 L
s
.55081 .65819 m .42647 .67343 L .55424 .68302 L .579 .526 .76 r
F
.55081 .65819 m .42439 .66092 L .42647 .67343 L F
1 0 0 r
.003 w
.42647 .67343 m
.4279 .6854 L
s
.25 g
.5 Mabswid
.42647 .67343 m
.55424 .68302 L
s
0 g
.006 w
.34922 .41588 m
.36668 .42551 L
s
.53628 .60882 m .41853 .63484 L .4217 .64801 L .55 .463 .71 r
F
.5254 .58482 m .41853 .63484 L .53628 .60882 L .519 .423 .685 r
F
1 0 0 r
.003 w
.41502 .62152 m
.41853 .63484 L
s
.25 g
.5 Mabswid
.52257 .58576 m
.5254 .58482 L
s
.42361 .60251 m
.50985 .56275 L
s
.41135 .60817 m
.42361 .60251 L
s
.42347 .5851 m
.49519 .54073 L
s
.41644 .58945 m
.42347 .5851 L
s
.54479 .63336 m .42439 .66092 L .55081 .65819 L .569 .497 .735 r
F
.54479 .63336 m .4217 .64801 L .42439 .66092 L F
1 0 0 r
.003 w
.42439 .66092 m
.42647 .67343 L
s
.25 g
.5 Mabswid
.42439 .66092 m
.55081 .65819 L
s
.53628 .60882 m .4217 .64801 L .54479 .63336 L .55 .463 .71 r
F
.25 g
.5414 .63377 m
.54479 .63336 L
s
.4217 .64801 m
.5414 .63377 L
s
1 0 0 r
.003 w
.4217 .64801 m
.42439 .66092 L
s
.41853 .63484 m
.4217 .64801 L
s
.25 g
.5 Mabswid
.41853 .63484 m
.4458 .62881 L
s
.4458 .62881 m
.53327 .60949 L
s
.53327 .60949 m
.53628 .60882 L
s
.43265 .61566 m
.52257 .58576 L
s
.41502 .62152 m
.43265 .61566 L
s
0 g
.006 w
.53314 .79804 m
.54221 .77714 L
s
.36668 .42551 m
.38527 .43676 L
s
.54221 .77714 m
.54898 .75493 L
s
.54898 .75493 m
.55329 .73167 L
s
.38527 .43676 m
.40459 .44972 L
s
.55329 .73167 m
.55507 .70761 L
s
.40459 .44972 m
.42422 .4644 L
s
.55424 .68302 m
.55507 .70761 L
s
.42422 .4644 m
.44372 .48079 L
s
.55081 .65819 m
.55424 .68302 L
s
.54479 .63336 m
.55081 .65819 L
s
.44372 .48079 m
.46267 .49884 L
s
.53628 .60882 m
.54479 .63336 L
s
.46267 .49884 m
.48066 .51842 L
s
.5254 .58482 m
.53628 .60882 L
s
.48066 .51842 m
.49733 .5394 L
s
.51234 .5616 m
.5254 .58482 L
s
.49733 .5394 m
.51234 .5616 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.313, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400049000181000`40O003h00Oogoo2Woo002`Ool2
001GOol00:ioo`800003Ool0000005Ioo`00Zgoo0`000goo0P00EWoo002YOol20006Ool00`00Ool0
001EOol00:Moo`8000Qoo`03001oo`0005Eoo`00Y7oo0`002Woo00@007ooOol005Aoo`00XWoo0P00
3Goo00D007ooOomoo`0005=oo`00Wgoo0`003goo00D007ooOomoo`0005=oo`00WGoo0P004Woo00<0
07ooOol00Woo00<007ooOol0D7oo002KOol2000EOol00`00Oomoo`02Ool00`00Oomoo`1?Ool009Qo
o`<001Moo`03001oogoo009oo`03001oogoo04moo`00UWoo0P006Woo00<007ooOol00goo00<007oo
Ool0CWoo002COol3000LOol00`00Oomoo`03Ool00`00Oomoo`1>Ool0095oo`8001moo`03001oogoo
00Aoo`03001oogoo04eoo`00Sgoo0P008Goo00<007ooOol01Goo00<007ooOol0C7oo002<Ool3000S
Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool008Yoo`8002Ioo`03001oogoo00Ioo`03001oogoo04]o
o`00Qgoo0`00:7oo00<007ooOol01goo00<007ooOol0BWoo0025Ool2000[Ool00`00Oomoo`07Ool0
0`00Oomoo`1:Ool008=oo`8002eoo`03001oogoo00Qoo`03001oogoo04Uoo`00P7oo0`00;goo00<0
07ooOol027oo00<007ooOol0BGoo001nOol2000bOol00`00Oomoo`09Ool00`00Oomoo`18Ool007]o
o`<003Aoo`03001oogoo00Yoo`03001oogoo04Moo`00NGoo0P00=goo00<007ooOol02Woo00<007oo
Ool0Agoo001gOol2000iOol00`00Oomoo`0;Ool00`00Oomoo`16Ool007Aoo`<003]oo`03001oogoo
00aoo`03001oogoo04Eoo`00LWoo0P00?goo00<007ooOol02goo00<007ooOol0AGoo001_Ool30011
Ool00`00Oomoo`0<Ool00`00Oomoo`14Ool006eoo`8004Aoo`03001oogoo00aoo`03001oogoo04Ao
o`00Jgoo0P00AWoo00<007ooOol03Goo00<007ooOol0@goo001XOol30018Ool00`00Oomoo`0>Ool0
0`00Oomoo`12Ool006Ioo`8004]oo`03001oogoo00ioo`03001oogoo049oo`00Hgoo0`00CGoo00<0
07ooOol03goo00<007ooOol0@Goo001QOol2001@Ool00`00Oomoo`0@Ool00`00Oomoo`10Ool005io
o`<0059oo`03001oogoo011oo`03001oogoo041oo`00G7oo0P00EGoo00<007ooOol04Goo00<007oo
Ool0?goo001JOol2001GOol00`00Oomoo`0AOol00`00Oomoo`0oOol005Moo`<005Uoo`03001oogoo
019oo`03001oogoo03ioo`00EGoo0P00G7oo00<007ooOol04goo00<007ooOol0?Goo001BOol3001N
Ool00`00Oomoo`0COol00`00Oomoo`0mOol0051oo`80065oo`03001oogoo01Aoo`03001oogoo03ao
o`00CWoo0P00Hgoo00<007ooOol05Goo00<007ooOol0>goo001;Ool3001UOol00`00Oomoo`0EOol0
0`00Oomoo`0kOol004Uoo`8006Uoo`03001oogoo01Eoo`03001oogoo03Yoo`00AWoo0`00Jgoo00<0
07ooOol05Goo00<007ooOol0>Woo0014Ool2001^Ool00`00Oomoo`0FOol00`00Oomoo`0iOol0049o
o`80071oo`03001oogoo01Moo`03001oogoo03Qoo`00?goo0`00LWoo00<007ooOol05goo00<007oo
Ool0>7oo000mOol2001eOol00`00Oomoo`0HOol00`00Oomoo`0gOol003Yoo`<007Moo`03001oogoo
01Uoo`03001oogoo03Ioo`00>7oo0P00NWoo00<007ooOol06Goo00<007ooOol0=Woo000fOol2001l
Ool00`00Oomoo`0JOol00`00Oomoo`0eOol003=oo`<007ioo`03001oogoo01Yoo`03001oogoo03Eo
o`00<Goo0P00PGoo00<007ooOol06goo00<007ooOol0=7oo000^Ool30023Ool00`00Oomoo`0LOol0
0`00Oomoo`0cOol002aoo`8008Ioo`03001oogoo01aoo`03001oogoo03=oo`00:Woo0P00R7oo00<0
07ooOol07Goo00<007ooOol0<Woo000WOol3002:Ool00`00Oomoo`0NOol00`00Oomoo`0aOol002Eo
o`8008eoo`03001oogoo01ioo`03001oogoo035oo`008Woo0`00Sgoo00<007ooOol07goo00<007oo
Ool0<7oo000POol2002COol00`00Oomoo`0NOol00`00Oomoo`0`Ool001ioo`8009Eoo`03001oogoo
01moo`03001oogoo02moo`006goo0`00Ugoo00<007ooOol087oo00<007ooOol0;Woo000IOol2002J
Ool00`00Oomoo`0POol00`00Oomoo`0^Ool001Moo`8009aoo`03001oogoo025oo`03001oogoo02eo
o`005goo0P00W7oo00<007ooOol08Woo00<007ooOol0;7oo000GOol00`00Ool0002KOol00`00Oomo
o`0ROol00`00Oomoo`0/Ool001Moo`04001oogoo002JOol00`00Oomoo`0SOol00`00Oomoo`0[Ool0
01Ioo`03001oogoo009oo`03001oogoo09Moo`03001oogoo02=oo`03001oogoo02]oo`005Woo00<0
07ooOol00goo00<007ooOol0UWoo00<007ooOol097oo00<007ooOol0:Woo000FOol00`00Oomoo`04
Ool00`00Oomoo`2EOol00`00Oomoo`0UOol00`00Oomoo`0YOol001Ioo`03001oogoo00Eoo`03001o
ogoo09Aoo`03001oogoo02Eoo`03001oogoo02Uoo`005Woo00<007ooOol01Woo00<007ooOol0Tgoo
00<007ooOol09Woo00<007ooOol0:7oo000FOol00`00Oomoo`07Ool00`00Oomoo`2BOol00`00Oomo
o`0WOol00`00Oomoo`0WOol001Eoo`03001oogoo00Uoo`03001oogoo07Qoo`P000037>L0000000<0
00037>L0000000D000=oo`03001oogoo02Moo`03001oogoo02Moo`005Goo00<007ooOol02Woo00<0
07ooOol0LGoo1P000V7>00hLif8@HO1R467`HQ0Lif8bHQ9R<UhA7>MN<f8c0ehc00<LieiDGU@01@00
:Goo00<007ooOol09Woo000EOol00`00Oomoo`0;Ool00`00Oomoo`1[Ool500006F6;GHXLieg=HLiM
cF7>GNlLieg`HQ1Mkf8@7>MR<UhAHS9N4F8b7>MR<ehcHS=N<acW00=NE005HUENE1cW001NEP02000W
Ool00`00Oomoo`0VOol001Eoo`03001oogoo00aoo`03001oogoo06Moo`<00003FBLLief;009MR`03
GHYQcQcW00AQcP0=7>MQl68@HO1R467`7>MR4V8bGQ5R<QcWHS<00ehc00=R<acWGU@00eiD00@LieiE
GUD0009NE@03000Li`0002Eoo`03001oogoo02Eoo`005Goo00<007ooOol03Goo00<007ooOol0HWoo
1000021I9eTVGBMI9QcWGHYQRef:HH/Lif7>GLeQcUg=HLhLif8@GNmR45g`7>MN4F8bGQ5R<UhA7>MN
<f8cGS=R<acW0UiD00aREEiDGU@LieiFFUD005YEGUHLieifFUH2000TOol00`00Oomoo`0TOol001Eo
o`03001oogoo00ioo`03001oogoo05aoo`D0009@P@097>MI9eTVFBMI9UTW7>MMRef:009MR`037>MQ
cV7>009QcP0<7>MR467`HQ1Ql68@7>MR<UhAHS9R4QcW0ehc00=R<ehc7>L015iD00DLieiEGUENE@00
009NE@037>MJMUYf009JMP80029oo`03001oogoo02Aoo`005Goo00<007ooOol03goo00<007ooOol0
F7oo0`0000Dl01cWD85@PDb1009@P@0S7>MI9UdWFBII9eTV7>MMRV6;GHYQRacWHLiMcF7>GLdLieg_
HQ1Ml68@7>MR<UhAHS9N4F8b7>MR<ehcHS=N<acWGUARE@03GU@03QcWFUENEEYE001JEAcWFUINMUYF
GWIJEQcWFWH2000QOol00`00Oomoo`0SOol001Aoo`03001oogoo015oo`03001oogoo05Aoo`03000L
i`0000E000037>M@PE21009@P@077>MI9eTVFBMI9UTW7>L00ef;00=QcQcWHLh00f7>00/Lif8@HO1R
467`7>MN4F8bHQ9R<QcW009N<`04HS=N<ehc7>L4GU@00acWGUENE@02GUD00`007>MJMP05FWH011cW
FWMJMeYg0P0087oo00<007ooOol08Woo000DOol00`00Oomoo`0BOol00`00Oomoo`1@Ool300002BP0
;00Lid00?01003`0@00Li`03D8408Tb17>MI9UTWFBIM9acWHH]MRV6;GHXLieg=HLiMcF7>7>MR45g`
HQ1Mkf8b7>MR<UhAHS9N4AcWGS=R<ehcHS<Lif9E0eiD01EREAcWGUEJEEiFFUD001cWGWIJEUifFUIN
MQcWFWMFMUYgFWIJN1cW00007goo00<007ooOol08Woo000DOol00`00Oomoo`0COol00`00Oomoo`1<
Ool00`007>LLi`06:0027>L4@0000acWD85@P@02D8401AcWFBII9eTV7>L00Uf;00=MRUf;7>L0167>
00dLif7`HQ1Ql68@7>MR<V8BHS9N4AcWGS=R<`03GS<00acWGUANE002GU@00acWGUENE@03GUD00`00
FWIJMP03FWH00acWFWMJM`03FWL00acWEWQFM`02000NOol00`00Oomoo`0QOol001Aoo`03001oogoo
01Aoo`03001oogoo04Qoo`<00003300@010000@Li`8X0008;00X01cW?01003`07>M<P@=@P@0N7>MM
9eTVFBLLif6;GHYQRef:7>MMcF7>GLeQcQcWHQ1Mkf8@GO0LiehAHS9N4F8b7>MR<ehcHS=N<acW0eiD
01YREEiD7>MJEEiFFUENEEYE001JEUifFUINMUYF7>MFMUYgFWIJMeIg7>MFMeYhEWMJN0007Goo00<0
07ooOol08Goo000DOol00`00Oomoo`0EOol00`00Oomoo`14Ool200067>L=O0000d007>M@P@02D840
1QcWFBII9eTV7>MMRP9MR`037>MQcV7>009QcP0<7>MR467`HQ1Ql1cWHQ9R<UhAHS8Lif8c0ehc00=R
<acWGU@00eiD00<LieiEGUD00eiE00<Li`00FWH00eYf00<LieYgFWL00UYg00=FMacWEWL00UIg00AF
N5Ig7>L001eoo`03001oogoo021oo`0057oo00<007ooOol05Woo00<007ooOol0@Goo0`0000<Lig`0
O00017`03Goo0g`001m<PE217>MI9eTVGBLLif6;GHYQRacWHLiMcF7>GLdLieg_HQ1Ml68@7>MR<UhA
HS9N4AcWGS=R<ehcHS<Li`02GU@07V9EGUANE1cWGUIJEEiEFUDLieYF001JEUifFUHLieIfFWMJMUYg
EWHLieIgFWQFMeYhEWLLie9hEWP001eoo`03001oogoo01moo`004goo00<007ooOol05goo00<007oo
Ool0?Woo00<001cW7>L00QcW0W`000<LigooOol04goo17`000=I9eTV7>L00Uf;00=MRQcWHLh00V7>
00/Lif7`HQ1Ql68@HQ8LiehAHS9R4QcW00=N<`03HS<LieiD00ANE0037>MNEEiE00=NE@037>MJMP00
00=JMP037>MJMeYg009JM`077>MFMeIgEWMFN5Ig7>L015Ih0P006goo00<007ooOol07goo000COol0
0`00Oomoo`0HOol00`00Oomoo`0jOol200057>L00g`0Oomoo`0JOol3O0006F6;GHYQRacWHLiMcF7>
7>MR45g`HQ1MkacWGQ5R<UhAHS8Lif8cGS=R<ehc7>MNE69E009NE00P7>MNEUYEGUEJEEiF7>MNMUYF
001JEUif7>MJMeYfFWMFMUYh7>MJN5IgFWQFMeYh7>MFN59hEWQBN5IhDWP001]oo`03001oogoo01io
o`004goo00<007ooOol06Goo00<007ooOol0=Woo0P001AcW00<001cWO00087oo0W`000<Lif7>HLh0
0V7>00XLif7`HQ1Ql68b7>MR<V8BHS8Li`9N<`03HS=N<acW00ENE0037>MNEEiE009NE@077>MJMUYf
FWH005Yf7>L01EYg00@LieIgEWMFN09FM`037>MFN5Ih00AFN08Li`03001oogoo01Uoo`03001oogoo
01eoo`004goo00<007ooOol06Woo00<007ooOol0<goo00<001cW7>L01QcW0W`08goo01El05g=HLiM
cAcWGO1R45g_HQ0Lif8bGQ5R<UhA7>MN<f8cGS=R<acWHUD00eiD028LieYEGUEJEEiFFUDLieYFGWIJ
EP00FUHLieYfFWMFMUYg7>MJN5IgFWQFMeYh7>MFN59hEWQBN5IhDWPLie9hDWT001]oo`03001oogoo
01eoo`004goo00<007ooOol06goo00<007ooOol0;goo0P002AcW00=l07ooOol097oo0W`000eQcQcW
HQ1Ql68@GQ4Lif8BHS9N4AcWGS=R<`02GS<00acWGUANE003GU@00acWGUENE@02GUD00acWFWIJMP02
FWH00`007>MJM`03FWL015Ig7>MFMeIh0UIg00<LieIhEWP015Ih00HLie9iDWUBN59i000KOol00`00
Oomoo`0LOol001=oo`03001oogoo01aoo`03001oogoo02aoo`8000XLi`03O01oogoo02Moo`9l000>
GNmR45g`7>MN4F8bGQ5R<QcWHS=N<f8cGS<Li`=NE00UHUDLieiEFUENEUYE7>MJEUifFUINMUYF001J
MUYgEWIJMeYf7>MFMeYhEWMJN5Ig7>MBN5IhDWQFN59hEWPLie9iDWQBNE9h00006goo00<007ooOol0
77oo000BOol00`00Oomoo`0NOol00`00Oomoo`0XOol2000<7>L00g`0Oomoo`0ZOol2O0001f8b7>MR
<UhAHS8Lif8c00=N<`037>MNE5iD00=NE0037>MNEEiE009NE@037>MJMUYf009JMP037>L005Yg00=J
M`037>MFMeIh00=FM`037>MFN5Ih00AFN0037>MBNE9h00=BN@03DWP007oo01Yoo`03001oogoo01]o
o`004Woo00<007ooOol07goo00<007ooOol09Goo00<001cW7>L031cW00=l07ooOol0;Goo00]l068b
GQ5R<UhA7>MN<f8cGS=R<acW009NE00YHUENE1cWFUENEUYEGUDLieifFUINMUYFGWHLi`00EWIJMeYf
7>MFMeYhEWMJN5Ig7>MBN5IhDWQFN59hEWPLie9iDWQBNE9hDWUBN1cWCWT0000KOol00`00Oomoo`0J
Ool0019oo`03001oogoo021oo`03001oogoo029oo`03000LiacW00DLi`03;0H/1acW00<Li`03>8Th
RW`0035oo`9l0003HQ8Liehc009N<`03HS<LieiD00=NE003GUDLieiE009NE@037>MJMUYf00=JMP04
7>MJMeYg0002FWL00acWEWQFM`02EWL00acWEWQFN004EWP00acWDWUBN003DWT00e9h7>M>N@02CWT0
0`00Oomoo`0HOol00`00Oomoo`0JOol0019oo`03001oogoo025oo`03001oogoo01eoo`037>MooacW
00DLi`03<0L/1QcW00<Li`07>8XdRCR:>8ThRQcWO000<goo0W`000MR<ehcHS=N<acWGUARE@02GU@0
9QcWGUIJEEiEFUDLieYFGWIJEUif7>MJMeIfFWL005Yg7>MJN5IgFWQFMeYh7>MFN59hEWQBN5Ih7>MB
NE9hDWUBN59iDWPLidiiDWX3CWT00`00Oomoo`0HOol00`00Oomoo`0IOol0019oo`03001oogoo029o
o`03001oogoo01]oo`03000LiacW008Li`03;0HLiacW00<Li`8hRP03>8TLiacW00@Li`03@>al07oo
03Aoo`9l0003GS<LieiD00=NE003GUDLieiE009NE@037>MJMUYf00=JMP077>MJMeYgFWL001cWEWP0
0eIg00=FN1cWEWP015Ih00<Lie9iDWP00e9i00=BN1cWCWT01Dii00<Li`00Ool06Goo00<007ooOol0
67oo000BOol00`00Oomoo`0SOol00`00Oomoo`0GOol00`007>LLi`067>L00cB9>8XLi`057>L01cc;
@>a0c43/?<]0k7`003Qoo`9l000YHUENE5iDGU@LieYEGUEJEEiF7>MNMUYFGWIJEQcWEWIJMeYfFWL0
05YhEWMJN5IgFWPLieIhDWQFN59hEWQBN1cWDWQBNE9hDWUBN1cWCWUBNP03CWT0159jCWTLi`006Woo
00<007ooOol067oo000BOol00`00Oomoo`0TOol00`00Oomoo`0DOol2000;7>L8@>`47>L00g`0Oomo
o`0hOol01G`0GUANE5iE7>L00eiE00<LieYfFWH00UYf00<LieYgFWL00eYg00H005IgEWMFMeIh7>L6
EWP00acWDWQBN@02DWT00e9hDWTLi`06CWT011cWBWY:NP006Woo00<007ooOol05goo000AOol00`00
Oomoo`0VOol00`00Oomoo`0AOol00`007>LLi`057>L01d3/@<a0k3c;@>a0c43/00PLi`04ABe9;TD]
O00lOol09W`0HUDLieiEFUENEQcWGWIJEUifFUINMQcWFWMJMUYgEWHLi`00FWQFMeYhEWLLie9hEWQB
N5IhDWPLie9hDWUBN59iDWQBNAcWDWX3CWT01e9jCWTLidYiCWY:N@0001Yoo`03001oogoo01Moo`00
4Goo00<007ooOol09goo00<007ooOol03Woo00@001cW7>LLi`I0k0LLi`05BBi5;DT]ABe9;P067>L0
0g`0Oomoo`0kOol00g`0GUENE@02GUD00acWFWIJMP02FWH00acWFWMJM`02FWL01acWEWL005IgEWQF
MacW00EFN0037>MBN59i009BN@03DWQBNAcW00I>N@037>M:NTYj009:NP03001oogoo01Uoo`03001o
ogoo01Ioo`004Goo00<007ooOol0:7oo00<007ooOol02goo0P0000=0k43<7>L01acW00=9;TD]7>L0
2AcW00M=Kde>CFm=CTe_CDil000nOol2O00085YE7>MJEUifFUINMQcWFWMJMUYgEWIJMacWFWP005Yh
EWLLie9hEWQBN5IhDWPLie9hDWUBN59iDWQBNAcWDWX3CWT02U9jCWTLidYiCWY:NDYjBWU>NP006goo
00<007ooOol05Goo000AOol00`00Oomoo`0YOol00`00Oomoo`09Ool00`007>LLi`0<7>L04De>CFm=
CTe_CDi=Kde>CFm=CTe_CDi=Kde>CFm=CTe_O000@7oo0W`015Yf00<LieYgFWL00UYg00HLieIgEWL0
05Ig7>L5EWP00acWDWQBN@02DWT00e9hDWTLi`06CWT00acWBWY:NP05BWX00`00Oomoo`0IOol00`00
Oomoo`0EOol0015oo`03001oogoo02Yoo`03001oogoo00Ioo`03000LiacW00@Li`0:CFm=CTe_CDi=
Kde>CFm=CTe_CDh@7>L00g`0Oomoo`10Ool077`0GWIJEQcWFWIJMeIfFWLLieYhEWMJN000FWPLieIh
DWQFN59hEWPLie9iDWQBNE9hDWTLie9j0dii00eBNTii7>M:NDijBWU:NTYiCWY:NAcW@UX0000KOol0
0`00Oomoo`0DOol0015oo`03001oogoo02]oo`03001oogoo00Aoo`03000LiacW00lLia1AS`03O01o
ogoo045oo`03O00LieYg00=JM`077>MFMeIgEWQFM`007>L01EIh00LLie9iDWUBNE9hDWTLi`06CWT0
0acWBWY:NP05BWX011cWAUY6FP0077oo00<007ooOol04goo000@Ool00`00Oomoo`0]Ool00`00Oomo
o`02Ool00`007>LLi`0>7>L04UF?DHmET56?EHmASeF@DHmESe6?EI1ASeF?DHmET56?EHml04Eoo`0H
O01JMeIfFWMJMQcWEWMJN5IgFWP005IhDWQFN59hEWPLie9iDWQBNE9hDWTLie9j0dii00UBNTii7>M:
NDijBWU:NTYiCWX00QcW00E2FTIkAUY6NP0001]oo`03001oogoo01=oo`0047oo00<007ooOol0;Woo
00P007ooOomoo`00EK1I/5F_0UF`00II/5F_EK1E/5V`EJl2EK000eV`EJmE/0027>L00`007>LLi`0<
7>L00g`0Oomoo`14Ool2O00015Yg7>MFMeIh0UIg00<Li`00EWP00eIh00LLie9iDWUBNE9hDWTLi`06
CWT00acWBWY:NP04BWX00acWAUY6FP04AUX00`00Oomoo`0JOol00`00Oomoo`0BOol0011oo`03001o
ogoo02moo`04001oogoo00087>L02eV`EJmI/5F_FK1E[eV`EJmI/5F_FK000P0000eE[eV`EJmI/5F_
FK1E[eV`EJmI/5F_FK1l0018Ool2O0004EYhEWMJN5Ig7>L005IhDWQFN1cWDWUBN59iDWQBNAcWDWX0
0dii01=BNTii7>M:NDijBWU:NTYiCWXLidIj@UY6NdIJAWY2FTIkAUX0000KOol00`00Oomoo`0BOol0
011oo`03001oogoo031oo`04001oogoo00057>L00eW@GM0Li`0:7>L2NZd200027>L2EK001eV`EJmE
/5F`FK1E[g`004Yoo`9l0004EWLLieIh0002EWP021cWDWUBNE9iDWQBNDii7>L5CWT00acWBWY:NP04
BWX00acWAUY6FP05AUX27>L00`00Oomoo`0IOol2000COol0011oo`03001oogoo035oo`03001oogoo
0080008Li`03FM0LiacW00HLi`0;GM1Id5g@FM1Md5W@NZif[GZ^001Md0087>L00g`0Oomoo`1:Ool0
3G`0DWQFN000EWQBN1cWDWQBNE9hDWUBN1cW00=>N@0FDWY>NAcWBWU>NTYiBWY:NDij7>M6NT9JAW]6
FTIj@UY6NacW@U/n>T9K000GOol300000goo001oo`0BOol0011oo`03001oogoo039oo`04001oogoo
Ool200047>L01F7`FM1Md5W@GM001AcW00EMd5W@NZej[Gk;00800008FM1Md5W@GM1Id5g@FM1l04eo
o`05O01FN000EWPLi`02DWT0159hDWUBNAcW1Dii00<LidYjBWX00dYj0QcW1dIJ00HLid9J?UY2FSiJ
000DOol30004Ool00`00Oomoo`0AOol0011oo`03001oogoo03=oo`09001oogooOolLi`00IS1R46Ha
00@Li`06GO1R45g`HQ5Id5g@0acW00]j[WJ]O/ajb`00FM1Md5W@GM1Id7`004moo`9l0007001BN59i
DWQBNE9h7>L00dii011BNTii7>M:NDijBWU:NTYi7>M6FTIj@UY6NdIJAWY2FP8Li`06@U/n>T9K?SY2
F`004Goo0`001goo00<007ooOol04Goo000?Ool00`00Oomoo`0eOol00`00Oomoo`02Ool00`007>LL
i`03IQ000f8@7>LLi`037>L015g`HO1Ml67`0WZ]00=jbgk;M/L00P0000@LieW@GM1l055oo`03001B
NE9h009BN@037>M>NDii00=>N@037>M:NTYj00=:NP037>M6FTIJ00E6FP0:7>LnFT9J?UY2FSiJ@UXn
FT9J000=Ool3000;Ool00`00Oomoo`0@Ool000moo`03001oogoo03Ioo`03001oogoo009oo`8000<L
i`06IS1R46HaHQ1V<68@11cW00MR4GZ]NZijbgk<M/Mja`0200000acWO01oo`1@Ool01@00O01l059h
7>L00dii00mBNTii7>M:NDijBWU:NTYi7>M6FTIj@UY6NdIJAWX00QcW00Xn>T9K?SY2Fchj@U/n>T9K
?SX000Yoo`<000ioo`03001oogoo011oo`003goo00<007ooOol0=goo00<007ooOol00goo0P001AcW
0VH@00AR46H@IQ1V40<Li`08O/]jbgK7M/MjagK7001l055oo`04001oogooO005CWT00acWBWY:NP03
BWX00acWAUY6FP04AUX02QcW@UXnFT9J?UY2FSiJ@UXnFT9J0QcW00<007ooOol01Goo0`004Goo00<0
07ooOol047oo000?Ool00`00Oomoo`0hOol00`00Oomoo`04Ool37>L00fY@IRlLi`027>L03F8@IS5R
46H`HQ1j[WZ]O/]faW[7M/Mjaf910080051oo`0=001oogooOoml04iiDWY>NAcWBWU>NTYiBWX00QcW
00E6FTIj@UY6NdIJ008Li`08@U/n>T9K?SY2Fchj@U/n>P8Li`04>S/f6SXk0002Ool4000DOol00`00
Oomoo`0@Ool000moo`03001oogoo03Uoo`03001oogoo00Aoo`07KTlLiacW7>MZ<6Y@JS000acW0VH@
00AR47Z]N/]nb`=fa`03HV5R@F9Q008004ioo`03001oogoo009oo`03O01>NAcW00A:NP037>M6FTIJ
00A6FP097>LnFT9J?UY2FSiJ@UXnFT9J008Li`<j>P03>S/j>P00008001Qoo`03001oogoo011oo`00
3goo00<007ooOol0>Woo00<007ooOol01Goo11cW00AZD6X`JU1V;`@Li`0;NZijbg[7M/Ijaf91IV5R
@FIQHT40001=Ool00`00Oomoo`03Ool057`0BWU>NTYiBWXLidIkAUY6NT9JAW]6FQcW?SY2Fchj@U/n
>T9K?SX27>L023Xk=QXj>cHJ>S/f6SXk000JOol00`00Oomoo`0@Ool000ioo`03001oogoo03aoo`03
001oogoo00Ioo`@Li`06JS1ZD6X`JU1Z<6H@0QcW00Ufag[7M/Mfaf91HV5R@F9Q7>L00P00Bgoo00<0
07ooOol017oo0W`000=:NQcWAUX014IJ0QcW00XnFT9J?UY2FSiJ@UXnFQcW>SXj>`<j>P06>S/j>SXj
>SXj>`006Goo00<007ooOol047oo000>Ool00`00Oomoo`0mOol00`00Oomoo`06Ool00fi?7>M^C`03
7>L04FH_JU1Z<6Y@MZenc7K7N/MfaVIQHT5VHF917>L01@060000BWoo00<007ooOol01Woo00il04Ik
AUY6NT9JAW/Lid9K?SY2Fchj@U/n>T9K0QcW00Tf6SXk=QXj>cHJ>S/f6SXk=QX00QcW00<007ooOol0
5goo00<007ooOol047oo000>Ool00`00Oomoo`0nOol00`00Oomoo`07Ool27>L026i`JS0LiacWJU1Z
<6Y@N//2M/L01W[7HT5RHF91HV4Li`801@0300H0000004Qoo`03001oogoo00Moo`03O016FTIJ008L
i`06@UXnFT9J?UY2FSiJ0QcW0SXj00Dj>cXj>SXj>SXk008j>P8Li`8anP03001oogoo01Qoo`03001o
ogoo00moo`003Woo00<007ooOol0?goo00<007ooOol027oo00@Lig9`KTmoo`8Li`0@JS1ZD7K6N/Mf
afIQHT5VHF917>L01@0600D01P050017Ool00`00Oomoo`08Ool027`07>Ln>T9K?SY2Fchj@U/27>L0
2CHJ>S/f6SXk=QXj>cHJ>S/f6P027>L01C7j;OXanRgj00006Woo00<007ooOol03goo000>Ool00`00
Oomoo`10Ool00`00Oomoo`08Ool27>L00fi?KW1oo`027>L02Gk;M/Mfaf91HV5R@F9Q7>L01P0300D0
0acW00/00016Ool00`00Oomoo`09Ool01G`0@UXnFT9J?UX00QcW00Dj>cXj>SXj>SXk00<j>P<Li`La
nP03001oogoo01Moo`03001oogoo00moo`003Woo00<007ooOol0@Goo00<007ooOol02Goo0QcW011^
L6i?OolLig[7M/IVHF91IV401AcW00D01P0500HLi`802`03001oogoo04=oo`03001oogoo00Yoo`0<
O012FacW7>Lf6SXk=QXj>cHJ>S/f6SXk0QcW00/]nS7j;OXanRgj<OX]nS7j;OXanP0001Uoo`03001o
ogoo00moo`003Woo00<007ooOol0@Woo00<007ooOol02Woo00/Lifi`KTm^L7K7N/MR@F9QHT401QcW
00801@0300HLi`0;00<02`03001oogoo049oo`03001oogoo00Qoo`<000047>Lj>SXj>S/3>SX013Xk
7>LLiacW337j00<007ooOol05goo00<007ooOol03goo000=Ool00`00Oomoo`14Ool00`00Oomoo`0:
Ool27>L03Vi?LW1fafIQHT5VH@057>L01@0600DLi`0;00`300/00`00Oomoo`11Ool00`00Oomoo`05
Ool30004Ool01G`0>S/f6SXk=QX00QcW00danRgj<OX]nS7j;OXanRgj<OX]nS7j;OXanP027>L00`00
Oomoo`0GOol00`00Oomoo`0?Ool000eoo`03001oogoo04Eoo`03001oogoo00]oo`8Li`9fa`05HV5R
@AcW00D01P0200D00acW00/02`0400/00`00Oomoo`10Ool00`00Oomoo`02Ool30007Ool00g`0>SXj
>P027>L:<OX57>L00bWJ:KT0000IOol00`00Oomoo`0?Ool000eoo`03001oogoo04Ioo`03001oogoo
00aoo`0:O01jaf91IV4Li`0600D01QcW00`300/01@0<00/Li`@>0000@Goo00<007oo00000P002goo
0QcW00PanRgj<OX]nS7j;OXanRgj11cW00PYfRFi:MXU^BWJ9KTYfP006Woo00<007ooOol03Woo000=
Ool00`00Oomoo`17Ool00`00Oomoo`0<Ool017K7HV5R@AcW0`0500<Li`0;00/0100;00<Li`@?10h0
0P00?Woo0`003goo00Al037j<OXanPDLi`0=:KTYfBVi:MXY^BWI:KTYfRVi:MTY^BWJ00006Goo00<0
07ooOol03Woo000=Ool00`00Oomoo`18Ool00`00Oomoo`0;Ool027[7HT5VHAcW00H01@067>L200/0
2P0<00/02acW10l43P@?10h43`00>Woo0`000Woo00<007ooOol03Woo01El01cW7>LU^BWJ9KTYfRFi
:MXU^BWJ9KTYfRFi:MXU^BWJ9KTYfRFi00006Goo00<007ooOol03Woo000=Ool00`00Oomoo`18Ool0
0`00Oomoo`0;Ool01gK7HV5R@AcW00D01QcW00D02`037>L43`@>00<43`0310h43`0003Eoo`@000Eo
o`03001oogoo00moo`0DO00Y^BWI:KTYfRVi:MTY^BWJ:KTYfBVi:MXY^BWI:KTYfRVi:MT001Uoo`03
001oogoo00ioo`0037oo00<007ooOol0BWoo00<007ooOol02goo00QR@FIQ7>L01P057>L02`0<0`0;
00LLi`@>10l43P@?10h43`027>L00`00Oomoo`0_Ool30009Ool00`00Oomoo`0?Ool02g`0:MXU^BWJ
9KTYfRFi:MXU^BWJ9KT021cW00<007ooOol05goo00<007ooOol03Woo000<Ool00`00Oomoo`1;Ool0
0`00Oomoo`0:Ool01F9QHT4Li`057>L01@0;00<Li`@>10l00P@?00<43P@?7>L00aRA00<007ooOol0
:goo0`0037oo00<007ooOol047oo2QcW0b6H00HQVB6H8IPQV26I000IOol00`00Oomoo`0>Ool000ao
o`03001oogoo04aoo`03001oogoo00Uoo`06HT401QcW00HLi`0<0`0;00h031cW10l43P@?10h43acW
794HT1bA690LT@00:Goo0`003goo00<007ooOol047oo01=l025h8ITQN2FI8GPQVB5h9ITQN26I8GPU
VB5h8ITQN2FI8GP0000IOol00`00Oomoo`0>Ool000aoo`03001oogoo04eoo`03001oogoo00Uoo`04
00DLi`057>L400/01acW10l43`@?10h43acW00HHT@03001oogoo02Aoo`<0019oo`03001oogoo015o
o`03O00QV26I00<QV0058ITQV26H8IPQV@038IP0126I8IPQV0006Woo00<007ooOol03Goo000<Ool0
0`00Oomoo`1>Ool00`00Oomoo`08Ool00`067>LLi`0300/04P0<7>L43`@>10l43P@?7>LLTAR@794H
T1bA690LTAR@000Lib5oo`<001Eoo`03001oogoo015oo`HLi`0<8GPQVB5h9ITQN26I8GPUVB5h8ITQ
N0006Woo00<007ooOol03Goo000<Ool00`00Oomoo`1?Ool00`00Oomoo`07Ool00acW00HLi`0400/0
11cW10l43`@>0P@?00<LiaRA69401QRA00<Li`00Ool07Goo0`0067oo00<007ooOol04Goo00Il01eG
7ELQV26I8IP87>L28IP00b6I001oo`0IOol00`00Oomoo`0=Ool000]oo`03001oogoo055oo`03001o
ogoo00Ioo`0I7>L01AcW00/0300;7>L43P@?10h43`@>7>LHT1bA690LTAR@794HT1bA7>LXlRCb0000
6Woo0`006goo00<007ooOol04Goo00@LiaeG7ELMF0<ME`077EPMEb6I8GPUVB5h8IT00acW00<007oo
Ool067oo00<007ooOol03Goo000;Ool00`00Oomoo`1BOol00`00Oomoo`05Ool00g`07>L02`0200/0
11cW10l43`@>0P@?00<LiaRA69401ARA0QcW12Sb00<007ooOol057oo0`007Woo00<007ooOol04Goo
00=l01cW7>L03QeG00<007ooOol067oo00<007ooOol03Goo000;Ool00`00Oomoo`1COol00`00Oomo
o`04Ool00g`07>L0300200/03QcW10l43P@?10hLiaR@794HT1bA690LTAR@7>L2:?801BCb:?<XlRSb
00004goo0`008Goo00<007ooOol04Woo00El01df7>LLiaeH00<ME`057EPMEaeG7ELMF0037EL00`00
Oomoo`0HOol00`00Oomoo`0=Ool000]oo`03001oogoo05Aoo`03001oogoo00=oo`07O00Li`0;00/L
i`@?10h00P@?00<LiaRA69401ARA00<LibSb:?801RSb00<007ooOol03Goo0`0097oo00<007ooOol0
4Woo00@Liadf7CHM=P<Li`TME`03001oogoo01Qoo`03001oogoo00eoo`002goo00<007ooOol0EGoo
00<007ooOol00Woo015l01cW00/02acW10h43`@>7>LHT1bA690LTAR@794HT1cW008XlP099?8XlbSb
:?8TlRSc:?8Li`0000]oo`<002Moo`03001oogoo019oo`03O00LiacW008M=P036CHM=QcW008Li`05
7EPMEaeG7ELMF0027EL00`00Oomoo`0GOol00`00Oomoo`0=Ool000]oo`03001oogoo05Ioo`05001o
ogooOoml000200/01AcW10h43`@?7>L01aRA00<LibSb:?801RSb0QcW00<a<cDc00001goo0`00:Woo
00<007ooOol04Woo00=l024E7AD00QcW1Adf0acW11eG00<007ooOol067oo00<007ooOol037oo000;
Ool00`00Oomoo`1GOol04000Oomoog`000/Li`@>10l43QcW690LTAR@794HT1bA0QcW0RSb00`TlRSc
:?8XlRCb:?<LicED<C<eE34c0004Ool3000]Ool00`00Oomoo`0BOol01AcW7ADQ5AdE8AH00QcW00HI
=Qdf7CHM=QTf7CH37>L00aeH001oo`0IOol00`00Oomoo`0<Ool000Yoo`03001oogoo05Uoo`05001o
ogooO00Li`0310l00acW694HT@0369400acW:?8XlP06:?827>L2<C<013Dc<C<a<c4c1000<7oo00<0
07ooOol04Goo00Il02DD7>LLib4E7AD28AD00acW7CHM=P067CH00acW001oo`0IOol00`00Oomoo`0<
Ool000Yoo`03001oogoo05Yoo`0>001oog`010l43P@?7>LLTAR@794HT1bA7>LXl`8XlP049?8XlbSb
:?827>L02S4c=E@a<cED<C<eE34c=E@a<`00<goo00<007ooOol047oo00TLibDe9A@U=AcW8ADM5B4F
7AD00QcW0adf00DI=Qdf7CHM=P0001Yoo`03001oogoo00aoo`002Woo00<007ooOol0Fgoo00D007`0
10l43acW00DHT@037>LXlRSb00DXlP037>Le<c4c008a<`05=C<a<c4c<C<e<`02<C<00`00Oomoo`0a
Ool00`00Oomoo`0@Ool027`07>LU=BDD9CDLib4E7AD38AD00acW7CHM=P047CH00`00Oomoo`0HOol0
0`00Oomoo`0<Ool000Yoo`03001oogoo05aoo`0:001l01cW794HT1bA690LTAcW:?<2:?800bCb:?<X
lP027>L02cED<C<eE34c=E@a<cED<C<eE34c=E@00QcW00<007ooOol0<7oo00<007ooOol03goo00Ml
02Td;CDLibDe9A@U=@027>L011dE8AHM5B4E0QcW0Qdf00<I=Qdf00006Woo00<007ooOol037oo000:
Ool00`00Oomoo`1MOol00g`07>LHT@0269427>L6:?800acW<C<e<`03<C<01SDc<C<a<c4c=C<a<`8L
i`<iM003001oogoo02moo`03001oogoo00moo`0;7>L]=2dd;C@LibDe9A@U=BDD7>LM5@038AD00adE
7>LLi`027CH00`00Oomoo`0HOol00`00Oomoo`0<Ool000Yoo`03001oogoo05eoo`07O00HT1bA690L
ibCb:?<00RSb00hTlRSc7>LLic4c=E@a<cED<C<eE34c=E@a<cED0QcW00HiM3ed>G@mM3Ud000aOol0
0`00Oomoo`0>Ool04W`0=EDLibdd:C@]=AcW9CDU52De9A@LiadE8AHM5B4E7ADQ5P8Li`03001oogoo
01Uoo`03001oogoo00]oo`002Goo00<007ooOol0GWoo00Al01RA694Li`DXlP8Li`8a<`05=C<a<c4c
<C<e<`03<C<27>L8>G@00`00Oomoo`0^Ool00`00Oomoo`0>Ool011cW<E@aE1cW0bdd00DLibDe9A@U
=BDD008Li`<Q5@047ADQ5B4E000KOol00`00Oomoo`0;Ool000Uoo`03001oogoo05ioo`05O00XlQcW
9?8Xl`02:?8032Cb7>La<cED<C<eE34c=E@a<cED<C<eE08Li`0;>G@mM3Ud?G@iM3ed>G@mM3Ud?G@0
000`Ool00`00Oomoo`0=Ool05W`0>G@Lic5D=EDLibdd:C@]=AcW9CDU52De9A@U=AcW8AHM5B4E7ADQ
5P006goo00<007ooOol02goo0009Ool00`00Oomoo`1NOol00g`07>LXlP03:?827>L3<C<01SDc<C<a
<c4c=C<a<`8Li`diM003001oogoo02eoo`03001oogoo00aoo`05O00iM3Ud>G@Li`02<E@02acW;C@]
=2dd7>LU=BDD9CDU52De7>L00b4E00<007ooOol06Woo00<007ooOol02goo0009Ool00`00Oomoo`1N
Ool00g`09?8Xl`02:?802QcW=E@a<cED<C<eE34c=E@a<cED0QcW010iM3ed>G@mM3Ud?G@iM3ed>G@m
M3Ud?G@iM3ed7>L002ioo`8000eoo`0=O00mU1cW>G@iMAcW=E@aE3EE7>L]=2Td;CD00QcW00@U52De
9A@U=@8Li`037AD007oo01]oo`03001oogoo00]oo`002Goo00<007ooOol0Ggoo00El02Sb:?8LicDc
00<a<`04=C<a<c4c<C<27>L=>G@37>L00d6e?KD0000ZOol30002Ool00`00Oomoo`09Ool01G`0?IDm
UAcW>GD00SUd00DLicED<E@aE1cW00@]=0087>LU52De9A@U=BDD7>L001aoo`03001oogoo00]oo`00
2Goo00<007ooOol0Ggoo00Yl01cW7>LeE34c=E@a<cED<C<eE08Li`0<>G@mM3Ud?G@iM3ed>G@mM3Ud
?G@iM3ed0acW00I1]Cfe@KDm]46e000VOol40006Ool00`00Oomoo`06Ool2O000646e7>LmU46e7>Li
MCUd>GDLicED<E@eEAcW;C@Y=2de:C@LibDD9CDU52De7>L001aoo`03001oogoo00]oo`002Goo00<0
07ooOol0Ggoo00=l034c=C<00c4c00@e<c4c7>LLi`/iM0<Li`0:@KDm]D6e?KE1]Cfe@KDm]D6e000R
Ool3000:Ool00`00Oomoo`05Ool02W`0AME1]DGE7>M1UCfE7>LiM3Ue0SUd00DLicED<E@aE1cW00@]
=0067>LU52De9A@U=@0077oo00<007ooOol02goo0008Ool00`00Oomoo`1POol01W`0=E@a<cED<C<e
E08Li`0:>G@mM3Ud?G@iM3ed>G@mM3Ud?G@37>L03D6e?KE1]Cfd@KDm]D6e?KA1]Cfe@KDm]00001mo
o`<000ioo`03001oogoo009oo`9l000KBOHLidGE@KE5eQcW@KDmU1cW>G@iMCUd7>LaE3ED<E@]=AcW
;C@Y=2de:C@LibDD9CDU500001eoo`03001oogoo00Yoo`0027oo00<007ooOol0HGoo00=l034c7>L0
0QcW2CUd0acW0151]Cfe@KDm]D6e?KE1]Cfe@KDm]D6e?KE1]Cfe@KDm]@0001]oo`<0019oo`0I001o
ogooO015eDWfAMDLid6eAME1]AcW?IE1UCfE7>LiM3Ue>G@Lic5D=E@aE2dd7>L012dd00<LibDD0000
7Woo00<007ooOol02Woo0008Ool00`00Oomoo`1QOol27>L02Ced>G@mM3Ud?G@iM3ed>G@mM0037>L0
546e?KE1]Cfd@KDm]D6e?KA1]Cfe@KDm]46e?KE1]Cfd@KDm]D6e000HOol3000FOol07`00O019mQcW
AME9mTGE7>M1]DGE@KDLicfD@KDLicUe>G@iMCUd7>LaE3ED<E@]=AcW;C@Y=2de:C@Li`0001ioo`03
001oogoo00Yoo`0027oo00<007ooOol0HGoo00=l03Ud>G@01CUd0acW01=1]Cfe@KDm]D6e?KE1]Cfe
@KDm]D6e?KE1]Cfe@KDm]D6e?KE1]@037>L00`00Oomoo`0BOol4000GOol2O00034XF001:5TGE7>M5
eDWfAMDLid6eAMDLi`8mU@0<@IDLicUd>G@iMCUd7>LaE3ED<E@]=1cW12dd00<007ooOol077oo00<0
07ooOol02Woo0008Ool00`00Oomoo`1ROol017`0?G@iM3ed0acW0191]Cfe@KDm]46e?KE1]Cfd@KDm
]D6e?KA1]Cfe@KDm]46e?KD47>L01DGF@ME5eT7E000047oo0`006Goo0W`0025>5Thg7>M>5`00CQI5
eAcWAME9mQcWAMI1]DGE7>M1]CfD@KDLicUe>G@iMAcW=EDaE3ED<E@LibTd;C@Y=2de00007Woo00<0
07ooOol02Woo0008Ool00`00Oomoo`1ROol057`0>G@LiacW@KDm]D6e?KE1]Cfe@KDm]D6e?KE1]Cfe
@KDm]D6e?KD57>L02D7FAMI1eDGF@MI5eT7EAMH0000=Ool3000JOol2O0001e9G7>M>=dhg7>M:5P00
009:5P097>M5mTGEBOHLidGE@KE5eAcW008mU@06@IDLicUd>G@iMAcW0S5D00<eE35D7>L00bdd00<0
07ooOol077oo00<007ooOol02Woo0007Ool00`00Oomoo`1SOol27>L03Cfe@KDm]46e?KE1]Cfd@KDm
]D6e?KA1]Cfe00DLi`0>@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@MD000Yoo`<001]oo`9l000:CSMB
F4hg7>M>5ThgCQHLidWf0002BOH061cWBOI5eDWf7>M5eT6e7>LmU46e?IA1]AcW>GDiM3Ue7>LeEC5D
=E@aE1cW:C@001moo`03001oogoo00Yoo`001goo00<007ooOol0Hgoo00]l03fe@KDm]D6e?KE1]Cfe
@KDm]D6e00@Li`0C@MI5eT7EAMI1eTGF@ME5eT7FAMI1eDGF@MI5eT7EAMI1eTGF00001goo0`0077oo
0W`000QBN1cWDUM>=e9GDSLLidhf0Thg00LLidXF001:5QcWAME5mP02AMD011cWAME1]AcW0cfE00HL
icUd>G@iM3Ue7>L2<E@013ED<E@Li`0087oo00<007ooOol02Goo0007Ool00`00Oomoo`1TOol017`0
?KA1]Cfe1QcW01Q5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF0002
Ool4000NOol0:G`0DUQFN59G7>M>=e9HCSMBF4hg7>M>5Thg7>M>5TWf0019mQcWAME9mTGE7>M1]DGF
@KDLicfD@KDmU1cW>G@iMCUd>GDLicEE<E@eE35D000087oo00<007ooOol02Goo0007Ool00`00Oomo
o`1SOol00`007>LLi`027>L06T7FAMI1eDGF@MI5eT7EAMI1eTGF@ME5eT7FAMI1eDGF@MI5eT7EAMI1
eTGF@ME5eT7FAMH37>L3000POol2O0000acWDWQBN002DWP02QcWDSMBEdhgDULLidhgCSI>=acW0TXF
00/001cWBOI5eDGfAMDLid6eAME1]AcW00<mU@057>LiM3Ud>G@Li`03<E@00cED001oo`0OOol00`00
Oomoo`09Ool000Moo`03001oogoo06=oo`0G001l047EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1
eDGF@ME5eT7EAMI1e@087>L4000POol2O000:eJIEYQFVAcWEWQBF5IhDULLidhgDUQ>=e9H7>M>=dhF
CSLLidhF001>5acWBOI5eDWf7>M5eD6eAMHLid6e?IA1]CfD7>LiM3Ue>G@Lic5D=EDaE000021oo`03
001oogoo00Uoo`001goo00<007ooOol0Hgoo00l007ooO011eTGF@ME5eT7FAMI1eDGF@MI5eT7EAMH0
21cW00E5mTGgAOI5mdGf00<00005AOI5mdGfAOL0000MOol2O0001eJi7>MFV5JIEYQFVAcW00=BN006
7>MBEe8gDUM>=acW0Thg011>=QcWBQI:5P00BQHLidWfAME5mQcWAME1]DGE7>M1U@<mU@077>LiM3Ud
>G@Lic5D00008Goo00<007ooOol02Goo0007Ool00`00Oomoo`1SOol01`00Ooml04GF@ME5eT7E00PL
i`0:BOM5mTGgAOI9mdGfAOM5mTWgAOH3000024GfAOM5mTWgAOI5mdGf000KOol2O000;UZjE[UJ^UJi
7>MBV5JIEYPLie9GEWQBF5Ih7>MBF4hgDUQ>=acWCQI>=dhF7>M9mThF000LidGEBOI5eDWf7>M5eD6e
AMHLid6e?IA1]AcW>GDiM3Ue>G@Li`008Goo00<007ooOol02Goo0006Ool00`00Oomoo`1TOol00`00
Ooml00047>L03TGfAOM5mTGgAOI5mdGfAOM5mTGgAOI5mdGfAOL400002dGfAOM5mTGgAOI5mdGfAOM5
mTGg00006Goo0W`000AJfQcWE[UJ^@9F^@067>MFVEJHEYUFV1cW159h00HLie9GDSMBEdhg7>L2CSL0
44hf7>M:5TXF000LidGEBOI5eAcW@KE5eD6eAMDLid6E0SfE00HLicUe>G@iM1cW000QOol00`00Oomo
o`09Ool000Ioo`03001oogoo06Aoo`0B001oog`0AOM5mTWgAOI5mdGfBOM5mTGgAOI9mdGfAOM5mTWg
0`0000m9mdGfAOM5mTWgAOI5mdGfBOM5mTGgAOI9mdGf00005goo0W`0035Jfe[JF]YJfQcWE[UJ^UJi
F[XLieJIDYQFVEJH7>MBEeIhDUQFN1cWDUQ>=e9H7>M>=dhFCSLLidhGBOI>5P007>M5eDWfAMDLid6e
AME1]AcW?IA1]CfD@KDLicUe>G@0000ROol00`00Oomoo`09Ool000Ioo`03001oogoo06Aoo`0?001o
ogooO015mdGfAOM5mTGgAOI5mdGfAOM5mTGg00<0000CAOM5mTGgAOI5mdGfAOM5mTGgAOI5mdGfAOM5
mTGgAOI5mdGf000057oo0W`000=K6acWF]X015[J00<LieJiF[T00UJi00HLieJIEYQFVEJH7>L3DWP0
1QcWCSMBEe8gDULLi`=>=`0E7>M:5TXF000LidGfAME9mTGE7>M1]DGE@KDLicfE@IDmUAcW>G@iM@00
02=oo`03001oogoo00Qoo`001Woo00<007ooOol0I7oo00@007ooOoml00PLi`<001DLi`03001oogoo
011oo`9l0007Ga]K6elLFa/Lie[JF]/00U[J02]F^AcWE[UJ^UJiF[XLieJIDYQFVAcWEWQBEeIhDUPL
idhgDUQ>=e9H7>M>=dhFCSLLidhGBOH001cWBOI5eDWf@KDLid6eAME1]AcW?IA1]CfD7>L0000TOol0
0`00Oomoo`08Ool000Ioo`03001oogoo06Aoo`09001oogooO01:5dHGBQM65dXG00<0000IBQM65dXG
AQM:5dHGBQM65dXGAQM:5dHGBQM65dXGAQM:5dHGBQM65dXGAQM:5dHG000047oo0W`000QOG5lK7>MO
6e/KGa]K6acW15[J00]F^AcWE[UJ^EJi7>MFV5JIEYQFVAcW00ABN0067>M>=e9GDSLLidhf0Thg01<L
idXFBQI:5P007>M5mTGEBOHLidGE@KE5eD6e7>LmUD6E?ID0000TOol00`00Oomoo`08Ool000Ioo`03
001oogoo06Aoo`05001oogooO0165`04000074XHAQM:64HGBQQ65dXHAQM:64HGBQQ65dXHAQM:64HG
BQQ65dXHAQM:64HGBQQ65dXHAQM:60003goo00il05mMGcaOG5/lGa`LielKFa]O75/K7>MJfU[K0U[J
02PLieZjE[UJ^UJi7>MFV5JIDYQFVAcWEWQBEeIh7>MBF4hgDUQ>=acWCQI>=dhF7>M9mThGBOH004GE
BOI5eDWf7>M5eT6eAMDLid6e?I@002Eoo`03001oogoo00Qoo`001Goo00<007ooOol0IGoo00<007oo
00000P0002565dXGAQM:5dHGBQM65dXGAQM:5dHGBQM65dXGAQM:5dHGBQM65dXGAQM:5dHGBQM65dXG
AQM:5dHGBQM65dXG000037oo0W`000=OWAcWGe`00emL00MO6acWGa]K6elKFa/Li`04F]X02acWE[UF
^EZiE[TLieJHEYUFV5JI7>L00e9h00LLie9GCSMBEe8g7>M>=P02CSL01acWBQI:5TXF0015eDGf0095
e@077>M5eD6eAMDLicfE00009Goo00<007ooOol027oo0005Ool00`00Oomoo`1TOol400000g`07>LL
i`067>L06THGBQQ65dXHAQM:64HGBQQ65dXHAQM:64HGBQQ65dXHAQM:64HGBQQ65dXHAQM:64HG000:
Ool2O00015nMGiiOWEnM0QcW00aO?5mLFcaOGAcWGa]K6elLFa/Lie[JF]/2F]X07QcWF[YF^EZjE[TL
ieJHEYUBV1cWDUQFN59GEWPLie9HCSMBF1cWCSM>5Thg7>M>5TWfCQM9mP00AME9mP95e@057>M5eT6e
AMD0000VOol00`00Oomoo`08Ool000Eoo`03001oogoo065oo`D00003DFmASg`00096>006BSQ6>4Hh
ASQ:>4Hh4AcW00Q65dXGAQM:5dHGBQM65dXG0`001Woo0W`000=KgAcW7>L01EnM00<LiemLGe`00UmL
00HLielKFa]O6e/K7>L4F]X02QcWE[UF^EZi7>MFVEJHEYUFV1cW0e9h00XLie8gDUM>=e9G7>M>=dhf
CSLLi`=:5P090019mTGEAOI5eAcW@KE5e@0002Moo`03001oogoo00Qoo`001Goo00<007ooOol0GWoo
1000021ET1cWDI1=Ke6@CFmAT7`0BSQ6>4XhASQ:>4HhBSQ6>4XhASQ:>4HhBSQ6>4XhASQ:>4HhBSQ6
>4XhASQ:>4Hh21cW1@0000TLigooO01l05_MFmiKgE_NFmd00QcW03AOWUnMGieOWAcWGcaOG5/lGedL
ielKFa]O75/K7>MJfU[KF]YJ^QcWF[YF^EZj7>MFVEJHEYUBV1cWDUQFN59G7>M>=e9HCSMBF1cWCSM>
5Thg7>M>5TWfCQL004WfAME9mT6e7>L002Uoo`03001oogoo00Moo`001Goo00<007ooOol0FWoo1000
00@Li`00DHmET09AS`067>MASde_DHmAKg`00QcW00=6>4XhASP00THh00E:>4HhASQ6>4Xh00=6>005
BSQ6>4HhASQ:>003ASP01DXhASQ6>4HhBSP00dHh00=:>00000000P0000DLig`0O01;fd^j00<Li`AK
g@037>MOWEnM009OW@037>MOG5mL009OG0057>MO6e/KGa/Li`04F]X02eZi7>MF^EJiF[TLieJIEYQF
VEJH7>L00e9h00DLie8gDUM>=acW009>=`03CSHLidXF00=:5P050019mTGEAOH0000ZOol00`00Oomo
o`07Ool000Eoo`03001oogoo05Moo`<0000B7>L00000EHmE/1cWEI1ASeF@DHlLide_DI1=Ke6@O016
>DHh1QcW01Q:>4HhBSQ6>4XhASQ:>4HhBSQ6>4XhASQ:>4HhBSQ6>4XhASQ:>4HhBSQ6>4XhASP20002
7>L00g`07>LLi`087>L015_MFmhLiacW0enM00XLiellGeaK?5mM7>MO6e/KGa`Li`9JfP0MF]]JfUZj
7>MJ^UJiF[XLieJIEYQFVAcWEWQBF5IhDULLidhgDUQ>=acWCQI>=dhF7>M9mThFBOHLi`03000[Ool0
0`00Oomoo`07Ool000Eoo`03001oogoo05Aoo`D0009I[`037>ME[eF_009E[`0:7>MASe6?EI1ASacW
DFmASde_O008AST57>L01DXhASQ6>4HhBSP00dHh00E:>4HhASQ6>4Xh00=6>005BSQ6>4Hh000Li`02
O00:Ool00`007>LLi`0200027>L2Gid27>L3Ge`01AcWGa]K6elK7>L015[J00YJ^AcWE[UF^AcWEYQF
VEJHEYTLi`=BN0057>MBEe8gDULLi`03CSL00dhf7>M:5P02BQH2000/Ool00`00Oomoo`07Ool000Ao
o`03001oogoo059oo`<0000GOol00000EJiI[eF^FJmE[QcWEHmI/5F?EK0LieF@DHmET56?7>M=Ke6@
O00Li`02AST01DHhASU6>DHiASP00dHi00=6>4Hi7>L01AcW00m6>4XhASQ:>4HhBSQ6>4XhASQ:>4Hh
BSQ6>000O0004Goo0P0000dLi`00001OWQcWGeaK?5mM7>MO6e/KGa`Li`02F]X06E[KF]XLieJiF[YF
^AcWDYQFVEJHEYTLieIhDUQFN1cWDUQ>=e9H7>M>=dhFCSLLidhG00800003Ool007oo02]oo`03001o
ogoo00Moo`0017oo00<007ooOol0CWoo10000goo00<005V^7>L00eV_00=E[UV_7>L015F_00XLie6?
DHmASeF@DHlLie5_O012>@@Li`i6>@DLi`=6>006BSQ6>4HhASQ:>0005goo0P0000TLi`00000001cW
Ga]K6elK7>L015[J00XLieJiE[UF^AcWEYQFVEJHEYTLi`=BN0057>MBEe8gDULLi`03CSL00`00Oomo
o`02Ool00`00Oomoo`0YOol00`00Oomoo`07Ool000Aoo`03001oogoo04]oo`<000Eoo`800003FJiI
SEV^008Li`0FEJiI[eF^FJlLieF`EHmI/5F?7>MASeF@DHmET1cWDI1l01cW@SU6FT8iAUX47>L01DHh
ASU6>DHiASP00dHi00E6>4HiASU6>DHh0096>@HLi`03BSQ6>00001eoo`03000Li`000080008Li`0E
F]YJfeJi7>MF^EZjE[TLie:HEYUFV1cWDUMFN59H7>M>=e9HCSLLidhF008000Ioo`03001oogoo02Qo
o`03001oogoo00Moo`0017oo00<007ooOol0B7oo0`001goo00T001cWFJiISUV^FHiI[UF^7>L00UV_
00=E[UV_7>L015F_00PLie6?DHmASeF@7>Ml03hj0QcW0d8j00=2>D8j@SX00acW4THi0QcW00<007oo
Ool087oo00L001cW000005[JE[TLi`02E[T01QcWEYUFV5JIEYPLi`=BN0037>L00000008000Uoo`03
001oogoo02Qoo`03001oogoo00Ioo`0017oo00<007ooOol0AGoo0`0027oo0P0001aIS5V^7>MI[UV=
FJiISEV^FHdLieF^FJmE[UV_7>ME/5F?FK1ESacWDHmET56?EI1l03hk?SXn>`<Li`06AUY2>DIJ@SU6
FT8i11cW0dHi00E6>4HiASU6>DHh00=6>@06ASQ6>DHiASU6>0009Woo1P0000DLi`00000001cW00<0
00moo`03001oogoo02Moo`03001oogoo00Ioo`0017oo00<007ooOol0@Woo0`002Woo00<005V<FH`0
0eV<0QcW00IISUV^FHiI[UV>7>L2FJl00eF^FJlLi`04EJl01QcWDHmASe6?O00Li`Dn>P8Li`05@SU2
>T8j@SY2>@03@SX47>L<AST00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`06Ool000=oo`03
001oogoo03moo`@000aoo`0N001IJQcWGHeIS5f<FHaMSEV=7>MISEV^FHeI[UV=7>ME[UV_EJiI[acW
EK1ESeV`EHlLie6?O00f6Shk0QcW00Dn>Shk>SXn>chj008Li`0:AUY2>DIJ@SU6FT8iAUY2>DIJ@ST3
7>L2AST01DHhASU6>DHiASP00THi00<007ooOol0@Woo00<007ooOol09Woo00<007ooOol01Woo0003
Ool00`00Oomoo`0lOol3000?Ool01000FDYIBUU:0QcW15V<00MISQcWFHiI[UV>FJiISP027>L015V_
EJiI[acW0eF_00MASacWO00f>cHJ=S/n>P027>L5?SX37>L00d8j@SU2>P02@SX01D8i@SY2>T8j@ST0
11cW1DHi00<007ooOol0@goo00<007ooOol09Goo00<007ooOol01Woo0003Ool00`00Oomoo`0iOol3
000AOol03@00FFYIBUUZFDYIJUU:7>MIS5f<FHaMSEV<008Li`0EFJiISEV^FHeI[acWFJmE[UV_7>ME
/5F?FK0Lig`07>Lf>cHJ=S/f6Shk008Li`06>SXn>chj?S/j>Shk0QcW00a2>DIJ@SU6FT8iAUY2>DIJ
@SU6FT8iAUX47>L00dHh001oo`15Ool00`00Oomoo`0TOol00`00Oomoo`06Ool000=oo`03001oogoo
03Ioo`<001=oo`03001E1acW00IIBP8Li`AIS00<FJhLieV^FHiI[UV>FJhLieV_EJiI[acW0eF_00Ul
02gk7>Lf>cHJ=S/f6SHk?SX00QcW1Shj0QcW0d8j00E2>D8j@SY2>T8i00=2>P05@SU2>T8j7>L00017
Ool00`00Oomoo`0SOol00`00Oomoo`06Ool000=oo`03001oogoo03=oo`<001Eoo`04001I1eD7F@L2
7>L075U:FFYIBUUZFDYIJQcWGHaIS5f=FHaI[QcWFJiISEV^FHeI[QcWFJmE[UV_7>ME/5F?O00Libgk
0QcW00hf6SHk=QXf>cHJ?S/Lichk?SXn>cXj?S/n>Shk0acW00e6FT8iAUY2>DIJ@SU6FT8iAUY2>DIJ
@ST00018Ool00`00Oomoo`0ROol00`00Oomoo`06Ool000=oo`03001oogoo02moo`@001Qoo`03001E
1eD700=E1`8Li`EIBP8Li`AIS08Li`0FFHiI[UV>FJhLieV_EJiI[acWEJml01fj7>L]nbWj7>Lf6SHk
=QXf>cHJ=S/27>L8?SX27>L01D8i@SY2>T8j@ST00d8j00=2>D8j0000B7oo00<007ooOol08goo00<0
07ooOol01Goo0002Ool00`00Oomoo`0]Ool3000KOol02@007>LLiacWF@ME1eT7E@MI1`027>L01EU:
FFYIBUUZFDX00QcW01AMSEV<GHaISAcWFHeI[UV=FJhLieV_EJiI[g`03ETLib6j7>L]nbWj0QcW00Hf
>cHJ=S/f6SHk=QX27>L023hk>SXn>chj?S/j>Shk?SX37>L01d8iAUY2>DIJ@SU6FP0004Yoo`03001o
ogoo029oo`03001oogoo00Eoo`000Woo00<007ooOol0:Woo0`007Goo00<004bSD:<00UD70QcW1ED7
0QcW1EU:00<LieV<FH`00UV<01XLieV>FJiISUV^7>MI[eF^O00=F0eI7>LM^QcW;O/YnRgk7>Lf>cHJ
=S/f6SHk=QXf>acW2Shj0QcW00E2>T8i@SY2>P0004]oo`03001oogoo025oo`03001oogoo00Eoo`00
0Woo00<007ooOol09goo0`0087oo00L0052SC:=@XdbSD:=E1`027>L01ET7E@MI1eD7F@L00QcW00AI
BUUZFDYIJP8Li`03FHaMS5V<008Li`03FJiISEV^008Li`0:O00Li`eH7>LM^B6j7>L]nbWj;O/27>L0
1SHJ=S/f6SHk=QXf>`8Li`0:>SXn>chj?S/j>Shk?SXn>cXj?S/27>L00d8iAUX0001<Ool00`00Oomo
o`0POol00`00Oomoo`05Ool0009oo`03001oogoo02Aoo`<0029oo`0:000LidbSD:=<Xe2SC:=@XdbS
E@L37>L4E@L27>L4FDX03acWFHaIS5V<FJhLieV^FHiI[UV>7>L=F1cW3EPLi`027KX27>L02bWj;O/Y
nQcW=QXf>cHJ=S/f6SHk=QX00QcW2Shj0QcW00<007ooOol0Bgoo00<007ooOol07goo00<007ooOol0
1Goo0002Ool00`00Oomoo`0POol4000TOol00`00A01000037>L024bSD:=<Xe2SC:=@XdbSF@L27>L0
15D7F@ME1eT70QcW00=IBUUZFDX00QcW00MMS5V<GHdLieV^FHeI[P027>L02`eH7>L=F1cW7KTQ^Qfj
7>LYnRgk:OX00QcW00Lf>cHJ=S/f6SHk=QXf>`027>L02chj?S/j>Shk?SXn>cXj?S/n>Shk0000CGoo
00<007ooOol07goo00<007ooOol01Goo0002Ool00`00Oomoo`0MOol3000XOol00`00@0140002A000
0d007>LLi`027>L01U2SC:=@XdbSD:=<X`8Li`AE1`8Li`=IBP8Li`9IS08Li`08FHhLi`0b7>L=F1cW
3EPLi`<M^P0?7>LYnRgk:OX]nacW=S/f6SHk=QXf>cHJ=S/f6QcW00Pn>P03001oogoo04eoo`03001o
ogoo01ioo`03001oogoo00Eoo`000Woo00<007ooOol06Woo0`00:Woo00/00400A01004@0@0140400
A01004@000<Li`05D:=<Xe2SC:=@X`037>L00eT7E@MI1`027>L01eU:FFYIBQcWFHaMSEV=008Li`0?
03<Li`3F7>LAF@eH7>LM^B6j7KXLibWj;O/YnRgk008Li`07=QXf>cHJ=S/f6SHk=QX00QcW00Ln>cXj
?S/n>Shk>SX0001@Ool00`00Oomoo`0NOol00`00Oomoo`04Ool00003Ool007oo01Uoo`<002eoo`05
000LiacWA0100003A0001T00A01404@0@01400<Li`05D:=<Xe2SC:=@X`037>L2E@L27>L2FDX27>L0
2eV<7>LLiacW03<Li`eI7>L=F@eH7>L00afj00HLibWj;O/YnRgk:OX27>L01cHk=QXf>cHJ=S/f6SHk
008Li`@n>P03001oogoo04moo`03001oogoo01eoo`03001oogoo00Aoo`0000=oo`00Ool05Woo0`00
<7oo00<00300=0001QcW00Q004@0@0140400A01004@011cW00A<Xe2SC:=@X`<Li`06F@LLiacWFDYI
JW`00acW01/0<QcW0=H=FAcW4ET=F1cW7KTQ^Qfj7>LYnRgk:OX]nbWj;O/LicHk=QXf>cHJ=S/f6SHk
=QX00QcW00<n>`00Ool0DWoo00<007ooOol077oo00<007ooOol017oo00000goo001oo`0BOol4000b
Ool00`00<00d0003<00013@0<00`03001AcW00E004@0A0140400009400<Li`04C:=@XdbSE@L27>L0
0eD77>Ml00027>L02`097>L0<`0b7>L0eQcW3EP=F@eH7>L00afj00LLibWj;O/YnRgk:OX]n`027>L0
2SHJ=S/f6SHk=QXf>cHJ=S/Li`00Dgoo00<007ooOol077oo00<007ooOol017oo00000goo001oo`0?
Ool3000fOol03`00=00`03@0<00d0300=00`03@0<00d0300=00`00057>L01D00A01004@0@00011cW
00E@XdbS7>Ml0000008Li`0?00PLiacW03<Li`3F3EPLi`eH4ETLiafj7KTQ^Qfj008Li`0?;O/YnRgk
:OX]nbWj7>Lf6SHk=QXf>cHJ=S/f6P0005Eoo`03001oogoo01]oo`03001oogoo00Aoo`0000=oo`00
Ool037oo0`00>Goo00<001cW7>L01AcW00Dd0300<00`03@000<`0004=00`0300<0067>L3A0027>L0
0g`0OolLi`027>L030097>LLi`0b03<Li`3F3EPLi`eH3ETLi`@M^P08;O/Libgk:OX]nbWj;O/YnP8L
i`06=S/f6SHk=QXf>`00EWoo00<007ooOol06Woo00<007ooOol017oo00000goo001oo`09Ool3000l
Ool02000700H01`0600L01P0700@7>L01300=00`03@00acW00=l07oo7>L00QcW00H02AcW7>L0<`0b
7>L20=H05acW3ET=F15I7>LM^Qfi8KXM^Rgk7>L]nbWj;O/YnRgk:OX]nacW=S/f6SHk0000F7oo00<0
07ooOol06Goo00<007ooOol017oo00000`00Oomoo`06Ool3000oOol00`00700L000E70077>L00g`0
7>LLi`027>L03P097>L03QcW03<0<QcW0=H=FAcW3ET=F0eI7>L47KX02Bgk7>L]nbWj;O/YnRgk:OX]
n`027>L00cHJ001oo`1HOol00`00Oomoo`0HOol00`00Oomoo`04Ool00003001oogoo009oo`@0049o
o`08000L01P0700H01`0600L01@Li`8000HLi`0700PLi`0>7>L0<P0c7>L00P3F01DAFAcW3ET=F15I
7>LM^Qfi8KXM^Rgk7>L]nbWj;O/YnRgk:OX]nbWj0000Fgoo00<007ooOol067oo00<007ooOol00goo
00000`00Ool000020016Ool00`007>LLi`057>L810067>L400000b<D7>LLi`077>L200T27>L0100c
0380<acW0P3F00HLi`eH3ET=F0eI7>L57KX021cW;O/YnRgk:OX]nbWj001LOol00`00Oomoo`0HOol0
0`00Oomoo`03Ool0008004Uoo`03000400@000L400HLi`L000TLi`04E/DLiacW7>L200T01QcW00hL
i`0c038Li`<0eP097>L=F0eI3EPAFAcW7KXM^B6j008M^P8Li`05:OX]nbWj;O/0001MOol00`00Oomo
o`0GOol00`00Oomoo`03Ool00003Ool0000004Qoo`04000400@010067>L900067>L013=E7>LLie>@
0acW00AFaAcW7>LLi`802@077>L03QcW0380<`0b7>L00P3F00L=F1cW3EP=F@eH3ETLi`057KX01BWj
7>LYnRgk0000Ggoo00<007ooOol05Woo00<007ooOol00goo0003Ool00`00Oomoo`15Ool010007>LL
iacW2`0011cW00DS5B<D7>LLicME00DLi`05FbXLie[57>L000027>L02@0800TLi`0>7>L0<`0b03<L
i`030=H02QcW4ET=F0eI3EPAFAcW7KXM^B6j0Qfj00@YnQcW:OX0061oo`03001oogoo01Eoo`03001o
ogoo00=oo`0017oo00<007ooOol0A7oo2`0011cW0b<D0acW0S=E0QcW00A;TQcW7>MKK@8Li`03E/DL
i`00008Li`802@087>L03P0>7>L0<`0b03<Li`<0eP077>L=F@eH3ET=F0eI7>L01Afj00<YnP00Ool0
HGoo00<007ooOol057oo00<007ooOol00goo0005Ool20015Ool600047>L01BLE8a@S5B<D9aD00QcW
00<cE3ME<e@00acW00E;TQcWDi0Lie/Y008Li`03F/DLi`00008Li`802@087>L03P0>7>L0<P0c038L
i`<0eP073ETLia5I3EP=F@eH7>L00Qfj00DM^B6j7KXM^P00069oo`03001oogoo01Aoo`03001oogoo
00=oo`001goo00<007ooOol0@Woo0P0011cW1R<D0acW0S=E00<gEAcW7>L00QcW00E;TQcWDi0LieM]
008Li`04F/EFaAcW00027>L300T021cW00h0<QcW0380<`0b7>L30=H01acW3EP=F@eH3ET=F1cW00@M
^P03001oogoo069oo`03001oogoo01Aoo`03001oogoo009oo`0027oo0P00@Woo00X001cW8aDS52LE
8a@S5B<D9aDS508Li`04=eDcE3ME<e@27>L03D>D7>M?Td^B7>MCT1cWEddLieLY7>MFaAcW0080008L
i`0400P02@097>L200h01AcW03<0<P0c7>L0103F00LLi`eH4ET=F0eI3EPLi`027KX00`00Oomoo`1T
Ool00`00Oomoo`0COol00`00Oomoo`02Ool000Yoo`03001oogoo03moo`03000S52<D00DS508Li`04
<eDgEC=E<eD27>L024=d@i@LidnCBi8Lie>@7>L2Efd27>L2E/D01QcW000001cW00<Li`802@097>L0
3P0>7>L0<P0c0380<acW00<0eP0:3EPLi`eH3ET=F0eI3EPLiafj001WOol00`00Oomoo`0BOol00`00
Oomoo`02Ool000]oo`80041oo`04000W5B<D8aD37>L023ME<e@gEC=D@i@Lid>D?g@27>L05DnCBi8L
ie>@7>MGCE]]7>MK:QcWF/EFa1cW000Li`0300@Li`0900PLi`0200h01P0b7>L0<P0c038Li`@0eP08
7>L=F@eH4ET=F0eI3EP006Uoo`03001oogoo015oo`03001oogoo009oo`003Goo00<007ooOol0?Goo
00D002<D7>LLicME00<cE@0;=eDcEAcW7>M3U4=d7>M;TTnCBi8Li`02Di003QcWEfeK:AcWFbTLieK5
F/DLi`007>L010037>L200T02QcW00h03P0>7>L0<`0b03<0<QcW103F00HLi`eI3EP=F@eH001ZOol0
0`00Oomoo`0AOol00`00Oomoo`02Ool000ioo`03001oogoo03aoo`08000Lic=D=eDcE3ME<e@gE@8L
i`0C?gA3U3md7>M;TTnCBi8Lie>@Ei4Lie]]EddLie/Y7>MFa5[57>L00P0000@Li`0300@Li`802@0:
7>L03P0>00hLi`0b03<0<P0c7>L50=H011cW3ET=F000K7oo00<007ooOol047oo00<007ooOol00Woo
000?Ool2000mOol00`00=eDcE@02<eD27>L00d>D@gA3U0027>L014^BCi=;TQcW0U>@00XLieM]EfeK
:QcWFbTLie[5E/DLi`8000047>L00`037>L200T02`0>7>L03P0>038Li`0b03<0<P0c7>L0103F00<L
i`eH0000KWoo00<007ooOol03goo00<007ooOol00Woo000AOol00`00Oomoo`0jOol00`00<e@gE@02
7>L05cmd@i@oM4>D7>M?Td^BCi=;TQcWDi1GTAcWFfeGCE]^7>MK:QcWF/EFaE[57>L00P0000PLi`03
00@Li`0900P02AcW0`0>00HLi`0c0380<`0b7>L50=H00`00Oomoo`1^Ool00`00Oomoo`0>Ool00`00
Oomoo`02Ool0019oo`8003]oo`0;000Lid>D@gA3U4=d@i@Lid^CBi9?T`027>L3Di0011cWEfeKKAcW
0U/Y00DLieK5E/EFaAcW008000047>L010037>L300T02acW00h03P0>7>L0<P0c0380<`0b7>L00`3F
00<007ooOol0L7oo00<007ooOol03Woo00<007ooOol00Goo000DOol00`00Oomoo`0iOol01000?gA3
U3md0QcW01=?Td^BCi<LieN@Di1GTE>@7>MGCE]^EddLieLYFbXLie[5E/@Li`03000011cW00<011cW
0`0900/Li`0>00h03P0b7>L0<P0c0380<acW0080eP03001oogoo079oo`03001oogoo00eoo`03001o
ogoo005oo`005Goo00<007ooOol0>Goo00P004=d7>M;TT^CBi9?TacW15>@00PLieM]FfeGKAcWFbUK
:QcW0UK500=JaAcW00000P0000@Li`0300<Li`<02@037>L03P0>00803P087>L0<`0b03<0<P0c7>L0
07Eoo`03001oogoo00eoo`03001oogoo005oo`005Woo0P00>Woo01L004^BCi=;TTnC7>MGT5>@Ei5C
T1cWEdeKKUM=FbXLie/ZFbTLieK4F/EFaAcW00<000087>L00`047>L02@0800TLi`@03P077>L0<P0c
0380<`0b0000Mgoo00<007ooOol037oo00<007ooOol00Goo000HOol00`00Oomoo`0hOol01000Bi9?
TacW15>@00<LieM]Ffd00UM]00HLie/ZFbTLieK5F/D2E/D021cW000000007>L010037>L300T00`0>
7>L03P0200h0100b7>L0<P0c0P00NGoo00<007ooOol02goo00<007ooOol00Goo000IOol2000iOol0
50007>LLie>@Ei5CT5N@7>MKKUM=FfdLie/ZFbUK:QcWF/EFaE[57>L4000011cW00<011cW0`0900<0
21cW00h00`0>00<Li`000000O7oo00<007ooOol02Woo00<007ooOol00Goo000KOol00`00Oomoo`0g
Ool00`00Di1CT002Di000acWFfeGK@02Efd01AcWFbUK:E/Y7>L00eK500DLi`00000001cW00<00`03
7>L02@0900802@047>L03P0>00h2001oOol00`00Oomoo`09Ool00`00Oomoo`01Ool001aoo`8003Qo
o`80000@Ei0Lie]^EdeKKEM=7>MK:E/ZEbTLieK5F/EFa5[57>L300001acW00@00`047>L02@080080
2@047>L03P000021Ool00`00Oomoo`0:Ool10001Ool1Ool001ioo`03001oogoo03Moo`<0009GK@06
FfdLie/YFbUK:QcW0UK500=JaEK57>L00`0000DLi`0300@00acW00@02@8008Aoo`03001oogoo00Uo
o`40005oo`5oo`007goo00<007ooOol0>Goo0`0000UK:ULYFbXLie[5E/AJaEK57>L0100000DLi`04
00<011cW00802@8008Moo`03001oogoo00Qoo`40005oo`5oo`0087oo0P00?7oo0P0000AK:AcWE/EJ
a@9Fa@037>L00000008000037>L00`0300@008Yoo`03001oogoo00Moo`40005oo`5oo`008Woo00<0
07ooOol0>goo3P00Sgoo00<007ooOol01Woo0@000Goo0Goo000SOol20016Ool00`00Oomoo`2?Ool0
0`00Oomoo`06Ool10001Ool1Ool002Eoo`03001oogoo04=oo`03001oogoo091oo`03001oogoo00Eo
o`40005oo`5oo`009Woo0P00@goo00<007ooOol0TGoo00<007ooOol01Goo0@000Goo000XOol00`00
Oomoo`10Ool00`00Oomoo`2BOol00`00Oomoo`04Ool10001Ool002Uoo`03001oogoo03moo`03001o
ogoo09=oo`03001oogoo00=oo`40005oo`00:Woo0P00?goo00<007ooOol0U7oo00<007ooOol00Woo
0@000Goo000/Ool00`00Oomoo`0lOol00`00Oomoo`2DOol00`00Oomoo`02Ool10001Ool002eoo`80
03aoo`03001oogoo09Eoo`05001oogooOol00001Ool002moo`03001oogoo03Uoo`03001oogoo09Io
o`04001oogoo0001Ool0031oo`03001oogoo03Qoo`03001oogoo09Moo`03001oo`00005oo`00<Goo
0P00=goo00<007ooOol0VGoo0@000Goo0@00000cOol00`00Oomoo`0dOol00`00Oomoo`2IOol10001
Ool1000003Aoo`8003Aoo`03001oogoo09Yoo`800000=Woo00<007ooOol0<Goo00<007ooOol0VGoo
0`00000gOol2000aOol00`00Oomoo`2EOol40003Ool003Uoo`03001oogoo02ioo`03001oogoo091o
o`D000Moo`00>Woo00<007ooOol0;Goo00<007ooOol0S7oo100037oo000kOol2000]Ool00`00Oomo
o`28Ool4000@Ool003eoo`03001oogoo02Yoo`03001oogoo08=oo`D001Aoo`00?Woo0P00:Woo00<0
07ooOol0Ogoo10006Goo0010Ool00`00Oomoo`0WOol00`00Oomoo`1jOol5000MOol0045oo`03001o
ogoo02Ioo`03001oogoo07Ioo`@0029oo`00@Woo0P009Woo00<007ooOol0LWoo10009Woo0014Ool0
0`00Oomoo`0SOol00`00Oomoo`1]Ool5000ZOol004Eoo`8002=oo`03001oogoo06Uoo`@002moo`00
Agoo00<007ooOol087oo00<007ooOol0I7oo1@00<goo0018Ool2000POol00`00Oomoo`1POol4000h
Ool004Yoo`03001oogoo01eoo`03001oogoo05]oo`D003aoo`00Bgoo00<007ooOol077oo00<007oo
Ool0Egoo1000@Goo001<Ool2000LOol00`00Oomoo`1COol40015Ool004ioo`03001oogoo01Uoo`03
001oogoo04ioo`D004Uoo`00Cgoo0P006Goo00<007ooOol0BWoo1000CWoo001AOol00`00Oomoo`0F
Ool00`00Oomoo`15Ool5001BOol0059oo`8001Ioo`03001oogoo045oo`@005Moo`00E7oo00<007oo
Ool04goo00<007ooOol0?Goo1000Fgoo001EOol00`00Oomoo`0BOol00`00Oomoo`0hOol5001OOol0
05Ioo`80015oo`03001oogoo03Eoo`@006Aoo`00F7oo00<007ooOol03Woo00<007ooOol0<7oo1@00
J7oo001IOol2000>Ool00`00Oomoo`0/Ool4001]Ool005]oo`03001oogoo00]oo`03001oogoo02Mo
o`D0075oo`00G7oo00<007ooOol02Woo00<007ooOol08goo1000MWoo001MOol2000:Ool00`00Oomo
o`0OOol4001jOol005moo`03001oogoo00Moo`03001oogoo01Yoo`D007ioo`00H7oo0P001goo00<0
07ooOol05Woo1000Pgoo001ROol00`00Oomoo`04Ool00`00Oomoo`0AOol50027Ool006=oo`8000Ao
o`03001oogoo00eoo`@008aoo`00IGoo00D007ooOomoo`0000]oo`@0091oo`00IWoo00@007ooOol0
00Ioo`D009Aoo`00Igoo0`000Woo1000VGoo001YOol3002MOol00001
\>"],
  ImageRangeCache->{{{0, 264.313}, {287, 0}} -> {0.0486402, -0.000148683, 
  0.00324458, 0.00324458}}]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell["And if Kappa is not 1, it doesn't come out even either.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(clear; top = 125; kappa[s_] = 2; tau[s_] := Sin[s]; width = .3; 
    ds = .1; \), 
    \(pribbonfrenet\)}], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-016 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.63068 .68773 m .68261 .61817 L .59957 .66639 L .453 .404 .712 r
F
.63068 .68773 m .69395 .63511 L .68261 .61817 L F
.66496 .70596 m .69395 .63511 L .63068 .68773 L .35 .356 .725 r
F
.59957 .66639 m .67209 .6003 L .57287 .642 L .525 .44 .702 r
F
.59957 .66639 m .68261 .61817 L .67209 .6003 L F
0 g
.006 w
.59957 .66639 m
.63068 .68773 L
s
.25 g
.5 Mabswid
.59957 .66639 m
.60467 .66343 L
s
.66496 .70596 m .70569 .65107 L .69395 .63511 L .35 .356 .725 r
F
.25 g
.69135 .63727 m
.69395 .63511 L
s
.70109 .72111 m .70569 .65107 L .66496 .70596 L .186 .284 .732 r
F
0 g
.006 w
.63068 .68773 m
.66496 .70596 L
s
.25 g
.5 Mabswid
.63068 .68773 m
.63451 .68455 L
s
.60537 .53295 m .60821 .53219 L .60566 .53179 L .703 .564 .695 r
F
.60821 .53219 m .61788 .52158 L .53008 .51987 L F
.63035 .51744 m .62145 .51883 L .6016 .54666 L .968 .879 .494 r
F
.65709 .48707 m .63979 .49192 L .63035 .51744 L .98 .852 .642 r
F
.61158 .50713 m .61006 .52143 L .62248 .5091 L .739 .599 .701 r
F
.61158 .50713 m .62248 .5091 L .62323 .50531 L F
.60819 .52139 m .61006 .52143 L .61158 .50713 L F
.63035 .51744 m .62248 .5091 L .62053 .51897 L .968 .879 .494 r
F
.63979 .49192 m .62688 .50474 L .63035 .51744 L .98 .852 .642 r
F
.62688 .50474 m .62248 .5091 L .62293 .50957 L F
.62688 .50474 m .62293 .50957 L .63035 .51744 L F
.53008 .51987 m .62688 .50474 L .53845 .48597 L .739 .599 .701 r
F
.62688 .50474 m .63093 .49977 L .53845 .48597 L F
.62323 .50531 m .62248 .5091 L .62688 .50474 L F
.63979 .49192 m .63895 .49215 L .62248 .5091 L .98 .852 .642 r
F
.53845 .48597 m .63093 .49977 L .63922 .49053 L .774 .639 .711 r
F
.65709 .48707 m .64041 .48341 L .63895 .49215 L .98 .852 .642 r
F
.68055 .45601 m .66509 .46135 L .65709 .48707 L .925 .79 .693 r
F
.64061 .48218 m .64041 .48341 L .64183 .48213 L .774 .639 .711 r
F
.53845 .48597 m .63922 .49053 L .64061 .48218 L F
.55456 .45234 m .64293 .48066 L .65148 .46267 L .809 .684 .726 r
F
.64183 .48213 m .63978 .48327 L .64041 .48341 L .925 .79 .693 r
F
.65091 .47402 m .64293 .48066 L .64183 .48213 L F
.53845 .48597 m .64183 .48213 L .55456 .45234 L .774 .639 .711 r
F
.64183 .48213 m .64293 .48066 L .55456 .45234 L F
.64293 .48066 m .63978 .48327 L .64183 .48213 L .925 .79 .693 r
F
.66509 .46135 m .64041 .48341 L .65709 .48707 L F
.64183 .48213 m .64693 .48194 L .64293 .48066 L .774 .639 .711 r
F
.64293 .48066 m .64693 .48194 L .64829 .4762 L .809 .684 .726 r
F
.64293 .48066 m .64829 .4762 L .65148 .46267 L F
.66509 .46135 m .61649 .47815 L .63978 .48327 L .925 .79 .693 r
F
.66509 .46135 m .63978 .48327 L .65091 .47402 L F
.64183 .48213 m .63922 .49053 L .64693 .48194 L .774 .639 .711 r
F
.64041 .48341 m .63922 .49053 L .64183 .48213 L F
.63093 .49977 m .64667 .48482 L .64693 .48194 L F
.63895 .49215 m .61649 .47815 L .61328 .49934 L .98 .852 .642 r
F
.64041 .48341 m .61649 .47815 L .63895 .49215 L F
.63895 .49215 m .61328 .49934 L .62183 .50841 L F
.63895 .49215 m .62183 .50841 L .62248 .5091 L F
.63093 .49977 m .6451 .50189 L .64667 .48482 L .774 .639 .711 r
F
.62688 .50474 m .6451 .50189 L .63093 .49977 L .739 .599 .701 r
F
.62688 .50474 m .61788 .52158 L .63651 .50323 L F
.61006 .52143 m .61788 .52158 L .62688 .50474 L F
.62053 .51897 m .61328 .49934 L .60897 .52077 L .968 .879 .494 r
F
.62248 .5091 m .61328 .49934 L .62053 .51897 L F
.53008 .51987 m .60819 .52139 L .61158 .50713 L .739 .599 .701 r
F
.60537 .53295 m .6071 .53332 L .60821 .53219 L .703 .564 .695 r
F
.62145 .51883 m .618 .5223 L .6016 .54666 L .968 .879 .494 r
F
.618 .5223 m .6142 .52615 L .6016 .54666 L F
.60471 .53573 m .6071 .53332 L .60537 .53295 L .703 .564 .695 r
F
.6184 .5193 m .60553 .53363 L .60497 .53546 L .968 .879 .494 r
F
.6142 .52615 m .60497 .53546 L .6016 .54666 L F
.6184 .5193 m .60497 .53546 L .6142 .52615 L F
.52967 .55313 m .59315 .54741 L .60537 .53295 L .703 .564 .695 r
F
.60241 .54511 m .60307 .54265 L .60255 .54482 L 0 0 0 r
F
.60942 .5207 m .60868 .52178 L .6016 .54666 L .968 .879 .494 r
F
.6016 .54666 m .60459 .53617 L .60241 .54511 L 0 0 0 r
F
.60255 .54482 m .6071 .53332 L .60471 .53573 L .703 .564 .695 r
F
.60213 .5466 m .60293 .54447 L .60255 .54482 L F
.60293 .54447 m .6071 .53332 L .60255 .54482 L F
.60942 .5207 m .60897 .52077 L .60868 .52178 L .968 .879 .494 r
F
.60459 .53617 m .60897 .52077 L .60241 .54511 L 0 0 0 r
F
.6016 .54666 m .60238 .54515 L .57216 .57437 L F
.60238 .54515 m .59552 .55166 L .57216 .57437 L F
.60255 .54482 m .60052 .54674 L .57216 .57437 L F
.58323 .56057 m .60052 .54674 L .59315 .54741 L .666 .532 .692 r
F
.57599 .57019 m .58133 .56508 L .58323 .56057 L F
.58133 .56508 m .60052 .54674 L .58323 .56057 L F
.60052 .54674 m .58429 .56208 L .58133 .56508 L 0 0 0 r
F
.60052 .54674 m .58133 .56508 L .57216 .57437 L F
.57298 .57403 m .58058 .56622 L .57853 .57172 L 0 0 .222 r
F
.58058 .56622 m .58106 .56572 L .57979 .56875 L F
.58058 .56622 m .57979 .56875 L .57853 .57172 L F
.57216 .57437 m .57891 .57157 L .54339 .60026 L F
.58434 .56702 m .65509 .56224 L .64937 .54233 L .666 .532 .692 r
F
.58256 .56851 m .65509 .56224 L .58434 .56702 L F
.57945 .56984 m .65509 .56224 L .57979 .56875 L F
.57891 .57157 m .57062 .5785 L .54339 .60026 L 0 0 .222 r
F
.54428 .59969 m .57062 .5785 L .54424 .59959 L .626 .502 .692 r
F
.5517 .61475 m .56756 .58438 L .54428 .59969 L F
.56756 .58438 m .57062 .5785 L .54428 .59969 L F
.5517 .61475 m .65509 .56224 L .57062 .5785 L F
.54337 .60029 m .59301 .58422 L .51666 .6241 L .16 0 .393 r
F
.54339 .60026 m .54341 .60026 L .54337 .60029 L F
.54341 .60026 m .59301 .58422 L .54337 .60029 L F
.57062 .5785 m .54958 .59613 L .54342 .60025 L 0 0 .222 r
F
.57062 .5785 m .54342 .60025 L .54339 .60026 L F
.54424 .59959 m .57062 .5785 L .53704 .58497 L .626 .502 .692 r
F
.57216 .57437 m .57407 .57244 L .57298 .57403 L 0 0 .222 r
F
.60238 .54515 m .60255 .54482 L .59552 .55166 L 0 0 0 r
F
.58133 .56508 m .64937 .54233 L .60052 .54674 L .666 .532 .692 r
F
.57407 .57244 m .58133 .56508 L .57298 .57403 L 0 0 .222 r
F
.58133 .56508 m .58106 .56572 L .57298 .57403 L F
.57599 .57019 m .57979 .56875 L .58133 .56508 L .666 .532 .692 r
F
.57979 .56875 m .64937 .54233 L .58133 .56508 L F
.59315 .54741 m .60213 .5466 L .60471 .53573 L .703 .564 .695 r
F
.60213 .5466 m .64937 .54233 L .6071 .53332 L F
.6056 .53355 m .60594 .53225 L .60553 .53363 L .968 .879 .494 r
F
.6184 .5193 m .60594 .53225 L .6056 .53355 L F
.6184 .5193 m .60942 .5207 L .60594 .53225 L F
.6027 .54455 m .60897 .52077 L .60391 .5422 L 0 0 0 r
F
.60255 .54482 m .60326 .54218 L .6027 .54455 L F
.60326 .54218 m .60897 .52077 L .6027 .54455 L F
.60307 .54265 m .60897 .52077 L .60255 .54482 L F
.60255 .54482 m .60391 .5422 L .58429 .56208 L F
.58133 .56508 m .60391 .5422 L .58106 .56572 L 0 0 .222 r
F
.56636 .57932 m .57714 .57725 L .57599 .57019 L .666 .532 .692 r
F
.57714 .57725 m .65509 .56224 L .57945 .56984 L F
.57853 .57172 m .57904 .57113 L .57891 .57157 L 0 0 .222 r
F
.57979 .56875 m .58256 .56851 L .58434 .56702 L .666 .532 .692 r
F
.58106 .56572 m .60391 .5422 L .57853 .57172 L 0 0 .222 r
F
.57714 .57725 m .57945 .56984 L .57599 .57019 L .666 .532 .692 r
F
.57891 .57157 m .60391 .5422 L .59846 .56342 L 0 0 .222 r
F
.57904 .57113 m .60391 .5422 L .57891 .57157 L F
.57891 .57157 m .59846 .56342 L .54958 .59613 L F
.57599 .57019 m .57945 .56984 L .57979 .56875 L .666 .532 .692 r
F
.57096 .5721 m .57599 .57019 L .59315 .54741 L F
.53704 .58497 m .56636 .57932 L .57599 .57019 L F
.59315 .54741 m .60471 .53573 L .60537 .53295 L .703 .564 .695 r
F
.62022 .51902 m .61518 .52454 L .6142 .52615 L .968 .879 .494 r
F
.62022 .51902 m .6142 .52615 L .618 .5223 L F
.63651 .50323 m .64596 .52213 L .6451 .50189 L .739 .599 .701 r
F
.62145 .51883 m .62053 .51897 L .618 .5223 L .968 .879 .494 r
F
.62053 .51897 m .61969 .5198 L .618 .5223 L F
.61788 .52158 m .64596 .52213 L .63651 .50323 L .739 .599 .701 r
F
.62053 .51897 m .62022 .51902 L .61969 .5198 L .968 .879 .494 r
F
.60821 .53219 m .64937 .54233 L .64596 .52213 L .703 .564 .695 r
F
.6071 .53332 m .64937 .54233 L .60821 .53219 L F
.52967 .55313 m .60537 .53295 L .53008 .51987 L F
.60537 .53295 m .60566 .53179 L .53008 .51987 L F
.60821 .53219 m .64596 .52213 L .61788 .52158 L F
.62022 .51902 m .6184 .5193 L .61518 .52454 L .968 .879 .494 r
F
.53704 .58497 m .57096 .5721 L .52967 .55313 L .666 .532 .692 r
F
.57096 .5721 m .59315 .54741 L .52967 .55313 L F
.25 g
.61328 .49934 m
.62183 .50841 L
s
.62183 .50841 m
.62248 .5091 L
s
0 g
.006 w
.64522 .50055 m
.65709 .48707 L
s
.25 g
.5 Mabswid
.60518 .5341 m
.60897 .52077 L
s
.60471 .53573 m
.60518 .5341 L
s
.57287 .642 m .66278 .58161 L .5517 .61475 L .58 .472 .696 r
F
.57287 .642 m .67209 .6003 L .66278 .58161 L F
0 g
.006 w
.57287 .642 m
.59957 .66639 L
s
.25 g
.5 Mabswid
.68914 .63911 m
.69135 .63727 L
s
.63451 .68455 m
.68914 .63911 L
s
.67887 .62034 m
.68261 .61817 L
s
.60467 .66343 m
.67887 .62034 L
s
.57287 .642 m
.57905 .6394 L
s
.63542 .48231 m
.64041 .48341 L
s
.64667 .48478 m
.65709 .48707 L
s
.58429 .56208 m
.60391 .5422 L
s
.70109 .72111 m .71742 .66596 L .70569 .65107 L .186 .284 .732 r
F
.25 g
.70285 .6549 m
.70419 .65309 L
s
.70419 .65309 m
.70569 .65107 L
s
.73772 .73328 m .71742 .66596 L .70109 .72111 L 0 .16 .696 r
F
.25 g
.66496 .70596 m
.66739 .70269 L
s
.66739 .70269 m
.70285 .6549 L
s
0 g
.006 w
.66496 .70596 m
.70109 .72111 L
s
.25 g
.5 Mabswid
.70109 .72111 m
.71689 .66774 L
s
.81517 .3036 m .74215 .37987 L .83888 .30797 L .777 .892 .926 r
F
.81517 .3036 m .73091 .38054 L .74215 .37987 L F
.5517 .61475 m .66278 .58161 L .65509 .56224 L .626 .502 .692 r
F
.25 g
.6569 .58337 m
.66278 .58161 L
s
.5517 .61475 m
.55874 .61265 L
s
.58319 .5632 m
.58429 .56208 L
s
0 g
.006 w
.5517 .61475 m
.57287 .642 L
s
.25 g
.5 Mabswid
.66722 .60235 m
.67209 .6003 L
s
0 g
.006 w
.54819 .60763 m
.5517 .61475 L
s
.57776 .41999 m .65148 .46267 L .65861 .44449 L .842 .736 .746 r
F
.55456 .45234 m .65148 .46267 L .57776 .41999 L .809 .684 .726 r
F
.68055 .45601 m .61829 .45745 L .61649 .47815 L .925 .79 .693 r
F
.25 g
.5 Mabswid
.61649 .47815 m
.63542 .48231 L
s
.60701 .38997 m .65861 .44449 L .66803 .42783 L .87 .793 .773 r
F
.57776 .41999 m .65861 .44449 L .60701 .38997 L .842 .736 .746 r
F
.69955 .42477 m .61829 .45745 L .68055 .45601 L .871 .742 .717 r
F
0 g
.006 w
.65709 .48707 m
.68055 .45601 L
s
.78576 .30453 m .73091 .38054 L .81517 .3036 L .798 .922 .92 r
F
.25 g
.5 Mabswid
.82397 .31905 m
.83888 .30797 L
s
.78576 .30453 m .71837 .38428 L .73091 .38054 L .798 .922 .92 r
F
1 0 0 r
.003 w
.73091 .38054 m
.74215 .37987 L
s
.54339 .60026 m .59846 .56342 L .59301 .58422 L .16 0 .393 r
F
.25 g
.5 Mabswid
.54339 .60026 m
.54342 .60025 L
s
.54342 .60025 m
.54675 .59802 L
s
.54675 .59802 m
.54958 .59613 L
s
0 g
.006 w
.53704 .58497 m
.54407 .59926 L
s
.54407 .59926 m
.54424 .59959 L
s
.25 g
.5 Mabswid
.58133 .56508 m
.58319 .5632 L
s
0 g
.006 w
.54339 .60026 m
.54421 .59953 L
s
.73772 .73328 m .72872 .67974 L .71742 .66596 L 0 .16 .696 r
F
.25 g
.5 Mabswid
.71689 .66774 m
.71742 .66596 L
s
.77344 .74267 m .72872 .67974 L .73772 .73328 L 0 0 .521 r
F
0 g
.006 w
.70109 .72111 m
.73772 .73328 L
s
.75191 .31106 m .71837 .38428 L .78576 .30453 L .829 .936 .899 r
F
.25 g
.5 Mabswid
.80656 .31146 m
.81517 .3036 L
s
.75191 .31106 m .70515 .39107 L .71837 .38428 L .829 .936 .899 r
F
1 0 0 r
.003 w
.71837 .38428 m
.73091 .38054 L
s
.25 g
.5 Mabswid
.56636 .57932 m
.57062 .5785 L
s
.59578 .57366 m
.65509 .56224 L
s
.53704 .58497 m
.54466 .5835 L
s
.54466 .5835 m
.55585 .58135 L
s
.55585 .58135 m
.56636 .57932 L
s
.71855 .32211 m .70515 .39107 L .75191 .31106 L .861 .929 .87 r
F
.71518 .32357 m .70515 .39107 L .71855 .32211 L F
.70864 .36756 m .6919 .40076 L .70515 .39107 L F
.70033 .37282 m .6919 .40076 L .70864 .36756 L F
.71186 .31153 m .66057 .34728 L .7156 .32339 L .738 .669 .783 r
F
.67804 .34274 m .6919 .40076 L .71508 .32373 L .883 .899 .837 r
F
.71508 .32373 m .71185 .33446 L .71518 .32357 L .861 .929 .87 r
F
.71185 .33446 m .7119 .33441 L .71518 .32357 L F
.70603 .35379 m .70608 .35375 L .71518 .32357 L F
.71518 .32357 m .70033 .37282 L .70864 .36756 L F
.66057 .34728 m .64169 .36044 L .66607 .35137 L .738 .669 .783 r
F
.64169 .36044 m .60618 .38519 L .64257 .36464 L F
.64169 .36044 m .64257 .36464 L .66607 .35137 L F
.60701 .38997 m .66803 .42783 L .64343 .36939 L .87 .793 .773 r
F
.60701 .38997 m .64343 .36939 L .61644 .38252 L F
.6422 .37167 m .60618 .38519 L .63299 .38873 L .762 .673 .764 r
F
.64889 .37368 m .66803 .42783 L .67931 .41312 L .885 .85 .804 r
F
.64432 .36775 m .64744 .37568 L .64889 .37368 L F
.64744 .37568 m .66803 .42783 L .64889 .37368 L F
.64391 .3685 m .66803 .42783 L .64432 .36775 L F
.64373 .3701 m .66803 .42783 L .64391 .3685 L F
.64354 .3692 m .64391 .3685 L .64282 .36582 L F
.64373 .3701 m .64391 .3685 L .64354 .3692 L F
.64282 .36582 m .67931 .41312 L .67765 .34417 L F
.68559 .37436 m .67931 .41312 L .6919 .40076 L .883 .899 .837 r
F
.67947 .37921 m .67931 .41312 L .68559 .37436 L F
.67819 .35113 m .67931 .41312 L .6796 .3493 L F
.67765 .34417 m .67783 .3516 L .67804 .34274 L F
.67783 .3516 m .67931 .41312 L .67819 .35113 L F
.67783 .3516 m .67819 .35113 L .67804 .34274 L F
.64354 .3692 m .60618 .38519 L .6422 .37167 L .762 .673 .764 r
F
.6796 .3493 m .67947 .37921 L .68559 .37436 L .883 .899 .837 r
F
.67804 .34274 m .67819 .35113 L .6796 .3493 L F
.71508 .32373 m .64258 .36465 L .70172 .34429 L .738 .669 .783 r
F
.64258 .36465 m .60618 .38519 L .64354 .3692 L F
.64282 .36582 m .64391 .3685 L .64432 .36775 L .885 .85 .804 r
F
.64258 .36465 m .64354 .3692 L .70172 .34429 L .738 .669 .783 r
F
.71419 .32419 m .60618 .38519 L .71508 .32373 L F
.64085 .36326 m .64373 .3701 L .64282 .36582 L .885 .85 .804 r
F
.64354 .3692 m .6422 .37167 L .67052 .36103 L .762 .673 .764 r
F
.67147 .35982 m .67052 .36103 L .69324 .35251 L F
.64354 .3692 m .67052 .36103 L .67147 .35982 L F
.70603 .35379 m .6919 .40076 L .70608 .35375 L .861 .929 .87 r
F
.71299 .39398 m .63593 .41364 L .61839 .43749 L .827 .708 .733 r
F
.63593 .41364 m .63575 .41369 L .63559 .41391 L F
.63593 .41364 m .63559 .41391 L .61839 .43749 L F
.70172 .34429 m .67445 .35596 L .69324 .35251 L .762 .673 .764 r
F
.67445 .35596 m .64354 .3692 L .67147 .35982 L F
.67445 .35596 m .67147 .35982 L .69324 .35251 L F
.6732 .3803 m .63447 .39354 L .64297 .40472 L .791 .686 .748 r
F
.63447 .39354 m .61252 .40104 L .62769 .40288 L F
.63447 .39354 m .62769 .40288 L .64297 .40472 L F
.61644 .38252 m .64343 .36939 L .64085 .36326 L .87 .793 .773 r
F
.63299 .38873 m .60994 .38569 L .61252 .40104 L .762 .673 .764 r
F
.60994 .38569 m .60618 .38519 L .60696 .38714 L F
.60994 .38569 m .60696 .38714 L .61252 .40104 L F
.69324 .35251 m .6422 .37167 L .63299 .38873 L F
.66057 .34728 m .66607 .35137 L .6761 .34513 L .738 .669 .783 r
F
.66057 .34728 m .67744 .34495 L .67897 .33929 L F
.64085 .36326 m .64282 .36582 L .67757 .34077 L .885 .85 .804 r
F
.64282 .36582 m .67765 .34417 L .67757 .34077 L F
.6761 .34513 m .66607 .35137 L .67744 .34495 L .738 .669 .783 r
F
.67897 .33929 m .67744 .34495 L .7156 .32339 L F
.67757 .34077 m .67765 .34417 L .67804 .34274 L .883 .899 .837 r
F
.67757 .34077 m .67804 .34274 L .71523 .32321 L F
.71513 .32366 m .71419 .32419 L .71508 .32373 L .738 .669 .783 r
F
.67804 .34274 m .71508 .32373 L .71523 .32321 L .883 .899 .837 r
F
.71185 .33446 m .70603 .35379 L .7119 .33441 L .861 .929 .87 r
F
.71974 .33657 m .70172 .34429 L .69324 .35251 L .762 .673 .764 r
F
.64297 .40472 m .61252 .40104 L .61654 .41859 L .791 .686 .748 r
F
.71996 .36432 m .6732 .3803 L .64297 .40472 L F
.63575 .41369 m .61654 .41859 L .61721 .42542 L .827 .708 .733 r
F
.63575 .41369 m .61721 .42542 L .61839 .43749 L F
.71523 .32321 m .71508 .32373 L .71518 .32357 L .861 .929 .87 r
F
.7156 .32339 m .71513 .32366 L .71974 .33657 L .738 .669 .783 r
F
.71513 .32366 m .70172 .34429 L .71974 .33657 L F
.71523 .32321 m .71518 .32357 L .71855 .32211 L .861 .929 .87 r
F
.25 g
.7313 .34631 m
.75191 .31106 L
s
.70515 .39107 m
.71594 .3726 L
s
1 0 0 r
.003 w
.70515 .39107 m
.71837 .38428 L
s
.25 g
.5 Mabswid
.77978 .31161 m
.78576 .30453 L
s
.74666 .35081 m
.77978 .31161 L
s
.71837 .38428 m
.74666 .35081 L
s
.80612 .31186 m
.80656 .31146 L
s
.73091 .38054 m
.80612 .31186 L
s
.74215 .37987 m
.82397 .31905 L
s
.69955 .42477 m .61839 .43749 L .61829 .45745 L .871 .742 .717 r
F
.25 g
.66734 .45631 m
.68055 .45601 L
s
.6509 .45669 m
.66193 .45644 L
s
.66193 .45644 m
.66734 .45631 L
s
.61829 .45745 m
.6509 .45669 L
s
.71299 .39398 m .61839 .43749 L .69955 .42477 L .827 .708 .733 r
F
0 g
.006 w
.68055 .45601 m
.69955 .42477 L
s
.25 g
.5 Mabswid
.61839 .43749 m
.67082 .42927 L
s
.67082 .42927 m
.69955 .42477 L
s
1 0 0 r
.003 w
.69484 .39861 m
.70515 .39107 L
s
.25 g
.5 Mabswid
.69236 .39924 m
.69575 .38798 L
s
.71508 .32373 m
.71523 .32321 L
s
.51666 .6241 m .52312 .62231 L .50443 .64084 L .337 .142 .462 r
F
.52312 .62231 m .588 .60439 L .52433 .63216 L F
.52312 .62231 m .52433 .63216 L .50443 .64084 L F
.51666 .6241 m .50443 .64084 L .50153 .63809 L F
.50555 .64272 m .52667 .63761 L .51104 .64581 L .444 .227 .489 r
F
.50857 .64602 m .51104 .64581 L .50925 .64675 L F
.50555 .64272 m .51104 .64581 L .50857 .64602 L F
.51182 .65668 m .50857 .64602 L .4921 .64738 L 0 0 .481 r
F
.49332 .64569 m .50555 .64272 L .47468 .66491 L .444 .227 .489 r
F
.4921 .64738 m .49277 .5941 L .47681 .64017 L 0 0 .481 r
F
.51182 .65668 m .50972 .64727 L .50857 .64602 L F
.50555 .64272 m .50925 .64675 L .47468 .66491 L .444 .227 .489 r
F
.50153 .63809 m .50443 .64084 L .49332 .64569 L .337 .142 .462 r
F
.5438 .63346 m .588 .60439 L .58388 .62375 L .444 .227 .489 r
F
.49332 .64569 m .54089 .62494 L .5438 .63346 L F
.54089 .62494 m .588 .60439 L .5438 .63346 L F
.52667 .63761 m .58388 .62375 L .52793 .64484 L F
.52667 .63761 m .52793 .64484 L .52122 .64737 L F
.52612 .6487 m .50972 .64727 L .51182 .65668 L .804 .381 0 r
F
.53012 .64979 m .58388 .62375 L .5368 .6516 L .516 .28 .496 r
F
.52122 .64737 m .52793 .64484 L .53012 .64979 L F
.52793 .64484 m .58388 .62375 L .53012 .64979 L F
.54569 .67097 m .53111 .65114 L .51182 .65668 L .804 .381 0 r
F
.53111 .65114 m .52839 .64743 L .52295 .65047 L F
.53111 .65114 m .52295 .65047 L .51182 .65668 L F
.54398 .6688 m .53248 .65513 L .53143 .65275 L F
.53111 .65114 m .53143 .65275 L .53012 .64979 L F
.54569 .67097 m .53143 .65275 L .53111 .65114 L F
.47468 .66491 m .52125 .65493 L .46198 .6817 L .516 .28 .496 r
F
.57698 .68328 m .55033 .66125 L .54569 .67097 L .892 .471 .169 r
F
.55033 .66125 m .54487 .66007 L .54569 .67097 L F
.54569 .67097 m .5435 .66836 L .54398 .6688 L .804 .381 0 r
F
.5435 .66836 m .53248 .65513 L .54398 .6688 L F
.52785 .65352 m .53143 .65275 L .52906 .65374 L .516 .28 .496 r
F
.53143 .65275 m .53161 .65369 L .52546 .65617 L F
.52415 .65579 m .52546 .65617 L .46198 .6817 L F
.53143 .65275 m .52546 .65617 L .52415 .65579 L F
.53248 .65513 m .53172 .65421 L .53193 .6539 L .804 .381 0 r
F
.55945 .66323 m .5811 .64211 L .58014 .65932 L .569 .313 .488 r
F
.54468 .65749 m .53172 .65421 L .54569 .67097 L .892 .471 .169 r
F
.54014 .65572 m .53172 .65421 L .54468 .65749 L F
.54675 .65829 m .5811 .64211 L .55945 .66323 L .569 .313 .488 r
F
.54014 .65572 m .54516 .65406 L .54675 .65829 L F
.54516 .65406 m .5811 .64211 L .54675 .65829 L F
.54675 .65829 m .54461 .65652 L .54487 .66007 L .892 .471 .169 r
F
.55033 .66125 m .54675 .65829 L .54487 .66007 L F
.54461 .65652 m .54014 .65572 L .54468 .65749 L F
.5368 .6516 m .54943 .65264 L .54014 .65572 L .516 .28 .496 r
F
.5368 .6516 m .54014 .65572 L .53477 .65476 L F
.53172 .65421 m .53161 .65369 L .53193 .6539 L .804 .381 0 r
F
.52122 .64737 m .50972 .64727 L .52612 .6487 L F
.47468 .66491 m .52122 .64737 L .53012 .64979 L .516 .28 .496 r
F
.53143 .65275 m .53012 .64979 L .5368 .6516 L F
.47468 .66491 m .53012 .64979 L .53143 .65275 L F
.53088 .65321 m .529 .65096 L .53193 .6539 L .804 .381 0 r
F
.53193 .6539 m .529 .65096 L .53012 .64979 L F
.5368 .6516 m .53251 .65826 L .53161 .65369 L .516 .28 .496 r
F
.53161 .65369 m .53251 .65826 L .46198 .6817 L F
.53172 .65421 m .53088 .65321 L .53161 .65369 L .804 .381 0 r
F
.53143 .65275 m .5368 .6516 L .53161 .65369 L .516 .28 .496 r
F
.54554 .65232 m .5811 .64211 L .54943 .65264 L F
.5368 .6516 m .54615 .6496 L .54554 .65232 L F
.54615 .6496 m .5811 .64211 L .54554 .65232 L F
.53012 .64979 m .529 .65096 L .52839 .64743 L .804 .381 0 r
F
.52839 .64743 m .52122 .64737 L .52612 .6487 L F
.529 .65096 m .52621 .64761 L .52839 .64743 L F
.54461 .65652 m .52687 .6484 L .53172 .65421 L .892 .471 .169 r
F
.5368 .6516 m .58388 .62375 L .5811 .64211 L .516 .28 .496 r
F
.52667 .63761 m .52122 .64737 L .5083 .64725 L .444 .227 .489 r
F
.52839 .64743 m .50163 .61102 L .50972 .64727 L .804 .381 0 r
F
.52839 .64743 m .52621 .64761 L .52575 .64384 L F
.52575 .64384 m .50936 .6274 L .50163 .61102 L F
.52621 .64761 m .50936 .6274 L .52575 .64384 L F
.54461 .65652 m .51559 .64324 L .50936 .6274 L .892 .471 .169 r
F
.54675 .65829 m .54446 .65719 L .54461 .65652 L F
.54446 .65719 m .51559 .64324 L .54461 .65652 L F
.57698 .68328 m .55621 .66973 L .55448 .66469 L F
.54932 .66515 m .5493 .66523 L .5492 .66519 L .569 .313 .488 r
F
.54916 .66518 m .54932 .66515 L .5492 .66519 L F
.54916 .66518 m .54014 .65572 L .54675 .65829 L F
.54937 .66527 m .54775 .66098 L .55448 .66469 L .892 .471 .169 r
F
.55033 .66125 m .54775 .66098 L .54675 .65829 L F
.55448 .66469 m .55007 .66225 L .55033 .66125 L F
.55007 .66225 m .54775 .66098 L .55033 .66125 L F
.54932 .66515 m .54675 .65829 L .55945 .66323 L .569 .313 .488 r
F
.54916 .66518 m .54675 .65829 L .54932 .66515 L F
.55621 .66973 m .54937 .66527 L .55448 .66469 L .892 .471 .169 r
F
.53256 .65824 m .54014 .65572 L .54916 .66518 L .569 .313 .488 r
F
.53477 .65476 m .54014 .65572 L .53251 .65826 L .516 .28 .496 r
F
.54937 .66527 m .51559 .64324 L .54775 .66098 L .892 .471 .169 r
F
.54964 .66538 m .54937 .66527 L .57698 .68328 L .857 .466 .303 r
F
.60427 .69386 m .56962 .67408 L .57698 .68328 L F
.56962 .67408 m .56436 .67237 L .57698 .68328 L F
.56467 .67126 m .58014 .65932 L .57591 .67613 L .611 .332 .469 r
F
.5546 .66689 m .56245 .66456 L .56467 .67126 L F
.56245 .66456 m .58014 .65932 L .56467 .67126 L F
.55997 .66858 m .55636 .66744 L .557 .66793 L .857 .466 .303 r
F
.56147 .66987 m .557 .66793 L .57698 .68328 L F
.55997 .66858 m .557 .66793 L .56147 .66987 L F
.54932 .66515 m .55945 .66323 L .55126 .66584 L .569 .313 .488 r
F
.54932 .66515 m .55126 .66584 L .5493 .66523 L F
.55166 .66383 m .54372 .66151 L .54949 .66529 L .857 .466 .303 r
F
.55636 .66744 m .54949 .66529 L .57698 .68328 L F
.55945 .66323 m .56376 .66417 L .5546 .66689 L .569 .313 .488 r
F
.55945 .66323 m .5546 .66689 L .55126 .66584 L F
.55166 .66383 m .54949 .66529 L .55636 .66744 L .857 .466 .303 r
F
.55126 .66584 m .5546 .66689 L .4563 .69604 L .569 .313 .488 r
F
.60427 .69386 m .56697 .67823 L .56678 .67765 L .857 .466 .303 r
F
.56962 .67408 m .55997 .66858 L .56436 .67237 L F
.56962 .67408 m .56678 .67765 L .56467 .67126 L F
.60427 .69386 m .56678 .67765 L .56962 .67408 L F
.64147 .71119 m .63862 .71029 L .62619 .70306 L .749 .395 .382 r
F
.4585 .70798 m .55896 .6812 L .58308 .69001 L .645 .337 .435 r
F
.4563 .69604 m .55564 .6795 L .4585 .70798 L .611 .332 .469 r
F
.55564 .6795 m .56592 .67779 L .55713 .68026 L F
.55564 .6795 m .55713 .68026 L .4585 .70798 L F
.46914 .71765 m .58523 .6897 L .59185 .70266 L .672 .327 .381 r
F
.64901 .71864 m .59654 .70574 L .64147 .71119 L .696 .347 .381 r
F
.4585 .70798 m .57235 .69155 L .46914 .71765 L .645 .337 .435 r
F
.57235 .69155 m .57362 .6923 L .46914 .71765 L F
.58308 .69001 m .58335 .69015 L .46914 .71765 L F
.56592 .67779 m .56606 .67785 L .4585 .70798 L .611 .332 .469 r
F
.56606 .67785 m .56581 .67887 L .4585 .70798 L F
.56678 .67765 m .56648 .67803 L .56606 .67785 L F
.56648 .67803 m .56581 .67887 L .56606 .67785 L F
.56592 .67779 m .5546 .66689 L .57591 .67613 L F
.4563 .69604 m .546 .66944 L .56592 .67779 L F
.546 .66944 m .5546 .66689 L .56592 .67779 L F
.56424 .67709 m .55668 .67392 L .56648 .67803 L .803 .436 .361 r
F
.5727 .68064 m .56648 .67803 L .60427 .69386 L F
.56592 .67779 m .56678 .67765 L .56606 .67785 L .611 .332 .469 r
F
.5492 .66519 m .54896 .66657 L .54338 .66834 L .569 .313 .488 r
F
.54176 .66766 m .54338 .66834 L .4563 .69604 L F
.5492 .66519 m .54338 .66834 L .54176 .66766 L F
.46198 .6817 m .54916 .66518 L .4563 .69604 L F
.54916 .66518 m .5492 .66519 L .4563 .69604 L F
.46198 .6817 m .53256 .65824 L .54916 .66518 L F
.56697 .67823 m .51996 .65853 L .56467 .67126 L .857 .466 .303 r
F
.56678 .67765 m .57591 .67613 L .56581 .67887 L .611 .332 .469 r
F
.57591 .67613 m .57684 .67643 L .4585 .70798 L F
.56424 .67709 m .56648 .67803 L .5727 .68064 L .803 .436 .361 r
F
.48839 .72523 m .59185 .70266 L .60133 .71407 L .687 .294 .296 r
F
.46914 .71765 m .59185 .70266 L .48839 .72523 L .672 .327 .381 r
F
.59654 .70574 m .52197 .68742 L .58754 .70046 L .696 .347 .381 r
F
.59654 .70574 m .58754 .70046 L .64147 .71119 L F
.57235 .69155 m .58308 .69001 L .57362 .6923 L .645 .337 .435 r
F
.58308 .69001 m .58523 .6897 L .58335 .69015 L F
.63862 .71029 m .5964 .69686 L .592 .69326 L .749 .395 .382 r
F
.5964 .69686 m .57858 .6912 L .5883 .69269 L F
.5964 .69686 m .5883 .69269 L .592 .69326 L F
.57858 .6912 m .52218 .67327 L .57061 .68714 L F
.57858 .6912 m .57061 .68714 L .592 .69326 L F
.63862 .71029 m .592 .69326 L .62619 .70306 L F
.58308 .69001 m .56818 .67874 L .58523 .6897 L .645 .337 .435 r
F
.55896 .6812 m .56818 .67874 L .58308 .69001 L F
.59067 .68817 m .58166 .68439 L .60427 .69386 L .803 .436 .361 r
F
.57656 .68226 m .5727 .68064 L .60427 .69386 L F
.56818 .67874 m .5814 .67522 L .58409 .68541 L .645 .337 .435 r
F
.56818 .67874 m .58409 .68541 L .58523 .6897 L F
.62619 .70306 m .59067 .68817 L .60427 .69386 L .803 .436 .361 r
F
.59067 .68817 m .57656 .68226 L .58166 .68439 L F
.57656 .68226 m .56424 .67709 L .5727 .68064 L F
.55997 .66858 m .55166 .66383 L .55636 .66744 L .857 .466 .303 r
F
.54949 .66529 m .54937 .66527 L .54964 .66538 L F
.54931 .66523 m .54937 .66527 L .54949 .66529 L F
.54931 .66523 m .5493 .66523 L .54937 .66527 L F
.5493 .66523 m .55126 .66584 L .54896 .66657 L .569 .313 .488 r
F
.5493 .66523 m .54896 .66657 L .5492 .66519 L F
.54372 .66151 m .54931 .66523 L .54949 .66529 L .857 .466 .303 r
F
.54372 .66151 m .5435 .66144 L .5493 .66523 L F
.54372 .66151 m .5493 .66523 L .54931 .66523 L F
.51728 .64421 m .5178 .64468 L .5435 .66144 L F
.51728 .64421 m .5435 .66144 L .54372 .66151 L F
.52125 .65493 m .52785 .65352 L .52415 .65579 L .516 .28 .496 r
F
.52785 .65352 m .52906 .65374 L .52415 .65579 L F
.52125 .65493 m .52415 .65579 L .46198 .6817 L F
.55166 .66383 m .51728 .64421 L .54372 .66151 L .857 .466 .303 r
F
.51728 .64421 m .51559 .64324 L .5178 .64468 L F
.5083 .64725 m .52122 .64737 L .47468 .66491 L .444 .227 .489 r
F
.56467 .67126 m .51996 .65853 L .51559 .64324 L .857 .466 .303 r
F
.57591 .67613 m .58014 .65932 L .5814 .67522 L .611 .332 .469 r
F
.57591 .67613 m .5814 .67522 L .57684 .67643 L F
.56424 .67709 m .51996 .65853 L .55668 .67392 L .803 .436 .361 r
F
.54775 .66098 m .51559 .64324 L .54675 .65829 L .892 .471 .169 r
F
.55945 .66323 m .58014 .65932 L .56376 .66417 L .569 .313 .488 r
F
.50857 .64602 m .49277 .5941 L .4921 .64738 L 0 0 .481 r
F
.50857 .64602 m .50931 .64545 L .50803 .64424 L F
.50972 .64727 m .50931 .64545 L .50857 .64602 L F
.50803 .64424 m .50163 .61102 L .49277 .5941 L F
.50931 .64545 m .50163 .61102 L .50803 .64424 L F
0 g
.006 w
.52256 .61883 m
.54339 .60026 L
s
.51666 .6241 m .59301 .58422 L .588 .60439 L .337 .142 .462 r
F
.25 g
.5 Mabswid
.58168 .63829 m
.66722 .60235 L
s
.58813 .60388 m
.6569 .58337 L
s
0 g
.006 w
.51666 .6241 m
.52256 .61883 L
s
.25 g
.5 Mabswid
.51666 .6241 m
.52138 .62163 L
s
.52138 .62163 m
.52259 .621 L
s
.52259 .621 m
.58909 .58627 L
s
.58909 .58627 m
.59301 .58422 L
s
0 g
.006 w
.52967 .55313 m
.53582 .57971 L
s
.53582 .57971 m
.53704 .58497 L
s
.25 g
.5 Mabswid
.59585 .56517 m
.59846 .56342 L
s
.54958 .59613 m
.59585 .56517 L
s
0 g
.006 w
.51343 .62708 m
.51666 .6241 L
s
.77344 .74267 m .73917 .69237 L .72872 .67974 L 0 0 .521 r
F
.25 g
.5 Mabswid
.72872 .67974 m
.73772 .73328 L
s
.80687 .7495 m .73917 .69237 L .77344 .74267 L .705 .186 0 r
F
0 g
.006 w
.73772 .73328 m
.77344 .74267 L
s
.25 g
.5 Mabswid
.59315 .54741 m
.59933 .54685 L
s
.6028 .54654 m
.64937 .54233 L
s
.52967 .55313 m
.58861 .54782 L
s
.58861 .54782 m
.59315 .54741 L
s
0 g
.006 w
.52967 .55313 m
.53008 .51987 L
s
.25 g
.5 Mabswid
.63093 .49977 m
.6451 .50189 L
s
.53845 .48597 m
.6136 .49719 L
s
1 0 0 r
.003 w
.6451 .50189 m
.64667 .48482 L
s
.64667 .48482 m
.64693 .48194 L
s
.6451 .50189 m
.64596 .52213 L
s
.25 g
.5 Mabswid
.64293 .48066 m
.64693 .48194 L
s
.55456 .45234 m
.61699 .47235 L
s
1 0 0 r
.003 w
.64693 .48194 m
.64829 .4762 L
s
.25 g
.5 Mabswid
.60701 .38997 m
.60888 .39195 L
s
.57776 .41999 m
.583 .42303 L
s
.583 .42303 m
.61836 .4435 L
s
.62001 .52162 m
.64596 .52213 L
s
.61788 .52158 m
.62001 .52162 L
s
.53008 .51987 m
.60819 .52139 L
s
.60819 .52139 m
.60879 .5214 L
s
1 0 0 r
.003 w
.64596 .52213 m
.64937 .54233 L
s
.64937 .54233 m
.65509 .56224 L
s
.65509 .56224 m
.66278 .58161 L
s
0 g
.006 w
.81517 .3036 m
.83888 .30797 L
s
1 0 0 r
.003 w
.66278 .58161 m
.67209 .6003 L
s
.397 .634 m .36822 .62555 L .36741 .6643 L .994 .871 .549 r
F
.397 .634 m .37265 .60327 L .36822 .62555 L F
.40908 .59989 m .41807 .59007 L .37912 .57603 L .42 .385 .714 r
F
.41974 .60679 m .41988 .60625 L .40908 .59989 L .276 .299 .705 r
F
.42589 .57924 m .42351 .58851 L .42397 .6019 L .914 .745 .658 r
F
.4265 .572 m .4245 .58303 L .42589 .57924 L F
.4245 .58303 m .42351 .58851 L .42589 .57924 L F
.44703 .56847 m .4265 .572 L .42397 .6019 L F
.41807 .59007 m .41552 .58165 L .37912 .57603 L .42 .385 .714 r
F
.42868 .57163 m .42597 .57094 L .4265 .572 L .914 .745 .658 r
F
.44703 .56847 m .42804 .56574 L .42868 .57163 L F
.42804 .56574 m .42306 .56503 L .42868 .57163 L F
.42271 .57232 m .41995 .55873 L .37912 .57603 L .42 .385 .714 r
F
.4265 .572 m .42306 .56503 L .42271 .57232 L F
.42306 .56503 m .41995 .55873 L .42271 .57232 L F
.46497 .53427 m .42879 .54413 L .44703 .56847 L .862 .694 .673 r
F
.41906 .54712 m .42879 .54413 L .42833 .5404 L .511 .443 .716 r
F
.37912 .57603 m .41929 .55022 L .41906 .54712 L F
.41929 .55022 m .42879 .54413 L .41906 .54712 L F
.42306 .56503 m .4204 .56464 L .42597 .57094 L .914 .745 .658 r
F
.41929 .55022 m .42342 .55725 L .42879 .54413 L .511 .443 .716 r
F
.37912 .57603 m .41995 .55873 L .41929 .55022 L F
.41995 .55873 m .42342 .55725 L .41929 .55022 L F
.4245 .58303 m .4265 .572 L .37912 .57603 L .42 .385 .714 r
F
.37912 .57603 m .42833 .5404 L .3535 .54979 L .511 .443 .716 r
F
.46497 .53427 m .42769 .53511 L .42833 .5404 L .862 .694 .673 r
F
.42478 .54085 m .42172 .53057 L .3535 .54979 L .511 .443 .716 r
F
.42833 .5404 m .42482 .53518 L .42478 .54085 L F
.42482 .53518 m .42172 .53057 L .42478 .54085 L F
.47674 .49993 m .43113 .51634 L .46497 .53427 L .817 .657 .684 r
F
.42769 .53511 m .42224 .53523 L .42879 .54413 L .862 .694 .673 r
F
.3535 .54979 m .42062 .52086 L .42004 .5158 L .576 .488 .719 r
F
.42062 .52086 m .42485 .52969 L .43113 .51634 L F
.3535 .54979 m .42172 .53057 L .42062 .52086 L F
.42172 .53057 m .42485 .52969 L .42062 .52086 L F
.3535 .54979 m .43029 .51056 L .3334 .52138 L F
.47674 .49993 m .42973 .50668 L .43029 .51056 L .817 .657 .684 r
F
.42713 .51092 m .42562 .50564 L .3334 .52138 L .576 .488 .719 r
F
.43029 .51056 m .42698 .50707 L .42713 .51092 L F
.42698 .50707 m .42562 .50564 L .42713 .51092 L F
.48148 .4662 m .43819 .48554 L .47674 .49993 L .778 .629 .695 r
F
.43819 .48554 m .43437 .49228 L .47674 .49993 L F
.3334 .52138 m .42692 .50542 L .43819 .48554 L .625 .528 .723 r
F
.48148 .4662 m .43662 .47728 L .43783 .48368 L .778 .629 .695 r
F
.43964 .48489 m .43783 .48368 L .43819 .48554 L F
.48148 .4662 m .43783 .48368 L .43964 .48489 L F
.31375 .45966 m .4376 .46292 L .43661 .44362 L .7 .6 .741 r
F
.47855 .43387 m .42874 .46095 L .48148 .4662 L .744 .608 .707 r
F
.3334 .52138 m .43125 .48606 L .31987 .49117 L .625 .528 .723 r
F
.43125 .48606 m .43106 .48411 L .31987 .49117 L F
.43783 .48368 m .43651 .48279 L .31987 .49117 L F
.31987 .49117 m .4376 .46292 L .31375 .45966 L .666 .564 .731 r
F
.43125 .48606 m .43783 .48368 L .43106 .48411 L .625 .528 .723 r
F
.3334 .52138 m .43819 .48554 L .43783 .48368 L F
.43662 .47728 m .43503 .47768 L .43819 .48554 L .778 .629 .695 r
F
.31987 .49117 m .43097 .48319 L .43397 .47402 L .666 .564 .731 r
F
.43503 .47768 m .43733 .48565 L .43819 .48554 L .778 .629 .695 r
F
.44607 .46268 m .43503 .47768 L .48148 .4662 L .744 .608 .707 r
F
.43097 .48319 m .44124 .48245 L .43928 .4719 L .666 .564 .731 r
F
.43097 .48319 m .43928 .4719 L .4376 .46292 L F
.43503 .47768 m .36717 .49444 L .43733 .48565 L .778 .629 .695 r
F
.43121 .46445 m .43397 .47402 L .4376 .46292 L .666 .564 .731 r
F
.31987 .49117 m .43397 .47402 L .43121 .46445 L F
.42874 .46095 m .43053 .47879 L .43503 .47768 L .744 .608 .707 r
F
.42874 .46095 m .43503 .47768 L .44607 .46268 L F
.42874 .46095 m .36717 .49444 L .43053 .47879 L F
.43783 .48368 m .44124 .48245 L .43651 .48279 L .625 .528 .723 r
F
.43783 .48368 m .43819 .48554 L .43961 .48304 L F
.43819 .48554 m .36717 .49444 L .37252 .51489 L .778 .629 .695 r
F
.42635 .49083 m .42698 .50707 L .47674 .49993 L F
.43961 .48304 m .44712 .50197 L .44124 .48245 L .625 .528 .723 r
F
.42692 .50542 m .44712 .50197 L .43961 .48304 L F
.43819 .48554 m .42635 .49083 L .43437 .49228 L .778 .629 .695 r
F
.42004 .5158 m .43113 .51634 L .43029 .51056 L .576 .488 .719 r
F
.42062 .52086 m .43113 .51634 L .42004 .5158 L F
.43029 .51056 m .37252 .51489 L .43113 .51634 L .817 .657 .684 r
F
.42973 .50668 m .42698 .50707 L .43029 .51056 L F
.42698 .50707 m .37252 .51489 L .43029 .51056 L F
.43029 .51056 m .44712 .50197 L .42562 .50564 L .576 .488 .719 r
F
.42635 .49083 m .37252 .51489 L .42698 .50707 L .778 .629 .695 r
F
.43459 .51509 m .43029 .51056 L .43113 .51634 L .817 .657 .684 r
F
.47674 .49993 m .43029 .51056 L .43459 .51509 L F
.42342 .54559 m .37563 .53629 L .37659 .55835 L .862 .694 .673 r
F
.42879 .54413 m .42316 .5433 L .42342 .54559 L F
.42316 .5433 m .37563 .53629 L .42342 .54559 L F
.42224 .53523 m .37563 .53629 L .42316 .5433 L F
.42224 .53523 m .42316 .5433 L .42879 .54413 L F
.43113 .51634 m .37252 .51489 L .37563 .53629 L .817 .657 .684 r
F
.43029 .51056 m .43113 .51634 L .43497 .50818 L .576 .488 .719 r
F
.43497 .50818 m .45478 .52126 L .44712 .50197 L F
.43113 .51634 m .42928 .52027 L .46497 .53427 L .817 .657 .684 r
F
.42492 .51857 m .42482 .53518 L .46497 .53427 L F
.42485 .52969 m .45478 .52126 L .43497 .50818 L .576 .488 .719 r
F
.43113 .51634 m .42492 .51857 L .42928 .52027 L .817 .657 .684 r
F
.42833 .5404 m .45478 .52126 L .42172 .53057 L .511 .443 .716 r
F
.42492 .51857 m .37563 .53629 L .42482 .53518 L .817 .657 .684 r
F
.43052 .54365 m .42833 .5404 L .42879 .54413 L .862 .694 .673 r
F
.46497 .53427 m .42833 .5404 L .43052 .54365 L F
.42104 .57294 m .37659 .55835 L .37553 .58078 L .914 .745 .658 r
F
.4265 .572 m .42085 .57046 L .42104 .57294 L F
.42085 .57046 m .37659 .55835 L .42104 .57294 L F
.4204 .56464 m .37659 .55835 L .42078 .56962 L F
.4204 .56464 m .42078 .56962 L .42597 .57094 L F
.42833 .5404 m .42879 .54413 L .43114 .53837 L .511 .443 .716 r
F
.43114 .53837 m .46368 .54019 L .45478 .52126 L F
.42879 .54413 m .42701 .54847 L .44703 .56847 L .862 .694 .673 r
F
.42398 .54544 m .42306 .56503 L .44703 .56847 L F
.42342 .55725 m .46368 .54019 L .43114 .53837 L .511 .443 .716 r
F
.42879 .54413 m .42398 .54544 L .42701 .54847 L .862 .694 .673 r
F
.42306 .56503 m .42597 .57094 L .42868 .57163 L .914 .745 .658 r
F
.4265 .572 m .42965 .55461 L .41995 .55873 L .42 .385 .714 r
F
.42398 .54544 m .37659 .55835 L .42306 .56503 L .862 .694 .673 r
F
.4265 .572 m .46368 .54019 L .42965 .55461 L .42 .385 .714 r
F
.4245 .58303 m .42933 .57775 L .4265 .572 L F
.42933 .57775 m .46368 .54019 L .4265 .572 L F
.42597 .57094 m .37659 .55835 L .4265 .572 L .914 .745 .658 r
F
.42933 .57775 m .47333 .55867 L .46368 .54019 L .42 .385 .714 r
F
.4245 .58303 m .42963 .58048 L .42933 .57775 L F
.42963 .58048 m .47333 .55867 L .42933 .57775 L F
.40908 .59989 m .41824 .59402 L .41807 .59007 L F
.41988 .60625 m .42042 .60035 L .40908 .59989 L .276 .299 .705 r
F
.42042 .60035 m .42117 .59214 L .41824 .59402 L F
.42042 .60035 m .41824 .59402 L .40908 .59989 L F
.42129 .60073 m .42042 .60035 L .42167 .60196 L .97 .809 .628 r
F
.41988 .60625 m .42098 .60198 L .42042 .60035 L .276 .299 .705 r
F
.42042 .60035 m .37553 .58078 L .42084 .60158 L .97 .809 .628 r
F
.42042 .60035 m .42084 .60158 L .42167 .60196 L F
.41858 .60204 m .37553 .58078 L .37265 .60327 L F
.42098 .60198 m .41853 .60084 L .41858 .60204 L F
.41853 .60084 m .37553 .58078 L .41858 .60204 L F
.41807 .59007 m .42117 .59214 L .4245 .58303 L .42 .385 .714 r
F
.41824 .59402 m .42117 .59214 L .41807 .59007 L F
.41807 .59007 m .4245 .58303 L .41552 .58165 L F
.4265 .572 m .42296 .57261 L .42351 .58851 L .914 .745 .658 r
F
.42296 .57261 m .42042 .60035 L .42397 .6019 L F
.42117 .59214 m .47333 .55867 L .4245 .58303 L .42 .385 .714 r
F
.42042 .60035 m .42399 .59033 L .42117 .59214 L .276 .299 .705 r
F
.42167 .60196 m .42084 .60158 L .42098 .60198 L .97 .809 .628 r
F
.42397 .6019 m .42129 .60073 L .42167 .60196 L F
.42098 .60198 m .42399 .59033 L .42042 .60035 L .276 .299 .705 r
F
.42084 .60158 m .37553 .58078 L .42098 .60198 L .97 .809 .628 r
F
.42296 .57261 m .37553 .58078 L .42042 .60035 L .914 .745 .658 r
F
.4421 .62127 m .47333 .55867 L .42399 .59033 L .276 .299 .705 r
F
.42397 .6019 m .42098 .60198 L .41968 .60701 L .97 .809 .628 r
F
.4421 .62127 m .42399 .59033 L .41974 .60679 L .276 .299 .705 r
F
.41968 .60701 m .37265 .60327 L .397 .634 L .97 .809 .628 r
F
.42098 .60198 m .37265 .60327 L .41968 .60701 L F
.25 g
.5 Mabswid
.37265 .60327 m
.397 .634 L
s
0 g
.006 w
.397 .634 m
.41968 .60701 L
s
.41968 .60701 m
.41982 .60684 L
s
.25 g
.5 Mabswid
.42117 .59214 m
.43026 .5863 L
s
0 g
.006 w
.41974 .60679 m
.41982 .60684 L
s
.25 g
.5 Mabswid
.37553 .58078 m
.41847 .5995 L
s
.41847 .5995 m
.42042 .60035 L
s
.4421 .62127 m .48318 .57665 L .47333 .55867 L .276 .299 .705 r
F
.47681 .64017 m .48318 .57665 L .4421 .62127 L .021 .15 .66 r
F
.25 g
.43026 .5863 m
.47333 .55867 L
s
0 g
.006 w
.41982 .60684 m
.4421 .62127 L
s
.25 g
.5 Mabswid
.4421 .62127 m
.44464 .61852 L
s
.71996 .36432 m .61654 .41859 L .71299 .39398 L .791 .686 .748 r
F
.25 g
.70288 .39656 m
.71299 .39398 L
s
.61654 .41859 m
.63575 .41369 L
s
.63575 .41369 m
.63593 .41364 L
s
0 g
.006 w
.69955 .42477 m
.71299 .39398 L
s
.25 g
.5 Mabswid
.71942 .36665 m
.7313 .34631 L
s
.36741 .6643 m .36272 .64788 L .33655 .69239 L .844 .817 .335 r
F
.36272 .64788 m .36099 .65003 L .33655 .69239 L F
.36272 .64788 m .36255 .64732 L .36099 .65003 L F
.33655 .69239 m .36255 .64732 L .35608 .6683 L 0 0 0 r
F
.33655 .69239 m .35608 .6683 L .30584 .71796 L F
.3073 .71696 m .35608 .6683 L .34927 .68821 L 0 0 .216 r
F
.30584 .71796 m .30902 .71481 L .3073 .71696 L F
.30902 .71481 m .35608 .6683 L .3073 .71696 L F
.36741 .6643 m .36822 .62555 L .36255 .64732 L .844 .817 .335 r
F
0 g
.006 w
.36741 .6643 m
.397 .634 L
s
.25 g
.5 Mabswid
.36741 .6643 m
.36822 .62555 L
s
0 g
.006 w
.35295 .67746 m
.36741 .6643 L
s
1 0 0 r
.003 w
.67209 .6003 m
.68261 .61817 L
s
.25 g
.5 Mabswid
.43005 .55444 m
.46368 .54019 L
s
.42965 .55461 m
.43005 .55444 L
s
.42342 .55725 m
.42965 .55461 L
s
0 g
.006 w
.3535 .54979 m
.37591 .57274 L
s
.25 g
.5 Mabswid
.37659 .55835 m
.4204 .56464 L
s
.4204 .56464 m
.42306 .56503 L
s
0 g
.006 w
.46282 .53836 m
.46497 .53427 L
s
.47681 .64017 m .49277 .5941 L .48318 .57665 L .021 .15 .66 r
F
.25 g
.5 Mabswid
.47681 .64017 m
.49198 .59637 L
s
.49198 .59637 m
.49277 .5941 L
s
0 g
.006 w
.4421 .62127 m
.47681 .64017 L
s
.25 g
.5 Mabswid
.44464 .61852 m
.48098 .57904 L
s
.48098 .57904 m
.48318 .57665 L
s
0 g
.006 w
.47681 .64017 m
.4921 .64738 L
s
.53008 .51987 m
.53845 .48597 L
s
1 0 0 r
.003 w
.68261 .61817 m
.69395 .63511 L
s
.25 g
.5 Mabswid
.58275 .60668 m
.588 .60439 L
s
.54089 .62494 m
.58275 .60668 L
s
.52433 .63216 m
.54089 .62494 L
s
.51891 .63453 m
.52433 .63216 L
s
0 g
.006 w
.47468 .66491 m
.49164 .64742 L
s
.49164 .64742 m
.49181 .64724 L
s
.25 g
.5 Mabswid
.36099 .65003 m
.36255 .64732 L
s
.34298 .68125 m
.36099 .65003 L
s
.44796 .52318 m
.45478 .52126 L
s
.43241 .52756 m
.44796 .52318 L
s
.42485 .52969 m
.43241 .52756 L
s
.3535 .54979 m
.37594 .54347 L
s
0 g
.006 w
.3334 .52138 m
.3535 .54979 L
s
.75655 .71439 m .75576 .714 L .74833 .7038 L .752 .238 0 r
F
.7563 .71422 m .75576 .714 L .75655 .71439 L .721 .228 .069 r
F
.7563 .71422 m .76104 .72297 L .75576 .714 L F
.80448 .74749 m .74897 .7043 L .74181 .69459 L .705 .186 0 r
F
.80492 .74786 m .80434 .74741 L .80448 .74749 L F
.80434 .74741 m .74897 .7043 L .80448 .74749 L F
.80354 .7469 m .74833 .7038 L .80492 .74786 L F
.74897 .7043 m .74833 .7038 L .74181 .69459 L F
.80687 .7495 m .80354 .7469 L .80492 .74786 L F
.8366 .75405 m .74833 .7038 L .80687 .7495 L .752 .238 0 r
F
.8366 .75405 m .75655 .71439 L .74833 .7038 L F
.8613 .75664 m .7563 .71422 L .8366 .75405 L .721 .228 .069 r
F
.7563 .71422 m .75655 .71439 L .8366 .75405 L F
.8613 .75664 m .76332 .72373 L .7563 .71422 L F
.76332 .72373 m .76104 .72297 L .7563 .71422 L F
.87969 .75758 m .76297 .72353 L .8613 .75664 L .667 .185 .097 r
F
.76297 .72353 m .76104 .72297 L .76332 .72373 L F
.76297 .72353 m .76332 .72373 L .8613 .75664 L F
.74181 .69459 m .74833 .7038 L .74003 .69309 L .705 .186 0 r
F
.74003 .69309 m .74833 .7038 L .73917 .69237 L F
.25 g
.5 Mabswid
.80374 .74706 m
.80687 .7495 L
s
.80354 .7469 m
.80374 .74706 L
s
.78182 .72994 m
.80354 .7469 L
s
0 g
.006 w
.77344 .74267 m
.80687 .7495 L
s
.25 g
.5 Mabswid
.73917 .69237 m
.73939 .69269 L
s
.77235 .74107 m
.77344 .74267 L
s
.77157 .73992 m
.77235 .74107 L
s
.73939 .69269 m
.74011 .69375 L
s
.77147 .73978 m
.77157 .73992 L
s
.74011 .69375 m
.77147 .73978 L
s
0 g
.006 w
.80687 .7495 m
.8366 .75405 L
s
1 0 0 r
.003 w
.69395 .63511 m
.70569 .65107 L
s
.25 g
.5 Mabswid
.37563 .53629 m
.42224 .53523 L
s
.42224 .53523 m
.42482 .53518 L
s
.46094 .53436 m
.46497 .53427 L
s
0 g
.006 w
.46497 .53427 m
.47674 .49993 L
s
.78576 .30453 m
.81517 .3036 L
s
.25 g
.5 Mabswid
.50163 .61102 m
.50931 .64545 L
s
.50931 .64545 m
.50972 .64727 L
s
0 g
.006 w
.53845 .48597 m
.55456 .45234 L
s
.71974 .33657 m .61252 .40104 L .71996 .36432 L .762 .673 .764 r
F
.25 g
.5 Mabswid
.71397 .36637 m
.71996 .36432 L
s
.71239 .36691 m
.71397 .36637 L
s
.61252 .40104 m
.63447 .39354 L
s
.63447 .39354 m
.67337 .38025 L
s
.67337 .38025 m
.71239 .36691 L
s
0 g
.006 w
.71299 .39398 m
.71996 .36432 L
s
.25 g
.5 Mabswid
.64295 .36824 m
.64343 .36939 L
s
.63593 .41364 m
.70288 .39656 L
s
0 g
.006 w
.71979 .34327 m
.71996 .36432 L
s
.71977 .34055 m
.71979 .34327 L
s
.71974 .33657 m
.71977 .34055 L
s
1 0 0 r
.003 w
.70569 .65107 m
.71742 .66596 L
s
.25 g
.5 Mabswid
.44148 .50293 m
.44712 .50197 L
s
.43519 .504 m
.44148 .50293 L
s
.42692 .50542 m
.43519 .504 L
s
.3334 .52138 m
.37247 .51471 L
s
0 g
.006 w
.31987 .49117 m
.3334 .52138 L
s
.30584 .71796 m .34927 .68821 L .27669 .74073 L 0 0 .216 r
F
.25 g
.5 Mabswid
.30584 .71796 m
.30902 .71481 L
s
.37252 .51489 m
.42589 .50723 L
s
.42589 .50723 m
.42698 .50707 L
s
.44796 .50406 m
.47674 .49993 L
s
0 g
.006 w
.47674 .49993 m
.48148 .4662 L
s
.25 g
.5 Mabswid
.47468 .66491 m
.48171 .66226 L
s
.48171 .66226 m
.51146 .65105 L
s
.51146 .65105 m
.5172 .64888 L
s
.57737 .62621 m
.58388 .62375 L
s
.54241 .63938 m
.57737 .62621 L
s
.52967 .64418 m
.54241 .63938 L
s
0 g
.006 w
.46198 .6817 m
.47468 .66491 L
s
1 0 0 r
.003 w
.71742 .66596 m
.72872 .67974 L
s
0 g
.006 w
.75191 .31106 m
.78576 .30453 L
s
.55456 .45234 m
.57776 .41999 L
s
.25 g
.5 Mabswid
.83206 .75181 m
.8366 .75405 L
s
.80082 .73632 m
.83206 .75181 L
s
0 g
.006 w
.8366 .75405 m
.8613 .75664 L
s
1 0 0 r
.003 w
.60897 .52077 m
.61328 .49934 L
s
.61328 .49934 m
.61649 .47815 L
s
.61649 .47815 m
.61829 .45745 L
s
.25 g
.5 Mabswid
.4396 .48257 m
.44124 .48245 L
s
.43651 .48279 m
.4396 .48257 L
s
.31987 .49117 m
.38128 .48676 L
s
1 0 0 r
.003 w
.60391 .5422 m
.60897 .52077 L
s
.61829 .45745 m
.61839 .43749 L
s
.59846 .56342 m
.60391 .5422 L
s
.25 g
.5 Mabswid
.70172 .34429 m
.71974 .33657 L
s
.67445 .35596 m
.70172 .34429 L
s
.64603 .36813 m
.67445 .35596 L
s
.64354 .3692 m
.64603 .36813 L
s
0 g
.006 w
.7156 .32339 m
.71974 .33657 L
s
.7155 .32309 m
.71551 .32312 L
s
.71509 .3218 m
.7155 .32309 L
s
1 0 0 r
.003 w
.61654 .41859 m
.61839 .43749 L
s
.72872 .67974 m
.73917 .69237 L
s
.27669 .74073 m .34268 .70679 L .25054 .76049 L .205 0 .316 r
F
.27669 .74073 m .34927 .68821 L .34268 .70679 L F
.25 g
.5 Mabswid
.35282 .67153 m
.35608 .6683 L
s
0 g
.006 w
.27669 .74073 m
.30584 .71796 L
s
.25 g
.5 Mabswid
.27669 .74073 m
.28143 .7373 L
s
.43053 .47879 m
.43503 .47768 L
s
.44012 .47642 m
.44946 .47411 L
s
.44946 .47411 m
.48148 .4662 L
s
0 g
.006 w
.57776 .41999 m
.60701 .38997 L
s
.71523 .32321 m
.71855 .32211 L
s
.71855 .32211 m
.75191 .31106 L
s
1 0 0 r
.003 w
.59301 .58422 m
.59846 .56342 L
s
.61252 .40104 m
.61654 .41859 L
s
.60696 .38714 m
.61252 .40104 L
s
.60673 .38657 m
.60696 .38714 L
s
.588 .60439 m
.59301 .58422 L
s
0 g
.006 w
.60701 .38997 m
.60783 .38932 L
s
.58428 .68611 m
.60416 .69382 L
s
1 0 0 r
.003 w
.73917 .69237 m
.74833 .7038 L
s
.14685 .34179 m .2142 .40917 L .22736 .40345 L .638 .73 .914 r
F
.71186 .31153 m .59747 .37137 L .60618 .38519 L .738 .669 .783 r
F
0 g
.006 w
.67757 .34077 m
.71523 .32321 L
s
.61644 .38252 m
.64085 .36326 L
s
1 0 0 r
.003 w
.60618 .38519 m
.60673 .38657 L
s
.25 g
.5 Mabswid
.60618 .38519 m
.62122 .37875 L
s
.67757 .34077 m
.67765 .34417 L
s
.64085 .36326 m
.64295 .36824 L
s
.31375 .45966 m .43661 .44362 L .31564 .4275 L .7 .6 .741 r
F
.25 g
.31375 .45966 m
.42571 .46261 L
s
0 g
.006 w
.31375 .45966 m
.31987 .49117 L
s
1 0 0 r
.003 w
.43928 .4719 m
.44124 .48245 L
s
.44124 .48245 m
.44712 .50197 L
s
0 g
.006 w
.64085 .36326 m
.67757 .34077 L
s
1 0 0 r
.003 w
.44712 .50197 m
.45478 .52126 L
s
.45478 .52126 m
.46368 .54019 L
s
.58388 .62375 m
.588 .60439 L
s
.25 g
.5 Mabswid
.51646 .66359 m
.52515 .66071 L
s
.46198 .6817 m
.51646 .66359 L
s
.5593 .64936 m
.56228 .64837 L
s
.54516 .65406 m
.5593 .64936 L
s
.54264 .6549 m
.54516 .65406 L
s
.56228 .64837 m
.5811 .64211 L
s
0 g
.006 w
.4563 .69604 m
.46198 .6817 L
s
.47855 .43387 m .35958 .47524 L .36717 .49444 L .744 .608 .707 r
F
.25 g
.5 Mabswid
.36717 .49444 m
.43053 .47879 L
s
.31564 .4275 m .43661 .44362 L .43853 .4249 L .729 .637 .756 r
F
.34404 .39728 m .43853 .4249 L .44352 .40712 L .753 .674 .774 r
F
.31564 .4275 m .43853 .4249 L .33278 .3973 L .729 .637 .756 r
F
.31564 .4275 m .33278 .3973 L .32064 .41173 L F
.33231 .39352 m .30899 .41712 L .3156 .41614 L .629 .585 .785 r
F
.33264 .39615 m .3156 .41614 L .33478 .41331 L F
.33231 .39352 m .3156 .41614 L .33264 .39615 L F
.35105 .37457 m .44352 .40712 L .35547 .36938 L .753 .674 .774 r
F
.33264 .39615 m .34107 .39699 L .35105 .37457 L F
.34107 .39699 m .44352 .40712 L .35105 .37457 L F
.33264 .39615 m .34361 .40013 L .34404 .39728 L F
.33278 .3973 m .34361 .40013 L .33264 .39615 L F
.34361 .40013 m .43853 .4249 L .34404 .39728 L F
.35394 .38615 m .33231 .39352 L .33478 .41331 L .629 .585 .785 r
F
.39688 .37737 m .44352 .40712 L .45155 .3907 L .771 .711 .796 r
F
.39385 .3818 m .44352 .40712 L .39688 .37737 L F
.37323 .37528 m .44352 .40712 L .37443 .3719 L F
.35558 .36821 m .44352 .40712 L .35566 .36732 L F
.3537 .36862 m .44352 .40712 L .35103 .36619 L F
.42481 .35958 m .45155 .3907 L .46242 .37608 L .78 .746 .821 r
F
.36687 .41174 m .36557 .39696 L .35654 .4225 L .655 .581 .76 r
F
.40128 .34927 m .41765 .36777 L .42481 .35958 L .78 .746 .821 r
F
.3983 .35469 m .41765 .36777 L .40128 .34927 L F
.37443 .3719 m .39385 .3818 L .39688 .37737 L .771 .711 .796 r
F
.35153 .32252 m .33744 .35385 L .35103 .36619 L .607 .596 .814 r
F
.35153 .32252 m .35103 .36619 L .35113 .36605 L F
.33744 .35385 m .30899 .41712 L .35112 .36628 L F
.35103 .36619 m .45155 .3907 L .37161 .33664 L .771 .711 .796 r
F
.37665 .33031 m .46242 .37608 L .40261 .30968 L .78 .746 .821 r
F
.37123 .32924 m .36982 .33241 L .37416 .33309 L .607 .596 .814 r
F
.37123 .32924 m .37416 .33309 L .37611 .33091 L F
.35566 .36732 m .37323 .37528 L .37443 .3719 L .771 .711 .796 r
F
.35103 .36619 m .35558 .36821 L .35566 .36732 L F
.3554 .37016 m .33231 .39352 L .35394 .38615 L .629 .585 .785 r
F
.35112 .36628 m .30899 .41712 L .35105 .37457 L .607 .596 .814 r
F
.35153 .32252 m .35105 .37457 L .37123 .32924 L F
.33264 .39615 m .35547 .36938 L .3441 .3645 L .753 .674 .774 r
F
.36982 .33241 m .35105 .37457 L .3767 .34861 L .607 .596 .814 r
F
.37142 .33617 m .46242 .37608 L .37665 .33031 L .78 .746 .821 r
F
.37933 .33964 m .3983 .35469 L .40128 .34927 L F
.37142 .33617 m .37884 .34129 L .37933 .33964 L F
.37884 .34129 m .3983 .35469 L .37933 .33964 L F
.37408 .35759 m .3554 .37016 L .35394 .38615 L .629 .585 .785 r
F
.37161 .33664 m .3983 .35469 L .37142 .33617 L .78 .746 .821 r
F
.38964 .33553 m .3767 .34861 L .37408 .35759 L .629 .585 .785 r
F
.3767 .34861 m .3554 .37016 L .37408 .35759 L F
.36982 .33241 m .3767 .34861 L .38964 .33553 L .607 .596 .814 r
F
.37003 .33557 m .37142 .33617 L .37665 .33031 L .78 .746 .821 r
F
.37611 .33091 m .37416 .33309 L .38964 .33553 L .607 .596 .814 r
F
.37003 .33557 m .37161 .33664 L .37142 .33617 L .78 .746 .821 r
F
.3441 .3645 m .35103 .36619 L .37003 .33557 L .771 .711 .796 r
F
.35103 .36619 m .37161 .33664 L .37003 .33557 L F
.35113 .36605 m .35103 .36619 L .35112 .36628 L .607 .596 .814 r
F
.4225 .35383 m .38178 .38468 L .36687 .41174 L .655 .581 .76 r
F
.38178 .38468 m .36557 .39696 L .36687 .41174 L F
.41765 .36777 m .45155 .3907 L .42481 .35958 L .78 .746 .821 r
F
.4488 .37684 m .36867 .42384 L .3498 .45762 L .683 .584 .739 r
F
.36867 .42384 m .36257 .42741 L .35978 .43401 L F
.36867 .42384 m .35978 .43401 L .3498 .45762 L F
.36257 .42741 m .33794 .44186 L .34565 .4521 L F
.36257 .42741 m .34565 .4521 L .3498 .45762 L F
.35654 .4225 m .34126 .41537 L .33794 .44186 L .655 .581 .76 r
F
.36557 .39696 m .34126 .41537 L .35654 .4225 L F
.3441 .3645 m .3537 .36862 L .35103 .36619 L .771 .711 .796 r
F
.32579 .39548 m .33264 .39615 L .3441 .3645 L .753 .674 .774 r
F
.32064 .41173 m .33278 .3973 L .32579 .39548 L .729 .637 .756 r
F
.33478 .41331 m .31711 .41592 L .32423 .42827 L .629 .585 .785 r
F
.31711 .41592 m .30899 .41712 L .31339 .42034 L F
.31711 .41592 m .31339 .42034 L .32423 .42827 L F
.32579 .39548 m .33278 .3973 L .33264 .39615 L .753 .674 .774 r
F
.34126 .41537 m .32423 .42827 L .33728 .44121 L .655 .581 .76 r
F
.34126 .41537 m .33728 .44121 L .33794 .44186 L F
.46764 .4038 m .35958 .47524 L .47855 .43387 L .712 .594 .722 r
F
0 g
.006 w
.47855 .43387 m
.48148 .4662 L
s
.25 g
.5 Mabswid
.36022 .47502 m
.4647 .43869 L
s
.4647 .43869 m
.46751 .43771 L
s
.46751 .43771 m
.47855 .43387 L
s
.69622 .29003 m .59747 .37137 L .71186 .31153 L .719 .672 .803 r
F
0 g
.006 w
.71186 .31153 m
.71509 .3218 L
s
.69622 .29003 m .58644 .35992 L .59747 .37137 L .719 .672 .803 r
F
1 0 0 r
.003 w
.59747 .37137 m
.60618 .38519 L
s
.25 g
.5 Mabswid
.59747 .37137 m
.71186 .31153 L
s
.31564 .4275 m
.32466 .4287 L
s
.34764 .43177 m
.35376 .43258 L
s
.37673 .43564 m
.4123 .44038 L
s
0 g
.006 w
.31375 .45966 m
.31564 .4275 L
s
.18308 .32746 m .22736 .40345 L .2424 .40041 L .61 .708 .914 r
F
.14685 .34179 m .22736 .40345 L .18308 .32746 L .638 .73 .914 r
F
1 0 0 r
.003 w
.2142 .40917 m
.22736 .40345 L
s
.46368 .54019 m
.47333 .55867 L
s
.25 g
.5 Mabswid
.42619 .42168 m
.43652 .42437 L
s
.40168 .41528 m
.42619 .42168 L
s
1 0 0 r
.003 w
.43917 .42262 m
.44352 .40712 L
s
.67305 .27286 m .58644 .35992 L .69622 .29003 L .705 .683 .826 r
F
0 g
.006 w
.69622 .29003 m
.71186 .31153 L
s
.67305 .27286 m .57328 .35115 L .58644 .35992 L .705 .683 .826 r
F
1 0 0 r
.003 w
.58644 .35992 m
.59747 .37137 L
s
.25054 .76049 m .33687 .72378 L .22878 .77709 L .34 .072 .354 r
F
.25054 .76049 m .34268 .70679 L .33687 .72378 L F
.25 g
.5 Mabswid
.34418 .6919 m
.34927 .68821 L
s
0 g
.006 w
.25054 .76049 m
.27669 .74073 L
s
.25 g
.5 Mabswid
.25054 .76049 m
.2567 .7569 L
s
.3503 .67402 m
.35282 .67153 L
s
.30902 .71481 m
.3503 .67402 L
s
.22358 .3179 m .2424 .40041 L .25872 .40022 L .591 .677 .9 r
F
.18308 .32746 m .2424 .40041 L .22358 .3179 L .61 .708 .914 r
F
1 0 0 r
.003 w
.22736 .40345 m
.2424 .40041 L
s
.25 g
.5 Mabswid
.14685 .34179 m
.2142 .40917 L
s
1 0 0 r
.003 w
.74833 .7038 m
.75576 .714 L
s
.25 g
.5 Mabswid
.42265 .39817 m
.44352 .40712 L
s
1 0 0 r
.003 w
.44352 .40712 m
.45155 .3907 L
s
.47333 .55867 m
.48318 .57665 L
s
.5811 .64211 m
.58388 .62375 L
s
.64304 .26075 m .57328 .35115 L .67305 .27286 L .699 .702 .85 r
F
.25 g
.5 Mabswid
.69069 .29355 m
.69622 .29003 L
s
.64304 .26075 m .5583 .34532 L .57328 .35115 L .699 .702 .85 r
F
.25 g
.58644 .35992 m
.59215 .35628 L
s
1 0 0 r
.003 w
.57328 .35115 m
.58644 .35992 L
s
.26651 .31368 m .25872 .40022 L .27568 .40296 L .585 .644 .876 r
F
.22358 .3179 m .25872 .40022 L .26651 .31368 L .591 .677 .9 r
F
1 0 0 r
.2424 .40041 m
.25872 .40022 L
s
.25 g
.5 Mabswid
.22358 .3179 m
.22422 .32072 L
s
.22422 .32072 m
.23937 .38714 L
s
.23937 .38714 m
.2424 .40041 L
s
.18308 .32746 m
.22736 .40345 L
s
0 g
.006 w
.31564 .4275 m
.31706 .42303 L
s
1 0 0 r
.003 w
.37563 .53629 m
.37659 .55835 L
s
.37252 .51489 m
.37563 .53629 L
s
.60728 .25424 m .5583 .34532 L .64304 .26075 L .7 .727 .871 r
F
.25 g
.5 Mabswid
.66849 .27644 m
.67305 .27286 L
s
.60728 .25424 m .54196 .34263 L .5583 .34532 L .7 .727 .871 r
F
.25 g
.59215 .35628 m
.60338 .34913 L
s
.57328 .35115 m
.5811 .34501 L
s
1 0 0 r
.003 w
.5583 .34532 m
.57328 .35115 L
s
.37553 .58078 m
.37659 .55835 L
s
.36717 .49444 m
.37252 .51489 L
s
.48318 .57665 m
.49277 .5941 L
s
.40261 .30968 m .46242 .37608 L .47576 .36367 L .78 .773 .847 r
F
1 0 0 r
.45155 .3907 m
.46242 .37608 L
s
.30984 .31518 m .27568 .40296 L .29263 .40862 L .591 .616 .845 r
F
.26651 .31368 m .27568 .40296 L .30984 .31518 L .585 .644 .876 r
F
1 0 0 r
.25872 .40022 m
.27568 .40296 L
s
.25 g
.5 Mabswid
.25872 .40022 m
.26651 .31368 L
s
1 0 0 r
.003 w
.37265 .60327 m
.37553 .58078 L
s
.46764 .4038 m .3498 .45762 L .35958 .47524 L .712 .594 .722 r
F
1 0 0 r
.35958 .47524 m
.36717 .49444 L
s
.25 g
.5 Mabswid
.35958 .47524 m
.36022 .47502 L
s
.35153 .32252 m .29263 .40862 L .30899 .41712 L .607 .596 .814 r
F
.30984 .31518 m .29263 .40862 L .35153 .32252 L .591 .616 .845 r
F
.25 g
.27568 .40296 m
.30984 .31518 L
s
1 0 0 r
.003 w
.27568 .40296 m
.29263 .40862 L
s
.25 g
.5 Mabswid
.29263 .40862 m
.3159 .3746 L
s
1 0 0 r
.003 w
.29263 .40862 m
.30899 .41712 L
s
.56726 .25372 m .54196 .34263 L .60728 .25424 L .709 .754 .887 r
F
.25 g
.5 Mabswid
.63996 .26382 m
.64304 .26075 L
s
.5811 .34501 m
.66849 .27644 L
s
.60338 .34913 m
.69069 .29355 L
s
.56726 .25372 m .52486 .34317 L .54196 .34263 L .709 .754 .887 r
F
.25 g
.5703 .33334 m
.63996 .26382 L
s
1 0 0 r
.003 w
.54196 .34263 m
.5583 .34532 L
s
.44044 .2878 m .47576 .36367 L .49105 .35386 L .768 .789 .87 r
F
.40261 .30968 m .47576 .36367 L .44044 .2878 L .78 .773 .847 r
F
.25 g
.5 Mabswid
.44952 .36175 m
.46242 .37608 L
s
1 0 0 r
.003 w
.46242 .37608 m
.47576 .36367 L
s
.25 g
.5 Mabswid
.40261 .30968 m
.40777 .31541 L
s
.40777 .31541 m
.42392 .33333 L
s
.4488 .37684 m .3498 .45762 L .46764 .4038 L .683 .584 .739 r
F
.25 g
.35382 .45578 m
.46764 .4038 L
s
.3498 .45762 m
.35382 .45578 L
s
1 0 0 r
.003 w
.3498 .45762 m
.35958 .47524 L
s
0 g
.006 w
.46764 .4038 m
.47855 .43387 L
s
.25 g
.5 Mabswid
.58409 .68541 m
.59926 .69177 L
s
.59926 .69177 m
.60427 .69386 L
s
1 0 0 r
.003 w
.36822 .62555 m
.37265 .60327 L
s
.4225 .35383 m .33794 .44186 L .4488 .37684 L .655 .581 .76 r
F
.25 g
.5 Mabswid
.33794 .44186 m
.33952 .44093 L
s
0 g
.006 w
.4488 .37684 m
.46764 .4038 L
s
1 0 0 r
.003 w
.33794 .44186 m
.3498 .45762 L
s
.25 g
.5 Mabswid
.30899 .41712 m
.31122 .41486 L
s
.31122 .41486 m
.32363 .40231 L
s
1 0 0 r
.003 w
.30899 .41712 m
.31339 .42034 L
s
.58014 .65932 m
.5811 .64211 L
s
.38964 .33553 m .32423 .42827 L .4225 .35383 L .629 .585 .785 r
F
.25 g
.5 Mabswid
.32423 .42827 m
.32462 .42798 L
s
.32621 .42677 m
.34126 .41537 L
s
.32462 .42798 m
.32621 .42677 L
s
.34126 .41537 m
.36557 .39696 L
s
.36557 .39696 m
.38178 .38468 L
s
.38178 .38468 m
.38846 .37962 L
s
.38846 .37962 m
.4225 .35383 L
s
1 0 0 r
.003 w
.31339 .42034 m
.32423 .42827 L
s
.25 g
.5 Mabswid
.35105 .37457 m
.3554 .37016 L
s
.3554 .37016 m
.3767 .34861 L
s
.3767 .34861 m
.38964 .33553 L
s
1 0 0 r
.003 w
.32423 .42827 m
.33794 .44186 L
s
.25 g
.5 Mabswid
.35154 .36769 m
.3537 .36862 L
s
.3441 .3645 m
.35154 .36769 L
s
.36867 .42384 m
.44232 .38064 L
s
.44232 .38064 m
.4488 .37684 L
s
.36257 .42741 m
.36867 .42384 L
s
.33952 .44093 m
.36257 .42741 L
s
.3159 .3746 m
.33612 .34505 L
s
.33612 .34505 m
.35153 .32252 L
s
0 g
.006 w
.32064 .41173 m
.32579 .39548 L
s
.25 g
.5 Mabswid
.32579 .39548 m
.33278 .3973 L
s
.37003 .33557 m
.37161 .33664 L
s
.52478 .25928 m .52486 .34317 L .56726 .25372 L .727 .777 .893 r
F
.25 g
.54196 .34263 m
.60664 .25512 L
s
.60664 .25512 m
.60728 .25424 L
s
.5583 .34532 m
.5703 .33334 L
s
.52478 .25928 m .50765 .34696 L .52486 .34317 L .727 .777 .893 r
F
1 0 0 r
.003 w
.52486 .34317 m
.54196 .34263 L
s
.25 g
.5 Mabswid
.52486 .34317 m
.56726 .25372 L
s
.48182 .27078 m .49105 .35386 L .50765 .34696 L .749 .791 .887 r
F
.44044 .2878 m .49105 .35386 L .48182 .27078 L .768 .789 .87 r
F
1 0 0 r
.003 w
.47576 .36367 m
.49105 .35386 L
s
.25 g
.5 Mabswid
.42392 .33333 m
.44952 .36175 L
s
.44678 .30142 m
.47576 .36367 L
s
.44374 .29488 m
.44678 .30142 L
s
.44044 .2878 m
.44374 .29488 L
s
.48182 .27078 m .50765 .34696 L .52478 .25928 L .749 .791 .887 r
F
.25 g
.50765 .34696 m
.52478 .25928 L
s
1 0 0 r
.003 w
.49105 .35386 m
.50765 .34696 L
s
.25 g
.5 Mabswid
.48182 .27078 m
.49105 .35386 L
s
1 0 0 r
.003 w
.50765 .34696 m
.52486 .34317 L
s
.36255 .64732 m
.36822 .62555 L
s
.49277 .5941 m
.50163 .61102 L
s
0 g
.006 w
.67305 .27286 m
.69622 .29003 L
s
1 0 0 r
.003 w
.35608 .6683 m
.36255 .64732 L
s
.25 g
.5 Mabswid
.56245 .66456 m
.58014 .65932 L
s
.55619 .66642 m
.56245 .66456 L
s
.53645 .67227 m
.54599 .66944 L
s
.52408 .67594 m
.52745 .67494 L
s
.52773 .67486 m
.53645 .67227 L
s
.4563 .69604 m
.52408 .67594 L
s
0 g
.006 w
.4563 .69604 m
.4585 .70798 L
s
1 0 0 r
.003 w
.58014 .65932 m
.5814 .67522 L
s
0 g
.006 w
.32579 .39548 m
.3441 .3645 L
s
.22878 .77709 m .33246 .73897 L .21273 .79041 L .424 .129 .358 r
F
.22878 .77709 m .33687 .72378 L .33246 .73897 L F
.25 g
.5 Mabswid
.33567 .71087 m
.34268 .70679 L
s
.2567 .7569 m
.33567 .71087 L
s
0 g
.006 w
.22878 .77709 m
.25054 .76049 L
s
.25 g
.5 Mabswid
.22878 .77709 m
.2362 .77343 L
s
.2362 .77343 m
.33687 .72378 L
s
.34025 .69474 m
.34418 .6919 L
s
.28143 .7373 m
.34025 .69474 L
s
1 0 0 r
.003 w
.34927 .68821 m
.35608 .6683 L
s
.50163 .61102 m
.50936 .6274 L
s
.87969 .75758 m .76377 .73068 L .76104 .72297 L .667 .185 .097 r
F
1 0 0 r
.75576 .714 m
.76104 .72297 L
s
.25 g
.5 Mabswid
.82928 .74588 m
.8613 .75664 L
s
.89065 .75724 m .76377 .73068 L .87969 .75758 L .602 .116 .073 r
F
0 g
.006 w
.8613 .75664 m
.87969 .75758 L
s
.4225 .35383 m
.4488 .37684 L
s
1 0 0 r
.003 w
.34268 .70679 m
.34927 .68821 L
s
.25 g
.5 Mabswid
.56818 .67874 m
.5814 .67522 L
s
.55896 .6812 m
.56818 .67874 L
s
0 g
.006 w
.64304 .26075 m
.67305 .27286 L
s
1 0 0 r
.003 w
.50936 .6274 m
.51559 .64324 L
s
.62619 .70306 m .52218 .67327 L .51996 .65853 L .803 .436 .361 r
F
.25 g
.5 Mabswid
.62004 .70129 m
.62619 .70306 L
s
.592 .69326 m
.62004 .70129 L
s
.58615 .69159 m
.592 .69326 L
s
.57061 .68714 m
.58615 .69159 L
s
1 0 0 r
.003 w
.5814 .67522 m
.58409 .68541 L
s
.25 g
.5 Mabswid
.5298 .68897 m
.54723 .68433 L
s
.4585 .70798 m
.52908 .68916 L
s
.54723 .68433 m
.55253 .68291 L
s
0 g
.006 w
.60427 .69386 m
.62619 .70306 L
s
.25 g
.5 Mabswid
.51996 .65853 m
.52259 .65963 L
s
.52259 .65963 m
.56648 .67803 L
s
.89065 .75724 m .76361 .73714 L .76377 .73068 L .602 .116 .073 r
F
1 0 0 r
.003 w
.76104 .72297 m
.76377 .73068 L
s
.25 g
.5 Mabswid
.85159 .75106 m
.87969 .75758 L
s
0 g
.006 w
.3441 .3645 m
.37003 .33557 L
s
.39782 .34009 m
.4225 .35383 L
s
.38964 .33553 m
.39782 .34009 L
s
1 0 0 r
.003 w
.33687 .72378 m
.34268 .70679 L
s
0 g
.006 w
.14685 .34179 m
.18308 .32746 L
s
.25 g
.5 Mabswid
.46914 .71765 m
.47725 .71569 L
s
.57385 .69243 m
.57876 .69125 L
s
.56179 .69534 m
.57385 .69243 L
s
1 0 0 r
.003 w
.58743 .69401 m
.58862 .69635 L
s
.58862 .69635 m
.59108 .70117 L
s
.51559 .64324 m
.51996 .65853 L
s
0 g
.006 w
.60728 .25424 m
.64304 .26075 L
s
.4585 .70798 m
.46914 .71765 L
s
.21273 .79041 m .33 .75216 L .20359 .80044 L .477 .153 .338 r
F
.21273 .79041 m .33246 .73897 L .33 .75216 L F
0 g
.21273 .79041 m
.22878 .77709 L
s
.25 g
.5 Mabswid
.21273 .79041 m
.33246 .73897 L
s
1 0 0 r
.003 w
.33246 .73897 m
.33687 .72378 L
s
.89328 .75596 m .76361 .73714 L .89065 .75724 L .521 .017 0 r
F
0 g
.006 w
.87969 .75758 m
.89065 .75724 L
s
.89328 .75596 m .76032 .74236 L .76361 .73714 L .521 .017 0 r
F
1 0 0 r
.003 w
.76361 .73714 m
.76377 .73068 L
s
.25 g
.5 Mabswid
.86296 .75286 m
.89065 .75724 L
s
0 g
.006 w
.37611 .33091 m
.38964 .33553 L
s
.35153 .32252 m
.37596 .33086 L
s
.37003 .33557 m
.37665 .33031 L
s
.37665 .33031 m
.40261 .30968 L
s
.18308 .32746 m
.22358 .3179 L
s
.30984 .31518 m
.35153 .32252 L
s
.56726 .25372 m
.60728 .25424 L
s
.22358 .3179 m
.26651 .31368 L
s
.88698 .75408 m .76032 .74236 L .89328 .75596 L .414 0 0 r
F
0 g
.89065 .75724 m
.89328 .75596 L
s
.88698 .75408 m .75381 .74635 L .76032 .74236 L .414 0 0 r
F
1 0 0 r
.003 w
.76032 .74236 m
.76361 .73714 L
s
.64147 .71119 m .52197 .68742 L .52218 .67327 L .749 .395 .382 r
F
.25 g
.5 Mabswid
.61244 .70542 m
.64147 .71119 L
s
.58754 .70046 m
.61244 .70542 L
s
1 0 0 r
.003 w
.51996 .65853 m
.52218 .67327 L
s
0 g
.006 w
.62619 .70306 m
.64147 .71119 L
s
.25 g
.5 Mabswid
.52489 .67404 m
.57061 .68714 L
s
.52218 .67327 m
.52489 .67404 L
s
0 g
.006 w
.40261 .30968 m
.44044 .2878 L
s
.26651 .31368 m
.30984 .31518 L
s
.52046 .73065 m .60133 .71407 L .61357 .72387 L .68 .223 .16 r
F
.52008 .73016 m .60133 .71407 L .52046 .73065 L F
.48839 .72523 m .60133 .71407 L .51593 .73098 L .687 .294 .296 r
F
.51592 .73098 m .49383 .73737 L .50152 .72956 L .5 .119 .25 r
F
.51593 .73098 m .61357 .72387 L .55374 .7347 L .68 .223 .16 r
F
.55415 .7351 m .51839 .7379 L .51634 .73214 L .5 .119 .25 r
F
.59577 .73959 m .55784 .73876 L .55415 .7351 L F
.55784 .73876 m .51839 .7379 L .55415 .7351 L F
.55413 .73508 m .62826 .73209 L .59296 .7381 L .622 .089 0 r
F
.5648 .73465 m .61357 .72387 L .62826 .73209 L F
.55413 .73508 m .56304 .7334 L .5648 .73465 L F
.56304 .7334 m .61357 .72387 L .5648 .73465 L F
.54151 .7181 m .51733 .72662 L .5135 .71383 L .576 .215 .319 r
F
.55374 .7347 m .61357 .72387 L .55413 .73508 L .622 .089 0 r
F
.60444 .73839 m .62826 .73209 L .64491 .73875 L .474 0 0 r
F
.61843 .74009 m .59577 .73959 L .59575 .73959 L .5 .119 .25 r
F
.60777 .73906 m .64491 .73875 L .63726 .74052 L .474 0 0 r
F
.60777 .73906 m .63726 .74052 L .62884 .74011 L F
.59331 .73828 m .64491 .73875 L .60777 .73906 L F
.59331 .73828 m .60087 .73675 L .60444 .73839 L F
.59296 .7381 m .60087 .73675 L .59331 .73828 L F
.60087 .73675 m .62826 .73209 L .60444 .73839 L F
.61956 .73966 m .50504 .72599 L .63779 .73279 L .5 .119 .25 r
F
.61843 .74009 m .61202 .73929 L .61956 .73966 L F
.61202 .73929 m .50504 .72599 L .61956 .73966 L F
.62884 .74011 m .63726 .74052 L .63723 .74053 L .474 0 0 r
F
.59331 .73828 m .59575 .73959 L .58357 .73776 L .5 .119 .25 r
F
.61843 .74009 m .59575 .73959 L .59008 .73656 L F
.59195 .73827 m .59331 .73828 L .60777 .73906 L .474 0 0 r
F
.59008 .73656 m .59331 .73828 L .50504 .72599 L .5 .119 .25 r
F
.59331 .73828 m .58357 .73776 L .50504 .72599 L F
.59195 .73827 m .59296 .7381 L .59331 .73828 L .474 0 0 r
F
.56927 .72234 m .55631 .72862 L .54151 .7181 L .576 .215 .319 r
F
.63779 .73279 m .58641 .73016 L .56927 .72234 L F
.58641 .73016 m .55631 .72862 L .56927 .72234 L F
.55631 .72862 m .51733 .72662 L .54151 .7181 L F
.51593 .73098 m .52008 .73016 L .52046 .73065 L .68 .223 .16 r
F
.51593 .73098 m .52008 .73016 L .51593 .73098 L F
.48839 .72523 m .51593 .73098 L .51589 .73097 L .687 .294 .296 r
F
.59577 .73959 m .50165 .72944 L .50504 .72599 L .5 .119 .25 r
F
.5509 .73521 m .55413 .73508 L .59195 .73827 L .622 .089 0 r
F
.55413 .73508 m .59296 .7381 L .59195 .73827 L F
.55352 .73503 m .51634 .73214 L .51593 .73098 L .5 .119 .25 r
F
.55415 .7351 m .51634 .73214 L .55352 .73503 L F
.5509 .73521 m .55374 .7347 L .55413 .73508 L .622 .089 0 r
F
.51839 .7379 m .49383 .73737 L .51593 .73098 L .5 .119 .25 r
F
.51592 .73098 m .51593 .73098 L .5509 .73521 L .68 .223 .16 r
F
.51593 .73098 m .55374 .7347 L .5509 .73521 L F
.51593 .73098 m .51592 .73098 L .50165 .72944 L .5 .119 .25 r
F
.51592 .73098 m .50152 .72956 L .50165 .72944 L F
.51592 .73098 m .51593 .73098 L .51593 .73098 L .68 .223 .16 r
F
.51589 .73097 m .51593 .73098 L .51592 .73098 L .687 .294 .296 r
F
.51733 .72662 m .50504 .72599 L .51061 .71799 L .576 .215 .319 r
F
.51733 .72662 m .51061 .71799 L .5135 .71383 L F
.25 g
.5 Mabswid
.47725 .71569 m
.55796 .69626 L
s
.58256 .70469 m
.5877 .70357 L
s
.4958 .72361 m
.50865 .72081 L
s
1 0 0 r
.003 w
.59385 .70508 m
.60133 .71407 L
s
.25 g
.5 Mabswid
.48839 .72523 m
.4958 .72361 L
s
1 0 0 r
.003 w
.60133 .71407 m
.61357 .72387 L
s
0 g
.006 w
.52478 .25928 m
.56726 .25372 L
s
.44044 .2878 m
.48182 .27078 L
s
.20359 .80044 m .33 .75216 L .33 .76321 L .508 .151 .296 r
F
1 0 0 r
.003 w
.33 .75216 m
.33246 .73897 L
s
.87153 .7519 m .75381 .74635 L .88698 .75408 L .272 0 0 r
F
.25 g
.5 Mabswid
.88682 .7553 m
.89328 .75596 L
s
.85901 .75246 m
.88682 .7553 L
s
.87153 .7519 m .74413 .74911 L .75381 .74635 L .272 0 0 r
F
1 0 0 r
.003 w
.75381 .74635 m
.76032 .74236 L
s
0 g
.006 w
.48182 .27078 m
.52478 .25928 L
s
.25 g
.5 Mabswid
.5509 .73521 m
.55374 .7347 L
s
1 0 0 r
.003 w
.61357 .72387 m
.62641 .73105 L
s
0 g
.006 w
.46914 .71765 m
.48839 .72523 L
s
.20359 .80044 m .33 .76321 L .20234 .80718 L .508 .151 .296 r
F
0 g
.20359 .80044 m
.21273 .79041 L
s
.25 g
.5 Mabswid
.20359 .80044 m
.33 .75216 L
s
0 g
.006 w
.88698 .75408 m
.89328 .75596 L
s
.8472 .74967 m .74413 .74911 L .87153 .7519 L .105 0 0 r
F
.25 g
.5 Mabswid
.8813 .75375 m
.88698 .75408 L
s
.83601 .75112 m
.8813 .75375 L
s
.8472 .74967 m .73152 .75064 L .74413 .74911 L .105 0 0 r
F
1 0 0 r
.003 w
.74413 .74911 m
.75381 .74635 L
s
.64901 .71864 m .51913 .70095 L .52197 .68742 L .696 .347 .381 r
F
1 0 0 r
.52197 .68742 m
.52218 .67327 L
s
.25 g
.5 Mabswid
.52948 .71627 m
.56874 .70771 L
s
.52197 .68742 m
.58754 .70046 L
s
.20234 .80718 m .33 .76321 L .33284 .77202 L .518 .121 .227 r
F
1 0 0 r
.003 w
.33 .76321 m
.33 .75216 L
s
.81478 .74756 m .73152 .75064 L .8472 .74967 L .038 .608 .728 r
F
.25 g
.5 Mabswid
.86782 .75182 m
.87153 .7519 L
s
.81478 .74756 m .71642 .75092 L .73152 .75064 L .038 .608 .728 r
F
1 0 0 r
.003 w
.73418 .75031 m
.74413 .74911 L
s
.63723 .74053 m .64491 .73875 L .66285 .7439 L .251 0 0 r
F
.25 g
.5 Mabswid
.63726 .74052 m
.64491 .73875 L
s
1 0 0 r
.003 w
.63378 .7343 m
.64491 .73875 L
s
.64796 .72573 m .51913 .70095 L .64901 .71864 L .64 .289 .36 r
F
.25 g
.5 Mabswid
.61201 .7136 m
.64901 .71864 L
s
0 g
.006 w
.64147 .71119 m
.64901 .71864 L
s
.25 g
.5 Mabswid
.56379 .7215 m
.59443 .71543 L
s
.59791 .72671 m
.61357 .72387 L
s
.77559 .74567 m .71642 .75092 L .81478 .74756 L .105 .652 .828 r
F
.25 g
.79115 .75014 m
.86782 .75182 L
s
.77559 .74567 m .69943 .74992 L .71642 .75092 L .105 .652 .828 r
F
1 0 0 r
.003 w
.71642 .75092 m
.73152 .75064 L
s
.64796 .72573 m .5135 .71383 L .51913 .70095 L .64 .289 .36 r
F
1 0 0 r
.51913 .70095 m
.52197 .68742 L
s
.25 g
.5 Mabswid
.51913 .70095 m
.61201 .7136 L
s
.68453 .74233 m .66285 .7439 L .6813 .7476 L 0 .523 .784 r
F
.63723 .74053 m .66285 .7439 L .68453 .74233 L .251 0 0 r
F
1 0 0 r
.003 w
.64491 .73875 m
.65322 .74114 L
s
.25 g
.5 Mabswid
.63723 .74053 m
.63726 .74052 L
s
.2097 .81076 m .33284 .77202 L .33877 .77853 L .5 .053 .12 r
F
.25 g
.31506 .76836 m
.33 .76321 L
s
.20234 .80718 m .33284 .77202 L .2097 .81076 L .518 .121 .227 r
F
.25 g
.20234 .80718 m
.31506 .76836 L
s
1 0 0 r
.003 w
.33 .76321 m
.33284 .77202 L
s
0 g
.006 w
.20234 .80718 m
.20359 .80044 L
s
.73145 .74397 m .69943 .74992 L .77559 .74567 L .077 .621 .846 r
F
.25 g
.5 Mabswid
.7863 .74854 m
.81478 .74756 L
s
.73152 .75064 m
.8472 .74967 L
s
.73145 .74397 m .6813 .7476 L .69943 .74992 L .077 .621 .846 r
F
.25 g
.71642 .75092 m
.7863 .74854 L
s
1 0 0 r
.003 w
.69943 .74992 m
.71642 .75092 L
s
.68453 .74233 m .6813 .7476 L .73145 .74397 L 0 .523 .784 r
F
.25 g
.5 Mabswid
.6813 .7476 m
.7146 .74519 L
s
.7146 .74519 m
.73145 .74397 L
s
1 0 0 r
.003 w
.6813 .7476 m
.69943 .74992 L
s
.66285 .7439 m
.6813 .7476 L
s
.25 g
.5 Mabswid
.69943 .74992 m
.76668 .74617 L
s
.76668 .74617 m
.77559 .74567 L
s
.66285 .7439 m
.68453 .74233 L
s
0 g
.006 w
.48839 .72523 m
.50282 .72824 L
s
.87153 .7519 m
.88698 .75408 L
s
.63779 .73279 m .5135 .71383 L .64796 .72573 L .576 .215 .319 r
F
.25 g
.5 Mabswid
.5135 .71383 m
.54534 .71665 L
s
.54534 .71665 m
.64796 .72573 L
s
0 g
.006 w
.51589 .73097 m
.51592 .73098 L
s
1 0 0 r
.003 w
.5135 .71383 m
.51913 .70095 L
s
0 g
.006 w
.64796 .72573 m
.64901 .71864 L
s
.25 g
.5 Mabswid
.51592 .73098 m
.51593 .73098 L
s
1 0 0 r
.003 w
.50504 .72599 m
.5135 .71383 L
s
.22596 .81138 m .33877 .77853 L .34784 .78276 L .44 0 0 r
F
.25 g
.5 Mabswid
.31567 .77742 m
.33284 .77202 L
s
.2097 .81076 m .33877 .77853 L .22596 .81138 L .5 .053 .12 r
F
1 0 0 r
.003 w
.33284 .77202 m
.33877 .77853 L
s
0 g
.006 w
.20234 .80718 m
.2097 .81076 L
s
.25 g
.5 Mabswid
.2097 .81076 m
.21903 .80783 L
s
.58641 .73016 m
.63779 .73279 L
s
.55631 .72862 m
.58641 .73016 L
s
.51733 .72662 m
.55631 .72862 L
s
.50504 .72599 m
.51733 .72662 L
s
1 0 0 r
.003 w
.50165 .72944 m
.50504 .72599 L
s
.25099 .80931 m .34784 .78276 L .35988 .78475 L .323 0 0 r
F
.25 g
.5 Mabswid
.31876 .78436 m
.33877 .77853 L
s
.29961 .78247 m
.31567 .77742 L
s
.22596 .81138 m .34784 .78276 L .25099 .80931 L .44 0 0 r
F
1 0 0 r
.003 w
.33877 .77853 m
.34784 .78276 L
s
.25 g
.5 Mabswid
.22596 .81138 m
.23491 .80877 L
s
0 g
.006 w
.63779 .73279 m
.64796 .72573 L
s
.59029 .7478 m .49383 .73737 L .61843 .74009 L .401 0 .142 r
F
.25 g
.5 Mabswid
.59576 .73959 m
.61843 .74009 L
s
.59195 .73827 m
.59296 .7381 L
s
.59029 .7478 m .48007 .74787 L .49383 .73737 L .401 0 .142 r
F
1 0 0 r
.003 w
.49383 .73737 m
.50165 .72944 L
s
.25 g
.5 Mabswid
.49383 .73737 m
.59576 .73959 L
s
0 g
.006 w
.51592 .73098 m
.5509 .73521 L
s
.8472 .74967 m
.87153 .7519 L
s
.28411 .80493 m .35988 .78475 L .37453 .7846 L .158 0 0 r
F
.25 g
.5 Mabswid
.29671 .79078 m
.31876 .78436 L
s
.27242 .79103 m
.29961 .78247 L
s
.25099 .80931 m .35988 .78475 L .28411 .80493 L .323 0 0 r
F
.25 g
.21903 .80783 m
.27242 .79103 L
s
.32297 .78957 m
.34784 .78276 L
s
1 0 0 r
.003 w
.34784 .78276 m
.35988 .78475 L
s
.25 g
.5 Mabswid
.25099 .80931 m
.25965 .80694 L
s
0 g
.006 w
.2097 .81076 m
.22596 .81138 L
s
.55435 .75601 m .48007 .74787 L .59029 .7478 L .272 0 0 r
F
.55435 .75601 m .46415 .75738 L .48007 .74787 L F
1 0 0 r
.003 w
.48007 .74787 m
.49383 .73737 L
s
.25 g
.5 Mabswid
.48007 .74787 m
.59029 .7478 L
s
.32407 .79868 m .37453 .7846 L .39126 .78245 L 0 0 0 r
F
.28411 .80493 m .37453 .7846 L .32407 .79868 L .158 0 0 r
F
.25 g
.29157 .80294 m
.31949 .7955 L
s
1 0 0 r
.003 w
.35988 .78475 m
.37453 .7846 L
s
.25 g
.5 Mabswid
.28971 .80344 m
.29157 .80294 L
s
.28411 .80493 m
.28971 .80344 L
s
.25965 .80694 m
.32297 .78957 L
s
.23491 .80877 m
.29671 .79078 L
s
.51212 .76467 m .46415 .75738 L .55435 .75601 L .118 0 0 r
F
.51212 .76467 m .4466 .76576 L .46415 .75738 L F
1 0 0 r
.003 w
.46415 .75738 m
.48007 .74787 L
s
.25 g
.5 Mabswid
.46415 .75738 m
.55435 .75601 L
s
.36912 .79105 m .39126 .78245 L .40938 .77847 L 0 0 0 r
F
.32407 .79868 m .39126 .78245 L .36912 .79105 L F
1 0 0 r
.003 w
.37453 .7846 m
.39126 .78245 L
s
.25 g
.5 Mabswid
.32848 .79745 m
.32992 .79705 L
s
.32407 .79868 m
.32848 .79745 L
s
.31949 .7955 m
.35988 .78475 L
s
.4656 .77362 m .4466 .76576 L .51212 .76467 L 0 0 0 r
F
.4656 .77362 m .42809 .77285 L .4466 .76576 L F
1 0 0 r
.003 w
.4466 .76576 m
.46415 .75738 L
s
.25 g
.5 Mabswid
.4466 .76576 m
.51212 .76467 L
s
.41711 .78254 m .40938 .77847 L .42809 .77285 L 0 0 0 r
F
.36912 .79105 m .40938 .77847 L .41711 .78254 L F
1 0 0 r
.003 w
.39126 .78245 m
.40938 .77847 L
s
.25 g
.5 Mabswid
.37376 .78925 m
.39126 .78245 L
s
.36912 .79105 m
.37376 .78925 L
s
.32992 .79705 m
.37453 .7846 L
s
.41711 .78254 m .42809 .77285 L .4656 .77362 L 0 0 0 r
F
.25 g
.42809 .77285 m
.4656 .77362 L
s
1 0 0 r
.003 w
.40938 .77847 m
.42809 .77285 L
s
.25 g
.5 Mabswid
.40938 .77847 m
.41711 .78254 L
s
1 0 0 r
.003 w
.42809 .77285 m
.4466 .76576 L
s
0 g
.006 w
.62667 .73698 m
.63779 .73279 L
s
.61956 .73966 m
.62667 .73698 L
s
.61844 .74008 m
.61956 .73966 L
s
.61843 .74009 m
.61844 .74008 L
s
.5509 .73521 m
.59195 .73827 L
s
.81478 .74756 m
.8472 .74967 L
s
.22596 .81138 m
.25099 .80931 L
s
.59195 .73827 m
.60777 .73906 L
s
.62884 .74011 m
.63723 .74053 L
s
.61958 .73965 m
.62884 .74011 L
s
.77559 .74567 m
.81478 .74756 L
s
.59029 .7478 m
.61843 .74009 L
s
.63723 .74053 m
.68453 .74233 L
s
.73145 .74397 m
.77559 .74567 L
s
.68453 .74233 m
.73145 .74397 L
s
.25099 .80931 m
.28411 .80493 L
s
.55435 .75601 m
.59029 .7478 L
s
.28411 .80493 m
.32407 .79868 L
s
.51212 .76467 m
.55435 .75601 L
s
.32407 .79868 m
.36912 .79105 L
s
.4656 .77362 m
.51212 .76467 L
s
.36912 .79105 m
.41711 .78254 L
s
.41711 .78254 m
.4656 .77362 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.313, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400049000181000`40O003h00Oogoo2Woo002`Ool2
001GOol00:ioo`800003Ool0000005Ioo`00Zgoo0`000goo0P00EWoo002YOol20006Ool00`00Ool0
001EOol00:Moo`8000Qoo`03001oo`0005Eoo`00Y7oo0`002Woo00@007ooOol005Aoo`00XWoo0P00
3Goo00D007ooOomoo`0005=oo`00Wgoo0`003goo00D007ooOomoo`0005=oo`00WGoo0P004Woo00<0
07ooOol00Woo00<007ooOol0D7oo002KOol2000EOol00`00Oomoo`02Ool00`00Oomoo`1?Ool009Qo
o`<001Moo`03001oogoo009oo`03001oogoo04moo`00UWoo0P006Woo00<007ooOol00goo00<007oo
Ool0CWoo002COol3000LOol00`00Oomoo`03Ool00`00Oomoo`1>Ool0095oo`8001moo`03001oogoo
00Aoo`03001oogoo04eoo`00Sgoo0P008Goo00<007ooOol01Goo00<007ooOol0C7oo002<Ool3000S
Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool008Yoo`8002Ioo`03001oogoo00Ioo`03001oogoo04]o
o`00Qgoo0`00:7oo00<007ooOol01goo00<007ooOol0BWoo0025Ool2000[Ool00`00Oomoo`07Ool0
0`00Oomoo`1:Ool008=oo`8002eoo`03001oogoo00Qoo`03001oogoo04Uoo`00P7oo0`00;goo00<0
07ooOol027oo00<007ooOol0BGoo001nOol2000bOol00`00Oomoo`09Ool00`00Oomoo`18Ool007]o
o`<003Aoo`03001oogoo00Yoo`03001oogoo04Moo`00NGoo0P00=goo00<007ooOol02Woo00<007oo
Ool0Agoo001gOol2000iOol00`00Oomoo`0;Ool00`00Oomoo`16Ool007Aoo`<003]oo`03001oogoo
00aoo`03001oogoo04Eoo`00LWoo0P00?goo00<007ooOol02goo00<007ooOol0AGoo001_Ool30011
Ool00`00Oomoo`0<Ool00`00Oomoo`14Ool006eoo`8004Aoo`03001oogoo00aoo`03001oogoo04Ao
o`00Jgoo0P00AWoo00<007ooOol03Goo00<007ooOol0@goo001XOol30018Ool00`00Oomoo`0>Ool0
0`00Oomoo`12Ool006Ioo`8004]oo`03001oogoo00ioo`03001oogoo049oo`00Hgoo0`00CGoo00<0
07ooOol03goo00<007ooOol0@Goo001QOol2001@Ool00`00Oomoo`0@Ool00`00Oomoo`10Ool005io
o`<0059oo`03001oogoo011oo`03001oogoo041oo`00G7oo0P00EGoo00<007ooOol04Goo00<007oo
Ool0?goo001JOol2001GOol00`00Oomoo`0AOol00`00Oomoo`0oOol005Moo`<005Uoo`03001oogoo
019oo`03001oogoo03ioo`00EGoo0P00G7oo00<007ooOol04goo00<007ooOol0?Goo001BOol3001N
Ool00`00Oomoo`0COol00`00Oomoo`0mOol0051oo`80065oo`03001oogoo01Aoo`03001oogoo03ao
o`00CWoo0P00Hgoo00<007ooOol05Goo00<007ooOol0>goo001;Ool3001UOol00`00Oomoo`0EOol0
0`00Oomoo`0kOol004Uoo`8006Uoo`03001oogoo01Eoo`03001oogoo03Yoo`00AWoo0`00Jgoo00<0
07ooOol05Goo00<007ooOol0>Woo0014Ool2001^Ool00`00Oomoo`0FOol00`00Oomoo`0iOol0049o
o`80071oo`03001oogoo01Moo`03001oogoo03Qoo`00?goo0`00LWoo00<007ooOol05goo00<007oo
Ool0>7oo000mOol2001eOol00`00Oomoo`0HOol00`00Oomoo`0gOol003Yoo`<007Moo`03001oogoo
01Uoo`03001oogoo03Ioo`00>7oo0P00NWoo00<007ooOol06Goo00<007ooOol0=Woo000fOol2001l
Ool00`00Oomoo`0JOol00`00Oomoo`0eOol003=oo`<007ioo`03001oogoo01Yoo`03001oogoo03Eo
o`00<Goo0P00PGoo00<007ooOol06goo00<007ooOol0=7oo000^Ool30023Ool00`00Oomoo`0LOol0
0`00Oomoo`0cOol002aoo`8008Ioo`03001oogoo01aoo`03001oogoo03=oo`00:Woo0P00R7oo00<0
07ooOol07Goo00<007ooOol0<Woo000WOol3002:Ool00`00Oomoo`0NOol00`00Oomoo`0aOol002Eo
o`8008eoo`03001oogoo01ioo`03001oogoo035oo`008Woo0`00Sgoo00<007ooOol07goo00<007oo
Ool0<7oo000POol2002COol00`00Oomoo`0NOol00`00Oomoo`0`Ool001ioo`8009Eoo`03001oogoo
01moo`03001oogoo02moo`006goo0`00Ugoo00<007ooOol087oo00<007ooOol0;Woo000IOol2002J
Ool00`00Oomoo`0POol00`00Oomoo`0^Ool001Moo`8009aoo`03001oogoo025oo`03001oogoo02eo
o`005goo0P00W7oo00<007ooOol08Woo00<007ooOol0;7oo000GOol00`00Ool0002KOol00`00Oomo
o`0ROol00`00Oomoo`0/Ool001Moo`04001oogoo001eOolE000@Ool00`00Oomoo`0SOol00`00Oomo
o`0[Ool001Ioo`03001oogoo009oo`03001oogoo06]oo`L0000EGaaK6elLFa]O71cWFaaFne/LE_]K
75KkFaaFne/L7>MJneKJF_]FfU[k00D000]oo`03001oogoo02=oo`03001oogoo02]oo`005Woo00<0
07ooOol00goo00<007ooOol0IWoo100000iO?1cWFaaK6e/LFa]K75/KFaaK6e/L7>MJo5Kk0U[k015J
o5KkF_]Jne[lE_/LieKKF_]FfeKkE]]JneKKE_]FfQcW008000Uoo`03001oogoo02Aoo`03001oogoo
02Yoo`005Woo00<007ooOol017oo00<007ooOol0HGoo100002MO6ellFa]O?5lK7>MK6elLFa]O75/K
GaaK6elLFa/LieKkFaaFne/LE_]K75KkFaaFnacWE]YJneKJF_]FfU[kE]YJneJj7>MF^U[JE[X00P00
1goo00<007ooOol09Goo00<007ooOol0:Goo000FOol00`00Oomoo`05Ool00`00Oomoo`1MOol30000
55lkGa]O?5lKGc]O6ellGa/Lie/KFaaK6e/LFa]K75/KFaaK6acWE_/2F_/04E[lE_]Jne[kF_aFnacW
E]]JneKKE_]Ffe[kE]]FneKJ7>L01UKJ0P001Goo00<007ooOol09Goo00<007ooOol0:Goo000FOol0
0`00Oomoo`06Ool00`00Oomoo`1JOol20000<V<k7>MO?5/KGcaO6ellFa]O?5lKGc`LielLFa]O75/K
GaaK6elLFa]O71cWFaaFne/LE_]K75KkFaaFnacWE]YJneKJF_]FfU[kE]YJneJj7>MF^U[JE[YJfeJj
F]YF^U[KE[X20003Ool00`00Oomoo`0VOol00`00Oomoo`0XOol001Ioo`03001oogoo00Moo`03001o
ogoo05Moo`80000GGa]S6elK7>MO6ellGa]O>elKGcaO6elkGa/Lie/KFaaK6e/LFa]K75/KFa`Li`02
F_/04E[lE_]Jne[kF_aFne[k7>MJneKKE_]Ffe[kE]]FneKJ7>L02UKJ00HLieZj000007oo000YOol0
0`00Oomoo`0WOol001Eoo`03001oogoo00Uoo`03001oogoo05Aoo`80000jHc]O6V<kGaYS>acWGcaO
6ellFa]O?5lKGcaK6ell7>MO75/KGaaK6elLFa]O75/K7>MFne/LE_]K75KkFaaFne/L7>MJneKJF_]F
fU[kE]YJneJj7>MF^U[JE[YJfeJjF]YF^U[KE[YJfQcWF[YF^EZjE[T2000YOol00`00Oomoo`0WOol0
01Eoo`03001oogoo00Yoo`03001oogoo055oo`80000MGa]S6elKHa]O6f<KGa/LielKGc]O6ellGa]O
>elKGcaO6acWFa]K75/KFaaK6e/LFa/Lie[kF_aFn`02F_/03E[lE_]JnacWF_]FfeKkE]]JneKKE_]F
fQcW00UFfP8Li`06F[YF^EZiE[UJ^UJi0`00:7oo00<007ooOol09Woo000EOol00`00Oomoo`0;Ool0
0`00Oomoo`1>Ool20000@f<kGaYS>elJHc]O6V<kGaYS>acWGcaK6ellGa]O?5/KGcaO6ell7>MO75/K
GaaK6elLFa]O71cWFaaFne/LE_]K75KkFa`Lie[kE]YJneKJF_]FfU[kE[XLieJjF]YF^U[KE[YJfUJj
F]]F^QcWE[UJ^UJiF[YF^EZjE[UJ^P00F[YF^@0002Moo`03001oogoo02Ioo`005Goo00<007ooOol0
37oo00<007ooOol0Bgoo0P0001mO6acWGa]S6elKHa]O6f<KGa]S6elKHa/LiellGa]O>elKGcaO6elk
7>MK75/KFaaK6e/LFa]K71cWF_aFn`02F_/03E[lE_]Jne[k7>MFfeKkE]]JneKKE_]FfQcW00UFfP0?
7>MF^EZjE[UJ^EJiF[YF^EZiE[UJ^P007>MJ^@0002Moo`03001oogoo02Eoo`005Goo00<007ooOol0
3Goo00<007ooOol0B7oo0P0003MS6UlJHaYO6QcWGaYS>elJHc]O6V<kGaYS>elJ7>MO6ellFa]O?5lK
GcaK6acWFa]O75/KGaaK6elLFa/LieKkFaaFne/LE_]K75Kk7>MFfU[kE]YJneKJF_]F^QcWE[YJfUJj
F]]F^U[JE[YJf`027>L02EJiF[YF^EZjE[UJ^UJiF[YF^@027>L01000F[QJ^@00:7oo00<007ooOol0
97oo000EOol00`00Oomoo`0>Ool00`00Oomoo`15Ool20005HaX076<K7>MS6elKHa]O6f<KGa]S6elK
Ha/LielkGa]O?5lKGc]O6ell7>MK75/KFaaK6e/LFa/LieKk0U[k00eJo5KkF_]JnacWE]]FneKKF_]F
feKkE]XLi`08E]X04acWF[UF^EZjE[UJ^EJiF[YF^EZiE[TLieZhF[T005ZiF[QJ^@0002Moo`03001o
ogoo02Aoo`005Goo00<007ooOol03goo00<007ooOol0@Woo0P000f<J041O6V<JHaYS6UlJ7>MO6V<k
GaYS>elJHc]O6V<kGaXLie/KGcaO6ellFa]O?5lK7>MK6elLFa]O75/KGa`Lie/LE_]K75KkFaaFnacW
E]YJneKJF_]FfU[kE]XLieJjF]YF^U[KE[YJfUJjF]/LieZjE[UJ^UJiF[YF^EZjE[UJ^P8Li`09F[QJ
^EZh001J^5ZiF[QJ^@00015oo`d000Uoo`03001oogoo02=oo`0057oo00<007ooOol04Goo00<007oo
Ool0?goo0P002V<J01UO6acWGa]S6elKHa]O6f<KGa]S6acWGcaO6elkGa]O?5lKGc/Lie/LFa]K75/K
Fa`Li`02F_/03E[lE_]Jne[kF_`LieKkE]]JneKKE_]FfacW00MFfP0>F[XLieZiE[UJ^UJiF[UF^EZj
E[UJ^AcWF[UJ^0=J^@06001J^EZiF[UJ^0003Goo100000Y[_1cWIkaS_6NmHkaW_6>lIkdLi`=SW@@0
00Ioo`03001oogoo029oo`0057oo00<007ooOol04Woo00<007ooOol067oo20007Goo00<006;j7>L0
0f<J00EO6V<JHaYS6UlJ00=S6P0]7>MS>elJHc]O6V<kGaYS>elJ7>MO6ellFa]O?5lKGcaK6acWFa]O
75/KGaaK6acWE_]K75KkFaaFne/L7>MJneKJF_]FfU[kE]XLieJjF]YF^U[KE[YJfUJj008Li`08F[YF
^EZjE[UJ^UJiF[YF^@8Li`0=F[UJ^5ZiF[QJ^EZh001J^5ZiF[QJ^EZh000027oo100001AW^f^lIk][
_6>l7>MS_6NmHkaW_F>lIkdLif>MGiaSWEnLHieOW1cW1goo00<007ooOol08Woo000DOol00`00Oomo
o`0COol00`00Oomoo`0AOol60002B[`00acWBY]6V`03BY/8000DOol01000H_URnAcW2f<J01YS6acW
Ha]O6f<KGa]S6elKHa/LielkGa]O?5lKGc]O6acWFa]K75/KFaaK6acWF_]Jo5Kk0U[k00UJo1cWE_]F
fe[kE]]FneKK7>L01eKJ00/LieJiF[UF^EZjE[UJ^EJiF[YF^AcW009J^@0:F[QJ^EZiF[UJ^5Zi001J
^EZhF[T27>L00`00Oomoo`03Ool3000041cWIka[_6NlJkaW_6^lHk`Lif>lIkeS_6NlHkaW_AcW0f>M
00ASW6>M7>LLi`Uoo`03001oogoo025oo`0057oo00<007ooOol057oo00<007ooOol02goo1@0001A:
_4ZkB[a6^dZlB[]:_4Jk7>M6VdZKAY]:VdJKBY]6VdZKAY]:VacW0TYj1P0037oo0P0000IRnUkiH_YR
nAcWGaX3HaX01ElJHaYS6V<JGaX00V<J03<LielJHc]O6V<kGaYS>elJ7>MK6ellGa]O?5/KGc`LielL
Fa]O75/KGa`Lie/LE_]K75KkFa`Lie[kE]YJneKJF_]FfQcWE[YJfUJjF]]F^U[JE[XLieJiF[YF^EZj
E[UJ^UJiF[X00QcW00]J^5ZiF[QJ^EZhF[UJ^5ZiF[P005Zh008Li`05G[QJV000001oo`03000066nk
JkY_^acWJkaW^f^lIk][_6Nk7>MS_6NmHkaW_F>lIkdLif>MGiaSWEnLHidLi`]oo`03001oogoo025o
o`0057oo00<007ooOol05Goo00<007ooOol017oo1P0000=>g4[L7>L02TZl00DLidZKBY]:VdJK00=:
V`03AY]:VacW00U:NP@000Moo`03001RnF;i00ERn@037>MS6V<J00QS6P0G7>MS6elKHa]O6f<KGa]S
6acWGcaO6elkGa]O?5lK7>MK6e/LFa]K71cWF_aFn`02F_/02E[lE_/LieKKF_]FfeKkE]/Li`06E]X0
2EJi7>MF^EZiE[UJ^UJiF[UF^@027>L3F[T01EZhF[UJ^EZiF[P00eZi00L001cWF[QN^5ZhG[QJ^002
000056nkJk]_^f^kKk/Lif^lIka[_6NlJkaW_1cWHkaW_F>lIkaS_6Nm7>L3Hid00f>LHidLi`0=Ool0
0`00Oomoo`0POol001Aoo`03001oogoo01Ioo`03001oo`0000<0000NB]a>gD[LC]a:g4kMB]a>g1cW
B[a:^dZlA[]:_4ZkB[a6^dZlB[/LidJKBY]6VdZKAY]:VdJKBY]6VacW0TYj00E6NTYjBWY:NTIj00=:
NP037>M>FDYI00@0009oo`0<001RnF;jG_URnV;iH_YNnF;jH_TLielJ0f<J02aO6V<JHaYS6UlJHaXL
if<kGaYS>elJHc]O6QcWGa]O?5/KGcaO6ell7>MO75/KGaaK6acWE_]K75KkFaaFnacWE]YJneKJF_]F
fQcWE[YJfUJjF]]F^U[J0QcW01=F^EZjE[UJ^UJiF[YF^AcWF[QJ^EZhF[UJ^5ZiF[QJ^EZhF[UJ^002
7>L01@00FYQN^5ZHG[P00`0001Q_^f^jKk][^VnkJkXLifNkJkaW^f^lIk/Lif>lIkeS_6NmHkaSWAcW
HieOW6>MGi`27>L?Ool00`00Oomoo`0OOol001=oo`03001oogoo01Moo`80000>D_a>g1cWB]a>g4[L
C]a:g4kLB]a>g4[LC]`Li`U:_0037>M:VdJK00=:V`04AY]:VdZK7>L;BWX01AcWBUU:FDYICUT00TYI
0`002V;i00<Lif<JHaX01f<J01@LielKHa]O6f<KGa]S6acWGc]O6ellGa]O>elK7>MK6e/LFa/LieKk
0U[k00UJo5Kk7>MFfe[kE]]FneKK7>L01UKJ00PLieZjE[UJ^EJiF[YF^EZi0QcW00EJ^5ZiF[UJ^EZh
00=J^@09F[QJ^AcW7>MJ^5jh001N^5Zh0080000DG[QJ^5jh001_^f^kKk][^acWIka[_6NlJkaW_1cW
HkaW_F>lIkaS_08Li`=SW@03Hi`Ligoo011oo`03001oogoo01moo`004goo00<007ooOol057oo0`00
02E>g5;mC]aBo1cWC]e:g4kLB]a>gD[LC]a:g4kMB]`LidJkB[a:^dZlA[]:_4ZkB[`LidZKAY]:VdJK
BY]6VdZKAY]:VacWBWY6NP03BWX034IjBWY:NTYjAWXLidYICUU:FDiIBUU>F@800003BUU>F@000080
000:H_YNnF;jH_URnUkiH_YRnAcWGaX3HaX0>elJHaYS6V<JGaXLielJHc]O6V<kGaYS>acWGcaO6ell
Fa]O?1cWGaaK6elL7>MK75KkFaaFnacWE]YJneKJF_]FfQcWE[YJfUJjF]]F^UZj7>MJ^UJiF[YF^EZj
E[UJ^QcWF[UJ^5ZiF[QJ^EZhF[UJ^5ZiF[P00QcW00AN^5ZHG[QJV0<0000LFYQN^5ZHG[QJV000JkY_
^f^jKk/Lif^lIk][_6NkIkdLifNmHkaW_F>l7>MOW6>MGiaSWEnL7>LCOol00`00Oomoo`0NOol001=o
o`03001oogoo019oo`80000CC]a>o4kLD_a>g4klC]aBo1cWC]a:g4kLB]a>g4[LC]a:g4kL7>L024Zl
00<LidJKBY/00TZK00I6VdZKBY]:VdJK7>L9BWX01AcWOom:FDYICUT00TYI00<006;I7>L00TYI00<L
idiHH_T00P001f;i00<Lif<JHaX01V<J014Lif<KGa]S6elKHa]O6acWGa]O>elKGc`Lie/LFa]K71cW
009Jn`09F_aFne[k7>MJneKKE_]FfacW00EFfP8Li`06F[YF^EZiE[UJ^UJi0QcW00=J^EZhF[T00UZi
00AJ^5ZiF[UJ^@8Li`05F[QN^5ZhG[QJ^00200003ejhF[QN^5ZhG[QJ^1cW001_^f^kKk/Lif^lIka[
_002Ik`01acWIkeS_6NlHk`Lif>L00=SW@8LiaEoo`03001oogoo01eoo`004goo00<007ooOol047oo
0P0002QBoDkLD_a>g5;mC]aBo4kLD_e>g1cWB]a>gD[LC]a:g4kMB]a>g4[L7>M:^dZlA[]:_4ZkB[a6
^dZl7>M:VdJKBY]6VdZKAY]:VdJK7>M6NP=:NP0BAWY:NTYjBWY6NTYj7>M>FDYICUU:FDiI001RfDYI
CUU:FAcW0diH00aBF6;i000006;jH_URnUkiH_YRnAcWGaX3HaX04UlJHaYS6V<k7>MS>elJHc]O6V<k
7>MO?5/KGcaO6acWFa]O70Ql000KE]YJneKJ7>MF^U[JE[YJfeJj7>MF^EZjE[UJ^UJiF[YF^AcWF[QJ
^EZhF[UJ^5ZiF[QJ^EZh008Li`05G[QJV5jhFYQN^00200001UZH001JV5jhFYQN^08Li`0EG[L006^j
Kk]W^acWIk][_6NkIkdLifNmHkaW_F>l7>MOW6>MGiaSWAcW01Moo`03001oogoo01eoo`004goo00<0
07ooOol04Goo01LLidkLC_a>g5;lC]a>o4kLD_a>g4klC]`Lid[LC]a:g4kLB]a>g4[LC]a:g1cW00M:
_0047>M:VdZKAY/3BY/00dJKBY/Li`09BWX011cWOom:FDiI0TYI00<006;IBUT00TYI00=>FAcWCUP0
1DiH00=Rn@00H_T01F;i00<Lif<JHaX01F<J00XLielKHa]O6f<KGa/LielKGcaO6`Al00Qoo`9l0003
7>Ml05KJ009FfP08E[TLieJiF[YF^EZiE[UJ^P8Li`9J^@06F[QJ^EZiF[UJ^5Zi0QcW00EJ^5jhF[QN
^5Zh008000057>MJ^5jh001N^0037>L04V:hG[MN]`00Kk][^acWIka[_6NlJk`LifNmHkaW_6>l7>MS
W0=SW@037>Moogoo01Moo`03001oogoo01aoo`004goo00<007ooOol04Woo02HLidkLD_e>g5;lC]aB
oDkLD_a>g5;mC]`Lid[LC]e:g4kLB]a>gD[LC]`LidZlB[]:_4JkB[a:^dZl7>M:VdJKBY]6VdZKAY]:
VacW0dYj01=6NTYjBWY:NTIjBWXLidiIBUU>FDYICUT006;IBUU>FDYICUTLi`02CUP01E9HCUQ>F4iH
DUP00TiH0P0000MRnF;jG_URnQcWHaYO6P03HaX02UlJHaXLif<kGaYS>elJHc/Liell0W`047oo0g`0
010LieJiF[YF^EZjE[UJ^QcWF[UJ^5ZiF[QJ^EZhF[UJ^08Li`05G[QJV5jhFYQN^00200007EZHG[QJ
V5jhFYP001cWH[QN]f:hG[MR^5jg001[^QcWIk][_6NkJk`LifNmHkaW_F>l7>MOW6>MGi`00QcW6Woo
00<007ooOol077oo000BOol00`00Oomoo`0DOol05AcWC]a>o4kLD_a>g4klC]aBo4kLC_`LidkLB]a>
g4[LC]a:g4kLB]`Li`07B[`00acWAY]:V`02BY/014JKBY]:VacW2DYj00<LigooCUT00dYI00H005kH
BUU:FDiI7>L<CUP00`00H_URn@02H_T00acWHaYS6P05HaX01acWHa]O6f<KGa/Lig`001Eoo`05O01J
^UJiF[UF^@027>L3F[T015ZhF[UJ^EZi0QcW00aJ^5jhF[QN^5ZhG[P005jhF[QN^5ZhG[P27>L01000
KiYN]f:h0ejg00iR^000Kk/Lif^lIka[_1cWIkeS_6NlHk`Lif>L0V>M00<LigooOol06goo00<007oo
Ool06goo000BOol00`00Oomoo`0EOol09QcWC]aBoDkLD_a>g5;mC]aBo4kLD_dLidkLB]a>gD[LC]a:
g4kM7>M:_4JkB[a:^dZlA[]:_1cWBY]6VdZKAY]:VdJKBY/LidYjAWX3BWX03dIjBWY:NQcWBUUoodYI
CUU:F@00G]Q>FDYICUTLi`02CUP01E9HCUQ>F4iHDUP00diH00aBF4iH7>M>E`00H_URnUkiH_XLif<J
GaX3HaX01UlJ7>MO6V<kGaYl01Qoo`9l0009E[TLieZhF[UJ^5ZiF[QJ^EZh008Li`06G[QJV5jhFYQN
^5ZH0P0000=N^5ZHG[P00acW01UR^5jg001N]f:hG[MR^5jgH[QN]`007>M[_6NkJk`LifNmHkaW_F>l
7>MOW6>MGi`Li`0OOol00`00Oomoo`0JOol0019oo`03001oogoo01Ioo`0C7>M>g4klC]aBo4kLC_a>
g5;lC]`Lid[LC]a:g4kLB]a>g4[L7>L01dZl00@LidZKBY]6V`=:V`037>M:NTYj00I:NP037>M:FDiI
00=:F@04001Nf4YIBUT27>L;CUP27>L3DUL00`00H_URn@02H_T00acWHaYS6P04HaX00acWO01l000K
Ool00g`0F[QJ^@02F[T02UZhF[TLiacWF[QN^5ZhG[QJ^5jh0P0000=J^5jhF[P00QcW00=_FEjgH[P0
0ejg00D005jgG[MN]f:h009N]`0<000LifNlJk`LifNmHkaW_6>l7>MSW6>M0QcW87oo00<007ooOol0
6Woo000BOol00`00Oomoo`0GOol08QcWC]aBoDkLD_a>g5;mC]aBo4kL7>M:g4kLB]a>gD[LC]a:g1cW
B[]:_4JkB[a:^dZl7>M:VdJKBY]6VdZKAY/LidIj0dYj00i6NTYjBWY:NQcWCUUoodiIBUT005kHCUU:
FAcW0diH00EBF4iHCUQ>F59H00=>F008DUPLie9HCUMBF59GDUQ>E`800006H_YNnF;j7>MS6UlJ0f<J
00<LigooOol077oo00Al05ZhF[UJ^08Li`0:G[QJV5jhFYQN^5ZHG[P005jhFYP37>L03EjgH[QN]f:h
G[MR^5jgH[P006:hG[MR^5jg008Li`07001W^f^l7>MW_F>lIkd00QcW00=OW6>M7>L08goo00<007oo
Ool06Goo000BOol00`00Oomoo`0HOol04QcWC]a>o4kLD_a>g4klC]aBo4kL7>M:g4kLB]a>g4[LC]`L
i`I:_0037>M6VdZK009:V`03AY]:VacW00M:NP037>M>FDYI009:F@03001N^1cW008Li`a>F0037>MB
Ee9G00MBE`05001RnF;iH_TLi`03HaX00g`0Oomoo`0MOol02g`0F[TLiacWF[QN^5ZhG[QJ^5jhF[P0
0P000acW00I_FF:hG[MN]fmIH[P3G[L01V:hG[L005jgH[QN]`8Li`0<H[L006^lHk`Lif>lIk`Lif>M
HiaSWAcW9Goo00<007ooOol067oo000BOol00`00Oomoo`0IOol07QcWC]aBoDkLD_a>g5;mC]aBo1cW
C]e:g4kLB]a>gD[L7>M6^dZlB[]:_4JkB[`LidZKAY]:VdJKBY/Li`=:NP0>AWY:NTYjBWY6NQcWBUUo
odYICUT005jhG[LLi`=>F005DUQ>F4iHCUQBF003CUP27>L04U9HCUMBF59GDUQ>Ee9HDUMBF4iGDUP0
06;jG_URnQcWHaYl025oo`0KO01N^5ZHG[QJV5jhFYQN^5ZH001[5f:hG[MR^5jgH[QN]g=iG[MR^5jg
H[QN]f:hG[MR^00000<Li`0;H[IV]`00JkaW^acWHkaW_AcWHieOW0027>LVOol00`00Oomoo`0HOol0
019oo`03001oogoo01Yoo`0@7>M>g4klC]aBo4kLC_a>g5;l7>M>g4[LC]a:g4kL7>L6B[`011cWBY]:
VdJK0TZK00<LidYjBWX01DYj00HLidYIBUU:FDiI0002G[P00diI7>M>F009CUP00acWDUMBE`0<DUL0
1@00H_URnF;iO0008goo00Yl05jhF[QN^5ZhG[QJ^000G[MR^0=N]`05H[QN]ejgG[MR^003G[L47>L0
0`00H[MR]`03H[L02@00Ik`Lif>lIk`Lif>MHi`Li`0YOol00`00Oomoo`0GOol0015oo`03001oogoo
01aoo`0K7>M>g5;mC]aBo4kLD_e>g1cWB]a>gD[LC]a:g4kM7>M:_4JkB[a:^acWAY]:VdJKBY]6VacW
009:NP0>AWY:NTYjBWY6NQcWBUU>FGooCUU:F@00G[M>F@=>F005DUQ>F4iHCUQBF003CUP03QcWDUMB
F4iGDUQBEe9HCUMBF59GDUQ>Ee9HDUL27>L015IG001RnW`09Goo00Al05jhFYQN^08Li`0;G[MR^5jg
H[QN]f:hKeQR^5jgH[QN]`037>L03f:gI[MR]VJg001V]f:fI[MR]fJg000Lif>lO00Li`02O0000acW
Oomoo`0XOol00`00Oomoo`0GOol0015oo`03001oogoo01eoo`0?7>M>g4klC]aBo4kLC_a>g1cWB]a>
g4[LC]a:g1cW00A:_0037>M:VdJK00=:V`037>M:NTYj00E:NP067>M:FDYICUU:F@000Ujh2TiH0QcW
359G0QcW0UIG00=FEP00O0009goo00=l01cW7>L00Ujg00ER^5jgG[MN]flh00=N]`03H[PLiacW00MR
]`03001R]f:g00=R]`03001l07`0031oo`03001oogoo01Ioo`004Goo00<007ooOol07Woo01XLidkL
D_e>g5;lC]aBoDkL7>M:g4kMB]a>g1cWB[a:^dZlA[/LidJKBY]6VdZKAY/LidIj0dYj00Y6NTYj7>M>
FDYICUU:FDiI001N^0=>F005DUQ>F4iHCUQBF002CUP05QcWDUQBEe9HCUMBF59GDUQ>Ee9HDUMBF4iG
DUPLieIGDUIFEe9FEUMBEP009goo00]l05jgH[QN]f:hG[MR^6/GH[QN]f:h00<Li`0?I[MR]VJgH[MV
]f:fI[MR]fJg001V]f:gI[MR]P0003Aoo`03001oogoo01Eoo`004Goo00<007ooOol07goo00dLidkL
C_a>g5;lC]a>o1cWC]a:g4kLB]`Li`04B[`01QcWBY]:VdZKAY/Li`I:NP047>M:FDYICUT2BUT00`00
G[Q>F008CUP27>L<DUL27>L3EUL01UIFEUMFEeIGEUH002Ioo`04001N]ejgH[P3G[L016:hG[LLiacW
36:g00<006:gH[L00V:g00<007ooOol0<Woo00<007ooOol05Goo000AOol00`00Oomoo`0POol05QcW
C]aBoDkLD_a>g5;m7>M>g4[LC]e:g1cWA[]:_4Zk7>M6VdZKAY]:VacW0dYj00Y6NTYjBWXLidYICUU:
FDiIBUT000=>F00CDUQ>F4iHCUQBF4iH7>M>Ee9HDUMBF4iGDUQBEe9HCUMBF59GDUP00QcW00aBEUIG
DUIFEe9FEUMBEUIGDUIFEe9F000TOol01`00J_Ml06:hG[M_>5jg00<Li`0?H[IV]f:gI[MR]VJgH[MV
]f:fI[MR]fJgH[IV]`0000@Li`03001oogoo03=oo`03001oogoo01Aoo`004Goo00<007ooOol08Goo
00`LidkLC_a>g5;lC]`Lid[LC]a:g7`07>L3O0001AcWO016VdZK7>L01TYj00<LidYICUT00dYI00<0
05ZG7>L01diH00DLie9GDUMBEejh00QBE`037>MFEeIF00=FE`05EUIFEeIGEUMFEP03EUL00`00Oomo
o`0QOol01@00J_MZmg`0G[L00acW3V:g0acW00D006:gJ]MVeP0003Moo`03001oogoo01=oo`0047oo
00<007ooOol08goo00LLidkLD_e>g5;lC]`Li`02O0000goo001oo`04Ool4O00034YjAWY:NTYj7>M:
FDiIBUU>FDYICUT0009>F00BDUQ>F4iHCUQBF4iH7>M>Ee9HDUMoodiGDUQBEe9HCUMBF59G0QcW011F
Ee9FEUMBEUIGDUIFEe9FEUMBEUIGDUIFEe9F7>L0025oo`0D001ZmfKfJ_Ml01cWH[IV]f:gI[MR]VJg
H[MV]f:fI[MR]fJgH[IV]`<Li`08I[MVeV[G001ZefKFJ]L003Moo`03001oogoo01=oo`0047oo00<0
07ooOol097oo00<LidkLC_`00W`01Goo00<007ooOol01Woo0W`00TYj00<LidiIBUT00TYI00=>F@00
CUP01TiH0QcW0e9G00=N^59GDUL01E9G00@LieIGEUMFEP=FE`05EUIFEeIGEUMFEP03EUL27>L00eYF
001oo`0OOol00`00J_MZm`02J_L00g`0H[MR]`0:H[L37>L2I]H01F[GI]IVeVKF00000VKF00<007oo
Ool0=goo00<007ooOol04Woo000@Ool00`00Oomoo`0UOol00acWO01oo`07Ool00`00Oomoo`07Ool2
O0002DiIBUU>FDYICUTLi`00CUQBF003CUP03E9H7>MBF4iGDUQBEejGCUMBF59GDUQ>Ee9H008Li`0=
DUIFEe9FEUMBEUIGDUIFEe9FEUMBEUIGDUH00QcW00EJEUIFFUIFEP0001ioo`0?001ZmfKfJ_MZmV[g
I_Il06:gI[MR]VJgH[MV]f:f00@Li`0=J]MVeV[GI]IZefKFJ]MVeV[G001ZefKF0000>Goo00<007oo
Ool04Woo000@Ool00`00Oomoo`0`Ool00`00Oomoo`08Ool2O0000dYICUTLi`07CUP00acWDUMBE`02
DUL00eZGDUMBE`03DUL27>L3EUL01EIFEUMFEeIGEUH00eIG00AFEUIG7>LLi`IJEP03001oogoo01]o
o`03001Zmf[g00EZm`04O01R]f:gH[L47>L3I]H01F[GI]IVeVKFJ]L00fKF00EZefKF001VeP0003Yo
o`8001=oo`0047oo00<007ooOol0<Goo00<007ooOol02Goo0W`00TiH01iBF4iHCUQ>F59H7>MBF4iG
DUQBEe9HCUMBF59GDUQ>EacWDUIFEe9FEUMBEUIGDUIFEe9FEUMBEUIGDUH27>L02UYFEUIJEUIFFUIF
EUYFEUIJEP006goo00X006[gI_IZmf[fJ_MVmV[gJ_Il00<Li`0DJ]MVeV[GI]IZefKFJ]MVeV[GI]IZ
efKFJ]MVeV[GI]IZe`00J]L003Moo`<00003Ool007oo019oo`0047oo00<007ooOol0<Woo00<007oo
Ool02Woo00=l0000CUP00TiH0QcW2E9G0QcW00EFEUIGEUMFEeIF00=FE`04EUIFEeIGEUL27>L2FUH0
0g`0FUIJEP06FUH00`00Oomoo`0HOol00`007>LLi`07J_L00g`0J]MVeP02I]H01F[GI]IVeVKFJ]L0
0fKF00EZefKFI]IVeV[G00=VeP8003Eoo`<000Aoo`03001oogoo015oo`0047oo00<007ooOol0<goo
00<007ooOol02Woo0W`001U>F1cWDUMBF4iGDUQBEe9HCUMBF59GGYLLieIGDUIFEe9FEUMBEUIGDUIF
Ee9FEUMBEP027>L03UYFEUHLiacWFUIFEUYFEUIJEUIFFUIFEUYF000IOol01000I[IVmV[g0QcW01QV
mV[gJ_IZmfKfO01VeV[GI]IZefKFJ]MVeV[GI]IZefKFJ]MVeV[GI]IZefKFJ]L37>L00`00Oomoo`0`
Ool30007Ool00`00Oomoo`0AOol000moo`03001oogoo03Eoo`03001oogoo00Uoo`03000Lig`000QB
E`05FYLLiacWEUMFEP03EUL01EIFEUMFEeIGEUH00acW45YF00<007ooOol05Goo00<006JfI[H00VJf
0V[g00<Lif[gJ_L00f[g00=l06KFJ]L00fKF00EZefKFI]IVeV[G00LLi`9^mP8002moo`<000]oo`03
001oogoo011oo`003goo00<007ooOol0=Woo00<007ooOol027oo00X005YgEUIl04iGDUQBEe9HCUMB
F08Li`0:DUIFEe9FEUMBEUIGDUIFEe9FEUL27>L055IFFUIFEUYFEUIJEUIFFUIFEUYFEUIJEUIFFUIF
EUYFEUIJEQcW000GOol00`00H[IV]`02I[H00f:fI[MZmP027>L01f[gJ_IZmg`0J]MVeV[G00LLi`09
K_IZmFkfJ_I^mV[eK_IZmVkf008002aoo`<000ioo`03001oogoo011oo`003goo00<007ooOol0=goo
00<007ooOol01goo00@005IFEUMFE`9l009BE`8Li`=FE`05EUIFEeIGEUMFEP02EUL27>L@FUH47>L0
0eif001oo`0EOol00`00I[IV]P07I[H01F[g7>MZmf[gO0000acW3fkf00<007oo0000:Goo0`004Goo
00<007ooOol047oo000?Ool00`00Oomoo`0hOol00`00Oomoo`06Ool01P00FWMFEUYgEUIJM`8Li`0:
DUIFEe9FEUMBEUIGDUIFEe9FEUL27>L03eIFFUIFEUYFEUHLieIFFUIFEUYFEUIJEUIFFUIFEP037>L0
1UYEGWIJEEifFUD001Eoo`03001R]VJg009V]P06H[IV]fJfI[IR]VJg0VJf0QcW01=l06kfJ_E^mV[f
K_IZmFkfJ_I^mV[eK_IZmVkfJ_E^mV[fK_H00002Ool00`00Oomoo`0SOol4000DOol00`00Oomoo`0@
Ool000moo`03001oogoo03Uoo`03001oogoo00Aoo`05001FEeIGFUMFEP02EUL01UYGO01FEeIGFUMF
EP=FE`03EUHLiacW00mJEP8Li`09GWENMUieGWINMEifGWENMP0001Aoo`03001V]VJf00eV]P03O01^
mVkf00m^mP04001oogoo000ROol3000HOol00`00Oomoo`0@Ool000moo`03001oogoo03Yoo`03001o
ogoo00=oo`0?001FEUYgEUIJMeIFFWMFEUIGO01FEe9FEUMBEUIG008Li`0>EUIJEUIFFUIFEUYFEUIJ
EUIFFUIFEUYFEUIJEP<Li`0;GWIJEEifFUENMUYEGWIJEEifFUD0000DOol01P00I[MV]VJfH[IV]`9V
]P06H[IV]fJfI[IR]VJg0VJf019l06kfJ_I^mV[eK_IZmVkfJ_E^mV[fK_IZmFkfJ_I^mV[e0003Ool0
0`00Oomoo`0MOol3000KOol00`00Oomoo`0@Ool000ioo`03001oogoo03aoo`03001oogoo009oo`03
001JEeIF009FE`06FUMFEUIGEUMl05IF0UIG0QcW3EYF0acW00mNMUieGWINMEifGWENMUieGWINMEif
GWENMUie00004Woo00<001cWI[H03VJf00=l06kfK_H03Vkf00D007ooOomoo`0001aoo`<001ioo`03
001oogoo011oo`003Woo00<007ooOol0?Goo00l007ooOomoo`00EUIJMeIFFWMFEUYgEUIJMeIFO000
0QcW00eFEUYFEUIJEUIFFUIFEUYFEUIJEUIFFUIFEP027>L04UifFUENMUYEGWIJEEifFUENMUYEGWIJ
EEifFUENMUYEGWH0019oo`03001NMAcW00<Li`03I[IR]VJg009V]P07H[IV]fJfI[IR]VJgO0003acW
00<007ooOol00Woo00<007ooOol05goo0`008Goo00<007ooOol047oo000>Ool00`00Oomoo`0nOol0
1000Oomoo`002QcW00=l05YFFUH02EYF0acW01ANMEifGWENMUieGWINMEifGWENMUieGWINMEifGWEN
MUieGWINM@004Goo00<006:FHYH00f:F00AV]QcW7>LLi`QV]P0@O01c5GLeLaEg=G<EMcEc5GLeLaEg
=G<EMcEc5GLe0005Ool00`00Oomoo`0DOol3000UOol00`00Oomoo`0?Ool000ioo`03001oogoo03mo
o`0F001oo`00DSIF=e8fESMB=UHgDSIF=e8fESMl05YFEUIJEUIFFUIFEUYFEUH37>L05eYEGWIJEEif
FUENMUYE7>MJEEifFUENMUYEGWIJEEifFUENMUYEGWIJEEif00004Goo00X006:FGWERUUieHYINMF:F
GWEV]P<Li`03I[IR]VJg009V]P0?O01g=W<EMcEc5GLfLaEg=G<EMcIc5GLeLaEg=P0000Ioo`03001o
ogoo015oo`<002Qoo`03001oogoo00moo`003Woo00<007ooOol0@7oo00<007oo00000e8f00EB=e8f
DSIB=U8g009B=P03O01JEUYF00=JEP8Li`0GGWENMUieGWINMEifGWENMUieGWINMEifGWENMUieGWIN
MEifGWENMUieGWINM@027>L00`00Oomoo`0>Ool00`00HYIRUP0:HYH00fJf7>LLi`027>L047`0McEc
5GLeLaEg=G<EMcEc5GLeLaEg=G<EMcEc5@001Woo00<007ooOol03Woo0`00:goo00<007ooOol03goo
000>Ool00`00Oomoo`11Ool200003EHgDSIF=e8fESMB=UHgDSIF=e8fO01FEUYF00<Li`0EGWIJEEif
FUENMUYEGWIJEEifFUENMUYEGWIJEEifFUEl05YEGWIJEEif00@Li`03GWERUP00011oo`0?001NMF:F
GWERUUieHYINMF:FGWERUUieHYINMF:F009V]P0@H[Il01cWMcEc5GLfLaEg=G<EMcIc5GLeLaEg=W<E
0007Ool00`00Oomoo`0;Ool3000^Ool00`00Oomoo`0?Ool000ioo`03001oogoo049oo`03001B=U8g
00=B=P0LDSMB=U8fDSIB=e8fO00LieifGWENMUieGWINMEifGWENMUieGWINMEifGWENMUieGWINME8f
O0047>L6HWD00`00Oomoo`0=Ool00`00HYIRUP0@HYH03W`0McEc5GLeLaEg=G<EMcEc5G`0LaEg=G<E
0008Ool00`00Oomoo`08Ool3000aOol00`00Oomoo`0?Ool000eoo`03001oogoo04=oo`0M001F=e8f
ESMB=UHgDSIF=e8fESMB=UHgO01NMUYEGWIJEEifFUENMUYEGWIJEEifFUENMUYEGWIJE@037>L03E8f
O01RMF:EGWERUV9eHYENMF:FHWERU@0000moo`0D001RUUieHYINMF:FGWERUUieHYINMF:FGWERUUie
HYINMF:FGWEl008Li`0:LaEg=G<EMcIc5G`0LaEg=W<E0009Ool00`00Oomoo`05Ool3000dOol00`00
Oomoo`0?Ool000eoo`03001oogoo04Aoo`04001B=U8fDSL3DSH04E8gDSIB=U8fDSMl05ifGWENMUie
GWINMEifGWENMUieGWH011cW0f9e00<Lig`0HWD02F9e00<007ooOol037oo00<006:FHYH04F:F00=l
07]dNe<01AcW00El07LeLaEg=@0000Uoo`03001oogoo009oo`<003Moo`03001oogoo00moo`003Goo
00<007ooOol0A7oo00T0058fESMB=UHgDSIF=e8fESL00acW00Ql05YEGWIJEEifFUENMUYE11cW01=R
UEieHYIRMF:EGWERUThFO01NMF:FHWERUEieHYIRMF:EGWD0000?Ool07@007>LLiacWHYINMF:FGWER
UUieHYINMF:FGWERUUieHYINMF:FGWEl07]COgAkDgmdNe=oM5ieO0000QcW00<007ooOol027oo00<0
07oo00000P00>goo00<007ooOol03Woo000=Ool00`00Oomoo`14Ool00`007>LLi`067>L4CQH00g`0
GWENMP047>L;HWD2CQH00g`0HWERM@06HWD00`00Oomoo`0=Ool01000GUENEEiF1QcW2V:F00Il07]d
Ne=kM7]CNg@2HYH00g`0Ng@0000:Ool3000nOol00`00Oomoo`0>Ool000eoo`03001oogoo04Eoo`04
001>5TXFCQL2CQH01dXFCQM>5ThFBQI>5g`0008Li`0KHYIRMF:EGWERUV9eHYENMF:FHWERUEieHYIR
MDhFBQI>5g`0HYENMF:FHWERUEieHYIRM@0000moo`0:001JEEifFUENMUYEGWIJEEifFUD77>L03Eie
HYINMG`0Ne=oM7]COgAkDf:FGWEl000000Qoo`<0009oo`03001oogoo03aoo`03001oogoo00ioo`00
3Goo00<007ooOol0AGoo00<004hFCQH02DhF00=l069eHWD03F9e1DhF00=l069eHWD01F9e00<007oo
Ool037oo00@005iEGUIJE@9NE@06GUIJEEiEGUENEUYE0UiE00ANEUYEGUERUP<Li`05O01kM7]CNgAk
D`03HYH00g`0001oo`03Ool40005Ool00`00Oomoo`0lOol00`00Oomoo`0>Ool000aoo`03001oogoo
04Moo`05001>5ThFBQI>5`02CQH05dXFCQM>5ThFO01RUV9eHYENMF:FHWERUEieHYIRMF:EGWERUV9e
HYE:5ThGCQH00QcW00El069eHYENMF:F00<Li`03001oogoo00aoo`0I001NMUYEGWIJEEifFUENMUYE
GWIJEEifFUENMUYEGWIJEEifFUENMUYEO01kDgmdNe<011cW00=l07ooOol00`002Goo00<007ooOol0
?7oo00<007ooOol03Woo000<Ool00`00Oomoo`17Ool00`00CQI>5P09CQH00g`0HWERM@0;HWD47>L0
0dGfBOIl00047>L3IYD00`00Oomoo`0<Ool01P00FUENEEiEGUIJE@9NE@06GUIJEEiEGUENEUYE0UiE
00iNEUYEGUENEEiFO00Lig]CNgAkDg]dGUENEW`00P0037oo00<007ooOol0?7oo00<007ooOol03Woo
000<Ool00`00Oomoo`18Ool01P00CQM>5ThFBQI>5`9>5P0>BQI>5dhFO01NMF:FHWERUEieHYIRMF:E
GWERUP@Li`08IYE9mTGfBOI5mTWfO01ZU@9VU@03IYAZU@0000moo`0N001NMUYEGWIJEEifFUENMUYE
GWIJEEifFUENMUYEGWIJEEifFUENMW`0NhmgKQcWFUENMUYEGWIJEG`03Woo00<007ooOol0?7oo00<0
07ooOol03Woo000<Ool00`00Oomoo`18Ool00`00CQI>5P08CQH017`0HWERMF9e1acW16JE0TGf00E9
mTGfAOI5mW`000EVU@03001oogoo00aoo`05001NEEiEGUIJE@02GUD01UiFFUENEEiEGUIJE@9NE@9o
o`9NE@03GUIJEG`0009kK`07FUENEEiEGUIJEEiEO0003Woo00<007ooOol0?Goo00<007ooOol03Goo
000<Ool00`00Oomoo`19Ool00`00BQI>5`02CQH00dXF7>LLi`027>L01G`07>LLiacWJYD00VJE00IV
U6ZEIYEVUFJDJYD2IYD034GfBOI5mTWfAOI9mTGfO01VU6ZEIYD000moo`0O001JEEifFUENMUYEGWIJ
EEifOomNMUYEGWIJEEifFUENMUYEGWIJEG`0MfikSg]^GWIJEEifFUENMUYEO0003Woo00<007ooOol0
?Goo00<007ooOol03Goo000<Ool00`00Oomoo`19Ool00`007>LLi`037>L3AOH00dWfO01VU@0;IYD0
0dGfIYE9mP03AOH014WfAOI5mW`00fJE00<007ooOol03Goo00<001cW7>L04AcW00=l07]_Nfl011cW
0UiE00=NEW`0Ool03Goo00<007ooOol0?Goo00<007ooOol03Goo000;Ool00`00Oomoo`1;Ool03000
BOI5mTWfAOI9mTGfBOI5mW`0IYAZU@9VU@0>IYAZUFJEIYEVU4WfAOIVUFJDJYE5mTWfAOI9mP<Li`04
O01VUFJE000@Ool06`00ESEJ=EHeFSIF=EXeESEJ=UHeFSEF=EXfESEJ=EHeFSIF=EXeESEl07]^FSEF
=EXfESEJ=@037>L00g`0Oomoo`0<Ool00`00Oomoo`0mOol00`00Oomoo`0=Ool000]oo`03001oogoo
04]oo`030015mTWf00=5mP05BOI5mTGfAOIl0005IYD2AOH5IYD2AOH37>L4?KH00g`0IYD0000@Ool0
1000ESEF=EXe0eHe00EJ=EHeESEF=EXe00=F=@06FSEF=EHeESDLig`00UHe00EJ=EHeESEF=EXe009F
=@03O01oogoo00aoo`03001oogoo03eoo`03001oogoo00eoo`002goo00<007ooOol0C7oo00d004Gf
BOI5mTWfAOI9mTGfBOIl06JEIYAZU@02IYD01fJDJYEVUFJEIYAZUFJE008Li`09@MHm]T7F?KE1eSff
@MIl0000015oo`0O001F=EXfESEJ=EHeFSIF=EXeESEJ=UHeFSEF=EXfESEJ=EHeFSIl05XeESEJ=UHe
FSEF=EXfESEJ=EHeO0003Woo00<007ooOol0?Goo00<007ooOol03Goo000;Ool00`00Oomoo`1=Ool0
0`00AOI9mP03AOH00dWfAOIl000=7>L8?KH00acWO01oo`0@Ool00`00FSEF=@02ESD01EXeESEF=EHe
FSD00eHe00UJ=EHeESEF=EXeESEl05HeFSD00eHe00MJ=EHeESEF=EXeESEl000=Ool00`00Oomoo`0m
Ool00`00Oomoo`0=Ool000]oo`03001oogoo04eoo`0P0019mTGfBOI5mTWfAOI9mW`0K]EZ]6kEJ[A^
eFZdK]EZ]6kEJ[A^eFZdK]Dm]T7F?KE1eSff@MHm]D7F7>Ml015oo`0P001F=EXeESEJ=UHeFSEF=EXf
ESEJ=EHeFSIF=EXeESEJ=UHeFSEl05XfESEJ=EHeFSIF=EXeESEJ=UHeFSEl00eoo`03001oogoo03eo
o`03001oogoo00eoo`002goo00<007ooOol0CWoo00@004GfAOI9mP95mP0?7>Ml06ZdK[EZ]6jeJ[A^
]FZdK[EZ]6jeJ[A^]FZd00Hm]P8Li`03<IHaMW`0011oo`04001F=EHeFSD3ESD01EXeESEF=EHeFSD0
0eHe00EJ=EHeESEF=G`000=F=@03FSEF=EHe00DLi`03O01oogoo00]oo`03001oogoo03ioo`03001o
ogoo00aoo`002goo00<007ooOol0CWoo00<004GfBOH00acW01=1eW`0K]EZ]6kEJ[A^eFZdK]EZ]6kE
J[A^eCffK]Dm]D7F?KI1eP027>L01C5e=IHaMCFFO0003Goo100000]F=EXfESEJ=EHeFSIF=EXeESEJ
=UHe00LLi`03O00LiacW00@Li`06EQIB5EHEDQEF5W`03Goo00<007ooOol0?Woo00<007ooOol037oo
000:Ool00`00Oomoo`1@Ool00`007>Lm]P03?KH03G`0J[A^]FZdK[EZ]6jeJ[A^]CffK[EZ]6je00<m
]P8Li`08=IHaMS6F<GHeUS5f<IIl00Uoo`<000=oo`04001J=EHeESD87>L3DQD01GooDQDLi`06O000
358E00=l07ooOol02Woo00<007ooOol0?Woo00<007ooOol037oo000:Ool00`00Oomoo`1AOol04`00
?KE1eSff@MIl06kEJ[A^eFZd@MIZ]6kEJ[A^eFZdK]EZ]47F008Li`0:<GDeUS5e=IHaMCFF<GDeUS5e
O005Ool40006Ool08@007>LLiacWEQIB5EHEDQEF5U8EEQEB5EHFDQEF5E8E7>L01W`0DQEF5U8EEQEB
5EHFDQEF5E8EEQIB5EHEDQEl000=Ool00`00Oomoo`0mOol00`00Oomoo`0<Ool000Yoo`03001oogoo
059oo`05000m]Sff?KIl00027>L02FZdK[EZ]6jeJ[A^]FZdK[EZ]0027>L03S6F<GHeUS5f<IHaMSFF
<GHaUS5f=IHaMW`0Ool3000:Ool00`00DQEB5@0;DQD01Goo7>L01P06O0003U8E00=l07ooOol02Woo
00<007ooOol0?Goo00<007ooOol037oo000:Ool00`00Oomoo`1COol01000?KE1eW`00W;d1QcW00m^
eFZdK]DaMCFF<GDeUS5e=IHaMCFF<GDeUS5e=IH00QcW00=l0000Ool037oo00l0058EEQIB5EHEDQEF
5U8EEQEB5EHFDQEF5Goo7>L00`0600el058EEQEB5EHFDQEF5E8EEQIB5EHEDQEF5P027>L00g`0Oomo
o`0:Ool00`00Oomoo`0mOol00`00Oomoo`0<Ool000Yoo`03001oogoo05Aoo`03000m]W`000Qbm0@L
i`0?<GHeUS5f<IHaMSFF<GHaUS5f000Lib4f8CDQ=W`000eoo`03001B5E8E00YB5@067>L01P0600HL
ig`01e8E1AcW0Tge00=l07ooOol02Woo00<007ooOol0?Goo00<007ooOol037oo000:Ool00`00Oomo
o`1EOol00`00O01fm003L_@01GKdL_Abm7;dM_@00g;d00PeUS5e=IHaMCFF<GDeUP000QcW00DQ=Qde
8CHM=G`000ioo`0<001F5E8EEQIB5EHEDQEF5U8EEQEB5EHF0P060QcW00=l05HEDQD01QcW0Tge00M=
mTgeCOE=mDgfCOEl000;Ool00`00Oomoo`0nOol00`00Oomoo`0;Ool000Uoo`03001oogoo05Moo`03
O01bm7;d00Ybm00@<GHaUS5f=IHaMP00<GHLib4e8CHQ=B4f8CDQ=R4eO00=Ool00`00DQEB5@09DQD0
1@067>L@310;O0000QcW3Tge00=l07ooOol02Goo00<007ooOol0?Woo00<007ooOol02goo0009Ool0
0`00Oomoo`1GOol017`0L_Abm7Kd0g;d00]fm7;dL_Abm7KdL_@eUS5e=IIbm3FF008Li`097CDQ=Qde
8CHM=B4f7CDQ=W`000eoo`0;001F5U8EEQEB5EHFDQEF5E8E7>MB5@027>L01A0<40/@37`0COH00dge
00E=mTgeCOE=mDgf00==m@06COI=mDgeCOE=mW`02Woo00<007ooOol0?Woo00<007ooOol02goo0009
Ool00`00Oomoo`1GOol00g`07>Mbm00:L_@04C5fL_@aMS6F7>LQ=R4e8CHQ=B4f8CDQ=R4e8CH0U1cW
O00037oo00@0058EDQEB5@DLi`0700HLia0;40`@2a0<O0004Tge00=l07ooOol027oo00<007ooOol0
?Woo00<007ooOol02goo0009Ool00`00Oomoo`1GOol01W`0Nc<LiacWL_Afm0=bm006M_Abm7;d000e
US5e0QcW00dQ=Qde8CHM=B4f7CDQ=Qde8CH0U1cW09Al000<Ool010007>LLiacW0dge00U=mQcW7>L@
2a0<40/@310;O0000dge00E=mTgeCOE=mDgf00==m@04COI=mDgeCOD37>L00g`0Oomoo`07Ool20010
Ool00`00Oomoo`0;Ool000Uoo`03001oogoo05Moo`04O01k<g/cNc<27>L7L_@03S5f7>LQ=B4f8CDQ
=R4e8CHQ=B4f8CDQ=P2D7>L219@00`2DO01oo`0;Ool00`00COE=m@03COD02AcW40`@2a0<40/@32R>
7>Ml000;COD47>L01DGEBME5eDWEO0001Goo0`000Woo00<007ooOol0?Goo00<007ooOol02goo0009
Ool00`00Oomoo`1FOol00g`0Nc=k<`04Nc<27>L3L_@057Kd7>LLiade8CHM=B4f7CDQ=Qde8CHM=B4f
09@Li`2D19@0U0BDO00<Ool01000COE=m@060QcW00D@310;40`@2bR>008Li`0498el04geCOH3COD0
0dgfCOE=m@037>L02TWFAME9eTGEBMI5eDWFAMEl07oo10001Woo00<007ooOol0?7oo00<007ooOol0
2goo0009Ool00`00Oomoo`1FOol00g`0Nc=k<`06Nc<27>L2L_@03B4f8CDQ=R4e8CHQ=B4f8CDQ=R4e
8CH0U1cW0084U00509@4U0BD19Al000<Ool0200000HLia0;40`@2a0<:8h27>L2:8h00g`0COE=m@03
COD47>L02TWEAME9eDGEBME5eDWEAME9eDGE0`002Woo00<007ooOol0?7oo00<007ooOol02goo0008
Ool00`00Oomoo`1GOol00g`0Nc=k<`08Nc<37>L0524f7CDQ=Qde8CHM=B4f7CDQ=Qde7>L0U0BD09@4
U02D19@0U1cWO00;Ool01P007>L@2a0<40/XSP8Li`0698dXSRB=:8il04gf11cW00]5eDWFAME9eTGE
BMI5eDWFAME9eTGE00<00003AME9eW`000]oo`03001oogoo03aoo`03001oogoo00Yoo`0027oo00<0
07ooOol0Egoo00=l07/cNc<02W/c00/Q=R4e8CHQ=B4f8CDQ=R4e8CHQ=AcW0084U00809@4U0BD19@0
U1cW00il00Yoo`05000@310;40`XSP027>L6:8h03W`07>M9eDGEBME5eDWEAME9eDGEBME5eDWEAMD3
00000dGEBME5e@027>L00`00O01oo`0:Ool00`00Oomoo`0kOol00`00Oomoo`0:Ool000Qoo`03001o
ogoo05Moo`03O00Lig/c00Uk<`0G000M=B4f7CDQ=Qde8CHM=B4f7CDLi`2D19@0U0BD09@4U02D19@L
i`0?00il0008Ool0100040`@2bR>0QcW00HTSBR>98dXSRB=:8h27>L02g`0BMI5eDWFAME9eTGEBMI5
eDWFAMD00`0000A5eDWFAME9eP8Li`<00003O01oogoo00Yoo`03001oogoo03Yoo`03001oogoo00Yo
o`0027oo00<007ooOol0Egoo00=l07ma7>L027/c100000LQ=R4e8CHQ=B4f8CDLi`0219@01@2D19@4
U0BD09@00PBD00@Li`0>00il00Moo`03000@32R>008Li`HXSP8Li`09=>ldcW`0AME9eDGEBME5eDWE
00@00004AME9eDGEBMD37>L00d6f0000000300000g`0Oomoo`0:Ool00`00Oomoo`0iOol00`00Oomo
o`0:Ool000Qoo`03001oogoo05Ioo`04O01oLG]`7>L7Nc<00`00Ool00002Ool05@008CHM=B4f7CDL
i`2D19@0U0BD09@4U02D19@0U1cW00h03`0>7>Ml0004Ool00a0<000XSP027>L01RB=:8h002R>98dX
SP8Li`08=<hhkcC>O015eDWFAME9eP<00006BMI5eDWFAME9eTGE0QcW00=1]Sfe@KH01P0000=l07oo
Ool02goo00<007ooOol0>7oo00<007ooOol02Woo0008Ool00`00Oomoo`1FOol01G`0Og1oLGm`7>L0
1G/c00@007ooOol000=oo`8000058CDLi`BD19@0U00319@01@2D19@4U0BD7>L00P0>00<03acWO000
0goo00@@30007>LLi`9oo`<XSP<Li`07=>ldccC_=<hdkg`0BMD00`0000I9eDGEBME5eDWEAMD37>L3
@KD00d6f0000000600000g`0Oomoo`0:Ool00`00Oomoo`0hOol00`00Oomoo`0:Ool000Moo`03001o
ogoo05Moo`06O01oLG]`Og5kL1cW17/c00@007ooOol000Eoo`0E0000U0BD09@4U02D19@0U0BD09@4
U02D7>L03P0?00h03acWO01oo`00008Li`0598dXSRB=:8hTS@027>L01cS_=<hdkcC>>>ldcSC_00<0
0006BMI5eDWFAME9eTGE0acW00Hm]D6f?KE1]Sfe@KH800000acW>IIl000<Ool00`00Oomoo`0gOol0
0`00Oomoo`0:Ool000Moo`03001oogoo05Moo`07O01oL7maOg1oLGm`7>L00W/c00D007ooOomoo`00
00Ioo`8000<4U00809@4U0BD19@0U1cW00h03`<03P037>Ml000000HXSP8Li`06=<ldkcC>=>ldccC_
0`0000LLig`0BME5eDWEAME9e@027>L3@KD01D6f@KE1]D6e@KH01`000QcW0SFF00<iUW`0Ool02goo
00<007ooOol0=goo00<007ooOol02Goo0007Ool00`00Oomoo`1GOol02G`0Og5kL7maNg1oLAcWNc<0
0004Ool00`00Oomoo`06Ool200004`2D19@0U0BD09@4U1cW00l03P0?00h03acWO01QH2R>98dXSRB=
008Li`04=>ldcSS_=<h400001acW?@i13cd>O015eDWF00<Li`09@KHm]D6f?KE1]Sfe@KHm]D6f00H0
008Li`06=IDiUSFE>IHeUG`03Goo00<007ooOol0=Woo00<007ooOol02Goo0007Ool00`00Oomoo`1F
Ool02G`07>MoL7maOg1oLGm`Og400004Ool00`00Oomoo`09Ool200001@BD09@4U0BD7>L00`0>00H0
3`0>7>MUH7`0:8h37>L00cC>=>ldc`0300002CC?7>LLid4??@m13cd?O015e@027>L2@KD01D6f@KE1
]D6e@KH00d6e00=1]P0000000`000QcW00DiUSFF=IHeUSVF00<eUP03O01oogoo00]oo`03001oogoo
03Eoo`03001oogoo00Uoo`001goo00<007ooOol0EWoo00Ql01cWOg5kL7maNg1oL@001Goo00<007oo
Ool02goo0P0000l0U1cW00h03`0>00l03P0?00hLig`0LLDdcSS_=<h00`0001LdcSC_7>LLicd>@@lm
3T4??@i13g`07>Lm]D6f?KE1]Sfe@KHm]D6f?KE1]Sfe00D0008Li`0<=IDiUSFE>IHeUCVF=IDiUSFE
7>LYEW`037oo00<007ooOol0=Goo00<007ooOol02Goo0007Ool00`00Oomoo`1FOol01g`07>MoL7ma
Og1oL@0000Ioo`03001oogoo00eoo`8000803P0800l03P0>00h03acWIF1l00<00003=<ldkacW008L
i`09@@lm3d4??@m13cd?@@lLig`000=1]@05@KI1]D6e@KE1]P03@KD5000011cW=IHeUSVF0cFF00Di
USFF=IHeUQcW008YMP03O01oogoo00]oo`03001oogoo03Aoo`03001oogoo00Uoo`001goo00<007oo
Ool0EGoo00Ml06]:7>MoLG]`Og400007Ool00`00Oomoo`0?Ool200001@0>00l03P0?00h00`0000=]
a775KL@00QcW00Q13cd>@@lm3T4??@i13cd>0QcW00a9;g`0@KHm]D6f?KE1]Sfe@KHm]D6f?KD40002
7>L02CVF=IDiUSFE>IHeUCVF=IDiUP027>L01BUF:GHYERegO0003Goo00<007ooOol0<goo00<007oo
Ool02Goo0006Ool00`00Oomoo`1FOol01W`0JbTLigm`Og4000Qoo`03001oogoo015oo`D0000<7>MU
H7`0LLA]a775KLA13cd?@@lm3d4?11cW00I5;TD_ABil046e@KH3@KD0146f@KE1]D6e0`000QcW0cFF
00DiUSFF=IHeUSVF008eUP037>LYMRUf00@YMP03O01oogoo00aoo`03001oogoo039oo`03001oogoo
00Uoo`001Woo00<007ooOol0EGoo00LLig`0JdXLigmaNg000008Ool00`00Oomoo`0?Ool3000013S_
OoldkcC>0QcW00Q13g`0KLU]a775KLA13cd>0QcW0119;dD^ABm5;TT_ABi5;g`0000m]D6f?KE1]Sfe
@KHm]@80008Li`0E>IHeUCVF=IDiUSFE>IHeUCVF=IDiUQcW;GLYERUf:EH]MbUF:GHYEW`000ioo`03
001oogoo035oo`03001oogoo00Uoo`001Woo00<007ooOol0EGoo00HLig`0JbXLigm`0009Ool00`00
Oomoo`0<Ool4000013C?OoldcSC_0QcW00Dm3d4??@ml06W8009Yb@0ALLE5;QcWABi5;dD^ABm5;TD_
ABi5;dD^O01oo`00@KE1]P03@KD01@007>LLicFF>IH00cFF00DiUSFF=IHeUSVF008eUP037>LYMRUf
00HYMP037>LE5W`000eoo`03001oogoo039oo`03001oogoo00Qoo`001Woo00<007ooOol0E7oo00HL
ig`0JbU[BQcW000:Ool00`00Oomoo`09Ool30002Ool00`00Oolhk`037>L01Woo?@i13cd>@@ml008L
i`0;KLUYb6g9KLA9;dD^ABm5;TT_ABi5;`027>L01g`0Oomoo`00?KE1]Sfe008Li`0<>IHeUCVF=IDi
USFE>IHeUCVF=IDiUSFE0QcW00d]MbUF:GHYEReg:EHYMRUF7>LE5QDG4AIl000=Ool00`00Oomoo`0a
Ool00`00Oomoo`08Ool000Ioo`03001oogoo05Aoo`057>Ml06/ZJbT0000;Ool00`00Oomoo`06Ool3
0004Ool02P007>LLiacW@@lm3d4??@m13cd?0QcW00=l06FZKLT00QcW00IYbFg9JLQ5;dD^ABl37>L0
0de>BDil0003Ool00`00@KDLi`03=IH01CVF=IHeUSFF>IH00cFF00<iUSFF7>L02BUf00HLiaDF5AHE
5QDGO00>Ool00`00Oomoo`0`Ool00`00Oomoo`08Ool000Ioo`03001oogoo05=oo`057>L007`0JbT0
000<Ool00`00Oomoo`02Ool40006Ool02000?@i13cd>@@lm3T4??@h37>L01dD^ABm5;W`0HJYUZfW8
00<Li`09JLQ]bAcWCDi9CTe>BDi=CW`000Aoo`0P000eUCVF=IDiUSFE>IHeUCVF=IDiUSFE>IHeUAcW
:EH]MbUF:GHYEReg:EHYMRUF;GLLiaDG4AHE5aDF5AMl00ioo`03001oogoo02moo`03001oogoo00Qo
o`001Goo00<007ooOol0E7oo0QcW00=l0000Ool037oo00<007oo00000P002Woo00H0044??@m13cd?
@@l27>L034D^ABm5;TD_ABi5;g`0IJ]UZVF[HJYUZ`8Li`08JLQYbFW9CDi9CTe>BDil00Eoo`800005
>IHeUSFF=IHiUP03=IH00cVF=IHLi`0::GH011cW5AHE5QDG0aDF00<0UG`0Ool03Goo00<007ooOol0
;Woo00<007ooOol027oo0005Ool00`00Oomoo`1COol27>L00g`0001oo`0<Ool3000<Ool01000@@lm
3T4?0acW0115;dD^BBm5;TD_ABi9;acWO00LifF[HJYUZf6ZIJ]QZP8Li`06KLU9CTe>BDhLig`01goo
00P003VF=IDiUSFE>IHeUCVF0QcW01DYEReg:EHYMRUF;GLYERUf:EH]MacW5ALA5QDG5AHE5a4F7>L0
U@2FO0003Woo00<007ooOol0;Goo00<007ooOol027oo0005Ool00`00Oomoo`1BOol010007>L01W`0
2goo0`0000=oo`00Ool037oo00/001cW7>LLidD_ABi5;dD^ABm5;TD_00<Li`03O01MRef;00@Li`04
HJYUZfFZIJ/47>L00de=O01oo`07Ool20003=IH00cVF7>LYMP0::GH011cW5AHE5QDG0aDF00<E5acW
09D00P2E00=l07ooOol02goo00<007ooOol0;Goo00<007ooOol027oo0005Ool00`00Oomoo`1BOol0
0acW00Il0009Ool30004Ool00`00Oomoo`0:Ool02@007>M5;dD^BBm5;TD_ABi9;`037>L01De>BDi=
CW`0GH`00Uf;00=IRef<GH/011cW00MUZf6ZIJ]QZU5=CDal0009Ool2000073VF7>LYMRUF;GLYERUf
:EH]MbUF:GHYEReg:EHLia4F5ALE5QDG4AHE5aDF7>L0U@2F09DLig`03Goo00<007ooOol0;Goo00<0
07ooOol01goo0005Ool00`00Oomoo`1AOol011cW00H01W`01Goo10001goo00<007ooOol02Goo00L0
04D^ABm5;TD_ABi5;`037>L01de>BDi=CTU>CDi9CW`0008Li`QMR`@Li`04IJYUZg`07>L:Ool00acW
:GHYMP0::GH00acW5AHE5`035AH011DG5AHE5QcW0`2E00<Li`0@O0003Goo00<007ooOol0;7oo00<0
07ooOol01goo0005Ool00`00Oomoo`1@Ool01AcW00HLiacWO0000Woo0`002goo00<007ooOol02Goo
00@004D_ABi9;`<Li`0<CDi9CTe>BDi=CTU>CDi9CTe>O01IBeE;11cW00EMS5f;GH]IRef<009MR`06
CD`LiacW7>MQZVF[0QcW27oo0P0001XYERUf:EH]MbUF:GHYEReg:EHLia4F5ALE5QDG4AHE5aDF5ALL
i`2F09D0UP2E7>L03g`03Woo00<007ooOol0:goo00<007ooOol01goo0005Ool00`00Oomoo`1>Ool2
7>L010067>LD2G`00`003Woo00<007ooOol027oo00<004D_7>L00QcW00U=CTU>CDi9CTe>BDi=CTU>
CDh00acW00=l05E;ED/015E;1AcW1Uf;00Al01cW7>MUZP8000Qoo`8000HYMP037>LE5QDG00<E5P05
5ALE5QDF5AHLi`0509D00acW011l000>Ool00`00Oomoo`0ZOol00`00Oomoo`07Ool000Aoo`03001o
ogoo04ioo`047>L01QcW7>L3000AOol00`00Oomoo`08Ool02`007>M=CTU>CDi9CTe>BDi=CTU>CDh0
0acW00mACDe=DDel05U<ED]IBeE;FDaEBeU;ED]IC5E;FD/011cW00EIRef<GH]MReV;00<Li`<000Mo
o`80000H:EH]MbUF:GHLiaDG5AHE5a4F5ALE5QDG4AHE5acW09H0U@2F09D0UQcW01003g`03Goo00<0
07ooOol0:Woo00<007ooOol01goo0004Ool00`00Oomoo`1=Ool00acW0000000200000aP9O01oo`0A
Ool00`00Oomoo`08Ool01`00CDi9CTe>BDi=CTU>00@Li`=AC@04CDeACE5=O0037>L<ED/57>L4GH/2
7>L20007Ool200000bUf7>LE5`035AH01QDG5AHE5QDF5ALLi`H0U@057>L03`0@O01HX00=Ool00`00
Oomoo`0YOol00`00Oomoo`07Ool000Aoo`03001oogoo04]oo`<000067>LH2A@960TD2G`04Woo00<0
07ooOol02Goo00<004e>7>L00acW00i=C55=CDeACDe<DDe=CE5=CDal04d:DB]=2U4[21cW00UEBeU;
ED]IC5E;FD]EBeU<ED/01AcW00AIRef<GH/000Qoo`80000F5AHE5a4F5ALE5QDG4AHE5aDF7>L0U@2F
09D0UP2E09HLi`0@00l047`0F:0=Ool00`00Oomoo`0XOol00`00Oomoo`07Ool000Aoo`03001oogoo
04Qoo`<000<Li`0360TD2AP9008Li`03O01oogoo011oo`03001oogoo00Uoo`04000Lie5=CDd3DDd0
1De=DDeACE5=CDd00acW00el04d;C@YA2dd:C@]=2U4;C@Y=2dd:D@]=2P087>L6ED/47>L20008Ool2
00001ADG5AHE5QDF5AL00QDF00<Li`2E09D0102E00PLi`0@01003`0@O01HX5BP37oo00<007ooOol0
:7oo00<007ooOol01Woo0004Ool00`00Oomoo`15Ool30002Ool27>L00a@960TD2@027>L00bQ;92Yl
000BOol00`00Oomoo`0:Ool200001E5=CDaACDe=DDd011cW00=A:eE<O00011cW015A:dd:DB]=2U4[
C@YA:dd:DB]=2U4[C@YA:dd:DB]=2U4[00TLi`04FD`LiacW0009Ool3000051DG5AHE5a4F7>L0U@2F
09D0UP2E09HLi`0@00l0400?7>Ml05RPE:0<Ool00`00Oomoo`0WOol00`00Oomoo`06Ool000Aoo`03
001oogoo049oo`<000Aoo`04000Lia@960T27>L012PZ:4XX:W`04goo00<007ooOol037oo0P000acW
00IEBe5;ED]ABeE;O002A<T00dS9A<U4b@0;7>L03dd;C@YA2dd:C@]=2QcWC@Y=2dd:D@]=2Td;C@YA
2`047>L2000:Ool200000aDF7>L0U@0609D00acW00l0400201001@0?7>Ml05cPE:002goo00<007oo
Ool09goo00<007ooOol01Woo0003Ool00`00Oomoo`0oOol40006Ool27>L02A@960TLibQ;:2XXBb@Z
:4]l000COol00`00Oomoo`0>Ool200005eE<DB]EBe4[ED`Lig`0A<U8bTC9B<U4bDS:A<U8bDC9B<Y4
bDS9A<U8bTC9B<T03QcW00M=2U4[C@YA:dd:DB/0000<Ool300004@2E09H0U@2F09D0UP2E7>L03`0@
00l0400?O01H`ESQG>002goo00<007ooOol09Woo00<007ooOol01Woo0003Ool00`00Oomoo`0lOol3
0009Ool00acW60TD2@027>L01bQ::2XXBRPZ:4XLig`001=oo`03001oogoo011oo`<0008Li`03O00L
idS900=4b@05B<U4bDC9A<U8b@03A<T01DS9A<U4bDC9B<T00dC900E8bDC9A<U4bDS900=4b@03B<U4
bAcW00DLi`03001oogoo00eoo`<000@0U@037>L0400?00<040067>Ml05S1F>5H`EcP2Woo00<007oo
Ool09Goo00<007ooOol01Woo0003Ool00`00Oomoo`0iOol3000:Ool02P007>LH2A@97>LT:RQ;:2XX
Bb@Z0QcW00=l07ooOol04Woo00<007ooOol04goo00@007`0>6HlIa0Li`0BA<U8bDC9B<Y4bDS9A<TL
idC9B<U4bDS:A<U8bDC9B<Y4bDS90P004goo0`0000l0UAcW00l0400?01003`0@O01DXUS1F>5H`AcW
F<402Goo00<007ooOol097oo00<007ooOol01Woo0003Ool00`00Oomoo`0fOol3000<Ool27>L01aP9
7>LLibPZ:4XX:RQ:008Li`03<6XdJW`001=oo`03001oogoo01Aoo`03O00lIcaW008lI`D000XlIa0L
i`8001Qoo`<00080400400l0400@O005D:800acWF<5Hh@08Ool00`00Oomoo`0SOol00`00Oomoo`06
Ool000=oo`03001oogoo03=oo`<000ioo`087>LD2AcW7>LXBb@Z:4/X:P8Li`04=8/`JSB;O00DOol0
0`00Oomoo`0COol00g`07>LLi`087>L:00001CQV?6LlIcaW>6H00caW00HhISaW?6LlI`00?6L20002
O00KOol300003@0?011l04aRB65DXU2RE:9@XUBRD:9HhAcW00Moo`03001oogoo029oo`03001oogoo
00Ioo`000goo00<007ooOol0;goo100047oo00L001@97>LX:RQ::2XXBP027>L01S1Z=6/`JSAZ7>Ml
01Aoo`03001oogoo019oo`0?O00`0c04<0<`1303<0@`0c04<0<`1303<0@`0c0400LLi`X000037>L0
000000X001Uoo`03001l040000900003?018HDQQ0098H@E@XP03F<5oogoo009oo`03001oogoo02=o
o`03001oogoo00Eoo`000Woo00<007ooOol0;Goo0`004goo00H001cW7>LX:RQ;92X27>L013B;<6Xd
Rc1Z0QcW00<lRW`0Ool04goo00<007ooOol047oo0W`001d/0c04;0<`12`3<0@/0c04;0<`12`3<0@/
0c04;0<`12`3<0@/0c04;0<`12`3<0@/0c04;0<`12`300@000aooaT0000BOoml03`0@00l0400?010
03`0@00l0400?01<HTQQE:9@XUBR0goo00<007ooOol08Woo00<007ooOol01Goo0002Ool00`00Oomo
o`0ZOol3000EOol01@007>LXBRPZ:4X00QcW00@`JSAZ<6XdJ`8Li`<hRP03O01oogoo019oo`03001o
ogoo00moo`03O00LiacW01TLi`@001Aoo`Al00TLi`86NP032WXLiacW00<Lia@0008Li`03001oogoo
025oo`03001oogoo00Eoo`000Woo00<007ooOol09goo0`005Woo00D001cW7>LXBbPZ008Li`03=8/`
JSB;00<Li`06?8XhRCb:>8TLig`057oo00<007ooOol03Woo01Ql0200700P01`0800L0200700P01`0
800L0200700P01`0800L0200700P01`08005000LOol2O00S7>L=000IOol00`00Oomoo`05Ool0009o
o`03001oogoo02Aoo`<001Qoo`8Li`07:2XXBQcW7>L`JSA[<6X00QcW1CR:0QcW00<lR7`0Ool04goo
00<007ooOol037oo0W`00b0000DL0200800P01`0008P00XLi`@004Aoo`<000047>L0000000087>L5
000DOol00`00Oomoo`05Ool0009oo`03001oogoo021oo`@001Yoo`037>LXBb@Z008Li`03=8/`JQcW
008Li`04>8TlRSR9?8X37>L01429?8Q0RG`057oo00<007ooOol02goo00=l01cW7>L02QcW00H800`0
200<00P03004001>Ool300000acW0000000200047>L00`00Oomoo`0COol00`00Oomoo`05Ool0009o
o`03001oogoo01eoo`<001eoo`06000XBQcW7>L`JSAZ0QcW13R:0acW00LlRCb8?8PlR3b9?8Ql000D
Ool00`00Oomoo`09Ool2O00?3004001COol00`00Oomoo`0NOol00`00Oomoo`05Ool0009oo`03001o
ogoo01Yoo`<001ioo`80008Li`08=8/`JQcW7>LlRSR9?8XhR@8Li`07@8TlR429?8Q0RCb8@8T00QcW
00=l07ooOol04Woo00<007ooOol01Woo0W`03QcW1000F7oo00<007ooOol07Woo00<007ooOol017oo
00000goo001oo`0IOol3000POol010007>LLic1Z0acW0cR:0acW0cb800<lRCb8?8P00acW00=0ISaV
O00057oo00<007ooOol017oo0W`04000GGoo00<007ooOol07Goo00<007ooOol017oo00000goo001o
o`0FOol3000QOol010007>LLicB;0QcW00@hRCb:>8TlRP8Li`06?8Q0RCb8@8TlR4290acW00I0IcaV
@6LlIQcWO00DOol00`00Oomoo`04O0057>L7001TOol00`00Oomoo`0LOol00`00Oomoo`04Ool00003
Ool007oo019oo`@002=oo`03000LiacW008Li`<hRP<Li`8lR003?8TlR3b800<Li`03@6HlIT1V00@L
i`8l8`037>Ml07oo00moo`9l00037>Ml07`000T006]oo`03001oogoo01aoo`03001oogoo00Aoo`00
00=oo`00Ool03goo0`009Woo00H001cW7>LlRSR9?8X37>L01D29?8Q0RCb8@8T00acW00=0IcaV7>L0
0acW00@l8cPR?2<l8P8Li`8d00037>Ml07`000Qoo`03O00LiacW009l00P0079oo`03001oogoo01]o
o`03001oogoo00Aoo`0000=oo`00Ool037oo0`009goo00<001cW7>L00cR:0QcW0Sb800<lRCb8?8P0
0acW00=0ISaV@6H00QcW1C`S0acW00@d01cW7>LLi`<T0004O00LiacWO0027>L00g`07>LLi`07001h
Ool00`00Oomoo`0JOol00`00Oomoo`04Ool00003Ool007oo00Uoo`<002Uoo`04000Licb:>8T37>L0
13b8@8TlR4290acW00A0IcaV@6LlIP8Li`04?2<h8S`S?2837>L01c@07>LLiacW900X02@000LLi`03
000LiacW00@000Aoo`03001oogoo07Moo`03001oogoo01Uoo`03001oogoo00Aoo`0000<007ooOol0
1Woo0`00:goo00<003R:7>L00QcW00@lR3b9?8PlR0<Li`04@6HlIT1V?6H37>L3?2<77>L290077>L7
0008Ool00`00Oomoo`1hOol00`00Oomoo`0HOol00`00Oomoo`04Ool00003001oogoo009oo`@002eo
o`07000LiacW?8Q0RCb8@8T00acW00=0IcaV@6L011cW00<h8S`S7>L01QcW00<X02@0:0001QcW1P00
3Goo00<007ooOol0NGoo00<007ooOol067oo00<007ooOol00goo00000`00Ool00002000`Ool00`00
7>LlR@02?8P37>L00d1V?6HLi`037>L2?2<47>L013@07>LLiacW0R@00QcW20004goo00<007ooOol0
NGoo00<007ooOol067oo00<007ooOol00goo0002000cOol00`00@8TLi`027>L00d1W7>LLi`027>L0
0c`R?2<Li`037>L00c@07>L00009000KOol00`00Oomoo`1jOol00`00Oomoo`0GOol00`00Oomoo`03
Ool00003Ool00000039oo`04000Lid1V?6H27>L2?2<27>L8000UOol00`00Oomoo`1kOol00`00Oomo
o`0FOol00`00Oomoo`03Ool000=oo`03001oogoo031oo`T002eoo`03001oogoo07aoo`03001oogoo
01Eoo`03001oogoo00=oo`0017oo00<007ooOol0IGoo00<007ooOol0OGoo00<007ooOol057oo00<0
07ooOol00goo0005Ool2001UOol00`00Oomoo`1mOol00`00Oomoo`0DOol00`00Oomoo`03Ool000Mo
o`03001oogoo069oo`03001oogoo07ioo`03001oogoo01Aoo`03001oogoo009oo`0027oo0P00HWoo
00<007ooOol0Ogoo00<007ooOol04goo00<007ooOol00Woo000:Ool00`00Oomoo`1OOol00`00Oomo
o`20Ool00`00Oomoo`0BOol00`00Oomoo`02Ool000]oo`8005ioo`03001oogoo089oo`03001oogoo
015oo`03001oogoo009oo`003Goo00<007ooOol0Fgoo00<007ooOol0PWoo00<007ooOol04Goo00<0
07ooOol00Woo000>Ool00`00Oomoo`1JOol00`00Oomoo`23Ool00`00Oomoo`0@Ool00`00Oomoo`02
Ool000moo`8005Yoo`03001oogoo08Aoo`03001oogoo00moo`03001oogoo009oo`004Goo00<007oo
Ool0Egoo00<007ooOol0QGoo00<007ooOol03Woo00<007ooOol00Woo000BOol2001GOol00`00Oomo
o`26Ool00`00Oomoo`0>Ool00`00Oomoo`01Ool001Aoo`03001oogoo05Aoo`03001oogoo08Moo`03
001oogoo00eoo`03001oogoo005oo`005Goo00<007ooOol0Dgoo00<007ooOol0Qgoo00<007ooOol0
3Goo00<007ooOol00Goo000FOol2001COol00`00Oomoo`28Ool00`00Oomoo`0<Ool00`00Oomoo`01
Ool001Qoo`03001oogoo051oo`03001oogoo08Uoo`03001oogoo00]oo`03001oogoo005oo`006Goo
0P00D7oo00<007ooOol0RWoo00<007ooOol02Woo00<007ooOol00Goo000KOol00`00Oomoo`1=Ool0
0`00Oomoo`2;Ool00`00Oomoo`09Ool00`00Oomoo`01Ool001aoo`8004eoo`03001oogoo08]oo`03
001oogoo00Yoo`40005oo`5oo`007Woo00<007ooOol0BWoo00<007ooOol0S7oo00<007ooOol02Goo
0@000Goo0Goo000OOol00`00Oomoo`19Ool00`00Oomoo`2=Ool00`00Oomoo`08Ool10001Ool1Ool0
021oo`8004Uoo`03001oogoo08ioo`03001oogoo00Moo`40005oo`5oo`008Woo00<007ooOol0AWoo
00<007ooOol0Sgoo00<007ooOol01Woo0@000Goo0Goo000SOol20016Ool00`00Oomoo`2?Ool00`00
Oomoo`06Ool10001Ool1Ool002Eoo`03001oogoo04=oo`03001oogoo091oo`03001oogoo00Eoo`40
005oo`5oo`009Woo0P00@goo00<007ooOol0TGoo00<007ooOol01Goo0@000Goo000XOol00`00Oomo
o`10Ool00`00Oomoo`2BOol00`00Oomoo`04Ool10001Ool002Uoo`03001oogoo03moo`03001oogoo
09=oo`03001oogoo00=oo`40005oo`00:Woo0P00?goo00<007ooOol0U7oo00<007ooOol00Woo0@00
0Goo000/Ool00`00Oomoo`0lOol00`00Oomoo`2DOol00`00Oomoo`02Ool10001Ool002eoo`8003ao
o`03001oogoo09Eoo`05001oogooOol00001Ool002moo`03001oogoo03Uoo`03001oogoo09Ioo`04
001oogoo0001Ool0031oo`03001oogoo03Qoo`03001oogoo09Moo`03001oo`00005oo`00<Goo0P00
=goo00<007ooOol0VGoo0@000Goo0@00000cOol00`00Oomoo`0dOol00`00Oomoo`2IOol10001Ool1
000003Aoo`8003Aoo`03001oogoo09Yoo`800000=Woo00<007ooOol0<Goo00<007ooOol0VGoo0`00
000gOol2000aOol00`00Oomoo`2EOol40003Ool003Uoo`03001oogoo02ioo`03001oogoo091oo`D0
00Moo`00>Woo00<007ooOol0;Goo00<007ooOol0S7oo100037oo000kOol2000]Ool00`00Oomoo`28
Ool4000@Ool003eoo`03001oogoo02Yoo`03001oogoo08=oo`D001Aoo`00?Woo0P00:Woo00<007oo
Ool0Ogoo10006Goo0010Ool00`00Oomoo`0WOol00`00Oomoo`1jOol5000MOol0045oo`03001oogoo
02Ioo`03001oogoo07Ioo`@0029oo`00@Woo0P009Woo00<007ooOol0LWoo10009Woo0014Ool00`00
Oomoo`0SOol00`00Oomoo`1]Ool5000ZOol004Eoo`8002=oo`03001oogoo06Uoo`@002moo`00Agoo
00<007ooOol087oo00<007ooOol0I7oo1@00<goo0018Ool2000POol00`00Oomoo`1POol4000hOol0
04Yoo`03001oogoo01eoo`03001oogoo05]oo`D003aoo`00Bgoo00<007ooOol077oo00<007ooOol0
Egoo1000@Goo001<Ool2000LOol00`00Oomoo`1COol40015Ool004ioo`03001oogoo01Uoo`03001o
ogoo04ioo`D004Uoo`00Cgoo0P006Goo00<007ooOol0BWoo1000CWoo001AOol00`00Oomoo`0FOol0
0`00Oomoo`15Ool5001BOol0059oo`8001Ioo`03001oogoo045oo`@005Moo`00E7oo00<007ooOol0
4goo00<007ooOol0?Goo1000Fgoo001EOol00`00Oomoo`0BOol00`00Oomoo`0hOol5001OOol005Io
o`80015oo`03001oogoo03Eoo`@006Aoo`00F7oo00<007ooOol03Woo00<007ooOol0<7oo1@00J7oo
001IOol2000>Ool00`00Oomoo`0/Ool4001]Ool005]oo`03001oogoo00]oo`03001oogoo02Moo`D0
075oo`00G7oo00<007ooOol02Woo00<007ooOol08goo1000MWoo001MOol2000:Ool00`00Oomoo`0O
Ool4001jOol005moo`03001oogoo00Moo`03001oogoo01Yoo`D007ioo`00H7oo0P001goo00<007oo
Ool05Woo1000Pgoo001ROol00`00Oomoo`04Ool00`00Oomoo`0AOol50027Ool006=oo`8000Aoo`03
001oogoo00eoo`@008aoo`00IGoo00D007ooOomoo`0000]oo`@0091oo`00IWoo00@007ooOol000Io
o`D009Aoo`00Igoo0`000Woo1000VGoo001YOol3002MOol00001
\>"],
  ImageRangeCache->{{{0, 264.313}, {287, 0}} -> {0.0486402, -0.000148683, 
  0.00324458, 0.00324458}}]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[CellGroupData[{

Cell["Reversing Helix: Kappa periodic, Tau constant.", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(clear; top = 180; kappa[s_] := 10\ Sin[s]; tau[s_] := 3.0; ds := 0.1; \n
    \(width = .5; pribbonfrenet\)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.78852 .39007 m .82845 .44879 L .78841 .46253 L .704 .74 .879 r
F
.78852 .39007 m .78841 .46253 L .78917 .39735 L F
.78917 .39735 m .78841 .46253 L .74917 .46699 L .677 .746 .903 r
F
.78917 .39735 m .74917 .46699 L .79065 .40582 L F
.79065 .40582 m .74917 .46699 L .71492 .46156 L .643 .738 .918 r
F
.79065 .40582 m .71492 .46156 L .79207 .41678 L F
.79207 .41678 m .71492 .46156 L .69138 .44668 L .607 .719 .924 r
F
.79207 .41678 m .69138 .44668 L .79098 .43086 L F
.79098 .43086 m .69138 .44668 L .6854 .42572 L .575 .692 .921 r
F
.79098 .43086 m .6854 .42572 L .78418 .44719 L F
.78418 .44719 m .6854 .42572 L .70155 .40657 L .548 .661 .911 r
F
.78418 .44719 m .70441 .40798 L .76938 .4631 L F
.70441 .40798 m .70461 .40826 L .76938 .4631 L F
.70408 .40781 m .70449 .40902 L .76938 .4631 L F
.76938 .4631 m .70601 .41028 L .73634 .4007 L .53 .627 .893 r
F
.70441 .40798 m .70408 .40781 L .70461 .40826 L .548 .661 .911 r
F
.70408 .40781 m .70155 .40657 L .70449 .40902 L F
.70601 .41028 m .70155 .40657 L .73634 .4007 L .53 .627 .893 r
F
.76938 .4631 m .73999 .4076 L .74701 .47463 L F
.73999 .4076 m .73919 .40608 L .73948 .40863 L F
.73999 .4076 m .73948 .40863 L .74701 .47463 L F
.73919 .40608 m .73634 .4007 L .73799 .41215 L F
.73919 .40608 m .73799 .41215 L .74701 .47463 L F
.74842 .47161 m .73634 .4007 L .77375 .41734 L .525 .597 .869 r
F
.74701 .47463 m .74608 .46823 L .74842 .47161 L F
.74608 .46823 m .73634 .4007 L .74842 .47161 L F
.74701 .47463 m .769 .42751 L .72122 .47825 L F
.769 .42751 m .77375 .41734 L .76169 .43133 L F
.769 .42751 m .76169 .43133 L .72122 .47825 L F
.7273 .47616 m .77375 .41734 L .78992 .45466 L .538 .581 .846 r
F
.72526 .47686 m .72687 .4749 L .7273 .47616 L F
.72687 .4749 m .77375 .41734 L .7273 .47616 L F
.72122 .47825 m .7261 .47259 L .72526 .47686 L F
.7261 .47259 m .77375 .41734 L .72526 .47686 L F
.70761 .47497 m .76132 .46171 L .69907 .4729 L F
.72122 .47825 m .76132 .46171 L .70761 .47497 L F
.72122 .47825 m .77821 .45868 L .76132 .46171 L F
.77821 .45868 m .78992 .45466 L .76452 .45976 L F
.77821 .45868 m .76452 .45976 L .69907 .4729 L F
.70618 .47532 m .78992 .45466 L .76864 .49653 L .564 .585 .833 r
F
.69907 .4729 m .70832 .47105 L .70618 .47532 L F
.70832 .47105 m .78992 .45466 L .70618 .47532 L F
.68988 .45171 m .69063 .4514 L .69024 .45014 L .589 .605 .836 r
F
.68766 .46141 m .69063 .4514 L .68988 .45171 L F
.69907 .4729 m .74986 .49015 L .68766 .46141 L .564 .585 .833 r
F
.74986 .49015 m .74734 .48849 L .68766 .46141 L F
.75442 .4917 m .75023 .48855 L .74206 .485 L F
.74734 .48849 m .74206 .485 L .68766 .46141 L F
.75442 .4917 m .74206 .485 L .74734 .48849 L F
.74986 .49015 m .75442 .4917 L .74734 .48849 L F
.75442 .4917 m .76864 .49653 L .75023 .48855 L F
.69082 .46836 m .76864 .49653 L .71491 .52143 L .589 .605 .836 r
F
.68959 .46567 m .69324 .4671 L .69082 .46836 L F
.69324 .4671 m .76864 .49653 L .69082 .46836 L F
.68766 .46141 m .69627 .46515 L .68959 .46567 L F
.69627 .46515 m .76864 .49653 L .68959 .46567 L F
.68766 .46141 m .70675 .50345 L .69063 .4514 L F
.70675 .50345 m .70652 .50083 L .69024 .45014 L F
.70843 .50677 m .70642 .49691 L .69024 .45014 L F
.70885 .50809 m .70844 .50618 L .70843 .50677 L F
.70844 .50618 m .70642 .49691 L .70843 .50677 L F
.70675 .50345 m .70885 .50809 L .70652 .50083 L F
.70885 .50809 m .71491 .52143 L .70642 .49691 L F
.69024 .45014 m .71491 .52143 L .65312 .51604 L .607 .63 .848 r
F
.69024 .45014 m .66515 .49468 L .70307 .44631 L F
.66515 .49468 m .65312 .51604 L .6721 .48954 L F
.66515 .49468 m .6721 .48954 L .70307 .44631 L F
.69677 .4551 m .65312 .51604 L .69359 .45301 L .611 .652 .866 r
F
.69095 .45127 m .65312 .51604 L .61374 .48285 L F
.69359 .45301 m .65312 .51604 L .69095 .45127 L F
.69721 .4545 m .69677 .4551 L .69605 .44918 L F
.69677 .4551 m .69359 .45301 L .69605 .44918 L F
.70307 .44631 m .69721 .4545 L .69605 .44918 L F
.69605 .44918 m .69359 .45301 L .69095 .45127 L F
.70307 .44631 m .64474 .47017 L .71598 .45354 L F
.64474 .47017 m .63994 .47213 L .64712 .47038 L F
.64474 .47017 m .64712 .47038 L .71598 .45354 L F
.63994 .47213 m .64199 .47269 L .71598 .45354 L F
.6327 .4751 m .63391 .47707 L .71598 .45354 L F
.7028 .45732 m .6549 .47105 L .70157 .45194 L .6 .665 .884 r
F
.6327 .4751 m .61374 .48285 L .63391 .47707 L .611 .652 .866 r
F
.6549 .47105 m .61374 .48285 L .65404 .46867 L .6 .665 .884 r
F
.6549 .47105 m .65404 .46867 L .70157 .45194 L F
.63994 .47213 m .6327 .4751 L .64199 .47269 L .611 .652 .866 r
F
.70232 .45168 m .61374 .48285 L .61809 .44019 L .6 .665 .884 r
F
.7024 .45257 m .70157 .45194 L .70232 .45168 L F
.7028 .45732 m .70157 .45194 L .7024 .45257 L F
.71598 .45354 m .7028 .45732 L .70232 .45168 L F
.71598 .45354 m .65426 .44513 L .71797 .46875 L F
.65426 .44513 m .61809 .44019 L .66054 .45233 L F
.65426 .44513 m .66054 .45233 L .71797 .46875 L F
.70928 .46204 m .66199 .45071 L .70932 .46013 L .574 .658 .894 r
F
.66199 .45071 m .61809 .44019 L .66268 .44994 L F
.66199 .45071 m .66268 .44994 L .70932 .46013 L F
.7092 .46624 m .70516 .46509 L .70928 .46204 L F
.70516 .46509 m .61809 .44019 L .70928 .46204 L F
.70932 .46013 m .61809 .44019 L .66408 .41507 L F
.71797 .46875 m .7092 .46624 L .70932 .46013 L F
.71797 .46875 m .68507 .43598 L .7047 .48358 L F
.68507 .43598 m .66408 .41507 L .68213 .44551 L F
.68507 .43598 m .68213 .44551 L .7047 .48358 L F
.70696 .47556 m .68399 .44315 L .72075 .42665 L .543 .629 .887 r
F
.68399 .44315 m .66408 .41507 L .72075 .42665 L F
.69957 .47492 m .66408 .41507 L .70696 .47556 L F
.7047 .48358 m .69957 .47492 L .70696 .47556 L F
.7047 .48358 m .72075 .42665 L .68147 .48991 L F
.68963 .48567 m .72075 .42665 L .69233 .48641 L .533 .593 .86 r
F
.6849 .48439 m .6864 .48197 L .68963 .48567 L F
.6864 .48197 m .72075 .42665 L .68963 .48567 L F
.69233 .48641 m .72075 .42665 L .74667 .46889 L F
.68147 .48991 m .6849 .48439 L .69233 .48641 L F
.68147 .48991 m .72687 .47527 L .65952 .48503 L F
.72687 .47527 m .74667 .46889 L .70864 .47593 L F
.72687 .47527 m .70864 .47593 L .65952 .48503 L F
.66866 .48919 m .74667 .46889 L .72329 .51405 L .555 .583 .837 r
F
.65952 .48503 m .67058 .48298 L .66866 .48919 L F
.67058 .48298 m .74667 .46889 L .66866 .48919 L F
.65952 .48503 m .69756 .50234 L .64905 .47294 L F
.69756 .50234 m .72329 .51405 L .68981 .49551 L F
.69756 .50234 m .68981 .49551 L .64905 .47294 L F
.65043 .47804 m .72329 .51405 L .66608 .53599 L .587 .602 .834 r
F
.64905 .47294 m .65777 .47777 L .65043 .47804 L F
.65777 .47777 m .72329 .51405 L .65043 .47804 L F
.64905 .47294 m .65933 .511 L .65334 .4619 L F
.65933 .511 m .66304 .52477 L .66009 .50565 L F
.65933 .511 m .66009 .50565 L .65334 .4619 L F
.66304 .52477 m .66458 .52727 L .66102 .50662 L F
.66048 .50813 m .66102 .50662 L .65334 .4619 L F
.66304 .52477 m .66102 .50662 L .66048 .50813 L F
.59819 .48485 m .60676 .52638 L .57241 .49438 L .615 .66 .87 r
F
.66304 .52477 m .66608 .53599 L .66458 .52727 L .587 .602 .834 r
F
.65334 .4619 m .66608 .53599 L .60676 .52638 L .609 .632 .848 r
F
.65334 .4619 m .62547 .50047 L .66683 .45947 L F
.62547 .50047 m .62574 .50042 L .66683 .45947 L F
.62492 .50124 m .63294 .49722 L .66683 .45947 L F
.6542 .46414 m .62983 .49611 L .59819 .48485 L .615 .66 .87 r
F
.62547 .50047 m .62492 .50124 L .62574 .50042 L .609 .632 .848 r
F
.62492 .50124 m .60676 .52638 L .63294 .49722 L F
.62983 .49611 m .60676 .52638 L .59819 .48485 L .615 .66 .87 r
F
.66683 .45947 m .65891 .46829 L .6542 .46414 L F
.65891 .46829 m .60676 .52638 L .6542 .46414 L F
.66683 .45947 m .61163 .47988 L .67861 .468 L F
.61163 .47988 m .6122 .48028 L .67861 .468 L F
.60891 .48088 m .6185 .48293 L .67861 .468 L F
.60216 .46114 m .57241 .49438 L .57423 .45864 L .602 .678 .894 r
F
.66564 .46684 m .61717 .48116 L .60216 .46114 L F
.61163 .47988 m .60891 .48088 L .6122 .48028 L .615 .66 .87 r
F
.60891 .48088 m .57241 .49438 L .6185 .48293 L F
.61717 .48116 m .57241 .49438 L .60216 .46114 L .602 .678 .894 r
F
.66499 .47139 m .57241 .49438 L .66564 .46684 L F
.67861 .468 m .66499 .47139 L .66564 .46684 L F
.67861 .468 m .61963 .46271 L .67928 .48347 L F
.61963 .46271 m .61969 .46393 L .67928 .48347 L F
.61459 .46226 m .62002 .46946 L .67928 .48347 L F
.61963 .46271 m .61459 .46226 L .61969 .46393 L F
.61459 .46226 m .57423 .45864 L .62002 .46946 L F
.67078 .47825 m .6151 .46694 L .60456 .43762 L .566 .674 .912 r
F
.67053 .47837 m .57423 .45864 L .67078 .47825 L F
.67019 .48132 m .57423 .45864 L .6712 .47851 L F
.6712 .47851 m .67053 .47837 L .67078 .47825 L F
.67928 .48347 m .67019 .48132 L .6712 .47851 L F
.67928 .48347 m .63882 .45864 L .66617 .49867 L F
.63882 .45864 m .63732 .46037 L .66617 .49867 L F
.63362 .45545 m .63164 .46445 L .66617 .49867 L F
.64852 .45524 m .60456 .43762 L .64244 .44028 L .503 .634 .911 r
F
.66371 .4926 m .63277 .46384 L .64852 .45524 L F
.63882 .45864 m .63362 .45545 L .63732 .46037 L .566 .674 .912 r
F
.63362 .45545 m .60456 .43762 L .63164 .46445 L F
.63277 .46384 m .60456 .43762 L .64852 .45524 L .503 .634 .911 r
F
.66328 .49251 m .60456 .43762 L .66371 .4926 L F
.6611 .49364 m .60456 .43762 L .66391 .49309 L F
.66391 .49309 m .66328 .49251 L .66371 .4926 L F
.66617 .49867 m .6611 .49364 L .66391 .49309 L F
.66617 .49867 m .65173 .46314 L .64337 .50772 L F
.65173 .46314 m .64244 .44028 L .64285 .47016 L F
.65173 .46314 m .64285 .47016 L .64337 .50772 L F
.6456 .50341 m .64372 .4659 L .66676 .46253 L .439 .547 .869 r
F
.64533 .50305 m .64244 .44028 L .6456 .50341 L F
.6433 .50238 m .64244 .44028 L .64537 .50386 L F
.64537 .50386 m .64533 .50305 L .6456 .50341 L F
.64337 .50772 m .6433 .50238 L .64537 .50386 L F
.64337 .50772 m .65756 .48031 L .61793 .50854 L F
.65756 .48031 m .65113 .48171 L .61793 .50854 L F
.66093 .47379 m .64854 .4797 L .61793 .50854 L F
.65756 .48031 m .66093 .47379 L .65113 .48171 L F
.62229 .50714 m .6492 .48015 L .66762 .49264 L .438 .466 .791 r
F
.66093 .47379 m .66676 .46253 L .64854 .4797 L .439 .547 .869 r
F
.6492 .48015 m .66676 .46253 L .66762 .49264 L .438 .466 .791 r
F
.62238 .50671 m .66676 .46253 L .62229 .50714 L F
.62168 .505 m .66676 .46253 L .62179 .5073 L F
.62179 .5073 m .62238 .50671 L .62229 .50714 L F
.61793 .50854 m .62168 .505 L .62179 .5073 L F
.61793 .50854 m .66762 .49264 L .59596 .5026 L F
.60086 .50243 m .66762 .49264 L .59964 .50384 L .508 .462 .74 r
F
.6001 .50399 m .66762 .49264 L .64726 .51979 L F
.59964 .50384 m .60046 .5037 L .6001 .50399 L F
.60046 .5037 m .66762 .49264 L .6001 .50399 L F
.59596 .5026 m .60137 .50185 L .59964 .50384 L F
.60137 .50185 m .60238 .50171 L .60086 .50243 L F
.60238 .50171 m .66762 .49264 L .60086 .50243 L F
.59596 .5026 m .64726 .51979 L .58055 .49321 L F
.58298 .49656 m .64726 .51979 L .61363 .53863 L .588 .515 .739 r
F
.58055 .49321 m .58684 .49572 L .58298 .49656 L F
.58684 .49572 m .64726 .51979 L .58298 .49656 L F
.64372 .4659 m .64244 .44028 L .66676 .46253 L .439 .547 .869 r
F
.6151 .46694 m .57423 .45864 L .60456 .43762 L .566 .674 .912 r
F
.25 g
.5 Mabswid
.67912 .47974 m
.69187 .46194 L
s
1 0 0 r
.003 w
.70606 .52066 m
.71491 .52143 L
s
.59693 .51723 m
.60038 .52045 L
s
.57515 .49693 m
.59693 .51723 L
s
.57241 .49438 m
.57515 .49693 L
s
.62905 .52999 m
.66608 .53599 L
s
.78576 .46283 m
.78841 .46253 L
s
.25 g
.5 Mabswid
.78841 .46253 m
.78847 .45751 L
s
.78854 .45148 m
.78872 .43629 L
s
1 0 0 r
.003 w
.78841 .46253 m
.82845 .44879 L
s
.25 g
.5 Mabswid
.73501 .4499 m
.74279 .44538 L
s
.6749 .46532 m
.69041 .46087 L
s
.66403 .52409 m
.66458 .52727 L
s
.66077 .50515 m
.66403 .52409 L
s
.66044 .50322 m
.66077 .50515 L
s
.6603 .5024 m
.66044 .50322 L
s
.66458 .52727 m
.66608 .53599 L
s
1 0 0 r
.003 w
.66608 .53599 m
.70579 .52077 L
s
.70579 .52077 m
.72329 .51405 L
s
.25 g
.5 Mabswid
.71364 .51775 m
.71491 .52143 L
s
1 0 0 r
.003 w
.71491 .52143 m
.76864 .49653 L
s
.25 g
.5 Mabswid
.78852 .39007 m
.82845 .44879 L
s
.57605 .49347 m
.61479 .48385 L
s
.61479 .48385 m
.6185 .48293 L
s
.6185 .48293 m
.64294 .47686 L
s
.57241 .49438 m
.57605 .49347 L
s
.72934 .44065 m
.74034 .4389 L
s
.76169 .43133 m
.77375 .41734 L
s
.73945 .45712 m
.76169 .43133 L
s
.76452 .45976 m
.78992 .45466 L
s
.76376 .45991 m
.76452 .45976 L
s
.74364 .46395 m
.76376 .45991 L
s
.70285 .45548 m
.7036 .45428 L
s
.71908 .42935 m
.72075 .42665 L
s
.56514 .4714 m .53361 .55113 L .49423 .54737 L .716 .701 .835 r
F
.56739 .47619 m .53361 .55113 L .56514 .4714 L .692 .645 .798 r
F
.56739 .47619 m .57422 .54859 L .53361 .55113 L F
.25 g
.73634 .4007 m
.73799 .41215 L
s
.73799 .41215 m
.74376 .45212 L
s
0 g
.006 w
.66179 .5004 m
.66617 .49867 L
s
.57169 .48368 m .57422 .54859 L .56739 .47619 L .65 .581 .764 r
F
1 0 0 r
.003 w
.57416 .45998 m
.57423 .45864 L
s
.57169 .48368 m .61363 .53863 L .57422 .54859 L .65 .581 .764 r
F
1 0 0 r
.53361 .55113 m
.57422 .54859 L
s
.25 g
.5 Mabswid
.60201 .50176 m
.60311 .50161 L
s
.74296 .48539 m
.76787 .4962 L
s
.74206 .485 m
.74296 .48539 L
s
.73901 .48368 m
.74206 .485 L
s
.76787 .4962 m
.76864 .49653 L
s
.56308 .46868 m .49423 .54737 L .4586 .53679 L .726 .748 .87 r
F
.56514 .4714 m .49423 .54737 L .56308 .46868 L .716 .701 .835 r
F
.25 g
.53361 .55113 m
.544 .52486 L
s
1 0 0 r
.003 w
.49423 .54737 m
.53361 .55113 L
s
.58055 .49321 m .61363 .53863 L .57169 .48368 L .588 .515 .739 r
F
.25 g
.5 Mabswid
.58055 .49321 m
.58551 .49519 L
s
.58551 .49519 m
.58684 .49572 L
s
.58684 .49572 m
.62339 .51028 L
s
1 0 0 r
.003 w
.57422 .54859 m
.61363 .53863 L
s
.5731 .48088 m
.57416 .45998 L
s
.57289 .48498 m
.5731 .48088 L
s
0 g
.006 w
.57169 .48368 m
.58055 .49321 L
s
.25 g
.5 Mabswid
.72553 .43444 m
.73834 .43723 L
s
1 0 0 r
.003 w
.68992 .42035 m
.70155 .40657 L
s
.25 g
.5 Mabswid
.69152 .49646 m
.71248 .50807 L
s
.68981 .49551 m
.69152 .49646 L
s
.67565 .48767 m
.68981 .49551 L
s
.71248 .50807 m
.72329 .51405 L
s
.67154 .42764 m
.68142 .44431 L
s
.66408 .41507 m
.67154 .42764 L
s
1 0 0 r
.003 w
.76933 .49516 m
.78992 .45466 L
s
.76864 .49653 m
.76933 .49516 L
s
.25 g
.5 Mabswid
.57535 .48848 m
.61363 .53863 L
s
.57169 .48368 m
.57535 .48848 L
s
.60456 .43762 m
.62853 .46137 L
s
0 g
.006 w
.66617 .49867 m
.67928 .48347 L
s
.25 g
.5 Mabswid
.70155 .40657 m
.70601 .41028 L
s
.70601 .41028 m
.74206 .44033 L
s
.65337 .45028 m
.65892 .45187 L
s
.65892 .45187 m
.66054 .45233 L
s
.66054 .45233 m
.69141 .46116 L
s
1 0 0 r
.003 w
.62073 .43875 m
.66408 .41507 L
s
.25 g
.5 Mabswid
.57423 .45864 m
.61564 .46842 L
s
.61564 .46842 m
.61996 .46945 L
s
.61996 .46945 m
.64192 .47464 L
s
1 0 0 r
.003 w
.57423 .45864 m
.60456 .43762 L
s
.56072 .46661 m .4586 .53679 L .43187 .5173 L .721 .78 .899 r
F
.25 g
.5 Mabswid
.49423 .54737 m
.51493 .52371 L
s
.544 .52486 m
.54578 .52036 L
s
.56308 .46868 m .4586 .53679 L .56072 .46661 L .726 .748 .87 r
F
1 0 0 r
.003 w
.4586 .53679 m
.49423 .54737 L
s
.25 g
.5 Mabswid
.56111 .47093 m
.56308 .46868 L
s
0 g
.006 w
.66398 .45999 m
.66683 .45947 L
s
.78541 .44425 m
.79092 .43098 L
s
.79092 .43098 m
.79098 .43086 L
s
.64744 .47843 m .60383 .54649 L .49796 .54159 L .685 .786 .927 r
F
0 g
.56739 .47619 m
.57169 .48368 L
s
.25 g
.5 Mabswid
.56781 .48068 m
.57066 .51087 L
s
.57389 .5451 m
.57422 .54859 L
s
.56739 .47619 m
.56781 .48068 L
s
.67 .46413 m .60383 .54649 L .64744 .47843 L .693 .787 .923 r
F
.67 .46413 m .72694 .5051 L .60383 .54649 L F
.25 g
.65493 .47368 m
.66676 .46253 L
s
.64244 .44028 m
.64279 .46604 L
s
.62853 .46137 m
.63164 .46445 L
s
.63164 .46445 m
.64293 .47563 L
s
.64279 .46604 m
.64299 .48031 L
s
0 g
.006 w
.67861 .468 m
.67871 .4704 L
s
.25 g
.5 Mabswid
.68142 .44431 m
.69528 .46768 L
s
.689 .47779 m
.70285 .45548 L
s
.69096 .47921 m
.70864 .47593 L
s
.70864 .47593 m
.73206 .4716 L
s
0 g
.006 w
.78852 .39007 m
.78917 .39735 L
s
.56514 .4714 m
.56739 .47619 L
s
.66683 .45947 m
.67861 .468 L
s
.79098 .43086 m
.79207 .41678 L
s
.65748 .49488 m .59932 .56237 L .49979 .55059 L .679 .788 .932 r
F
1 0 0 r
.003 w
.52019 .54262 m
.52209 .54271 L
s
.25 g
.5 Mabswid
.54578 .52036 m
.56514 .4714 L
s
.63568 .52644 m .59932 .56237 L .62817 .52889 L .689 .794 .929 r
F
.68144 .48124 m .72992 .52391 L .59932 .56237 L F
.66556 .54018 m .62015 .58731 L .56147 .5911 L .647 .827 .969 r
F
.67469 .53572 m .67121 .53901 L .66556 .54018 L F
.67121 .53901 m .62015 .58731 L .66556 .54018 L F
.65126 .54691 m .56147 .5911 L .52106 .58425 L .62 .804 .971 r
F
.67469 .53572 m .56147 .5911 L .65552 .54569 L .647 .827 .969 r
F
.65552 .54569 m .6539 .54647 L .65126 .54691 L .62 .804 .971 r
F
.6539 .54647 m .56147 .5911 L .65126 .54691 L F
.65552 .54569 m .52106 .58425 L .63866 .55359 L F
.63866 .55359 m .52106 .58425 L .49886 .57029 L .598 .765 .959 r
F
.50205 .56991 m .5015 .57009 L .51998 .56866 L F
.52127 .56845 m .51998 .56866 L .62342 .56071 L F
.50205 .56991 m .51998 .56866 L .52127 .56845 L F
.63866 .55359 m .55065 .5641 L .62342 .56071 L F
.55065 .5641 m .50205 .56991 L .53462 .56744 L F
.55065 .5641 m .53462 .56744 L .62342 .56071 L F
.50205 .56991 m .49886 .57029 L .5015 .57009 L F
.68144 .48124 m .63568 .52644 L .65748 .49488 L .689 .794 .929 r
F
.63568 .52644 m .62817 .52889 L .65748 .49488 L F
.25 g
.60324 .55782 m
.61473 .54449 L
s
1 0 0 r
.003 w
.50753 .5515 m
.51947 .55292 L
s
.51947 .55292 m
.5712 .55905 L
s
.5712 .55905 m
.58215 .56034 L
s
0 g
.006 w
.78917 .39735 m
.79065 .40582 L
s
.69465 .52267 m .62015 .58731 L .67469 .53572 L .675 .834 .96 r
F
.69465 .52267 m .69382 .56891 L .62015 .58731 L F
.25 g
.5 Mabswid
.67121 .53901 m
.67469 .53572 L
s
1 0 0 r
.003 w
.56147 .5911 m
.62015 .58731 L
s
.70155 .40657 m
.73634 .4007 L
s
0 g
.006 w
.79065 .40582 m
.79207 .41678 L
s
.25 g
.5 Mabswid
.56147 .5911 m
.58009 .58211 L
s
1 0 0 r
.003 w
.52106 .58425 m
.56147 .5911 L
s
0 g
.006 w
.56308 .46868 m
.56514 .4714 L
s
.67808 .44698 m .72694 .5051 L .67 .46413 L .698 .778 .914 r
F
.68957 .46443 m .72992 .52391 L .68144 .48124 L .697 .787 .92 r
F
.7114 .50661 m .69382 .56891 L .69465 .52267 L .696 .826 .945 r
F
.67808 .44698 m .80815 .43755 L .72694 .5051 L .698 .778 .914 r
F
.68957 .46443 m .82058 .45159 L .72992 .52391 L .697 .787 .92 r
F
.7114 .50661 m .77216 .53327 L .69382 .56891 L .696 .826 .945 r
F
1 0 0 r
.003 w
.62015 .58731 m
.69382 .56891 L
s
.25 g
.5 Mabswid
.69382 .56891 m
.69465 .52267 L
s
.55916 .46357 m .43187 .5173 L .42344 .48636 L .708 .794 .918 r
F
.25 g
.4586 .53679 m
.48428 .51915 L
s
.51493 .52371 m
.51638 .52205 L
s
.56072 .46661 m .43187 .5173 L .55916 .46357 L .721 .78 .899 r
F
.25 g
.55765 .46872 m
.56072 .46661 L
s
1 0 0 r
.003 w
.43187 .5173 m
.4586 .53679 L
s
.62271 .48369 m .49796 .54159 L .46815 .48958 L .678 .776 .925 r
F
.25 g
.5 Mabswid
.43187 .5173 m
.47387 .49957 L
s
.48428 .51915 m
.48487 .51874 L
s
.64744 .47843 m .49796 .54159 L .62271 .48369 L .685 .786 .927 r
F
1 0 0 r
.003 w
.49796 .54159 m
.52019 .54262 L
s
.25 g
.5 Mabswid
.54743 .48656 m
.56111 .47093 L
s
.53077 .48719 m
.55765 .46872 L
s
.50044 .48835 m
.55802 .46405 L
s
.49796 .54159 m
.53099 .52626 L
s
1 0 0 r
.003 w
.77375 .41734 m
.78329 .43936 L
s
.7893 .45324 m
.78989 .4546 L
s
.60456 .43762 m
.64244 .44028 L
s
.66676 .46253 m
.66687 .46611 L
s
.25 g
.5 Mabswid
.67 .46413 m
.68463 .47465 L
s
.70955 .4447 m
.71363 .43813 L
s
.71363 .43813 m
.71908 .42935 L
s
1 0 0 r
.003 w
.78737 .45484 m
.79856 .44553 L
s
.79856 .44553 m
.80643 .43899 L
s
.72075 .42665 m
.73088 .44315 L
s
0 g
.006 w
.56072 .46661 m
.56308 .46868 L
s
.25 g
.5 Mabswid
.52106 .58425 m
.54253 .57866 L
s
1 0 0 r
.003 w
.66408 .41507 m
.72075 .42665 L
s
.25 g
.5 Mabswid
.68144 .48124 m
.71085 .50713 L
s
1 0 0 r
.003 w
.73634 .4007 m
.77375 .41734 L
s
.6332 .49865 m .49979 .55059 L .48264 .49632 L .673 .774 .926 r
F
1 0 0 r
.48999 .52769 m
.4957 .53765 L
s
.65748 .49488 m .49979 .55059 L .6332 .49865 L .679 .788 .932 r
F
1 0 0 r
.49979 .55059 m
.50753 .5515 L
s
.25 g
.5 Mabswid
.61473 .54449 m
.62817 .52889 L
s
.62817 .52889 m
.65748 .49488 L
s
.63462 .49843 m
.64744 .47843 L
s
.53353 .53745 m
.55117 .53059 L
s
.49979 .55059 m
.53353 .53745 L
s
.6539 .54647 m
.65552 .54569 L
s
1 0 0 r
.003 w
.64244 .44028 m
.66676 .46253 L
s
.71919 .48938 m .77216 .53327 L .7114 .50661 L .706 .808 .928 r
F
.71919 .48938 m .83501 .4822 L .77216 .53327 L F
1 0 0 r
.69382 .56891 m
.77216 .53327 L
s
.25 g
.5 Mabswid
.7114 .50661 m
.77216 .53327 L
s
.62342 .56071 m .49886 .57029 L .4943 .55199 L .587 .713 .93 r
F
.25 g
.49886 .57029 m
.5015 .57009 L
s
.5015 .57009 m
.51998 .56866 L
s
.51998 .56866 m
.53386 .5676 L
s
.53386 .5676 m
.54247 .56694 L
s
1 0 0 r
.003 w
.49886 .57029 m
.52106 .58425 L
s
.55916 .46357 m .42344 .48636 L .56092 .45823 L .708 .794 .918 r
F
0 g
.006 w
.55916 .46357 m
.56072 .46661 L
s
.25 g
.5 Mabswid
.55802 .46405 m
.55916 .46357 L
s
.56092 .45823 m .42344 .48636 L .44626 .44372 L .692 .792 .926 r
F
1 0 0 r
.003 w
.42344 .48636 m
.43187 .5173 L
s
.56092 .45823 m .44626 .44372 L .56918 .45022 L .692 .792 .926 r
F
0 g
.006 w
.55916 .46357 m
.56092 .45823 L
s
.25 g
.5 Mabswid
.42344 .48636 m
.56092 .45823 L
s
.62342 .56071 m .4943 .55199 L .60771 .56797 L .587 .713 .93 r
F
.60771 .56797 m .4943 .55199 L .5073 .53214 L .585 .655 .886 r
F
.25 g
.4943 .55199 m
.51201 .55449 L
s
.51201 .55449 m
.5241 .55619 L
s
.5241 .55619 m
.53216 .55732 L
s
1 0 0 r
.003 w
.4943 .55199 m
.49886 .57029 L
s
.25 g
.5 Mabswid
.54253 .57866 m
.59201 .56575 L
s
.58009 .58211 m
.6539 .54647 L
s
.54247 .56694 m
.57994 .56405 L
s
1 0 0 r
.003 w
.48738 .51133 m
.4983 .54588 L
s
.25 g
.5 Mabswid
.62015 .58731 m
.67121 .53901 L
s
0 g
.006 w
.64744 .47843 m
.67 .46413 L
s
.62271 .48369 m .46815 .48958 L .61039 .47795 L .678 .776 .925 r
F
0 g
.62271 .48369 m
.64744 .47843 L
s
.25 g
.5 Mabswid
.59184 .49801 m
.62271 .48369 L
s
.56918 .45022 m .51131 .39517 L .5864 .44062 L .682 .78 .925 r
F
.56918 .45022 m .44626 .44372 L .51131 .39517 L F
0 g
.006 w
.56092 .45823 m
.56918 .45022 L
s
1 0 0 r
.003 w
.42344 .48636 m
.44626 .44372 L
s
0 g
.006 w
.65748 .49488 m
.68144 .48124 L
s
.63866 .55359 m
.65552 .54569 L
s
.65552 .54569 m
.67469 .53572 L
s
.67469 .53572 m
.69465 .52267 L
s
.6332 .49865 m .48264 .49632 L .62341 .49181 L .673 .774 .926 r
F
0 g
.6332 .49865 m
.65748 .49488 L
s
.25 g
.5 Mabswid
.55117 .53059 m
.6332 .49865 L
s
.66735 .43388 m .80815 .43755 L .67808 .44698 L .695 .766 .906 r
F
.66735 .43388 m .80919 .37477 L .80815 .43755 L F
1 0 0 r
.003 w
.80643 .43899 m
.80815 .43755 L
s
.61039 .47795 m .46815 .48958 L .54445 .41619 L .677 .764 .916 r
F
1 0 0 r
.46815 .48958 m
.48999 .52769 L
s
0 g
.006 w
.62342 .56071 m
.63866 .55359 L
s
.61039 .47795 m .54445 .41619 L .61929 .46534 L .677 .764 .916 r
F
0 g
.61039 .47795 m
.62271 .48369 L
s
.25 g
.5 Mabswid
.46815 .48958 m
.61039 .47795 L
s
.71286 .47469 m .83501 .4822 L .71919 .48938 L .707 .786 .913 r
F
.67521 .45361 m .82058 .45159 L .68957 .46443 L .697 .773 .91 r
F
.67521 .45361 m .809 .38502 L .82058 .45159 L F
.71286 .47469 m .85388 .42614 L .83501 .4822 L .707 .786 .913 r
F
1 0 0 r
.003 w
.77216 .53327 m
.83501 .4822 L
s
.25 g
.5 Mabswid
.71919 .48938 m
.83501 .4822 L
s
.67808 .44698 m
.6898 .44613 L
s
0 g
.006 w
.69465 .52267 m
.7114 .50661 L
s
.60771 .56797 m .5073 .53214 L .5891 .57542 L .585 .655 .886 r
F
.5891 .57542 m .5073 .53214 L .53697 .51472 L .59 .606 .837 r
F
.25 g
.5 Mabswid
.5073 .53214 m
.58721 .57442 L
s
1 0 0 r
.003 w
.4943 .55199 m
.5073 .53214 L
s
.25 g
.5 Mabswid
.53216 .55732 m
.56315 .56169 L
s
0 g
.006 w
.60771 .56797 m
.62342 .56071 L
s
.5864 .44062 m .61591 .35538 L .61233 .43225 L .679 .767 .918 r
F
.5864 .44062 m .51131 .39517 L .61591 .35538 L F
0 g
.58383 .44205 m
.5864 .44062 L
s
.5891 .57542 m .53697 .51472 L .56604 .58203 L .59 .606 .837 r
F
0 g
.5891 .57542 m
.60771 .56797 L
s
.67 .46413 m
.67808 .44698 L
s
.56604 .58203 m .53697 .51472 L .57813 .50548 L .599 .573 .795 r
F
.56604 .58203 m .57813 .50548 L .53911 .58577 L F
0 g
.56604 .58203 m
.5891 .57542 L
s
.53911 .58577 m .57813 .50548 L .61808 .51059 L .611 .554 .765 r
F
.53911 .58577 m .61808 .51059 L .51192 .58423 L F
0 g
.53911 .58577 m
.56604 .58203 L
s
.62341 .49181 m .55938 .42842 L .63438 .47939 L .674 .76 .916 r
F
.62341 .49181 m .48264 .49632 L .55938 .42842 L F
0 g
.62341 .49181 m
.6332 .49865 L
s
.25 g
.5 Mabswid
.48264 .49632 m
.62341 .49181 L
s
.44626 .44372 m
.51221 .44721 L
s
1 0 0 r
.003 w
.48264 .49632 m
.48738 .51133 L
s
0 g
.006 w
.7114 .50661 m
.71919 .48938 L
s
.51192 .58423 m .61808 .51059 L .63748 .53264 L .625 .547 .746 r
F
.51192 .58423 m .63174 .535 L .49081 .57583 L F
.63174 .535 m .63131 .53504 L .49081 .57583 L F
.63131 .53504 m .62817 .53538 L .6254 .5362 L F
.63131 .53504 m .6254 .5362 L .49081 .57583 L F
.63174 .535 m .63748 .53264 L .62817 .53538 L F
.49081 .57583 m .63748 .53264 L .61895 .56619 L .641 .552 .738 r
F
.49081 .57583 m .60338 .56736 L .48279 .56124 L F
.60338 .56736 m .61895 .56619 L .597 .56539 L F
.60338 .56736 m .597 .56539 L .48279 .56124 L F
.48709 .56323 m .61895 .56619 L .56018 .597 L .658 .569 .743 r
F
.48279 .56124 m .49498 .56168 L .48709 .56323 L F
.49498 .56168 m .61895 .56619 L .48709 .56323 L F
.48279 .56124 m .54608 .59048 L .4919 .54418 L F
.54608 .59048 m .56018 .597 L .54428 .5847 L F
.54608 .59048 m .54428 .5847 L .4919 .54418 L F
.49091 .55019 m .54311 .58547 L .4814 .60812 L .673 .595 .76 r
F
.54311 .58547 m .56018 .597 L .4814 .60812 L F
.4919 .54418 m .49859 .54936 L .49091 .55019 L F
.49859 .54936 m .56018 .597 L .49091 .55019 L F
.4919 .54418 m .48382 .59335 L .51542 .53076 L F
.48382 .59335 m .4814 .60812 L .49115 .58595 L F
.48382 .59335 m .49115 .58595 L .51542 .53076 L F
.50516 .53704 m .4814 .60812 L .41916 .58966 L .68 .623 .784 r
F
.51542 .53076 m .51176 .53908 L .50516 .53704 L F
.51176 .53908 m .4814 .60812 L .50516 .53704 L F
.51542 .53076 m .43909 .57747 L .54268 .52678 L F
.43909 .57747 m .44456 .57601 L .54268 .52678 L F
.42743 .5846 m .43055 .58386 L .4377 .58022 L F
.43596 .58032 m .4377 .58022 L .54268 .52678 L F
.42743 .5846 m .4377 .58022 L .43596 .58032 L F
.52698 .52909 m .45638 .56875 L .40849 .54652 L .678 .642 .807 r
F
.43909 .57747 m .42743 .5846 L .44456 .57601 L .68 .623 .784 r
F
.42743 .5846 m .41916 .58966 L .43055 .58386 L F
.45638 .56875 m .41916 .58966 L .40849 .54652 L .678 .642 .807 r
F
.54268 .52678 m .52851 .534 L .52698 .52909 L F
.52851 .534 m .41916 .58966 L .52698 .52909 L F
.54268 .52678 m .44955 .54048 L .55904 .53399 L F
.44955 .54048 m .40849 .54652 L .46337 .54195 L F
.44955 .54048 m .46337 .54195 L .55904 .53399 L F
.54683 .52965 m .4298 .54392 L .46136 .49925 L .667 .647 .82 r
F
.55904 .53399 m .54106 .53549 L .54683 .52965 L F
.54106 .53549 m .40849 .54652 L .54683 .52965 L F
.55904 .53399 m .49423 .51094 L .55429 .54792 L F
.49423 .51094 m .49521 .51286 L .55429 .54792 L F
.48858 .50893 m .48929 .51387 L .49805 .51847 L F
.49521 .51286 m .49805 .51847 L .55429 .54792 L F
.48858 .50893 m .49805 .51847 L .49521 .51286 L F
.55429 .54792 m .54967 .5455 L .55411 .54227 L .653 .635 .819 r
F
.48858 .50893 m .46136 .49925 L .48929 .51387 L .667 .647 .82 r
F
.54967 .5455 m .46136 .49925 L .55411 .54227 L .653 .635 .819 r
F
.49423 .51094 m .48858 .50893 L .49521 .51286 L .667 .647 .82 r
F
.55411 .54227 m .46136 .49925 L .55194 .47534 L .653 .635 .819 r
F
.55429 .54792 m .55279 .50161 L .53008 .55975 L F
.55279 .50161 m .54914 .50494 L .53008 .55975 L F
.55258 .49503 m .54312 .50941 L .53008 .55975 L F
.55258 .49503 m .55194 .47534 L .54312 .50941 L F
.54119 .55025 m .55194 .47534 L .54427 .54943 L .641 .61 .803 r
F
.5319 .55273 m .53277 .54935 L .54119 .55025 L F
.53277 .54935 m .55194 .47534 L .54119 .55025 L F
.55279 .50161 m .55258 .49503 L .54914 .50494 L .653 .635 .819 r
F
.54427 .54943 m .55194 .47534 L .62434 .4912 L .641 .61 .803 r
F
.53008 .55975 m .5319 .55273 L .54427 .54943 L F
.53008 .55975 m .5141 .5535 L .49992 .56151 L F
.53008 .55975 m .58845 .5173 L .5141 .5535 L F
.58845 .5173 m .57015 .52183 L .5141 .5535 L F
.5141 .5535 m .51545 .55273 L .51009 .55959 L .637 .582 .776 r
F
.51545 .55273 m .51687 .55553 L .51009 .55959 L F
.51009 .55959 m .51687 .55553 L .51816 .55807 L F
.58845 .5173 m .62434 .4912 L .57015 .52183 L .641 .61 .803 r
F
.51545 .55273 m .62434 .4912 L .51687 .55553 L .637 .582 .776 r
F
.51816 .55807 m .62434 .4912 L .62958 .53706 L F
.51687 .55553 m .62434 .4912 L .51816 .55807 L F
.49992 .56151 m .5141 .5535 L .51009 .55959 L F
.49992 .56151 m .57877 .54664 L .48136 .55115 L F
.57877 .54664 m .62546 .53783 L .56448 .54347 L F
.57877 .54664 m .56448 .54347 L .48136 .55115 L F
.49536 .55641 m .56622 .54619 L .56401 .58219 L .646 .57 .754 r
F
.62546 .53783 m .62958 .53706 L .62819 .53719 L .637 .582 .776 r
F
.62546 .53783 m .62819 .53719 L .59637 .54022 L F
.59656 .54051 m .59637 .54022 L .48136 .55115 L F
.62546 .53783 m .59637 .54022 L .59656 .54051 L F
.50024 .54936 m .62958 .53706 L .49332 .55564 L .646 .57 .754 r
F
.49332 .55564 m .49522 .55539 L .49536 .55641 L F
.49522 .55539 m .62958 .53706 L .49536 .55641 L F
.48136 .55115 m .50024 .54936 L .49332 .55564 L F
.48136 .55115 m .53122 .56988 L .48527 .53399 L F
.53122 .56988 m .53005 .5653 L .48527 .53399 L F
.48306 .54335 m .52627 .56409 L .47021 .59777 L .665 .586 .756 r
F
.53122 .56988 m .54286 .57425 L .53005 .5653 L .646 .57 .754 r
F
.54286 .57425 m .56401 .58219 L .55034 .57382 L F
.54286 .57425 m .55034 .57382 L .48527 .53399 L F
.52627 .56409 m .56401 .58219 L .47021 .59777 L .665 .586 .756 r
F
.48527 .53399 m .49553 .54027 L .48306 .54335 L F
.49553 .54027 m .56401 .58219 L .48306 .54335 L F
.48527 .53399 m .4762 .57239 L .50888 .51968 L F
.4762 .57239 m .47021 .59777 L .48745 .56296 L F
.4762 .57239 m .48745 .56296 L .50888 .51968 L F
.49363 .52776 m .48107 .56532 L .40426 .5751 L .679 .619 .781 r
F
.50888 .51968 m .50377 .53 L .49363 .52776 L F
.50377 .53 m .47021 .59777 L .49363 .52776 L F
.4298 .54392 m .40849 .54652 L .42891 .52826 L .667 .647 .82 r
F
.4298 .54392 m .42891 .52826 L .46136 .49925 L F
.50888 .51968 m .44592 .55303 L .53706 .51623 L .679 .619 .781 r
F
.44592 .55303 m .44695 .55279 L .53706 .51623 L F
.44452 .55378 m .45609 .55212 L .53706 .51623 L F
.51795 .51788 m .4565 .54881 L .4019 .52788 L .679 .646 .809 r
F
.44592 .55303 m .44452 .55378 L .44695 .55279 L .679 .619 .781 r
F
.44452 .55378 m .40426 .5751 L .45609 .55212 L F
.4565 .54881 m .40426 .5751 L .4019 .52788 L .679 .646 .809 r
F
.53706 .51623 m .51951 .52401 L .51795 .51788 L F
.51951 .52401 m .40426 .5751 L .51795 .51788 L F
.53706 .51623 m .45579 .52323 L .55185 .52486 L F
.45579 .52323 m .4019 .52788 L .46883 .52653 L F
.45579 .52323 m .46883 .52653 L .55185 .52486 L F
.53965 .51917 m .4019 .52788 L .46115 .48257 L .667 .653 .827 r
F
.55185 .52486 m .5324 .52525 L .53965 .51917 L F
.5324 .52525 m .4019 .52788 L .53965 .51917 L F
.55185 .52486 m .49869 .50007 L .54403 .53934 L F
.49869 .50007 m .49736 .49945 L .49851 .50044 L F
.49869 .50007 m .49851 .50044 L .54403 .53934 L F
.49736 .49945 m .49772 .50297 L .54403 .53934 L F
.48722 .49472 m .49569 .50623 L .54403 .53934 L F
.54422 .52968 m .49852 .50376 L .54551 .46297 L .648 .639 .827 r
F
.49736 .49945 m .48722 .49472 L .49772 .50297 L .667 .653 .827 r
F
.48722 .49472 m .46115 .48257 L .49569 .50623 L F
.49852 .50376 m .46115 .48257 L .54551 .46297 L .648 .639 .827 r
F
.5336 .5322 m .46115 .48257 L .54422 .52968 L F
.54403 .53934 m .5336 .5322 L .54422 .52968 L F
.54403 .53934 m .54487 .49587 L .51806 .55044 L F
.54487 .49587 m .54347 .49648 L .51806 .55044 L F
.54492 .49341 m .53392 .50157 L .51806 .55044 L F
.54492 .49341 m .54545 .46607 L .53392 .50157 L F
.54545 .46607 m .54551 .46297 L .54482 .46516 L F
.54545 .46607 m .54482 .46516 L .53323 .50209 L F
.53392 .50157 m .53323 .50209 L .51806 .55044 L F
.54545 .46607 m .53323 .50209 L .53392 .50157 L F
.52626 .52963 m .54551 .46297 L .53134 .52858 L .631 .606 .807 r
F
.52626 .52963 m .53134 .52858 L .52848 .5418 L F
.52249 .54265 m .52626 .52963 L .52848 .5418 L F
.52041 .54295 m .5211 .54076 L .52249 .54265 L F
.5211 .54076 m .54551 .46297 L .52249 .54265 L F
.54487 .49587 m .54492 .49341 L .54347 .49648 L .648 .639 .827 r
F
.52867 .54165 m .54551 .46297 L .60752 .47627 L .631 .606 .807 r
F
.52853 .54161 m .54551 .46297 L .52867 .54165 L F
.52848 .5418 m .52853 .54161 L .52867 .54165 L F
.51806 .55044 m .52041 .54295 L .52848 .5418 L F
.51806 .55044 m .56746 .50949 L .48771 .55157 L F
.56746 .50949 m .56486 .50957 L .48771 .55157 L F
.57211 .50562 m .55428 .50973 L .48771 .55157 L F
.56746 .50949 m .57211 .50562 L .56486 .50957 L F
.57211 .50562 m .60752 .47627 L .55428 .50973 L F
.50227 .54702 m .60752 .47627 L .58429 .52136 L .621 .562 .767 r
F
.48771 .55157 m .50183 .5427 L .50227 .54702 L F
.50183 .5427 m .60752 .47627 L .50227 .54702 L F
.48771 .55157 m .55784 .52963 L .46721 .54179 L F
.55784 .52963 m .55549 .52843 L .46721 .54179 L F
.56747 .52662 m .56031 .52554 L .46721 .54179 L F
.58429 .52136 m .56 .52268 L .55209 .52431 L F
.56031 .52554 m .55209 .52431 L .46721 .54179 L F
.58429 .52136 m .55209 .52431 L .56031 .52554 L F
.47961 .53924 m .4846 .53821 L .47818 .54217 L .627 .526 .72 r
F
.58429 .52136 m .60752 .47627 L .61882 .51056 L .621 .562 .767 r
F
.58429 .52136 m .61882 .51056 L .56 .52268 L F
.4846 .53821 m .61882 .51056 L .47974 .54182 L .627 .526 .72 r
F
.4846 .53821 m .47974 .54182 L .47818 .54217 L F
.55784 .52963 m .56747 .52662 L .55549 .52843 L .621 .562 .767 r
F
.56747 .52662 m .58429 .52136 L .56031 .52554 L F
.47922 .54221 m .61882 .51056 L .53793 .54424 L .627 .526 .72 r
F
.56622 .54619 m .62958 .53706 L .56401 .58219 L .646 .57 .754 r
F
.53793 .54424 m .61882 .51056 L .58277 .54579 L .627 .526 .72 r
F
.47818 .54217 m .47974 .54182 L .47922 .54221 L F
.47974 .54182 m .61882 .51056 L .47922 .54221 L F
.46721 .54179 m .47961 .53924 L .47818 .54217 L F
.46721 .54179 m .53793 .54424 L .46435 .5251 L F
.53793 .54424 m .53457 .54057 L .46435 .5251 L F
.55364 .54478 m .53849 .53805 L .53105 .53675 L F
.53457 .54057 m .53105 .53675 L .46435 .5251 L F
.55364 .54478 m .53105 .53675 L .53457 .54057 L F
.4724 .52742 m .47536 .52791 L .46944 .52871 L .655 .529 .698 r
F
.55364 .54478 m .58277 .54579 L .53849 .53805 L .627 .526 .72 r
F
.47536 .52791 m .58277 .54579 L .47093 .52893 L .655 .529 .698 r
F
.47536 .52791 m .47093 .52893 L .46944 .52871 L F
.4739 .52677 m .47641 .5272 L .4724 .52742 L F
.47641 .5272 m .58277 .54579 L .4724 .52742 L F
.53793 .54424 m .55364 .54478 L .53457 .54057 L .627 .526 .72 r
F
.46944 .52871 m .58277 .54579 L .52324 .56689 L .655 .529 .698 r
F
.46435 .5251 m .4739 .52677 L .46944 .52871 L F
.46435 .5251 m .50898 .55677 L .47847 .50755 L F
.50898 .55677 m .50703 .54541 L .47847 .50755 L F
.48285 .51334 m .48329 .51394 L .48053 .51232 L .695 .578 .72 r
F
.50898 .55677 m .52324 .56689 L .50703 .54541 L .655 .529 .698 r
F
.48329 .51394 m .52324 .56689 L .4816 .51368 L .695 .578 .72 r
F
.48329 .51394 m .4816 .51368 L .48053 .51232 L F
.48053 .51232 m .4816 .51368 L .47747 .51242 L F
.4816 .51368 m .52324 .56689 L .47809 .51315 L F
.4816 .51368 m .47809 .51315 L .47747 .51242 L F
.48203 .51227 m .48285 .51334 L .48053 .51232 L F
.48107 .56532 m .47021 .59777 L .40426 .5751 L .679 .619 .781 r
F
.47747 .51242 m .52324 .56689 L .46573 .56918 L .695 .578 .72 r
F
.47847 .50755 m .48203 .51227 L .47747 .51242 L F
.47847 .50755 m .46873 .55468 L .49945 .50111 L F
.46873 .55468 m .47889 .54262 L .49945 .50111 L F
.47847 .50755 m .49945 .50111 L .50285 .49423 L F
.49945 .50111 m .49905 .50191 L .49921 .4997 L .726 .653 .776 r
F
.46873 .55468 m .46573 .56918 L .47889 .54262 L .695 .578 .72 r
F
.49905 .50191 m .46573 .56918 L .49845 .50126 L .726 .653 .776 r
F
.49905 .50191 m .49845 .50126 L .49921 .4997 L F
.49921 .4997 m .49845 .50126 L .49728 .49872 L F
.49845 .50126 m .46573 .56918 L .4969 .49957 L F
.49845 .50126 m .4969 .49957 L .49728 .49872 L F
.49996 .50008 m .49945 .50111 L .49921 .4997 L F
.49728 .49872 m .46573 .56918 L .42596 .55605 L F
.50285 .49423 m .49996 .50008 L .49728 .49872 L F
.50285 .49423 m .44373 .54177 L .52905 .48756 L F
.44373 .54177 m .42596 .55605 L .46217 .532 L F
.44373 .54177 m .46217 .532 L .52905 .48756 L F
.52344 .48972 m .42596 .55605 L .40833 .53416 L .732 .722 .841 r
F
.52905 .48756 m .52045 .49327 L .52344 .48972 L F
.52045 .49327 m .42596 .55605 L .52344 .48972 L F
.52905 .48756 m .40833 .53416 L .55066 .48715 L F
.5451 .48803 m .40833 .53416 L .41009 .50956 L .712 .77 .898 r
F
.55066 .48715 m .54035 .49055 L .5451 .48803 L F
.54035 .49055 m .40833 .53416 L .5451 .48803 L F
1 0 0 r
.003 w
.44626 .44372 m
.51131 .39517 L
s
.61233 .43225 m .73165 .34445 L .64227 .42897 L .682 .758 .909 r
F
.61233 .43225 m .61591 .35538 L .73165 .34445 L F
.64227 .42897 m .80919 .37477 L .66735 .43388 L .688 .758 .905 r
F
.64227 .42897 m .73165 .34445 L .80919 .37477 L F
.61929 .46534 m .69077 .36934 L .64597 .45452 L .683 .757 .908 r
F
.61929 .46534 m .54445 .41619 L .69077 .36934 L F
0 g
.006 w
.68144 .48124 m
.68957 .46443 L
s
.25 g
.5 Mabswid
.68957 .46443 m
.76381 .45715 L
s
0 g
.006 w
.66735 .43388 m
.67808 .44698 L
s
.61748 .4679 m
.61929 .46534 L
s
1 0 0 r
.003 w
.48 .47819 m
.54445 .41619 L
s
.25 g
.5 Mabswid
.51131 .39517 m
.54549 .41586 L
s
.62934 .53504 m
.63748 .53264 L
s
1 0 0 r
.003 w
.80902 .38516 m
.80919 .37477 L
s
0 g
.006 w
.65781 .43201 m
.66735 .43388 L
s
.25 g
.5 Mabswid
.4814 .60812 m
.48719 .59495 L
s
1 0 0 r
.003 w
.41916 .58966 m
.4814 .60812 L
s
.4814 .60812 m
.56018 .597 L
s
.25 g
.5 Mabswid
.42142 .58851 m
.43023 .58403 L
s
.41916 .58966 m
.42142 .58851 L
s
1 0 0 r
.003 w
.41661 .57935 m
.41916 .58966 L
s
.25 g
.5 Mabswid
.59649 .56537 m
.61895 .56619 L
s
.58885 .56509 m
.59649 .56537 L
s
.64597 .45452 m .809 .38502 L .67521 .45361 L .691 .761 .905 r
F
.64597 .45452 m .69077 .36934 L .809 .38502 L F
.63438 .47939 m .68974 .38426 L .6612 .4691 L .681 .753 .906 r
F
.25 g
.70354 .37104 m
.73165 .34445 L
s
.79048 .38257 m
.80434 .37679 L
s
.63438 .47939 m .55938 .42842 L .68974 .38426 L .681 .753 .906 r
F
0 g
.006 w
.62401 .49113 m
.63438 .47939 L
s
.67521 .45361 m
.68957 .46443 L
s
.25 g
.5 Mabswid
.55938 .42842 m
.63438 .47939 L
s
.61412 .39388 m
.61591 .35538 L
s
1 0 0 r
.003 w
.51137 .4709 m
.55938 .42842 L
s
.25 g
.5 Mabswid
.54445 .41619 m
.56182 .4276 L
s
.80434 .37679 m
.80919 .37477 L
s
0 g
.006 w
.66632 .45389 m
.67521 .45361 L
s
.25 g
.5 Mabswid
.5451 .58533 m
.56018 .597 L
s
1 0 0 r
.003 w
.56018 .597 m
.61895 .56619 L
s
.69147 .46703 m .85388 .42614 L .71286 .47469 L .7 .767 .904 r
F
0 g
.006 w
.71286 .47469 m
.71919 .48938 L
s
.6612 .4691 m .80417 .38576 L .69147 .46703 L .691 .755 .901 r
F
.6612 .4691 m .68974 .38426 L .80417 .38576 L F
0 g
.63438 .47939 m
.6612 .4691 L
s
.25 g
.5 Mabswid
.68144 .38707 m
.69077 .36934 L
s
.6612 .4691 m
.68974 .38426 L
s
.69147 .46703 m .80417 .38576 L .85388 .42614 L .7 .767 .904 r
F
.25 g
.69147 .46703 m
.80417 .38576 L
s
0 g
.006 w
.6612 .4691 m
.69147 .46703 L
s
.69147 .46703 m
.71286 .47469 L
s
.25 g
.5 Mabswid
.80787 .44198 m
.85388 .42614 L
s
.71286 .47469 m
.80787 .44198 L
s
.80549 .38682 m
.809 .38502 L
s
1 0 0 r
.003 w
.83501 .4822 m
.85388 .42614 L
s
.809 .38502 m
.80994 .39044 L
s
.43741 .65475 m .39674 .68453 L .33409 .65095 L .444 .681 .965 r
F
.5437 .60203 m .49121 .64569 L .41181 .59802 L .523 .692 .945 r
F
.50179 .62325 m .45508 .66499 L .37187 .6122 L .505 .686 .948 r
F
.46764 .65311 m .39674 .68453 L .43741 .65475 L .492 .709 .967 r
F
.5735 .59894 m .49121 .64569 L .5437 .60203 L .545 .701 .942 r
F
.52947 .61952 m .45508 .66499 L .50179 .62325 L .529 .702 .949 r
F
.5735 .59894 m .59767 .66169 L .49121 .64569 L .545 .701 .942 r
F
.52947 .61952 m .57352 .68001 L .45508 .66499 L .529 .702 .949 r
F
.46764 .65311 m .48346 .70368 L .39674 .68453 L .492 .709 .967 r
F
.4931 .64449 m .48346 .70368 L .46764 .65311 L .533 .719 .959 r
F
.4931 .64449 m .57474 .69723 L .48346 .70368 L F
1 0 0 r
.39674 .68453 m
.48346 .70368 L
s
.54188 .676 m
.56083 .6784 L
s
.25 g
.5 Mabswid
.46764 .65311 m
.48346 .70368 L
s
1 0 0 r
.003 w
.61895 .56619 m
.63748 .53264 L
s
.25 g
.5 Mabswid
.47634 .58539 m
.48474 .56842 L
s
.50287 .53183 m
.50314 .53127 L
s
.47021 .59777 m
.47634 .58539 L
s
1 0 0 r
.003 w
.40426 .5751 m
.47021 .59777 L
s
.47021 .59777 m
.52719 .58831 L
s
.52719 .58831 m
.56401 .58219 L
s
.25 g
.5 Mabswid
.42275 .5669 m
.43815 .56008 L
s
.50216 .5317 m
.51597 .52558 L
s
.40426 .5751 m
.42275 .5669 L
s
1 0 0 r
.003 w
.4019 .52788 m
.40426 .5751 L
s
.25 g
.5 Mabswid
.61431 .49687 m
.62434 .4912 L
s
1 0 0 r
.003 w
.62782 .52166 m
.63748 .53264 L
s
.80417 .38576 m
.85388 .42614 L
s
.25 g
.5 Mabswid
.58762 .54105 m
.62819 .53719 L
s
.62819 .53719 m
.62958 .53706 L
s
.51362 .52662 m
.52114 .53056 L
s
1 0 0 r
.003 w
.73165 .34445 m
.80919 .37477 L
s
.51131 .39517 m
.61591 .35538 L
s
.59691 .58742 m .59767 .66169 L .5735 .59894 L .56 .698 .932 r
F
.59691 .58742 m .69068 .64167 L .59767 .66169 L F
1 0 0 r
.55557 .65536 m
.59767 .66169 L
s
.40914 .65121 m .33409 .65095 L .30268 .61393 L .407 .639 .951 r
F
.43741 .65475 m .33409 .65095 L .40914 .65121 L .444 .681 .965 r
F
1 0 0 r
.33409 .65095 m
.39674 .68453 L
s
.25 g
.5 Mabswid
.39674 .68453 m
.43741 .65475 L
s
.53323 .56335 m
.56401 .58219 L
s
1 0 0 r
.003 w
.56401 .58219 m
.61267 .5487 L
s
.61267 .5487 m
.62958 .53706 L
s
.54445 .41619 m
.57004 .408 L
s
.57004 .408 m
.69077 .36934 L
s
.54493 .60629 m .57352 .68001 L .52947 .61952 L .553 .704 .941 r
F
.54493 .60629 m .66567 .64545 L .57352 .68001 L F
1 0 0 r
.56083 .6784 m
.57352 .68001 L
s
.25 g
.5 Mabswid
.5735 .59894 m
.58081 .61793 L
s
.49243 .52605 m
.52371 .52543 L
s
.4019 .52788 m
.40879 .52774 L
s
1 0 0 r
.003 w
.45295 .48883 m
.46115 .48257 L
s
.43 .50639 m
.45295 .48883 L
s
.4019 .52788 m
.40918 .52231 L
s
.69077 .36934 m
.809 .38502 L
s
.51693 .59654 m .41181 .59802 L .39897 .53819 L .512 .675 .938 r
F
.5437 .60203 m .41181 .59802 L .51693 .59654 L .523 .692 .945 r
F
1 0 0 r
.41181 .59802 m
.44593 .6185 L
s
.25 g
.5 Mabswid
.52136 .62061 m
.5437 .60203 L
s
1 0 0 r
.003 w
.55938 .42842 m
.68974 .38426 L
s
.25 g
.5 Mabswid
.55946 .50647 m
.60752 .47627 L
s
.55428 .50973 m
.55946 .50647 L
s
.55397 .50993 m
.55428 .50973 L
s
.52085 .53074 m
.55397 .50993 L
s
.53423 .49892 m
.53645 .49184 L
s
.54308 .4707 m
.54482 .46516 L
s
.53785 .48739 m
.54308 .4707 L
s
.53323 .50209 m
.53423 .49892 L
s
.52507 .52809 m
.53323 .50209 L
s
.54482 .46516 m
.54551 .46297 L
s
.56 .52268 m
.61882 .51056 L
s
.55209 .52431 m
.56 .52268 L
s
.54865 .52501 m
.55209 .52431 L
s
.50975 .53303 m
.54865 .52501 L
s
.47566 .61708 m .37187 .6122 L .36757 .55115 L .5 .665 .936 r
F
.50179 .62325 m .37187 .6122 L .47566 .61708 L .505 .686 .948 r
F
1 0 0 r
.003 w
.37187 .6122 m
.43881 .65468 L
s
.25 g
.5 Mabswid
.46115 .48257 m
.46597 .48587 L
s
.46597 .48587 m
.46834 .48749 L
s
.46834 .48749 m
.4722 .49014 L
s
.4722 .49014 m
.48347 .49786 L
s
.49828 .508 m
.52552 .52666 L
s
.50628 .62973 m .57474 .69723 L .4931 .64449 L .559 .714 .944 r
F
.25 g
.46882 .65271 m
.50179 .62325 L
s
.50628 .62973 m .63847 .65908 L .57474 .69723 L .559 .714 .944 r
F
1 0 0 r
.003 w
.48346 .70368 m
.57474 .69723 L
s
.25 g
.5 Mabswid
.52947 .61952 m
.54282 .63784 L
s
.4931 .64449 m
.57474 .69723 L
s
1 0 0 r
.003 w
.62434 .4912 m
.62958 .53706 L
s
.61152 .4884 m
.62434 .4912 L
s
.25 g
.5 Mabswid
.53849 .53805 m
.58277 .54579 L
s
.53105 .53675 m
.53849 .53805 L
s
.52614 .53589 m
.53105 .53675 L
s
.52211 .53519 m
.52614 .53589 L
s
.49586 .5306 m
.52211 .53519 L
s
1 0 0 r
.003 w
.61591 .35538 m
.73165 .34445 L
s
.46115 .48257 m
.54551 .46297 L
s
.68974 .38426 m
.80417 .38576 L
s
.25 g
.5 Mabswid
.46573 .56918 m
.47889 .54262 L
s
.47889 .54262 m
.48202 .5363 L
s
.48202 .5363 m
.49493 .51022 L
s
1 0 0 r
.003 w
.45339 .56511 m
.46573 .56918 L
s
.46573 .56918 m
.52324 .56689 L
s
.40914 .65121 m .30268 .61393 L .38661 .64538 L .407 .639 .951 r
F
.37911 .63983 m .30268 .61393 L .30039 .58154 L .401 .595 .923 r
F
.38213 .6437 m .30268 .61393 L .37911 .63983 L F
.38661 .64538 m .38213 .6437 L .37911 .63983 L F
.38661 .64538 m .30039 .58154 L .37038 .63983 L F
.36704 .63442 m .30039 .58154 L .31986 .55805 L .433 .565 .887 r
F
.36699 .63475 m .30039 .58154 L .36704 .63442 L F
.36807 .63791 m .30039 .58154 L .36749 .63515 L F
.36749 .63515 m .36699 .63475 L .36704 .63442 L F
.37038 .63983 m .36807 .63791 L .36749 .63515 L F
.37038 .63983 m .3369 .58564 L .35885 .63603 L F
.3369 .58564 m .32783 .57399 L .35885 .63603 L F
.3369 .58564 m .31986 .55805 L .32783 .57399 L F
.35882 .63559 m .31986 .55805 L .35257 .54452 L .489 .557 .852 r
F
.35885 .63603 m .35871 .63576 L .35882 .63559 L F
.35871 .63576 m .31986 .55805 L .35882 .63559 L F
.35493 .63523 m .35457 .57367 L .34962 .63416 L F
.35885 .63603 m .35882 .63559 L .35493 .63523 L F
.35882 .63559 m .35457 .57367 L .35493 .63523 L F
.35457 .57367 m .35201 .56149 L .34962 .63416 L F
.35457 .57367 m .35257 .54452 L .35201 .56149 L F
.47566 .61708 m .36757 .55115 L .46356 .60642 L .5 .665 .936 r
F
.51693 .59654 m .39897 .53819 L .50304 .58635 L .512 .675 .938 r
F
.55066 .48715 m .41384 .50897 L .56503 .49102 L .712 .77 .898 r
F
.41384 .50897 m .41009 .50956 L .41415 .50908 L F
.41384 .50897 m .41415 .50908 L .56503 .49102 L F
.50304 .58635 m .48292 .53374 L .50691 .57834 L .519 .663 .926 r
F
.56503 .49102 m .41009 .50956 L .42671 .4862 L .669 .792 .94 r
F
.48292 .53374 m .46989 .49966 L .48653 .53503 L .519 .663 .926 r
F
.48292 .53374 m .48653 .53503 L .50691 .57834 L F
.50304 .58635 m .39897 .53819 L .46989 .49966 L F
.46356 .60642 m .36757 .55115 L .44721 .51892 L .517 .656 .922 r
F
.34962 .63416 m .35257 .54452 L .39117 .54052 L .551 .571 .828 r
F
.34962 .63416 m .37533 .57621 L .3408 .63328 L F
.37533 .57621 m .37659 .56736 L .3408 .63328 L F
.37533 .57621 m .39117 .54052 L .37659 .56736 L F
.3408 .63328 m .39117 .54052 L .42938 .54576 L .607 .601 .819 r
F
.3408 .63328 m .39794 .57683 L .33187 .63181 L F
.39794 .57683 m .42938 .54576 L .4033 .56878 L F
.39794 .57683 m .4033 .56878 L .33187 .63181 L F
.25 g
.5 Mabswid
.30268 .61393 m
.33739 .62693 L
s
1 0 0 r
.003 w
.37123 .60321 m
.37137 .60521 L
s
.37137 .60521 m
.37187 .6122 L
s
.25 g
.5 Mabswid
.43155 .61501 m
.47566 .61708 L
s
.38305 .61273 m
.43155 .61501 L
s
.37187 .6122 m
.38305 .61273 L
s
1 0 0 r
.003 w
.30268 .61393 m
.33409 .65095 L
s
.25 g
.5 Mabswid
.33409 .65095 m
.40914 .65121 L
s
1 0 0 r
.003 w
.30039 .58154 m
.30268 .61393 L
s
.25 g
.5 Mabswid
.50703 .54541 m
.52324 .56689 L
s
.50371 .54101 m
.50703 .54541 L
s
.50112 .53758 m
.50371 .54101 L
s
.48921 .52178 m
.50112 .53758 L
s
1 0 0 r
.003 w
.52324 .56689 m
.58277 .54579 L
s
.25 g
.5 Mabswid
.47964 .52038 m
.5089 .50094 L
s
1 0 0 r
.003 w
.58277 .54579 m
.61882 .51056 L
s
.60876 .57063 m .69068 .64167 L .59691 .58742 L .564 .686 .922 r
F
.60876 .57063 m .74014 .59424 L .69068 .64167 L F
1 0 0 r
.65567 .6492 m
.69068 .64167 L
s
0 g
.006 w
.40914 .65121 m
.43741 .65475 L
s
.43741 .65475 m
.46764 .65311 L
s
.52142 .4895 m
.52905 .48756 L
s
.38661 .64538 m
.40914 .65121 L
s
1 0 0 r
.003 w
.54551 .46297 m
.60752 .47627 L
s
0 g
.006 w
.46764 .65311 m
.4931 .64449 L
s
.25 g
.5 Mabswid
.47566 .51192 m
.52412 .49591 L
s
1 0 0 r
.003 w
.40841 .53306 m
.41009 .50956 L
s
0 g
.006 w
.51693 .59654 m
.5437 .60203 L
s
.5437 .60203 m
.5735 .59894 L
s
.47566 .61708 m
.50179 .62325 L
s
.50179 .62325 m
.52947 .61952 L
s
1 0 0 r
.003 w
.60752 .47627 m
.61882 .51056 L
s
0 g
.006 w
.37038 .63983 m
.38661 .64538 L
s
.25 g
.5 Mabswid
.46186 .59731 m
.51693 .59654 L
s
1 0 0 r
.003 w
.39897 .53819 m
.39902 .53842 L
s
0 g
.006 w
.50304 .58635 m
.51693 .59654 L
s
.52905 .48756 m
.55066 .48715 L
s
.25 g
.5 Mabswid
.30039 .58154 m
.34589 .61943 L
s
0 g
.006 w
.35885 .63603 m
.37038 .63983 L
s
.25 g
.5 Mabswid
.39897 .53819 m
.39926 .53832 L
s
.40318 .57165 m
.4174 .57984 L
s
.46356 .60642 m .44721 .51892 L .46958 .59924 L .517 .656 .922 r
F
.25 g
.4174 .57984 m
.46356 .60642 L
s
.46051 .56667 m
.50304 .58635 L
s
0 g
.006 w
.46356 .60642 m
.47566 .61708 L
s
.54139 .58993 m .66567 .64545 L .54493 .60629 L .563 .693 .928 r
F
.60921 .55283 m .74014 .59424 L .60876 .57063 L .554 .671 .915 r
F
.54139 .58993 m .67466 .57579 L .66567 .64545 L .563 .693 .928 r
F
1 0 0 r
.003 w
.63273 .65781 m
.66567 .64545 L
s
.25 g
.5 Mabswid
.66786 .62846 m
.69068 .64167 L
s
.41009 .50956 m
.41415 .50908 L
s
.41415 .50908 m
.4634 .50318 L
s
1 0 0 r
.003 w
.30039 .58154 m
.31986 .55805 L
s
.56503 .49102 m .45534 .4872 L .57287 .49691 L .669 .792 .94 r
F
.45534 .4872 m .47545 .48977 L .57287 .49691 L F
.45534 .4872 m .42671 .4862 L .47545 .48977 L F
.57287 .49691 m .42671 .4862 L .45553 .46638 L .611 .788 .966 r
F
.57287 .49691 m .4768 .47191 L .57685 .50327 L F
.4768 .47191 m .45553 .46638 L .49245 .47761 L F
.4768 .47191 m .49245 .47761 L .57685 .50327 L F
.57584 .50262 m .45553 .46638 L .49686 .45231 L .55 .76 .975 r
F
.57685 .50327 m .57392 .50238 L .57584 .50262 L F
.57392 .50238 m .45553 .46638 L .57584 .50262 L F
.57685 .50327 m .49686 .45231 L .58013 .50963 L F
.58006 .50947 m .49686 .45231 L .55205 .44769 L .507 .718 .967 r
F
.58013 .50963 m .57973 .50935 L .58006 .50947 L F
.57973 .50935 m .49686 .45231 L .58006 .50947 L F
1 0 0 r
.41009 .50956 m
.42671 .4862 L
s
.25 g
.5 Mabswid
.47111 .50226 m
.47555 .50173 L
s
.47555 .50173 m
.47986 .50121 L
s
.47986 .50121 m
.53747 .49432 L
s
0 g
.006 w
.59949 .58377 m
.60876 .57063 L
s
.25 g
.5 Mabswid
.31986 .55805 m
.34912 .61658 L
s
0 g
.006 w
.34962 .63416 m
.35885 .63603 L
s
.50311 .6132 m .63847 .65908 L .50628 .62973 L .568 .699 .929 r
F
.50311 .6132 m .63866 .59686 L .63847 .65908 L F
1 0 0 r
.003 w
.57474 .69723 m
.63847 .65908 L
s
0 g
.006 w
.4931 .64449 m
.50628 .62973 L
s
.54239 .60847 m
.54493 .60629 L
s
.25 g
.5 Mabswid
.54493 .60629 m
.54913 .60765 L
s
.63854 .63666 m
.66567 .64545 L
s
.50628 .62973 m
.63847 .65908 L
s
.42671 .4862 m
.47545 .48977 L
s
.47545 .48977 m
.48306 .49033 L
s
.48306 .49033 m
.55056 .49528 L
s
.58013 .50963 m .55205 .44769 L .58523 .51656 L .507 .718 .967 r
F
.58523 .51656 m .61906 .45795 L .59306 .52534 L .496 .681 .949 r
F
.58523 .51656 m .55205 .44769 L .61906 .45795 L F
.50691 .57834 m .58928 .51326 L .52407 .57896 L .539 .664 .918 r
F
.50691 .57834 m .46989 .49966 L .58928 .51326 L F
0 g
.006 w
.50304 .58635 m
.50691 .57834 L
s
.46958 .59924 m .56205 .53828 L .48712 .6014 L .543 .663 .915 r
F
.46958 .59924 m .44721 .51892 L .56205 .53828 L F
0 g
.46356 .60642 m
.46958 .59924 L
s
.25 g
.5 Mabswid
.46989 .49966 m
.48169 .52473 L
s
1 0 0 r
.003 w
.39897 .53819 m
.46989 .49966 L
s
.4232 .52864 m
.44721 .51892 L
s
.39316 .54079 m
.4232 .52864 L
s
.25 g
.5 Mabswid
.45553 .46638 m
.49245 .47761 L
s
.49245 .47761 m
.49413 .47812 L
s
.49413 .47812 m
.56619 .50003 L
s
0 g
.006 w
.3408 .63328 m
.34962 .63416 L
s
.48712 .6014 m .63866 .59686 L .50311 .6132 L .562 .68 .918 r
F
.25 g
.5 Mabswid
.50311 .6132 m
.58694 .60309 L
s
0 g
.006 w
.50311 .6132 m
.50628 .62973 L
s
.52407 .57896 m .67466 .57579 L .54139 .58993 L .557 .677 .919 r
F
0 g
.54139 .58993 m
.5435 .59971 L
s
.60921 .55283 m .73527 .53691 L .74014 .59424 L .554 .671 .915 r
F
.60229 .53729 m .73527 .53691 L .60921 .55283 L .534 .66 .917 r
F
.59306 .52534 m .68713 .48795 L .60229 .53729 L .511 .662 .929 r
F
.59306 .52534 m .61906 .45795 L .68713 .48795 L F
.60229 .53729 m .68713 .48795 L .73527 .53691 L .534 .66 .917 r
F
.52407 .57896 m .58928 .51326 L .67466 .57579 L .557 .677 .919 r
F
0 g
.52407 .57896 m
.54139 .58993 L
s
1 0 0 r
.003 w
.66567 .64545 m
.67466 .57579 L
s
0 g
.006 w
.51418 .5786 m
.52407 .57896 L
s
.48712 .6014 m .56205 .53828 L .63866 .59686 L .562 .68 .918 r
F
.25 g
.5 Mabswid
.54344 .55395 m
.56205 .53828 L
s
.48712 .6014 m
.54344 .55395 L
s
.62851 .58069 m
.67466 .57579 L
s
.56341 .53932 m
.58928 .51326 L
s
.61885 .58171 m
.62851 .58069 L
s
0 g
.006 w
.48712 .6014 m
.50311 .6132 L
s
1 0 0 r
.003 w
.63847 .65908 m
.63866 .59686 L
s
0 g
.006 w
.46958 .59924 m
.48712 .6014 L
s
.25 g
.5 Mabswid
.58694 .60309 m
.63866 .59686 L
s
.49686 .45231 m
.5178 .46672 L
s
.5178 .46672 m
.57973 .50935 L
s
.57973 .50935 m
.58013 .50963 L
s
0 g
.006 w
.58013 .50963 m
.58222 .51246 L
s
1 0 0 r
.003 w
.42671 .4862 m
.45553 .46638 L
s
.25 g
.5 Mabswid
.6383 .54916 m
.73527 .53691 L
s
.67381 .58232 m
.74014 .59424 L
s
1 0 0 r
.003 w
.69068 .64167 m
.74014 .59424 L
s
.25 g
.5 Mabswid
.55205 .44769 m
.58331 .51258 L
s
1 0 0 r
.003 w
.73527 .53691 m
.74014 .59424 L
s
.25 g
.5 Mabswid
.61824 .46009 m
.61906 .45795 L
s
.59586 .51808 m
.61824 .46009 L
s
.61333 .53088 m
.68713 .48795 L
s
.33187 .63181 m .42938 .54576 L .46041 .56059 L .653 .639 .824 r
F
.33187 .63181 m .46041 .56059 L .32418 .62791 L F
0 g
.006 w
.33187 .63181 m
.3408 .63328 L
s
.25 g
.5 Mabswid
.46835 .59484 m
.46958 .59924 L
s
.45618 .55114 m
.45857 .55971 L
s
.45903 .56136 m
.46835 .59484 L
s
1 0 0 r
.003 w
.31986 .55805 m
.35257 .54452 L
s
.25 g
.5 Mabswid
.44721 .51892 m
.45618 .55114 L
s
.32418 .62791 m .46041 .56059 L .47587 .58492 L .687 .679 .837 r
F
.32418 .62791 m .47587 .58492 L .32088 .62021 L F
.32088 .62021 m .47587 .58492 L .46748 .61605 L .71 .715 .853 r
F
.32088 .62021 m .46748 .61605 L .32616 .60855 L F
.32616 .60855 m .46748 .61605 L .43173 .64712 L .724 .747 .87 r
F
.32616 .60855 m .43173 .64712 L .34332 .5948 L F
.34332 .5948 m .43173 .64712 L .37523 .66763 L .731 .775 .888 r
F
.34332 .5948 m .37344 .66354 L .3721 .58305 L F
.37344 .66354 m .37362 .66325 L .3721 .58305 L F
.37363 .66399 m .37494 .65985 L .3721 .58305 L F
.37344 .66354 m .37363 .66399 L .37362 .66325 L F
.37363 .66399 m .37523 .66763 L .37494 .65985 L F
.3721 .58305 m .37523 .66763 L .31713 .66699 L .73 .798 .906 r
F
.3721 .58305 m .3241 .65634 L .40645 .57845 L F
.3241 .65634 m .32932 .6536 L .40645 .57845 L F
.31986 .66282 m .32245 .66172 L .40645 .57845 L F
.30256 .63166 m .31713 .66699 L .28576 .64026 L .721 .815 .924 r
F
.39948 .58202 m .33177 .65189 L .30256 .63166 L F
.3241 .65634 m .31986 .66282 L .32932 .6536 L .73 .798 .906 r
F
.31986 .66282 m .31713 .66699 L .32245 .66172 L F
.33177 .65189 m .31713 .66699 L .30256 .63166 L .721 .815 .924 r
F
.39795 .58688 m .31713 .66699 L .39948 .58202 L F
.40645 .57845 m .39795 .58688 L .39948 .58202 L F
.40645 .57845 m .30846 .62863 L .43519 .58449 L F
.30846 .62863 m .28576 .64026 L .32179 .62682 L F
.30846 .62863 m .32179 .62682 L .43519 .58449 L F
.32999 .59289 m .28576 .64026 L .30705 .59472 L .703 .82 .937 r
F
.4231 .58546 m .32204 .62579 L .32999 .59289 L F
.32204 .62579 m .28576 .64026 L .32999 .59289 L F
.43519 .58449 m .42014 .59011 L .4231 .58546 L F
.42014 .59011 m .28576 .64026 L .4231 .58546 L F
.43519 .58449 m .33808 .59224 L .447 .60012 L F
.33808 .59224 m .34185 .59362 L .447 .60012 L F
.32999 .59289 m .34797 .5963 L .447 .60012 L F
.4405 .59521 m .34915 .59487 L .38423 .55269 L .685 .81 .942 r
F
.33808 .59224 m .32999 .59289 L .34185 .59362 L .703 .82 .937 r
F
.32999 .59289 m .30705 .59472 L .34797 .5963 L F
.34915 .59487 m .30705 .59472 L .38423 .55269 L .685 .81 .942 r
F
.43223 .59955 m .30705 .59472 L .4405 .59521 L F
.447 .60012 m .43223 .59955 L .4405 .59521 L F
.447 .60012 m .40231 .56635 L .43732 .6191 L F
.40231 .56635 m .40268 .57346 L .43732 .6191 L F
.39051 .55744 m .38997 .55987 L .39289 .56352 L F
.39396 .56198 m .39289 .56352 L .43732 .6191 L F
.39051 .55744 m .39289 .56352 L .39396 .56198 L F
.40231 .56635 m .39051 .55744 L .40268 .57346 L F
.39051 .55744 m .38423 .55269 L .38997 .55987 L F
.43691 .61316 m .38423 .55269 L .442 .611 L .673 .79 .937 r
F
.43367 .61453 m .4318 .61219 L .43691 .61316 L F
.4318 .61219 m .38423 .55269 L .43691 .61316 L F
.44237 .61036 m .38423 .55269 L .48195 .5418 L F
.442 .611 m .44149 .61048 L .44237 .61036 L F
.44149 .61048 m .38423 .55269 L .44237 .61036 L F
.43732 .6191 m .43367 .61453 L .442 .611 L F
.43732 .6191 m .46754 .56676 L .4123 .63271 L F
.46754 .56676 m .46412 .56951 L .4123 .63271 L F
.4703 .56198 m .4621 .56772 L .4123 .63271 L F
.46754 .56676 m .4703 .56198 L .46412 .56951 L F
.4703 .56198 m .48195 .5418 L .4621 .56772 L F
.42834 .62532 m .4729 .5559 L .54204 .57291 L .672 .769 .923 r
F
.4123 .63271 m .42024 .62235 L .42834 .62532 L F
.42024 .62235 m .48195 .5418 L .42834 .62532 L F
.4123 .63271 m .49713 .59361 L .38677 .63435 L F
.49713 .59361 m .54204 .57291 L .47941 .59769 L F
.49713 .59361 m .47941 .59769 L .38677 .63435 L F
.49006 .62998 m .54204 .57291 L .52816 .62836 L .682 .755 .907 r
F
.40579 .63354 m .4803 .60039 L .49006 .62998 L F
.4803 .60039 m .54204 .57291 L .49006 .62998 L F
.38677 .63435 m .40545 .62696 L .40579 .63354 L F
.40545 .62696 m .54204 .57291 L .40579 .63354 L F
.38677 .63435 m .47724 .63052 L .37704 .62351 L F
.47724 .63052 m .52816 .62836 L .46563 .62636 L F
.47724 .63052 m .46563 .62636 L .37704 .62351 L F
.43128 .66105 m .52816 .62836 L .45199 .67538 L .698 .756 .897 r
F
.3878 .63096 m .46244 .62958 L .43128 .66105 L F
.46244 .62958 m .52816 .62836 L .43128 .66105 L F
.37704 .62351 m .39628 .62413 L .3878 .63096 L F
.39628 .62413 m .52816 .62836 L .3878 .63096 L F
.37704 .62351 m .42426 .65619 L .39141 .60704 L F
.42426 .65619 m .42541 .65121 L .39141 .60704 L F
.43494 .66358 m .43931 .66108 L .43157 .65234 L F
.42924 .65618 m .43157 .65234 L .39141 .60704 L F
.43494 .66358 m .43157 .65234 L .42924 .65618 L F
.38969 .61836 m .42208 .64801 L .38614 .62084 L .714 .774 .899 r
F
.42426 .65619 m .43494 .66358 L .42541 .65121 L .698 .756 .897 r
F
.43494 .66358 m .45199 .67538 L .43931 .66108 L F
.42208 .64801 m .45199 .67538 L .41981 .64873 L .714 .774 .899 r
F
.42208 .64801 m .41981 .64873 L .38614 .62084 L F
.39695 .61328 m .39945 .61611 L .38969 .61836 L F
.39945 .61611 m .45199 .67538 L .38969 .61836 L F
.38614 .62084 m .45199 .67538 L .36054 .6878 L F
.39141 .60704 m .39695 .61328 L .38614 .62084 L F
.39141 .60704 m .37227 .65711 L .42361 .59588 L F
.37227 .65711 m .36232 .68314 L .38626 .64906 L F
.37227 .65711 m .38626 .64906 L .42361 .59588 L F
.34222 .64042 m .36054 .6878 L .3087 .65876 L .72 .801 .915 r
F
.40661 .60518 m .38304 .64744 L .34222 .64042 L F
.36232 .68314 m .36054 .6878 L .36163 .6862 L .714 .774 .899 r
F
.36232 .68314 m .36163 .6862 L .37405 .6681 L F
.37274 .6683 m .37405 .6681 L .42361 .59588 L F
.36232 .68314 m .37405 .6681 L .37274 .6683 L F
.4729 .5559 m .50671 .55462 L .54204 .57291 L .672 .769 .923 r
F
.38304 .64744 m .36054 .6878 L .34222 .64042 L .72 .801 .915 r
F
.42361 .59588 m .41513 .60824 L .40661 .60518 L F
.41513 .60824 m .36054 .6878 L .40661 .60518 L F
.42361 .59588 m .35373 .63412 L .45523 .5981 L F
.35373 .63412 m .33727 .64313 L .36381 .633 L F
.35373 .63412 m .36381 .633 L .45523 .5981 L F
.33727 .64313 m .3087 .65876 L .33353 .64848 L F
.33727 .64313 m .33353 .64848 L .45523 .5981 L F
.43747 .59909 m .3087 .65876 L .38161 .60221 L .708 .82 .934 r
F
.38161 .60221 m .3087 .65876 L .33176 .60499 L F
.45523 .5981 m .43584 .60613 L .43747 .59909 L F
.43584 .60613 m .3087 .65876 L .43747 .59909 L F
.4478 .59851 m .38161 .60221 L .45745 .61173 L F
.4478 .59851 m .45745 .61173 L .46803 .61306 L F
.45523 .5981 m .4478 .59851 L .46803 .61306 L F
.38161 .60221 m .39376 .60866 L .46803 .61306 L F
.45798 .61246 m .45579 .61233 L .45674 .61076 L .685 .815 .945 r
F
.45798 .61246 m .45674 .61076 L .4604 .60471 L F
.46803 .61306 m .45798 .61246 L .4604 .60471 L F
.38161 .60221 m .33176 .60499 L .39376 .60866 L .708 .82 .934 r
F
.45887 .60724 m .33176 .60499 L .4604 .60471 L .685 .815 .945 r
F
.45579 .61233 m .45057 .61202 L .45887 .60724 L F
.45057 .61202 m .33176 .60499 L .45887 .60724 L F
.4604 .60471 m .33176 .60499 L .42018 .56066 L F
.46803 .61306 m .43986 .58221 L .45635 .63206 L F
.43986 .58221 m .42018 .56066 L .43689 .59363 L F
.43986 .58221 m .43689 .59363 L .45635 .63206 L F
.45635 .63206 m .45185 .62317 L .46474 .62173 L .668 .793 .941 r
F
.46474 .62173 m .42018 .56066 L .51878 .5552 L F
.45185 .62317 m .42018 .56066 L .46474 .62173 L F
.45635 .63206 m .49313 .58678 L .42963 .64456 L F
.49313 .58678 m .48692 .59063 L .42963 .64456 L F
.50001 .57831 m .48023 .59384 L .42963 .64456 L F
.49313 .58678 m .50001 .57831 L .48692 .59063 L F
.50001 .57831 m .51878 .5552 L .48023 .59384 L F
.44786 .6374 m .51878 .5552 L .56848 .58999 L .667 .766 .924 r
F
.42963 .64456 m .44062 .63355 L .44786 .6374 L F
.44062 .63355 m .51878 .5552 L .44786 .6374 L F
.43133 .64389 m .51006 .61295 L .49459 .6176 L F
.43133 .64389 m .49459 .6176 L .40519 .64447 L F
.42963 .64456 m .43133 .64389 L .40519 .64447 L F
.51006 .61295 m .51249 .612 L .50933 .61296 L F
.51006 .61295 m .50933 .61296 L .40519 .64447 L F
.51249 .612 m .55264 .59622 L .4981 .61407 L F
.51249 .612 m .4981 .61407 L .40519 .64447 L F
.55264 .59622 m .56848 .58999 L .55659 .59396 L F
.55264 .59622 m .55659 .59396 L .40519 .64447 L F
.42378 .64406 m .56848 .58999 L .55036 .64129 L .678 .748 .903 r
F
.40519 .64447 m .42543 .63771 L .42378 .64406 L F
.42543 .63771 m .56848 .58999 L .42378 .64406 L F
.40519 .64447 m .48834 .64265 L .39807 .63286 L F
.48834 .64265 m .48797 .64198 L .39807 .63286 L F
.49346 .64253 m .48403 .63775 L .39807 .63286 L F
.48834 .64265 m .49346 .64253 L .48797 .64198 L F
.49346 .64253 m .54738 .64136 L .48403 .63775 L F
.54738 .64136 m .55036 .64129 L .54847 .64119 L F
.54738 .64136 m .54847 .64119 L .48373 .6376 L F
.48403 .63775 m .48373 .6376 L .39807 .63286 L F
.54738 .64136 m .48373 .6376 L .48403 .63775 L F
.40899 .63894 m .41399 .63902 L .41405 .64175 L .699 .747 .889 r
F
.41399 .63902 m .55036 .64129 L .41405 .64175 L F
.41405 .64175 m .55036 .64129 L .48671 .6822 L F
.39807 .63286 m .4171 .63391 L .40899 .63894 L F
.4171 .63391 m .55036 .64129 L .40899 .63894 L F
.39807 .63286 m .44798 .66065 L .41355 .61677 L F
.44798 .66065 m .44941 .65927 L .41355 .61677 L F
.45287 .66337 m .45544 .65424 L .41355 .61677 L F
.41477 .67765 m .48671 .6822 L .41517 .69791 L .724 .768 .888 r
F
.41373 .62619 m .45249 .65594 L .41477 .67765 L F
.44798 .66065 m .45287 .66337 L .44941 .65927 L .699 .747 .889 r
F
.45287 .66337 m .48671 .6822 L .45544 .65424 L F
.45249 .65594 m .48671 .6822 L .41477 .67765 L .724 .768 .888 r
F
.41426 .65219 m .41477 .67765 L .43069 .63975 L F
.42265 .62491 m .48671 .6822 L .41373 .62619 L F
.41426 .65219 m .43069 .63975 L .44528 .60501 L F
.41355 .61677 m .42265 .62491 L .41373 .62619 L F
.41355 .61677 m .41426 .65219 L .44528 .60501 L F
.41477 .67765 m .42632 .66352 L .42792 .65858 L F
.42292 .65824 m .42868 .65624 L .44528 .60501 L F
.42081 .66326 m .42792 .65858 L .42868 .65624 L F
.42081 .66326 m .42868 .65624 L .42292 .65824 L F
.41477 .67765 m .42792 .65858 L .42081 .66326 L F
.41477 .67765 m .41517 .69791 L .42632 .66352 L F
.44164 .61625 m .41517 .69791 L .43741 .61411 L .743 .81 .905 r
F
.43693 .61387 m .42381 .66455 L .36716 .68784 L F
.42381 .66455 m .41517 .69791 L .36716 .68784 L F
.43741 .61411 m .41517 .69791 L .43693 .61387 L F
.44267 .61306 m .44164 .61625 L .43768 .61307 L F
.44164 .61625 m .43741 .61411 L .43768 .61307 L F
.43768 .61307 m .43741 .61411 L .43693 .61387 L F
.44528 .60501 m .44267 .61306 L .43768 .61307 L F
.44528 .60501 m .40417 .6486 L .48002 .60348 L F
.40417 .6486 m .40944 .64844 L .48002 .60348 L F
.39661 .65661 m .41531 .65185 L .48002 .60348 L F
.39661 .65661 m .36716 .68784 L .41531 .65185 L F
.46738 .61198 m .36716 .68784 L .46805 .60959 L .737 .86 .938 r
F
.46818 .61233 m .36716 .68784 L .47022 .60983 L F
.40417 .6486 m .39661 .65661 L .40944 .64844 L .743 .81 .905 r
F
.46947 .60849 m .36716 .68784 L .35772 .66157 L .737 .86 .938 r
F
.47022 .60983 m .46738 .61198 L .46947 .60849 L F
.46738 .61198 m .46805 .60959 L .46947 .60849 L F
.47059 .61052 m .46818 .61233 L .47022 .60983 L F
.48002 .60348 m .47059 .61052 L .46947 .60849 L F
.48002 .60348 m .41824 .63282 L .50548 .61273 L F
.41824 .63282 m .42292 .63449 L .50548 .61273 L F
.40453 .63933 m .4221 .64029 L .50548 .61273 L F
.41824 .63282 m .40453 .63933 L .42292 .63449 L F
.40453 .63933 m .35772 .66157 L .4221 .64029 L F
.49499 .61445 m .41 .64362 L .38422 .63254 L .69 .886 .97 r
F
.49431 .61489 m .35772 .66157 L .49499 .61445 L F
.49373 .61662 m .35772 .66157 L .49618 .61425 L F
.49618 .61425 m .49431 .61489 L .49499 .61445 L F
.50548 .61273 m .49373 .61662 L .49618 .61425 L F
.50548 .61273 m .43148 .62482 L .51588 .6292 L F
.43148 .62482 m .38422 .63254 L .44305 .63105 L F
.43148 .62482 m .44305 .63105 L .51588 .6292 L F
.45205 .61596 m .38422 .63254 L .43215 .61183 L .616 .869 .99 r
F
.50943 .62786 m .44348 .63033 L .45205 .61596 L F
.44348 .63033 m .38422 .63254 L .45205 .61596 L F
.50868 .62805 m .38422 .63254 L .50943 .62786 L F
.50593 .62945 m .38422 .63254 L .51011 .628 L F
.51011 .628 m .50868 .62805 L .50943 .62786 L F
.51588 .6292 m .50593 .62945 L .51011 .628 L F
.51588 .6292 m .46497 .61864 L .51228 .64805 L F
.46497 .61864 m .43215 .61183 L .46856 .62829 L F
.46497 .61864 m .46856 .62829 L .51228 .64805 L F
.51041 .64509 m .46185 .62446 L .48481 .60467 L .549 .816 .996 r
F
.51055 .64533 m .50995 .64507 L .51041 .64509 L F
.50995 .64507 m .43215 .61183 L .51041 .64509 L F
.51228 .64805 m .50652 .64545 L .51055 .64533 L F
.50652 .64545 m .43215 .61183 L .51055 .64533 L F
.51228 .64805 m .48481 .60467 L .49954 .66567 L F
.50138 .66242 m .48481 .60467 L .53039 .61114 L .51 .736 .976 r
F
.50133 .6625 m .5013 .66237 L .50138 .66242 L F
.5013 .66237 m .48481 .60467 L .50138 .66242 L F
.49954 .66567 m .49853 .6615 L .50133 .6625 L F
.49853 .6615 m .48481 .60467 L .50133 .6625 L F
.49954 .66567 m .53039 .61114 L .48295 .68046 L F
.48703 .67786 m .53039 .61114 L .56309 .62922 L .499 .644 .921 r
F
.48295 .68046 m .48622 .67569 L .48703 .67786 L F
.48622 .67569 m .53039 .61114 L .48703 .67786 L F
.46185 .62446 m .43215 .61183 L .48481 .60467 L .549 .816 .996 r
F
.41 .64362 m .35772 .66157 L .38422 .63254 L .69 .886 .97 r
F
.4729 .5559 m .48195 .5418 L .50671 .55462 L .672 .769 .923 r
F
.25 g
.35172 .5704 m
.35201 .56149 L
s
1 0 0 r
.003 w
.31713 .66699 m
.32352 .66706 L
s
.45553 .46638 m
.49686 .45231 L
s
.25 g
.5 Mabswid
.35201 .56149 m
.35257 .54452 L
s
.38458 .55266 m
.39117 .54052 L
s
.42692 .54793 m
.42938 .54576 L
s
.31713 .66699 m
.31939 .66475 L
s
1 0 0 r
.003 w
.28576 .64026 m
.31713 .66699 L
s
.29821 .7543 m .19023 .83002 L .1299 .78328 L .614 .61 .824 r
F
.33141 .75477 m .19023 .83002 L .29821 .7543 L .624 .61 .816 r
F
.33141 .75477 m .29091 .84223 L .19023 .83002 L F
.25 g
.5 Mabswid
.41819 .61344 m
.42199 .61364 L
s
.40525 .62264 m
.40577 .62323 L
s
1 0 0 r
.003 w
.36054 .6878 m
.36684 .68694 L
s
.27317 .74513 m .1299 .78328 L .13957 .71141 L .602 .597 .819 r
F
.29821 .7543 m .1299 .78328 L .27317 .74513 L .614 .61 .824 r
F
1 0 0 r
.1299 .78328 m
.19023 .83002 L
s
.35257 .54452 m
.39117 .54052 L
s
.25 g
.5 Mabswid
.40445 .6238 m
.40893 .61727 L
s
.36054 .6878 m
.36487 .68148 L
s
1 0 0 r
.003 w
.3087 .65876 m
.36054 .6878 L
s
.56205 .53828 m
.62478 .58625 L
s
.62478 .58625 m
.63866 .59686 L
s
.58928 .51326 m
.64441 .55364 L
s
.64441 .55364 m
.67466 .57579 L
s
.54575 .5083 m
.58928 .51326 L
s
.46989 .49966 m
.54575 .5083 L
s
.36498 .74811 m .29091 .84223 L .33141 .75477 L .626 .594 .798 r
F
.36498 .74811 m .39893 .82338 L .29091 .84223 L F
1 0 0 r
.19023 .83002 m
.29091 .84223 L
s
.49686 .45231 m
.55205 .44769 L
s
.44721 .51892 m
.56205 .53828 L
s
.39117 .54052 m
.42938 .54576 L
s
.25 g
.5 Mabswid
.45867 .65713 m
.48364 .67946 L
s
.48401 .67979 m
.48671 .6822 L
s
.45544 .65424 m
.45867 .65713 L
s
.45503 .65387 m
.45544 .65424 L
s
.43571 .63659 m
.45503 .65387 L
s
1 0 0 r
.003 w
.41517 .69791 m
.48671 .6822 L
s
.50759 .66878 m
.5078 .66865 L
s
.48671 .6822 m
.50759 .66878 L
s
.53442 .65154 m
.55036 .64129 L
s
.5078 .66865 m
.53442 .65154 L
s
.68713 .48795 m
.73527 .53691 L
s
.25 g
.5 Mabswid
.41517 .69791 m
.42632 .66352 L
s
.42632 .66352 m
.42792 .65858 L
s
.42792 .65858 m
.42889 .65558 L
s
.42889 .65558 m
.43483 .63725 L
s
1 0 0 r
.003 w
.36716 .68784 m
.41517 .69791 L
s
.25 g
.5 Mabswid
.4696 .55792 m
.4787 .54605 L
s
.42886 .61109 m
.42912 .61075 L
s
.4787 .54605 m
.48195 .5418 L
s
1 0 0 r
.003 w
.42938 .54576 m
.4326 .5473 L
s
.27317 .74513 m .13957 .71141 L .26395 .7288 L .602 .597 .819 r
F
.25295 .73668 m .12072 .7953 L .10683 .71502 L .593 .589 .817 r
F
.28517 .73815 m .12072 .7953 L .25295 .73668 L .606 .609 .828 r
F
.28517 .73815 m .23452 .82842 L .12072 .7953 L F
.25 g
.5 Mabswid
.19023 .83002 m
.20484 .81978 L
s
.28576 .64026 m
.321 .62711 L
s
.321 .62711 m
.32179 .62682 L
s
.32179 .62682 m
.32252 .62654 L
s
1 0 0 r
.003 w
.28576 .64026 m
.30705 .59472 L
s
.25 g
.5 Mabswid
.38423 .55269 m
.39906 .57124 L
s
.26395 .7288 m .13957 .71141 L .22892 .63968 L .594 .577 .804 r
F
1 0 0 r
.003 w
.13845 .71971 m
.13957 .71141 L
s
.55205 .44769 m
.61906 .45795 L
s
.25 g
.5 Mabswid
.48023 .59384 m
.50853 .56547 L
s
.47019 .60391 m
.48023 .59384 L
s
.50853 .56547 m
.51878 .5552 L
s
.31676 .72656 m .23452 .82842 L .28517 .73815 L .619 .615 .825 r
F
.39388 .73737 m .39893 .82338 L .36498 .74811 L .617 .567 .776 r
F
.31676 .72656 m .38695 .79551 L .23452 .82842 L .619 .615 .825 r
F
.25 g
.29091 .84223 m
.30428 .81336 L
s
1 0 0 r
.003 w
.12072 .7953 m
.23452 .82842 L
s
.25 g
.5 Mabswid
.30705 .59472 m
.34797 .5963 L
s
.34797 .5963 m
.34901 .59634 L
s
.33353 .64848 m
.37072 .63309 L
s
.37072 .63309 m
.37357 .63191 L
s
.37357 .63191 m
.42522 .61052 L
s
.3087 .65876 m
.33353 .64848 L
s
.36498 .74811 m
.3859 .79448 L
s
.39388 .73737 m .48897 .78451 L .39893 .82338 L .617 .567 .776 r
F
.25 g
.38642 .79562 m
.39893 .82338 L
s
1 0 0 r
.003 w
.29091 .84223 m
.39893 .82338 L
s
.25 g
.5 Mabswid
.5447 .64098 m
.54847 .64119 L
s
.48938 .63791 m
.48992 .63794 L
s
.48373 .6376 m
.48938 .63791 L
s
.54847 .64119 m
.55036 .64129 L
s
1 0 0 r
.003 w
.55036 .64129 m
.55215 .63621 L
s
.55601 .6253 m
.56848 .58999 L
s
.25 g
.5 Mabswid
.42537 .5709 m
.43601 .59191 L
s
.43601 .59191 m
.43689 .59363 L
s
.43689 .59363 m
.44307 .60583 L
s
.42018 .56066 m
.42537 .5709 L
s
.36716 .68784 m
.40807 .65726 L
s
.40807 .65726 m
.42031 .6481 L
s
.42031 .6481 m
.43764 .63516 L
s
1 0 0 r
.003 w
.35772 .66157 m
.36716 .68784 L
s
.25295 .73668 m .10683 .71502 L .23736 .72246 L .593 .589 .817 r
F
.25218 .73323 m .10066 .80165 L .21868 .73234 L .602 .617 .839 r
F
1 0 0 r
.12028 .79279 m
.12072 .7953 L
s
.25218 .73323 m .20888 .82532 L .10066 .80165 L .602 .617 .839 r
F
.25 g
.5 Mabswid
.54716 .59711 m
.55659 .59396 L
s
.51265 .60862 m
.54716 .59711 L
s
.55659 .59396 m
.56848 .58999 L
s
1 0 0 r
.003 w
.61906 .45795 m
.68713 .48795 L
s
.23736 .72246 m .10683 .71502 L .20286 .63185 L .588 .565 .796 r
F
1 0 0 r
.10683 .71502 m
.11986 .79037 L
s
.10683 .71502 m
.19833 .63578 L
s
0 g
.006 w
.34311 .75245 m
.36498 .74811 L
s
.25 g
.5 Mabswid
.39082 .60849 m
.39376 .60866 L
s
.39376 .60866 m
.42969 .61079 L
s
.48295 .68046 m .56309 .62922 L .46612 .69262 L .499 .644 .921 r
F
.46612 .69262 m .57994 .65721 L .45031 .70334 L .509 .564 .847 r
F
.46612 .69262 m .56309 .62922 L .57994 .65721 L F
.25 g
.48295 .68046 m
.48405 .67885 L
s
.51342 .63593 m
.53039 .61114 L
s
0 g
.006 w
.46612 .69262 m
.48295 .68046 L
s
.25 g
.5 Mabswid
.43791 .63506 m
.48373 .6376 L
s
.48481 .60467 m
.49017 .62685 L
s
.49017 .62685 m
.49146 .63221 L
s
.45031 .70334 m .57707 .69415 L .43459 .714 L .534 .519 .785 r
F
.45031 .70334 m .57994 .65721 L .57707 .69415 L F
0 g
.006 w
.45031 .70334 m
.46612 .69262 L
s
.25 g
.5 Mabswid
.49146 .63221 m
.4922 .63526 L
s
.4922 .63526 m
.49785 .65868 L
s
.46612 .69262 m
.46953 .69039 L
s
.46953 .69039 m
.4719 .68884 L
s
.5302 .65073 m
.56309 .62922 L
s
.50992 .64105 m
.51342 .63593 L
s
.48601 .67599 m
.48622 .67569 L
s
.48405 .67885 m
.48601 .67599 L
s
.43459 .714 m .54858 .73824 L .41664 .72543 L .566 .514 .757 r
F
.43459 .714 m .57707 .69415 L .54858 .73824 L F
0 g
.006 w
.43459 .714 m
.45031 .70334 L
s
.25 g
.5 Mabswid
.43459 .714 m
.43481 .71397 L
s
.45031 .70334 m
.45715 .70091 L
s
.54075 .67115 m
.57994 .65721 L
s
.41664 .72543 m .48897 .78451 L .39388 .73737 L .596 .536 .758 r
F
0 g
.006 w
.36498 .74811 m
.39388 .73737 L
s
.28488 .72227 m .20888 .82532 L .25218 .73323 L .618 .624 .835 r
F
.28488 .72227 m .35004 .796 L .20888 .82532 L F
.25 g
.5 Mabswid
.23452 .82842 m
.23987 .81888 L
s
.14162 .7776 m
.21868 .73234 L
s
.10066 .80165 m
.14162 .7776 L
s
1 0 0 r
.003 w
.10066 .80165 m
.20888 .82532 L
s
.25 g
.5 Mabswid
.20888 .82532 m
.25218 .73323 L
s
0 g
.006 w
.40843 .62208 m
.41355 .61677 L
s
.41664 .72543 m .54858 .73824 L .48897 .78451 L .596 .536 .758 r
F
.25 g
.5 Mabswid
.52961 .7364 m
.54858 .73824 L
s
0 g
.006 w
.39388 .73737 m
.41664 .72543 L
s
1 0 0 r
.003 w
.39893 .82338 m
.48897 .78451 L
s
0 g
.006 w
.41664 .72543 m
.43459 .714 L
s
.25 g
.5 Mabswid
.39388 .73737 m
.48897 .78451 L
s
.26395 .7288 m .22892 .63968 L .27374 .7106 L .594 .577 .804 r
F
0 g
.006 w
.26395 .7288 m
.26418 .72921 L
s
.25 g
.5 Mabswid
.24076 .72556 m
.26395 .7288 L
s
1 0 0 r
.003 w
.30705 .59472 m
.38423 .55269 L
s
.48195 .5418 m
.50889 .55575 L
s
.25 g
.5 Mabswid
.45897 .63064 m
.47298 .63029 L
s
.41088 .644 m
.4221 .64029 L
s
.4221 .64029 m
.45065 .63085 L
s
.27374 .7106 m .36747 .60464 L .29749 .69815 L .596 .562 .787 r
F
.27374 .7106 m .22892 .63968 L .36747 .60464 L F
1 0 0 r
.003 w
.32758 .61473 m
.33176 .60499 L
s
.25 g
.5 Mabswid
.3657 .607 m
.39082 .60849 L
s
.35364 .60628 m
.35959 .60664 L
s
.33176 .60499 m
.35364 .60628 L
s
0 g
.006 w
.26395 .7288 m
.27374 .7106 L
s
.25 g
.5 Mabswid
.35772 .66157 m
.41088 .644 L
s
.22892 .63968 m
.27374 .7106 L
s
1 0 0 r
.003 w
.21124 .65387 m
.22892 .63968 L
s
0 g
.006 w
.4308 .61038 m
.44528 .60501 L
s
.41355 .61677 m
.4308 .61038 L
s
1 0 0 r
.003 w
.51878 .5552 m
.56848 .58999 L
s
.22892 .63968 m
.24172 .63644 L
s
0 g
.006 w
.48002 .60348 m
.48371 .60482 L
s
.33093 .7095 m .38695 .79551 L .31676 .72656 L .625 .605 .81 r
F
.33093 .7095 m .4904 .7137 L .38695 .79551 L F
1 0 0 r
.003 w
.23452 .82842 m
.38695 .79551 L
s
.25 g
.5 Mabswid
.31676 .72656 m
.38695 .79551 L
s
1 0 0 r
.003 w
.48897 .78451 m
.54858 .73824 L
s
.25 g
.5 Mabswid
.46912 .73053 m
.52961 .7364 L
s
1 0 0 r
.003 w
.39787 .57184 m
.42018 .56066 L
s
0 g
.006 w
.44528 .60501 m
.48002 .60348 L
s
.29555 .73434 m
.31676 .72656 L
s
.23736 .72246 m .20286 .63185 L .24578 .7035 L .588 .565 .796 r
F
0 g
.23736 .72246 m
.24907 .73314 L
s
.25 g
.5 Mabswid
.10683 .71502 m
.23736 .72246 L
s
.29749 .69815 m .48019 .63323 L .3218 .69767 L .607 .565 .781 r
F
.25 g
.47983 .63338 m
.4932 .63943 L
s
.29749 .69815 m .36747 .60464 L .48019 .63323 L .607 .565 .781 r
F
.25 g
.47376 .63064 m
.4786 .63283 L
s
0 g
.006 w
.27374 .7106 m
.29749 .69815 L
s
.25 g
.5 Mabswid
.46856 .62829 m
.47376 .63064 L
s
.46124 .62498 m
.46856 .62829 L
s
1 0 0 r
.003 w
.38423 .55269 m
.48195 .5418 L
s
.54858 .73824 m
.57707 .69415 L
s
.3218 .69767 m .4904 .7137 L .33093 .7095 L .62 .584 .792 r
F
.25 g
.5 Mabswid
.29749 .69815 m
.30964 .68191 L
s
.3218 .69767 m .48019 .63323 L .4904 .7137 L .62 .584 .792 r
F
.25 g
.48741 .69014 m
.54075 .67115 L
s
.48947 .70635 m
.57707 .69415 L
s
0 g
.006 w
.29749 .69815 m
.3218 .69767 L
s
.25 g
.5 Mabswid
.48607 .67958 m
.5302 .65073 L
s
.48622 .67569 m
.50992 .64105 L
s
.24578 .7035 m .35458 .59694 L .27106 .69084 L .595 .555 .779 r
F
.24578 .7035 m .20286 .63185 L .35458 .59694 L F
0 g
.006 w
.23736 .72246 m
.24578 .7035 L
s
1 0 0 r
.003 w
.34208 .59981 m
.39787 .57184 L
s
.25 g
.5 Mabswid
.20286 .63185 m
.24578 .7035 L
s
1 0 0 r
.003 w
.19833 .63578 m
.20286 .63185 L
s
.30197 .70511 m .35004 .796 L .28488 .72227 L .627 .615 .819 r
F
.30197 .70511 m .45775 .71965 L .35004 .796 L F
1 0 0 r
.20888 .82532 m
.35004 .796 L
s
0 g
.006 w
.3218 .69767 m
.32953 .70768 L
s
.25 g
.5 Mabswid
.28488 .72227 m
.35004 .796 L
s
1 0 0 r
.003 w
.38695 .79551 m
.4314 .76036 L
s
.25 g
.5 Mabswid
.35613 .71017 m
.4493 .71262 L
s
0 g
.006 w
.21868 .73234 m
.25218 .73323 L
s
1 0 0 r
.003 w
.42018 .56066 m
.51878 .5552 L
s
0 g
.006 w
.25218 .73323 m
.28488 .72227 L
s
.27106 .69084 m .46333 .63498 L .29549 .69177 L .611 .567 .78 r
F
.27106 .69084 m .35458 .59694 L .46333 .63498 L F
.25 g
.5 Mabswid
.3218 .69767 m
.3727 .67697 L
s
0 g
.006 w
.24578 .7035 m
.27106 .69084 L
s
1 0 0 r
.003 w
.20286 .63185 m
.35458 .59694 L
s
.41871 .61764 m
.43215 .61183 L
s
.25 g
.5 Mabswid
.43215 .61183 m
.46124 .62498 L
s
1 0 0 r
.003 w
.57707 .69415 m
.57994 .65721 L
s
.43215 .61183 m
.48481 .60467 L
s
.29549 .69177 m .45775 .71965 L .30197 .70511 L .624 .592 .797 r
F
.29549 .69177 m .46333 .63498 L .45775 .71965 L F
1 0 0 r
.4314 .76036 m
.4904 .7137 L
s
.35004 .796 m
.45775 .71965 L
s
.25 g
.5 Mabswid
.4582 .71286 m
.4904 .7137 L
s
0 g
.006 w
.27106 .69084 m
.29549 .69177 L
s
.28488 .72227 m
.30197 .70511 L
s
.25 g
.5 Mabswid
.29549 .69177 m
.396 .65776 L
s
.42138 .64917 m
.46333 .63498 L
s
.396 .65776 m
.42138 .64917 L
s
.27106 .69084 m
.35458 .59694 L
s
.46298 .64024 m
.48019 .63323 L
s
0 g
.006 w
.29549 .69177 m
.30197 .70511 L
s
.25 g
.5 Mabswid
.30197 .70511 m
.37759 .71217 L
s
.37759 .71217 m
.45775 .71965 L
s
1 0 0 r
.003 w
.56309 .62922 m
.57994 .65721 L
s
.40071 .61307 m
.48019 .63323 L
s
.48207 .64803 m
.4867 .68456 L
s
.4867 .68456 m
.4904 .7137 L
s
.48019 .63323 m
.48207 .64803 L
s
.53039 .61114 m
.56309 .62922 L
s
.48481 .60467 m
.53039 .61114 L
s
.4593 .6962 m
.46333 .63498 L
s
.45775 .71965 m
.4593 .6962 L
s
.35458 .59694 m
.46333 .63498 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.313, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400049000181000`40O003h00Oogoo2Woo002`Ool2
001GOol00:ioo`800003Ool0000005Ioo`00Zgoo0`000goo0P00EWoo002YOol20006Ool00`00Ool0
001EOol00:Moo`8000Qoo`03001oo`0005Eoo`00Y7oo0`002Woo00@007ooOol005Aoo`00XWoo0P00
3Goo00D007ooOomoo`0005=oo`00Wgoo0`003goo00D007ooOomoo`0005=oo`00WGoo0P004Woo00<0
07ooOol00Woo00<007ooOol0D7oo002KOol2000EOol00`00Oomoo`02Ool00`00Oomoo`1?Ool009Qo
o`<001Moo`03001oogoo009oo`03001oogoo04moo`00UWoo0P006Woo00<007ooOol00goo00<007oo
Ool0CWoo002COol3000LOol00`00Oomoo`03Ool00`00Oomoo`1>Ool0095oo`8001moo`03001oogoo
00Aoo`03001oogoo04eoo`00Sgoo0P008Goo00<007ooOol01Goo00<007ooOol0C7oo002<Ool3000S
Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool008Yoo`8002Ioo`03001oogoo00Ioo`03001oogoo04]o
o`00Qgoo0`00:7oo00<007ooOol01goo00<007ooOol0BWoo0025Ool2000[Ool00`00Oomoo`07Ool0
0`00Oomoo`1:Ool008=oo`8002eoo`03001oogoo00Qoo`03001oogoo04Uoo`00P7oo0`00;goo00<0
07ooOol027oo00<007ooOol0BGoo001nOol2000bOol00`00Oomoo`09Ool00`00Oomoo`18Ool007]o
o`<003Aoo`03001oogoo00Yoo`03001oogoo04Moo`00NGoo0P00=goo00<007ooOol02Woo00<007oo
Ool0Agoo001gOol2000iOol00`00Oomoo`0;Ool00`00Oomoo`16Ool007Aoo`<003]oo`03001oogoo
00aoo`03001oogoo04Eoo`00LWoo0P00?goo00<007ooOol02goo00<007ooOol0AGoo001_Ool30011
Ool00`00Oomoo`0<Ool00`00Oomoo`14Ool006eoo`8004Aoo`03001oogoo00aoo`03001oogoo04Ao
o`00Jgoo0P00AWoo00<007ooOol03Goo00<007ooOol0@goo001XOol30018Ool00`00Oomoo`0>Ool0
0`00Oomoo`12Ool006Ioo`8004]oo`03001oogoo00ioo`03001oogoo049oo`00Hgoo0`00CGoo00<0
07ooOol03goo00<007ooOol0@Goo001QOol2001@Ool00`00Oomoo`0@Ool00`00Oomoo`10Ool005io
o`<0059oo`03001oogoo011oo`03001oogoo041oo`00G7oo0P00EGoo00<007ooOol04Goo00<007oo
Ool0?goo001JOol2001GOol00`00Oomoo`0AOol00`00Oomoo`0oOol005Moo`<005Uoo`03001oogoo
019oo`03001oogoo03ioo`00EGoo0P00G7oo00<007ooOol04goo00<007ooOol0?Goo001BOol3001N
Ool00`00Oomoo`0COol00`00Oomoo`0mOol0051oo`80065oo`03001oogoo01Aoo`03001oogoo03ao
o`00CWoo0P00Hgoo00<007ooOol05Goo00<007ooOol0>goo001;Ool3001UOol00`00Oomoo`0EOol0
0`00Oomoo`0kOol004Uoo`8006Uoo`03001oogoo01Eoo`03001oogoo03Yoo`00AWoo0`00Jgoo00<0
07ooOol05Goo00<007ooOol0>Woo0014Ool2001^Ool00`00Oomoo`0FOol00`00Oomoo`0iOol0049o
o`80071oo`03001oogoo01Moo`03001oogoo03Qoo`00?goo0`00LWoo00<007ooOol05goo00<007oo
Ool0>7oo000mOol2001eOol00`00Oomoo`0HOol00`00Oomoo`0gOol003Yoo`<007Moo`03001oogoo
01Uoo`03001oogoo03Ioo`00>7oo0P00NWoo00<007ooOol06Goo00<007ooOol0=Woo000fOol2001l
Ool00`00Oomoo`0JOol00`00Oomoo`0eOol003=oo`<007ioo`03001oogoo01Yoo`03001oogoo03Eo
o`00<Goo0P00PGoo00<007ooOol06goo00<007ooOol0=7oo000^Ool30023Ool00`00Oomoo`0LOol0
0`00Oomoo`0cOol002aoo`8008Ioo`03001oogoo01aoo`03001oogoo03=oo`00:Woo0P00R7oo00<0
07ooOol07Goo00<007ooOol0<Woo000WOol3002:Ool00`00Oomoo`0NOol00`00Oomoo`0aOol002Eo
o`8008eoo`03001oogoo01ioo`03001oogoo035oo`008Woo0`00Sgoo00<007ooOol07goo00<007oo
Ool0<7oo000POol2002COol00`00Oomoo`0NOol00`00Oomoo`0`Ool001ioo`8009Eoo`03001oogoo
01moo`03001oogoo02moo`006goo0`00Ugoo00<007ooOol087oo00<007ooOol0;Woo000IOol2002J
Ool00`00Oomoo`0POol00`00Oomoo`0^Ool001Moo`8009aoo`03001oogoo025oo`03001oogoo02eo
o`005goo0P00W7oo00<007ooOol08Woo00<007ooOol0;7oo000GOol00`00Ool0002KOol00`00Oomo
o`0ROol00`00Oomoo`0/Ool001Moo`04001oogoo002JOol00`00Oomoo`0SOol00`00Oomoo`0[Ool0
01Ioo`03001oogoo009oo`03001oogoo09Moo`03001oogoo02=oo`03001oogoo02]oo`005Woo00<0
07ooOol00goo00<007ooOol0UWoo00<007ooOol097oo00<007ooOol0:Woo000FOol00`00Oomoo`04
Ool00`00Oomoo`2EOol00`00Oomoo`0UOol00`00Oomoo`0YOol001Ioo`03001oogoo00Eoo`03001o
ogoo09Aoo`03001oogoo02Eoo`03001oogoo02Uoo`005Woo00<007ooOol01Woo00<007ooOol0Tgoo
00<007ooOol09Woo00<007ooOol0:7oo000FOol00`00Oomoo`07Ool00`00Oomoo`2BOol00`00Oomo
o`0WOol00`00Oomoo`0WOol001Eoo`03001oogoo00Uoo`03001oogoo095oo`03001oogoo02Moo`03
001oogoo02Moo`005Goo00<007ooOol02Woo00<007ooOol0T7oo00<007ooOol0:7oo00<007ooOol0
9Woo000EOol00`00Oomoo`0;Ool00`00Oomoo`2?Ool00`00Oomoo`0XOol00`00Oomoo`0VOol001Eo
o`03001oogoo00aoo`03001oogoo08moo`03001oogoo02Qoo`03001oogoo02Eoo`005Goo00<007oo
Ool03Goo00<007ooOol0SWoo00<007ooOol0:Goo00<007ooOol097oo000EOol00`00Oomoo`0>Ool0
0`00Oomoo`2=Ool00`00Oomoo`0YOol00`00Oomoo`0TOol001Eoo`03001oogoo00moo`03001oogoo
08aoo`03001oogoo02Yoo`03001oogoo02=oo`0057oo00<007ooOol04Goo00<007ooOol0Rgoo00<0
07ooOol0:goo00<007ooOol08Woo000DOol00`00Oomoo`0BOol00`00Oomoo`2:Ool00`00Oomoo`0[
Ool00`00Oomoo`0ROol001Aoo`03001oogoo01=oo`03001oogoo08Uoo`03001oogoo02aoo`03001o
ogoo025oo`0057oo00<007ooOol057oo00<007ooOol0R7oo00<007ooOol0;7oo00<007ooOol08Goo
000DOol00`00Oomoo`0EOol00`00Oomoo`27Ool00`00Oomoo`0]Ool00`00Oomoo`0POol001Aoo`03
001oogoo01Ioo`03001oogoo08Ioo`03001oogoo02ioo`03001oogoo01moo`004goo00<007ooOol0
5goo00<007ooOol0QWoo00<007ooOol0;Woo00<007ooOol07goo000COol00`00Oomoo`0HOol00`00
Oomoo`25Ool00`00Oomoo`0_Ool00`00Oomoo`0NOol001=oo`03001oogoo01Uoo`03001oogoo08Ao
o`03001oogoo031oo`03001oogoo01eoo`004goo00<007ooOol06Woo00<007ooOol0Pgoo00<007oo
Ool0<7oo00<007ooOol07Goo000COol00`00Oomoo`0KOol00`00Oomoo`22Ool01000Oomoogoo2G`0
9goo00<007ooOol077oo000COol00`00Oomoo`0LOol00`00Oomoo`1eOol<O0003@00O01l07`0EaaB
o5LLD_aG75;l7>MFneLL009l02Eoo`03001oogoo01aoo`004Woo00<007ooOol07Woo00<007ooOol0
Jgoo2G`001]Fo5LLE_aG75KlEaaFo5LLE_aG75KlEa`005LLE_aG75KlEaaFo5LLE_`LieKlEaaFo5LL
E_`00g`08goo00<007ooOol06goo000BOol00`00Oomoo`0OOol00`00Oomoo`1XOol2O0009e<L7>MB
o5LLD_aG75;lEaaBo5LLD_aG75;lEaaBo5LLD_aG75;lEaaBo000D_aG75;lEaaBo5LLD_`LieKkEaaF
o5LLE_]G75KlEaaFn`02O00ROol00`00Oomoo`0JOol0019oo`03001oogoo021oo`03001oogoo06Ao
o`=l000MEaeC75LL7>MG75KlEaaFo5LLE_aG75KlEaaFo5LLE_aG75KlEaaFo5LLE_aG75Kl001Fo5LL
E_aG70027>L035KlEaaFo5LLE_aG75KlEaaFo5LLE_aG70=l01moo`03001oogoo01Yoo`004Woo00<0
07ooOol08Goo00<007ooOol0HGoo0W`0035G7E<LEaeC75LMDa`Lie;lEaaBo5LLD_aG75;lEaaBo5LL
D_aG75;lEaaBo5LLD_aG75;lEa`005LLD_aG71cWEaaFneLLE_aG75KkEaaFo5LLE_]G75KlEaaFneLL
E_aG7002O00NOol00`00Oomoo`0IOol0019oo`03001oogoo029oo`03001oogoo05eoo`=l0005DaaG
75LLEaeC7002Ea`055LM7>MG75KlEaaFo5LLE_aG75KlEaaFo5LLE_aG75KlEaaFo5LLE_`2O0006000
O01l01cWEaaFo5LLE_aG75KlEaaFo5LLE_aG75KlEaaFo5LLE_aG75KlEaaFo0=l01aoo`03001oogoo
01Qoo`004Woo00<007ooOol08goo00<007ooOol0FWoo0W`001]C75LMDaaG7E<LEaeC75LMDaaG7E<L
7>MBo5LLD_aG75;lEaaBo5LLD_aG75;lEaaBo5LLD_`00g`000EFo1cW001G71cW00Ql000@EaaFneLL
E_aG75KkEaaFo5LLE_]G75KlEaaFneLLE_`2O00JOol00`00Oomoo`0HOol0019oo`03001oogoo02Ao
o`03001oogoo05Moo`9l009G7006EaeC75LLEaaG7E<L0ULL011G7E<LEa`LieLLE_aG75KlEaaFo5LL
E_aG75KlEaaFo0=l00=Fo00=7>MFo000E_aG75KlEaaFo5LLE_aG75KlEa`027`000YFo5LLE_aG75Kl
EaaFo5LLE_aG709l01Uoo`03001oogoo01Moo`004Goo00<007ooOol09Woo00<007ooOol0Dgoo0g`0
01QC75LMDaaG7E<LEaeC75LMDaaG7E<LEaeC75LMDa`Lie;lEaaBo5LLD_aG75;lEa`4O0006e;lEaaB
o5LLD_aG71cWEa`005LLE_]G75KlEaaFneLLE_aG75KkEaaFo5LLE_]G75KlEaaFn`08O0027>L00eLL
O01oo`0HOol00`00Oomoo`0GOol0015oo`03001oogoo02Moo`03001oogoo051oo`9l0003EaaG7E<L
009G7006EaeC75LLEaaG7E<L0ULL00]G7E<LEaaG75LM7>MG75KlEaaFo5LL00=l00UFo0047>Ml07`0
000=O0002eLLE_aG75KlEaaFo5LLE_aG75KlEa`00QcW17`06Woo00<007ooOol05Woo000AOol00`00
Oomoo`0XOol00`00Oomoo`1<Ool3O0005eLMDaaG7E<LEaeC75LMDaaG7E<LEaeC75LMDaaG7E<LEaeC
75LMDa`Lie;lEa`00g`000YG75;lEaaBo5LLD_aG75;lEaaBo0=l000@D_`Li`00EaaFneLLE_]G75Kk
EaaFneLLE_]G75KkEa`@O0000gooO01oo`0IOol00`00Oomoo`0EOol0015oo`03001oogoo02Uoo`03
001oogoo04Uoo`9l0006EaeC75LLEaaG7E<L0ULL00IG7E<LEaaG75LMDa`2Ea`01eLMDaaG75LLEaeC
75LL00=l00YFo0=l00=Fo0037>MFo00001YFo08Li`03Eaal07`001Yoo`03001oogoo01Eoo`004Goo
00<007ooOol0:Woo00<007ooOol0AWoo0W`001IC75LMDaaG7E<LEaeC75LMDaaG7E<LEaeC75LMDaaG
7E<LEaeC75LMDaaG7@=l000:7>MBo5LLD_aG75;lEaaBo5LLD_`3O0009e;lE_aBneKlD_aFo1cWEa`0
05LLE_]G75KkEaaFneLLE_]G75KkEaaFneLLE_]G75KkEaaFneLLE_]G75KkEaaFneLL7>MK75LLFaaG
6`02O00JOol00`00Oomoo`0DOol0015oo`03001oogoo02]oo`03001oogoo04=oo`9l0004EadLiacW
Da`2Ea`01ULMDaaG75LLEaeC709G7006EaeC75LLEaaG7E<L17`02UKl0g`02EKl00<LieKl000065Kl
00<Lie/LEa`00ULL00AK75LLEaal01Yoo`03001oogoo01=oo`0047oo00<007ooOol0;Goo00<007oo
Ool0@Goo00Il05<LEaeC75LMDa`27>L035LMDaaG7E<LEaeC75LMDaaG7E<LEaeC70=l000;DaaG75;l
EaaBo5LLD_aG75;lEaaBo003O0009E;lE_aBneKlD_aFo5;kE_aBo5KlD_/LieKkEa`005LLE_]G75Kk
EaaFneLLE_]G75KkEaaFneLLE_]G75KkEaaFneLLE_]G75Kk008Li`0:FaaG75/LEa]K75LLFaaG6e/L
O00IOol00`00Oomoo`0COol0011oo`03001oogoo02ioo`03001oogoo03moo`09O01G75LMEaaG7ELL
EaeG75LM008Li`03EaaG7E<L009G7003EaeC77`0009l0003DaaFo5Kl00UFo09l00iFo0047>MFo5Kl
000EE_`00acWEaaK7003Ea`01E/LEaaG75LLFa`00ULL0W`067oo00<007ooOol04Woo000@Ool00`00
Oomoo`0_Ool00`00Oomoo`0lOol2O0002e<LEaeC75LMDaaG7E<LEaeC75LMDa`00QcW00=G7E<LEad0
0W`000aC75LLD_aG75;lEaaBo5LLD_aG75;lEa`3O0009eKlD_]Fo5;lE_aBneKlD_aFo5;kE_aBo5Kl
D_]Fo5;l7>MFneLL001G75KkEaaFneLLE_]G75KkEaaFneLLE_]G75KkEaaFneLLE_]G70027>L045LK
FaaG75/LEa]K75LLFaaG6e/LEaaK75LKFaaG77`05goo00<007ooOol04Woo000@Ool00`00Oomoo`0`
Ool00`00Oomoo`0jOol03W`0EaeG75LMEaaG7ELLEaeG75LMEaaG7ELLEad2Ea`00acWO01l000;E_`3
O00BE_`01AcWE_aFo5Kl00004UKl00@LieLLEaaK70=G7005FaaG75LLEaaK7003Ea`01E/LEaaG75LL
O0005Woo0P004goo000@Ool00`00Oomoo`0aOol00`00Oomoo`0hOol047`0EaeC75LMDaaG7E<LEaeC
75LMDaaG7E<LEaeC75LM0W`000YBo5LLD_aG75;lEaaBo5LLD_aG70=l000ZE_aBneKlD_aFo5;kE_aB
o5KlD_]Fo5;lE_aBneKlD_aFo5;kE_aBo5Kl7>MG75KkEa`005LLE_]G75KkEaaFneLLE_]G75KkEaaF
neLLE_]G75Kk0QcW01AK75LKFaaG75/LEa]K75LLFaaG6e/LEaaK75LKFaaG75/LEa]K75LL0W`04Goo
0`0000=oo`00Ool04Woo000@Ool00`00Oomoo`0bOol00`00Oomoo`0eOol2O0004ELMEaaG7ELLEaeG
75LMEaaG7ELLEaeG75LMEaaG7G`0Ea`00QcW1UKl0g`065Kl00DLieKlE_aFo00000mFo0057>MG75LL
EaaK7003Ea`01E/LEaaG75LLFa`00eLL00EK75LLEaaG75/L00=G7003Faal07oo00aoo`<000Aoo`03
001oogoo015oo`0047oo00<007ooOol0<goo00<007ooOol0<goo01Il05<LEaeC75LMDaaG7E<LEaeC
75LMDaaG7E<LEaeC75LMO01G7E;lEaeBo08Li`1>Eaal07`0O01Fo5;kE_aBo5KlD_]Fo5;lE_aBneKl
D_aFo5;kE_aBo5KlD_]Fo5;lE_aBneKlD_aFo5;k7>MFneLLE_]G75Kk001FneLLE_]G75KkEaaFneLL
E_]G75KkEaaFnacWEaaK75LKFaaG75/LEa]K75LLFaaG6e/LEaaK75LKFaaG75/LEa]K75LLFaaG6e/L
Ea`Lig`02Goo0`001goo00<007ooOol04Goo000?Ool00`00Oomoo`0eOol00`00Oomoo`0`Ool2O000
4eLLEaeG75LMEaaG7ELLEaeG75LMEaaG7ELLEaeG75LMO01G75<L00=G7003Daal07`001eFo0037>MF
o5Kl00=Fo003001Fo5Kl00UFo08Li`=G7005FaaG75LLEaaK7003Ea`01E/LEaaG75LLFa`00eLL00AK
75LLEaaG70<Li`03Eaal07oo00Eoo`<000]oo`03001oogoo011oo`003goo00<007ooOol0=Woo00<0
07ooOol0;Woo01]l05LMDaaG7E<LEaeC75LMDaaG7E<LEaeC75LMDaaG7E<LEael05LMD_aG7E;lEaeB
o7`0D_`00QcW04AFo5;kE_aBo5KlD_]Fo5;lE_aBneKlD_aFo5;kE_aBo5KlD_]Fo5;lE_aBneKlD_aF
o5;kE_`LieLLE_]G75KkEaaFn`00E_]G75KkEaaFneLLE_]G75KkEa`Lie/LEaaK75LKFaaG75/LEa]K
75LLFaaG6e/LEaaK75LKFaaG75/LEa]K75LL0acW00AG75/lEaal00Aoo`<000ioo`03001oogoo011o
o`003goo00<007ooOol0=goo00<007ooOol0;7oo01El05LMEaaG7ELLEaeG75LMEaaG7ELLEaeG75LM
EaaG7ELLEael05LLDa`00eLL00MC77`0D_aG75;lEa`Li`0JE_`00acWE_aFo004E_`00`00E_aFo006
E_`27>L01E/LEaaG75LLFa`00eLL00EK75LLEaaG75/L00=G7004FaaG75LLEa`37>L025LLFaaG75/L
EaaK77`0Ool3000AOol00`00Oomoo`0@Ool000moo`03001oogoo03Qoo`03001oogoo02Uoo`9l000O
EaeC75LMDaaG7E<LEaeC75LMDaaG7E<LEaeC75LMDaaG7G`0EaeBo5LMD_aG7E;lO01Bo5LMD_aG7E;l
Ead00QcW03]BneKlD_aFo5;kE_aBo5KlD_]Fo5;lE_aBneKlD_aFo5;kE_aBo5KlD_]Fo5;lE_`LieLL
E_]G75KkEaaFn`00E_]G75KkEaaFneLLE_/LieLKFaaG75/LEa]K75LLFaaG6e/LEaaK75LKFaaG75/L
Ea]K75LL00<Li`0;EaaK?5LLFceG75/lEaaK?ELLO000000DOol00`00Oomoo`0@Ool000moo`03001o
ogoo03Uoo`03001oogoo02Moo`03O00LiacW00HLi`0=EaaG7ELLEaeG75LMEaaG7ELLEael05LLDa`0
0eLL00aC77`0D_aG75;lEaaBo5LLD_aG75;l7>LFE_`00acWE_aFo005E_`00`00E_aFo003E_`27>L0
0eLLFaaG7002Ea`01E/LEaaG75LLFa`00eLL00AK75LLEaaG70<Li`0<EaaK75LLFaaG75/LEaaK75LL
FaaG77`05Woo00<007ooOol047oo000?Ool00`00Oomoo`0jOol00`00Oomoo`0UOol02W`0EaaG?ELL
FceG75LmEaaK?ELL21cW0W`000=G7E;lEad02G`000IG7E;lEaeBo5LMD_`27>L0<eKlD_aFo5;kE_aB
o5KlD_]Fo5;lE_aBneKlD_aFo5;kE_aBo5KlD_/LieKkEaaFneLLE_]G75Kk001FneLLE_]G71cWFaaG
6e/LEaaK75LKFaaG75/LEa]K75LLFaaG6e/LEaaK70027>L03eLLFcaG75/mEaaK?5LLFceG75/lEaaK
?ELLFcal000FOol00`00Oomoo`0@Ool000ioo`03001oogoo03aoo`03001oogoo02Aoo`0>O01G?ELM
EceG75LmEaeG?ELLEceG7ELmEaaG?@Ul00LngP037>Ln_G`000El0003D_aG71cW01=Fo0037>MFo5Kl
00EFo005001Fo5KlE_`Li`02Ea`01E/LEaaG75LLFa`00eLL00EK75LLEaaG75/L00<Li`0AFaaG75/L
EaaK75LLFaaG75/LEaaK75LLFaaG75/LEaal000FOol00`00Oomoo`0@Ool000ioo`03001oogoo03eo
o`03001oogoo029oo`0<O01G?ELLFceG75LmEaaK?ELLEceG75/m0g`000E77d;n7>LngD;N008ngP06
?]e2gSkN?]hngD;N0SkN00TngAcW>[dn_SZm?[hj_Cjn>[d01W`001YFo5;kE_aBo5KlD_]Fo5;lE_aB
neKlD_aFo5;kE_`LieLLE_]G75KkEaaFneLLE_/005Kk0QcW00eK75LKFaaG75/LEa]K75LLFaaG6e/L
EaaK70037>L04e/lEaaK?ELLFcaG75/mEaaK?5LLFceG75/lEaaK?ELLFcaG77`001Moo`03001oogoo
011oo`003Woo00<007ooOol0?Woo00<007ooOol08Goo00Yl05LMEceG75LmEaeG?ELLEceG7@9l0006
Aai2oTLN@_i77T;n0QcW33kN00<Licjm?[d02Sjm1G`02UKl00<LieKlE_`01UKl00<001cWEa`00ULL
00EK75LLEaaG75/L00=G700JFa`LiacW7>MK75LLFaaG75/LEaaK75LLFaaG75/LEaaK75LLFaaG75/L
EaaK75LLFaal01Qoo`03001oogoo00moo`003Woo00<007ooOol0?goo00<007ooOol07goo00Ql05LL
FceG75LmEaaK?ELL0g`000a2oTLN@_i77d;nAai2oTLO@_i77QcW@]h2?]h01SkM@]hngSkN?]e2gP8n
gP0B7>Ln_SZm?[hj_Cjn>[dn_SZm?[hj_Cjn>[dn_SZm?[hLid:m0W`001aBneKlD_aFo5;kE_aBo5Kl
7>MG75KkEaaFneLLE_]G71cW001G75/LEa]K75LLFaaG6e/LEaaK70<Li`0IFcaG75/mEaaK?5LLFceG
75/lEaaK?ELLFcaG75/mEaaK?5LLFceG75/lEaaK?ELLO00067oo00<007ooOol03goo000>Ool00`00
Oomoo`10Ool00`00Oomoo`0NOol01W`0EceG75LmEaeG?@9l000?@_i77T;nAai2oTLN@_i77T;nAai2
oTLN@_i77QcW00/ngP037>Ln_Cjm00/n_@037>LnWCjL008nW@9l00EFo0037>MFo5Kl009Fo0H0009G
7006FaaG75LLEaaK75LL0QcW01]K75LLFaaG75/LEaaK75LLFaaG75/LEaaK75LLFaaG75/LEaaK75LL
FaaG75/LEaaK75LLO0006Goo00<007ooOol03goo000>Ool00`00Oomoo`11Ool00`00Oomoo`0LOol0
1G`0FceG75LmEa`00W`000=??T/M7>L00QcW00a2oTLO@_i77T;nAam2oTLN@_i77d;nAah27>L2?]h0
73kM@]hngSkN?]e2gSkN7>Lj_Cjn>[dn_SZm?[hj_Cjn>[dn_SZm?[hj_AcW?Ya2_CjL@[dnW4:m0W`0
00=Bo5Kl00001@0000DLie/L001K?ELL00<00003EaaK75LK00<Li`0MEaaK?ELLFcaG75/mEaaK?5LL
FceG75/lEaaK?ELLFcaG75/mEaaK?5LLFceG75/lEaaK?ELLFcal000IOol00`00Oomoo`0?Ool000io
o`03001oogoo049oo`03001oogoo01]oo`0<O01G75LmEael04/NCai;7TlNBai?7T/N11cW00]77T;n
Aai2oTLN@_i77T;nAai2oQcW00TngP037>Ln_Cjm00Tn_@037>LnW3jM008nW@05?Y`nWCjM?YdnW003
O00025LLEaeG75LMEaaG7AcW0002Ea`01000EaeG70000QcW021G75/LEaaK75LLFaaG75/LEaaK75LL
FaaG75/LEaaK75LLFaaG75/LEaaK75LLFaaG75/LEaaK75LLFaaG77`06Goo00<007ooOol03goo000=
Ool00`00Oomoo`14Ool00`00Oomoo`0IOol00g`0EaaG?@02O00034/NCci;7DlnBai??T/MCci;7Tln
Bae??P<Li`08Aam2oTLN@_i77d;nAai2oP8Li`03?]hngD;N008ngP0K?]e2gQcW?[hj_Cjn>[dn_SZm
?[hj_Cjn>[dn_QcW@[dnW4:m?Ya2_CjL@[dnW4:m?Ya2_CjL009l000]FceG75LmEa`005LLFceG7000
EaaK?ELLFcd005/lEaaK?ELLFcaG75/mEaaK?5LLFceG75/lEaaK?ELLFcaG75/mEaaK?5LLFceG75/l
EaaK?ELLFcaG77`001Yoo`03001oogoo00moo`003Goo00<007ooOol0AGoo00<007ooOol067oo0g`0
015?7T/NCai;7TlNBai?7T/NCai;7TlNBai?7T/NCai;7TlN00<Li`08Aai2oTLN@_i77T;nAahLi`Ln
gP037>Ln_Cjm00Pn_@047>LnWCjM?Y`3?Yd01CjL?YdnWCjM?Y`00cjM0W`000=G700000000ULL01iG
7@00EaaG75LMEa`005LLFaaG75/LEaaK75LLFaaG75/LEaaK75LLFaaG75/LEaaK75LLFaaG75/LEa`7
7>L00g`0Oomoo`0HOol00`00Oomoo`0?Ool000eoo`03001oogoo04Ioo`03001oogoo01Ioo`9l00HL
i`0@Bai??T/MCci;7TlnBae??T/NCci;7DlnBai??T/MCch37>L01DLO@_i77T;nAal00QcW024ngD;N
?]hngSkM7>Lj_Cjn>[dn_SZm?[hj_Cjn>[dLicjL@[dnW4:m?Ya2_CjL@[dnW4:m?Ya2_CjL@[dnW4:m
?Y`00W`0019G?AcWFceG7000EaaK?ELLFceG7000EaaK?5LLFceG75/lEa`?7>L01eLlFceG?5/mEcaK
?G`001aoo`03001oogoo00ioo`003Goo00<007ooOol0Agoo00<007ooOol05Goo00Ql05<MEceC7E<m
DaeG?E<M4AcW00=;7TlN7>L00acW00=2oTLN@_h00QcW13kN00<Licjm?[d01Sjm00<LicjM?Y`00cjM
00DnW3jM?YdnWCjL00<nW@06?Y`nWCjM?YdnW3jM0W`000@LieLLEa`000=G7003Ead001cW00HLi`0C
EcaK?ELmFceG?5/mEceK?ELlFceG?E/mEcaK?ELmFceG?5/mEcd00W`07Goo00<007ooOol03Woo000=
Ool00`00Oomoo`18Ool00`00Oomoo`0DOol06G`0EceC7ELmDaeG?E<MEceC7ELmDaeG?E<MEceC7ELm
DaeG?E<MEceC7DlnBai??T/M00XLi`03AahLid;N008ngP0L7>Ln_SZm?[hj_Cjn>[dn_QcW@[dnW4:m
?Ya2_CjL@[dnW4:m?Ya2_CjL@[dnW4:m?Ya2_CjL@[d27>L094:LO00Lie/m001K?ELLFcd005/mEcaK
?ELlFceG?5/mEcaK?ELlFceG?5/mEcaK?ELlFceG?5/mEcaK?ELlFceG?5/mEcal01moo`03001oogoo
00ioo`003Goo00<007ooOol0B7oo00<007ooOol04goo01El05LmDaeC?E<MEceC7E<mDaeG?E<MDceC
7ELmDaeC?E<MEceC7E<mDad021cW00=BVTjI7>L00dii1AcW0SkN00<Licjm?[d013jm00<LicjL?Yd0
0SjM00DnW3jM?YdnWCjL00<nW@05?Y`nWCjM?YdnW0027>L4@Y`08G`07>L005LLEaeG7000EceK?ELl
FceG?E/mEcaK?ELmFceG?5/mEceK?ELlFceG?E/mEcaK?ELmFceG?5/mEcel000POol00`00Oomoo`0>
Ool000aoo`03001oogoo04Yoo`03001oogoo015oo`0?O01G?E<MEceC7ELmDaeG?E<MEceC7ELmDaeG
?E<M00El008Li`03Ea]K75LK00<Li`0;CWUBVTii7>M>F59iCUQ>NDiHDWU>F0037>L063kN7>Lj_Cjn
>[dn_SZm@[dLid:m?Ya2_CjL@[dnW4:m?Ya2_CjL@[dnW4:m?Ya2_@8Li`0V@Ya2WD:L@Ye2W4:M@Yal
0000FceG7000EcaK?ELlFceG?5/mEcaK?ELlFceG?5/mEcaK?ELlFceG?5/mEcaK?ELlFceG?5/mEcal
025oo`03001oogoo00ioo`0037oo00<007ooOol0Bgoo00<007ooOol047oo00Ml05<MDceC7ELmDaeC
?@067>L2O0000d:L7>M2W002@Y`:O0000e:I7>M>N@05CWT011cWCSM>>4hg0acW13jm00DLicjM?Ydn
WCjL00<nW@05?Y`nWCjM?YdnW003?Yd00acW@Ya2W008@Y`07@007>MG70007>MG?5/mEceK?ELlFceG
?E/mEcaK?ELmFceG?5/mEceK?ELlFceG?E/mEcaK?ELmO0008Woo00<007ooOol03Woo000<Ool00`00
Oomoo`1<Ool00`00Oomoo`0>Ool00g`07>LLi`057>L015/LEa]K75LK0W`00152_CjL@[dLid:m@Ya6
_D:L@[e2W4Jm@Ya2_D:LA[e2W4:m00]l000FCSQ:=dhh7>Ln_SZm?[hj_AcW?Ya2_CjL@[dnW4:m?Ya2
_CjL@[dnW4:m?Y`27>L044:M@Ya2WD:L@Ye2W4:M@Ya2WD:L@Yd007`0001KGULm0QcW01=K?ELlFceG
?5/mEcaK?ELlFceG?5/mEcaK?ELlFceG?5/mEcaK?@02O00SOol00`00Oomoo`0>Ool000aoo`03001o
ogoo04eoo`03001oogoo00eoo`05O01K75/LFaaK6`03Fa`035/KFaal07`0?Ya2WCjM@YdnW4:L7>M2
W@=2W005@Ye2W4:L@Ya2W@03@Y`01D:M@Ya2W4:L@Yd00d:L00=2WD:L@Y`01W`000Dn_AcW?YdnWCjL
00<nW@06?Y`nWCjM?YdnW3jM0QcW3D:L00@004:LO01l00=GG@8Li`0AEceK?ELlFceG?E/mEcaK?ELm
FceG?5/mEceK?ELlFcel000VOol00`00Oomoo`0=Ool000aoo`03001oogoo04ioo`03001oogoo00ao
o`08O01G6e/LEa]K75LKFaaG6`9l000V@[dnW4:m?Ya2_CjL@[dnW1cW@Ya2_D:LA[e2W4:m@Ya6_D:L
@[e2W4Jm@Ya2_D:LA[e2W4:m@Ya6_D:L@[e2W4Jm@Ya2_D:L7>M2_09l000T@[dnW4:m?Ya2_CjL@[dn
W4:m?Ya2_AcW@Ye2W4:M@Ya2WD:L@Ye2W4:M@Ya2WD:L@Ye2W4:M0012WD:L@Yel05]NEceKGELm0QcW
00iK?ELlFceG?5/mEcaK?ELlFceG?5/mEcaK?G`09goo00<007ooOol03Goo000<Ool00`00Oomoo`1?
Ool00`00Oomoo`0:Ool017`0FaaK75/K0e/L0W`000<nWG`0O0000W`000U2WCjL@YdnWD:M@Y`Lid:L
@Yd00d:L00E2WD:L@Ya2W4:M00=2W005@Ye2W4:L@Ya2W@03@Y`01D:M@Ya2W4:L7>L00dJl00=6_G`0
?Yd00SjM00DnW3jM?YdnWCjL008Lia12W0030012W4:L0092W003O01GGEMM00=GG@<Li`0:FceG?E/m
EcaK?ELmFceG?5/mO00XOol00`00Oomoo`0=Ool000]oo`03001oogoo055oo`03001oogoo00Uoo`9l
0003Ea]K75LK00El0004?Y`Lid:LA[d6O0009QcWA[e2W4:m@Ya6_D:L@[e2W4Jm@Ya2_D:LA[e2W4:m
@Ya6_D:L@[e2W4Jm@Ya2_D:L7>M2_4Jm@[a6_D:lA[el04:m?Ya2_CjL@[d27>L084:L@Ye2W4:M@Ya2
WD:L@Ye2W4:M@Ya2WD:L@Ye2W4:M@Ya2W@00@Ye2W4:M@Ya2WG`0FeiG?E]MEceKGULmFed27>L01ELl
FceG?5/mEc`00W`0:Goo00<007ooOol03Goo000;Ool00`00Oomoo`1BOol00`00Oomoo`07Ool2O000
0acWFaal0002O0001d:M?Ya2WCjL@YdnW1cW00=2W004AYa2W4:L@Y`6O002@Y`01D:M@Ya2W4:L@Yd0
0d:L00E2WD:L@Ya2W4:M00=2W0057>M6_4JlA[a6_@03A[`014JmO01l03jM0QcW54:L00<004:L@Y`0
14:L00=l05MMEed01UMM0QcW00=K?ELlO000:goo00<007ooOol03Goo000;Ool00`00Oomoo`1COol0
0`00Oomoo`06Ool4O0005d:m?Ya2WCjL@YdnW4:M?Ya2WAcWA[e2W4Jm@Ya6_D:LA[e2W4Jm@Ya6_D:L
A[d01W`00492W4:m@Ya6_D:L@[e2W4Jm@Ya2_D:L7>M2_4Jm@[a6_D:lA[e2_4Jm@[a6_D:lO012W4:M
@Ya2WD:L@Ye2W4:M@Ya2WD:L@Ye2W4:M@Ya2WD:L@Ye2W4:M@Ya2W@00@Ye2W4:M@Ya2WD:L@Yel05]N
EceKGELmFeiG?E]MEceKGQcWO00/Ool00`00Oomoo`0=Ool000]oo`03001oogoo05Aoo`03001oogoo
00Aoo`=l000>?Ya2WCjL@YdnW4:M?Ya2WCjL@YdnW1cW@Ya6W0=2W005AYa2W4:L@Ya6W003@Y`01TJL
@Ya2W4:LAYa2W0Il0005@Ye2W4:L@Y`Li`03A[`01DJmA[a6_4JlA[d00dJl00=6_DJlO0005D:L00<0
04:L@Y`00d:L0acW00=l05MMEed015MM0W`0;Woo00<007ooOol03Goo000;Ool00`00Oomoo`1EOol7
O0009d:M?Ya2WCjL@YdnW4:M?Ya2WCjL@YdnW4:M7>M6_D:LA[e2W4Jm@Ya6_D:LA[e2W4Jm@Ya6_D:L
A[e2W4Jm@Ya6_D:LA[e2W4Jm@Ya6_@04O0003d:lA[e2_4Jm@[a6_D:lA[e2_4Jm@[a6_D:lA[e2_002
O00054:M@Ya2WD:L@Ye2W4:M@Ya2WD:L@Ye2W4:M@Ya2WD:L@Ye2W4:M00057>L024:LA[e2W7`0EceK
GULmFed2O00`Ool00`00Oomoo`0=Ool000]oo`03001oogoo04ioo`Ml0005AUY2>DII7>M>F@02BUT5
O0002T:M?Ya2WCjL@YdnW4:M?Ya2WAcW0T:L1W`00T:L00E6W4:L@Ya2W4JL00=2W005AYa2W4:L@Ya6
W003@Y`01AcWA[al07`0A[d00dJl00E6_DJlA[a6_4Jm00=6_004A[e6_4JlO00;@Y`77>L01000A[a6
_4:l0dJl00=2_4JlO0000UMM0W`0<goo00<007ooOol037oo000;Ool00`00Oomoo`1<Ool2O0004chk
7>M6FT8iAUY2>DIJ@SU6FT8i7>M:FDiiBUU>NTYICWU:FDij00al0006DaeG?E<L7>MC75LM0W`000i2
W4Jm@Ya6_D:LA[e2W4Jm@Ya6_D:LA[e2W4Jm0QcW01U6_4Jm@[a6_G`0A[e2_4Jm@[a6_D:lA[e2_4Jm
@[a6_D:lA[e2_4JmO012WD:L@Ye2W0067>L044Jm@Ya6_D:LA[e2W4Jm0016_D:LA[e2W4Jm@Ya6_D:L
0g`0=Goo00<007ooOol037oo000:Ool00`00Oomoo`1;Ool2O00033Xj?SXn>QcW@SU6FDHiAUY2>DII
ASTLi`=:F@03CUUl07`000Ml000@EceC7ELmDaeG?E<MEceC7ELmDadLie<LEaeC75LMDa`2O0001DJL
@Ya2W4:LAY`00d:L00E6W4:L@Y`LidJm00=6_005A[e6_4JlO016_@03A[`01DJmA[a6_4JlA[d00dJl
00=6_DJlA[`00W`00QcW0TJl00E2_4JlA[a6_4:l00=6_005@[a6_4Jl0012_003A[`01D:lA[a6_4Jl
O000=goo00<007ooOol037oo000:Ool00`00Oomoo`19Ool2O0003Chk>SXn>cXj?S/LidIJ@SU6FT8i
AUY2>DIJ00El000IEceC75LmDaeG?E<LEceC7ELmDaaG?E<MEceC75LmDaeG?E<LEadLieLMDaaG7E<L
Ead01g`000m6_D:LA[e2W4Jm7>M6_DJlA[e2_4JmA[a6_D:lA[d00W`002Q2_4Jm@[a6_D:lA[e2_4Jm
@[a6_D:lA[e2_4Jm@[al04:LA[e2W4Jm@Ya6_D:LA[e2W4Jm@Ya6_D:LA[e2W000@Ya6_D:LA[e2W4Jm
@Yal03Moo`03001oogoo00aoo`002Woo00<007ooOol0Agoo0W`00Shj00/j>Shj?SXn>SXj7>M6>DIJ
@SU6FDHi009l000AEcdLieLmDaeG?E<MEceC7ELmDaeG?E<MEceC7ELmDaeG?@0=O0001eLmDceC?E<m
EcdLie<M009l0092W0037>M6_DJl0096_005A[e6_4JlA[a6_@03A[`01G`0A[a6_4JlA[d00dJl00E6
_DJlA[a6_4Jm00=6_003O012_4Jl0096_005@[a6_4JlA[a2_003A[`01D:lA[`004Jl@[`00dJl00=2
_4JlO000=goo00<007ooOol037oo000:Ool00`00Oomoo`16Ool03W`0?S/Lichk>SXn>cXj?S/j>Shk
7>M6FT8iAUX2O002Ecd02U<mEchLieLmDaaG?E<MEceC75Lm1g`002IG?E<MEceC7ELmDaeG?E<MEceC
7ELmDaeG?E<MEceC7ELm7>MG7E<LEaeC77`07>M6_DJlA[e2_4JmA[a6_D:lA[e6_4Jm@[a6_DJl0W`0
00i6_D:lA[e2_4Jm@[a6_D:lA[e2_4Jm@[a6_D:l0W`001E6_D:LA[e2W4Jm@Ya6_D:LA[e2W4Jm@Y`0
04:LA[e2W4Jm@Ya6_D:LO000=goo00<007ooOol037oo000:Ool00`00Oomoo`15Ool01G`0=S/f>acW
>SX00chj00Dj>Shj7>M6FT8i009l00IG?@067>MC7ELmDaeG?E<M0W`000=G?AcWEcd00e<m00EG?E<m
DceC?ELm00=C?@05EceC?E<mDceG?@03Dcd025Lm7>MC7E<LDaeC75<MDa`2O002A[`01DJmA[a6_4Jl
A[d00dJl00I6_DJlA[a6_4JmO002A[`01DJmA[a6_4JlA[d00dJl00I6_DJlA[a6_4JmO003A[`01D:l
A[a6_4Jl@[`00dJl00D004JlA[a6_4:l00=6_003@[al07oo03Eoo`03001oogoo00aoo`002Woo00<0
07ooOol0A7oo00al03Hl<S/f?3Xj7>Lj>Shk>SXn>cXj7>L2O0001U<mEciG?ELmDceG?P9G?@04DcdL
ie<MEcd2O002Ecd0<5<m7>MC7ELmDaeG?E<MEceC7ELmDaeG?E<MEceC7ELmDaeG?E<MEceC7ELm7>MG
7E<LEaeC75LMDaaG7E<LEael04JmA[a6_D:lA[e6_4Jm@[a6_DJlA[e2_4JmA[a6_@9l000S@[a6_D:l
A[e2_4Jm@[a6_D:lA[e2_4Jm@[a6_G`0A[e2W4Jm@Ya6_D:LA[e2W4Jm@Y`004:LA[e2W4Jm@Ya6_D:L
A[el000gOol00`00Oomoo`0;Ool000Uoo`03001oogoo04Eoo`03O00f>cHl008f>`037>Ln>SXj00<n
>P03O01G?ELm00UG?@=l00IG?@037>MC?ELm00=C?@05EceC?E<mDceG?@03Dcd04ULmDceC?E<mEcdL
ie<MDaaC7E<LDaeC75<MDaaC7E<LDael0096_005A[e6_4JlA[a6_@03A[`02DJmA[a6_4JlA[e6_7`0
A[a6_@03A[`01DJmA[a6_4JlA[d00dJl00=6_G`0O0000TJl00U2_4JlA[a6_4:lA[`004Jl@[`00dJl
00A2_4JlA[al03Moo`03001oogoo00]oo`002Goo00<007ooOol0A7oo00Yl038k=S`b>cHl<S/n>acW
?S/j>P9l0003EceC?ELn009G?@05DceG?ULmEceC?@02O0000eLmDceG?P02Ecd095<mEciG?ELm7>MG
?E<MEceC7ELmDaeG?E<MEceC7ELmDaeG?E<MEceC7ELm7>MG7E<LEaeC75LMDaaG7E<LEaeC75LMDaaG
7@9l000JA[a6_D:lA[e6_4Jm@[a6_DJlA[e2_4JmA[a6_D:lO012_4Jm@[a6_D:lA[e2_4Jm@[a6_@DL
i`0BO012W4Jm@Ya6_D:LA[e2W000@Ya6_D:LA[e2W4Jm@Ya6_G`0=goo00<007ooOol02goo0009Ool0
0`00Oomoo`13Ool00g`0=S/f?003=S/00cHl=S/Li`02O00:Ecd2O00<Ecd011cWDceC?ELm0e<m00EG
?E<mDceC?ELm00=C?@0EEcdLie<MDaaC7E<LDaeC75<MDaaC7E<LDaeC75<MDaaC7E<LO016_4Jm00=6
_005A[e6_4JlA[a6_@03A[`014JmA[al07`021cW00=6_DJlA[d00TJm0acW00=6_4:lA[`00TJl00D0
04JlA[a6_4:l00=6_003@[al07oo03Ioo`03001oogoo00]oo`002Goo00<007ooOol0@goo00Ml01cW
<S/f?38k=S`b>`02O0001ELnEceG?E<mEch00ULm00=C?ELnEcd00W`000EG?ULmEceC?ELn009G?@0Y
DceG?ULmEceC?ELnEcdLie<MEceC7ELmDaeG?E<MEceC7ELmDaeG?E<MEcdLieLMDaaG7E<LEaeC75LM
DaaG7E<LEaeC75LMDaaG7E<LEaeC7002O0007dJm@[a6_DJlA[e2_4JmA[a6_D:lA[e6_4Jm@[a6gG`0
A]e6_4KMA[a6gDJlA]e6_4KMA[a6gDJlO012W4Jm00@Li`800009@Ya6_D:LA[e2W4Jm@Ya6_G`003Mo
o`03001oogoo00]oo`002Goo00<007ooOol0@goo00El039L7>Lf>cHl009l00YG?@9l015G?@057>MC
?E<mDceG?@03Dcd07ELmDceC?E<mEcdLie<MDaaC7E<LDaeC75<MDaaC7E<LDaeC75<MDaaC7E<LDaeC
75<MDaaC7G`0A[d00dJl00E6_DJlA[a6_4Jm00=6_006A[e6_4JmO016_DJl0dJm00Y6_4JmA[e6_DJl
O016_4JmA[a6_@<0008Li`03000LidJl0096_004@[a6_4JlO00gOol00`00Oomoo`0;Ool000Uoo`03
001oogoo04=oo`03O00bGBiL009l0003EceC?ELn009G?@05DceG?ULmEceC?@02O0000eLmDceG?P02
Ecd01U<mEciG?ELmDceG?P9G?@0WDceG?ULmEceC?ELn7>MG?E<MEceC7ELmDaeG?E<MEceC7ELm7>MG
7E<LEaeC75LMDaaG7E<LEaeC75LMDaaG7E<LEaeC75LMDaaG7E<L008Li`0LO016_4Jm@[a6_DJlA[e2
_4JmA[a6_D:lA[e6_4Jm@[a6_G`0A]e6_4KMA[a6gDJlA]e6_4KMO00400001dJmA[a6_DJlA[e6_000
00@Li`03@Ya6_G`003Moo`03001oogoo00]oo`002Goo00<007ooOol0@goo00=l039LO0002QcW0g`0
5ELm00<LieLmDcd00U<m01IG?E<mDceC?ELm7>MC7E<LDaeC75<MDaaC7E<LDaeC75<MDaaC7E<LDaeC
70DLi`03E_al04Jl0096_005A[e6_4JlA[a6_@03A[`014JmA[a6_4Jl0acW00=l04JmA[`00dJm01=6
_000000004JlA[e6_4JmA[a6_DJlA[e6_4Jm0016_DJlA[e6_0027>L00g`0Oomoo`0eOol00`00Oomo
o`0;Ool000Qoo`03001oogoo04Eoo`08O01G?E]MEcaKGELmFeeG?0Al00037>M:>4iH00=l0003EceC
?ELn009G?@06DceG?ULmEceC?ELn0ULm01eC?ELnEceG?E<m7>MC7ELmDaeG?E<MEceC7ELm7>MG7E<L
EaeC75LMDaaG7E<LEaeC75LMDaaG7E<L00<Li`0@D_]Fo5;lE_aBneKlO016_D:lA[e6_4Jm@[a6_DJl
A[d67>L01dJlA]e6_7`0A[a6gDJl00<0000DA[a6gG`0A[e6_4JmA[a6_DJlA[e6_4JmA[a6_@00A[e6
_4JmA[al03Uoo`03001oogoo00Yoo`0027oo00<007ooOol0AGoo00Al05LmEceK?@Al00=:>0077>M:
>4hhBSQ>>4XhCSP00g`045Lm20001W`000IC7E<LDaeC75<MDa`37>L01E;lE_aFo5KlD_`00eKl00Al
04JlA[a6_@LLi`0:A]e6_4KMA[e6gDJlA]e6_DKMO00300005TJlA[e6_DJmA[al04JlA[e6_4JmA[a6
_DJlA[e6_4JmA[a6_@00A[e6_7`0>Woo00<007ooOol02Woo0008Ool00`00Oomoo`14Ool5O0000dXh
BSM:>002BSP034Xg7>M:>4iHBSM>F4XhCUQ:=diHBSQ>F0=l00DLi`06DceG?ULmEceC?ELn0P0000<L
ig`0O0001G`000I3?TLo@chLickn@_l6O00035;kE_aBo5KlD_]Fo5;lE_aBneKlD_al00<Li`0>A]e6
_4[MA[a6gDJlB]e6_4KMA[a:gDJlA]e6_0<0000HA[a6gDJlA]e6_4KMA[a6gG`0A[e6_4JmA[a6_DJl
A[e6_4JmA[a6_DJlA[d007`0>goo00<007ooOol02Woo0008Ool00`00Oomoo`11Ool4O009BSP03acW
BSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>003O002Fcd47>L00`00O01l0002O0002d<oAcm3?dLo
@cm7?d<oAcm3?dLo7>L023kn17`000=Fo5;lE_`00UKl011Bo5KlO016gDJlA]e6_DKMA[a6gDJmA]e6
_4KMA[e6g@@00005A[a6gG`0A[e6_003A[d04dJlA[el04JmA[a6_DJlA[e6_4JmA[a6_DJlA[e6_4Jm
A[al000003]oo`03001oogoo00Yoo`0027oo00<007ooOol0?Goo17`00dXh00E:=dXhBSQ:>4Xg00=:
>00BBSM:>1cWCUQ:=diHBSQ>F4XgCUQ:>4iHBSM>F4XhCUQ:=diH17`00QcW00@007`0O01?O`8Li`0H
@ci7?d<nAcm3?TLo@ci7?d<nAcm3?TLo7>M2oSkn@_lnoT;n?_i2ockn@_hLicjM0W`0011BneKlD_aF
o7`0B]e6_4KMA[a:gDJlA]e6_4[MA[a6g@<0000MA]e6_4[MA[a6gDJlO016_4KMA[a6gDJlA]e6_7`0
A[a6_DJlA[e6_4JmA[a6_DJlA[e6_4JmA[al0002Ool00`00Oomoo`0hOol00`00Oomoo`0:Ool000Qo
o`03001oogoo03Uoo`Al011:>00D7>M>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>
>0Al0005Bgi?OdmoCgm;OP027>L02dLo@cm7?d<oAcm3?dLo@cm7?d<o7>L02Ckn00HLicjL?Y`nW7`0
D_`2E_`02G`0A[a6gDJmA]e6_4KMA[e6g@0300002TKMA[a6gDJmA]e6_4KMA[e6gG`00dJm0116_4Jm
A[e6_G`0A[e6_4JmA[a6_DJlA[e6_4JmA[a6_@9l00=oo`03001oogoo03Qoo`03001oogoo00Yoo`00
1goo00<007ooOol0=Woo17`000=:>4XgBSP00TXh00E:=dXhBSQ:>4Xg00=:>00OBSM:>4XhBSQ:=dXh
7>M>F4XgCUQ:>4iHBSM>F4XhCUQ:=diHBSQ>F4XgCUQ:>4iHBSM>F4XhCUQ:=diHBSP017`000=?Od]n
Cgl00QcW01M3?TLo@ci7?d<nAcm3?TLo7>M2ockn@_hnoT;o?_i2oSkn7>LnW3jM>Y`nWCjL00=l0006
A[a6gDJlB]e6_4KM0`000216gDJlB]e6_4KMA[a:gDJlA]e6_4[MA[al04JlA]e6_4KMA[a6gDJlO016
_4JmA[a6_DJlA[e6_4JmA[a6_G`01Woo00<007ooOol0=goo00<007ooOol02Woo0007Ool00`00Oomo
o`0bOol4O00FBSP07AcWCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>
>4XhCSQ:>4hhBSP01G`000Y?OacW@cm7?d<oAcm3?dLo@clLi`LnoP057>LnW3jL?Y`nW@03?Y`01CjM
O01l04JmA]d00`000196gDJlA]e6_DKMA[a6gDJmA]e6_4KMA[e6gDJlA]el04JmA[`3A[d03DJlA[el
04JmA[a6_DJlA[e6_4JmA[a6_G`000Qoo`03001oogoo03Moo`03001oogoo00Uoo`001goo00<007oo
Ool0;Woo17`00dXh00E:=dXhBSQ:>4Xg00=:>005BSM:>4XhBSQ:=`03BSP09dXgBSQ:>4XhBSM:>1cW
CUQ:=diHBSQ>F4XgCUQ:>4iHBSM>F4XhCUQ:=diHBSQ>F4XgCUQ:>4iHBSM>F4XhCUQ:=diHBSQ>F4Xg
CUQ:>006O0027>L054Lo@ci7?acW@_hnoT;o?_i2oSkn7>LnW3jM>Y`nWCjL?YdjW3jM?Y`4000094KM
A[a:gDJlA]e6_4[MA[a6gDJlB]e6_4KMA[a:gDJlA]e6_7`0A[a6gDJlA]e6_4KMA[al04JlA[e6_4Jm
A[a6_DJlA[el00Yoo`03001oogoo03Ioo`03001oogoo00Uoo`001goo00<007ooOol0:goo0g`074Xh
02DLidhhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4Xh
CSQ:>4hhBSQ>>4XhCSQ:>002O0001ThhO01l07`0Acm3?`8Li`DnoP047>LnW3jL?Yd3?Y`300005cjL
7>Ln>W`0A[e6gDJlA]e6_DKMA[a6gDJmA]e6_4KMA[e6gDJlA]e6_DKMO0000dJm00E6_4JmA[el04Jm
008Li`06A[e6_4JmA[a6_G`037oo00<007ooOol0=Goo00<007ooOol02Goo0007Ool00`00Oomoo`0Z
Ool00g`0ASPLi`02BSP01DXgBSQ:>4XhBSL00dXh00E:=dXhBSQ:>4Xg00=:>005BSM:>4XhBSQ:=`03
BSP09DXgBSPLidiHBSM>F4XhCUQ:=diHBSQ>F4XgCUQ:>4iHBSM>F4XhCUQ:=diHBSQ>F4XgCUQ:>4iH
BSM>F4XhCUQ:=diHBSQ>F4Xg00<Li`03BUQl04Xh008Li`03O00LiacW008Li`09?_i2oSkn@_lLicjM
>Y`nWCjL00<0000T?Y`nWAcW7>Ln>T8jO01:gDJlA]e6_4[MA[a6gDJlB]e6_4KMA[a:gDJlA]e6_4[M
A[al01cWA]e6_4KMA[a6gG`0A]e2_4KM0QcW00=6_4JmO0003Goo00<007ooOol0=Goo00<007ooOol0
2Goo0007Ool00`00Oomoo`0YOol017`0BSQ:>AcW6dXh028LidhhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:
>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>08Li`06CUQ>FDiHCUUl01cW
0TiH00=Fng`0E_/00QcW0ckn00<LicjL?Y`00`0000DnW3jM?Y`nW1cW00Dn>P0DO016gDJmA]e6_4KM
A[e6gDJlA]e6_DKMA[a6gDJmA]e6_4KMO016g@@Li`09A[al04JmA]e6_DKMO00Lig`000moo`03001o
ogoo03Aoo`03001oogoo00Uoo`001goo00<007ooOol0:7oo00Il04HhBSU6>4Xi7>L3BSP01DXgBSQ:
>4XhBSL00dXh00E:=dXhBSQ:>4Xg00=:>005BSM:>4XhBSQ:=`02BSP07acWBSM>F4XhCUQ:=diHBSQ>
F4XgCUQ:>4iHBSM>F4XhCUQ:=diHBSQ>F4XgCUQ:>4iHBSM>F4XhCUQ:=diH00<Li`0BCUU>F4iIBUQ>
FDiHO01:F4iIBUQJo7`0F_aFnacW?_i2oacW0`0002HnW3jM>Y`nWCjL@SXLid8j?SY2>Shj@SXn>T8j
O00LidJlA]e6_4[MA[a6gDJlB]e6_4KMA[a:gDJlA]e6_7`0@]e6gD;MA]e2gAcW1G`04goo00<007oo
Ool0<goo00<007ooOol02Goo0006Ool00`00Oomoo`0XOol00g`0BSQ:>@03BSP00acWBSQ:>00GBSP0
7AcWBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSP0
0acW00Y>FDiHCUU>F4iICUQ>FDiHCUUl00A>F003O01FneKk00@00003?Y`nWCjL008nW004?YdnW1cW
7>L9?SX00g`07>LLi`037>L02dJmA]e6_4KMA[e6gDJlA]e6_DKMO0000dKM17`067oo00<007ooOol0
<Woo00<007ooOol02Goo0006Ool00`00Oomoo`0VOol2O0002DHhBSU6>4XiASQ:>DHh7>M:=`03BSP0
1DXgBSQ:>4XhBSL00dXh00E:=dXhBSQ:>4Xg00=:>00MBSM:>4Xh7>M:=diHBSQ>F4XgCUQ:>4iHBSM>
F4XhCUQ:=diHBSQ>F4XgCUQ:>4iHBSM>F4XhCUQ:=`047>L04DiICUQ>FDYHCUU>F4iIBUQ>FDiHCUU:
F7`0BUQ>FDYHCUT00`0001UJo1cW7>LjW3jM?Y`nWCZL?Ydn>QcW?SY2>Shj@SXn>T8j?SY2>Shj@SXn
>W`0@]e6gP02A]d00d;M7>LLi`027>L01T[MA[a6gDJlB]e6_0Al01eoo`03001oogoo035oo`03001o
ogoo00Uoo`001Woo00<007ooOol09Goo00Al04XhBSQ:>@=:>005BSU:>4XhBSPLi`0EBSP061cWBSQ>
>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>0<Li`0>CUQ>FDiHCUU>F4iI
CUQ>FDiHCUU>F4iICUQ>F@9>F003O01>F00000800007O01FneKlE_/LicjL?Yd00cjL00<nWAcW7>L0
33hj00<Lig`0A]d01dKM11cW00=6_4KMO00087oo00<007ooOol0<Woo00<007ooOol027oo0006Ool0
0`00Oomoo`0TOol03g`0BSU6>4XiASQ:>DHhBSU6>4XiASQ:>AcWBSQ:=`03BSP01DXgBSQ:>4XhBSL0
0dXh00E:=dXhBSQ:>4Xg009:>00F7>M:=diHBSQ>F4XgCUQ:>4iHBSM>F4XhCUQ:=diHBSQ>F4XgCUQ:
>4iHBSL37>L04TYHCUU>F4iIBUQ>FDiHCUU:F4iICUQ>FDYHCUU>F4iIBUQ>F@<0000<CUU:F4iIO01J
o5KkF_`LicjM?Y`nWCZL0QcW00]2>Shj@SXn>T8j?SY2>Shj@SXn>T8j00<Li`05@QQl04KM@]e6gP02
A]d01d;MA]i6gDKM@]e6gTKM008Li`03O01oogoo01moo`03001oogoo035oo`03001oogoo00Qoo`00
1Woo00<007ooOol08goo00Al04XhBSQ:>@=:>005BSU:>4XhBSQ:>@02BSP00acWBSQ:>00@BSP051cW
BSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hhBSP37>L04TiHCUU>F4iICUQ>FDiHCUU>
F4iICUQ>FDiHCUU>F4iICUQ>F@<00003CUQl04iH00=>F005O01FneKk7>LnW@03?Y`00acW?SXn>P09
?SX27>L4@QP00g`0A]e6g@0:A]d2O00SOol00`00Oomoo`0`Ool00`00Oomoo`08Ool000Ioo`03001o
ogoo029oo`0CO01:>DHhBSU6>4XiASQ:>DHhBSU6>4XiASQ:>DHhBSTLidXhBSL00dXh00E:=dXhBSQ:
>4Xg00=:>00EBSM:>4Xh7>M:=diHBSQ>F4XgCUQ:>4iHBSM>F4XhCUQ:=diHBSQ>F4Xg00<Li`0ABUQ>
FDiHCUU:F4iICUQ>FDYHCUU>F4iIBUQ>FDiHCUU:F00400003diICUQ>FG`0CUU:F4iIBUQ>FEKkO00L
icjM?Y`nW@027>L02Chj@SXn>T8j?SY2>Shj@SXn>P037>L6@QP01W`0A]i6gDKM@]e6gP96g@03@]e6
gTKM009l02Ioo`03001oogoo02moo`03001oogoo00Qoo`001Goo00<007ooOol08Woo00Al04XhBSQ:
>@=:>005BSU:>4XhBSQ:>@03BSP00dXiBSPLi`0?BSP04AcWBSQ>>4XhCSQ:>4hhBSQ>>4XhCSQ:>4hh
BSQ>>4XhCSP00QcW015>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiH00<00008CUQ>FDiH
CUU>F4iICUQl00E>F004E_]l01cW?Y`27>L8?SX37>L9@QP00g`0A]e6g@07A]d00g`0Oomoo`0WOol0
0`00Oomoo`0^Ool00`00Oomoo`08Ool000Eoo`03001oogoo025oo`0DO01:>DHhBSU6>4XiASQ:>DHh
BSU6>4XiASQ:>DHhBSU6>4XiASPLi`9:>005BSM:>4XhBSQ:=`03BSP04TXgBSQ:>4Xh7>M>F4XhCUQ:
=diHBSQ>F4XgCUQ:>4iHBSM>F0<Li`0@CUU>F4iIBUQ>FDiHCUU:F4iICUQ>FDYHCUU>F4iIBUP30000
4TYHCUU>F4iIBUQ>FDiHCUU:F4iIO01>FDYHCUU:F4iIBUQl008Li`07?SY2>Shj@SXn>T8j?SX00acW
2d8H00El04KMA]e2gDKN0096g@04@]e6gW`0O00[Ool00`00Oomoo`0]Ool00`00Oomoo`08Ool000Eo
o`03001oogoo01moo`9l009:>005BSU:>4XhBSQ:>@03BSP01DXiBSQ:>4XhBST00dXh00=:>AcWBSP0
34Xh00`LidhhBSQ>>4XhCSQ:>4hhBSQ>>4XhCSP37>L044iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iI
CUQ>FDiH0`0000i>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F7`01TiH00=l03hj?SX01Chj0QcW3T8H
00=l04KMA]d014KM0W`0;Goo00<007ooOol0;Goo00<007ooOol027oo0005Ool00`00Oomoo`0NOol0
67`0ASQ:>DHhBSU6>4XiASQ:>DHhBSU6>4XiASQ:>DHhBSU6>4XiASQ:>DHhBSTLi`=:>005BSM:>4Xh
BSQ:=`03BSP02QcWCUQ:>4iHBSM>F4XhCUQ:=diH0acW011>FDiHCUU:F4iICUQ>FDYHCUU>F4iIBUQ>
FDiHCUU:F0<0000LBUQ>FDiHCUU:F4iICUQ>FDYHCUU>F4iIBUQ>FDiHCUUl04iIBUQ>FDYHCUU:F7`0
?SY2>Shj@SX37>L@@QP00g`0@]e6gP02A]d2O00`Ool00`00Oomoo`0]Ool00`00Oomoo`07Ool000Eo
o`03001oogoo01eoo`05O01:>4XhBSQ:>@03BSP01DXiBSQ:>4XhBST00dXh00E:>DXhBSQ:>4Xi00=:
>003BSTLidXh00Q:>0087>M>>4XhCSQ:>4hhBSQ>>0<Li`0?CUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiH
CUU>F4iI00@0000DCUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUQl00I>F003O00n
>QcW008Lia=26005O016gDKMA]el000cOol00`00Oomoo`0/Ool00`00Oomoo`07Ool000Eoo`03001o
ogoo01aoo`0LO016>4XiASQ:>DHhBSU6>4XiASQ:>DHhBSU6>4XiASQ:>DHhBSU6>4XiASQ:>DHhBSU6
>1cWBSL3BSP01DXgBSQ:>0007>L01`00010LidiICUQ>FDYHCUU>F4iIBUQ>FDiHCUU:F4iICUQ>F@<0
000PCUU:F4iICUQ>FDYHCUU>F4iIBUQ>FDiHCUU:F4iICUQ>FDYHCUU>F4iIBUQ>FG`0CUU:F4iIBUQ>
FDYHO00LiaI26004O016gG`0O00eOol00`00Oomoo`0[Ool00`00Oomoo`07Ool000Eoo`03001oogoo
01]oo`05O01:>4XhBSQ:>@03BSP01DXiBSQ:>4XhBST00dXh00E:>DXhBSQ:>4Xi00=:>005BSU:>4Xh
BSPLi`04BSP20008BSP03P00CUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUT300006diICUQ>FDiHCUU>
F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUQl0006CUP00g`0@QQ2600B@QP3
7>L2O00hOol00`00Oomoo`0ZOol00`00Oomoo`07Ool000Aoo`03001oogoo01]oo`0PO016>4XiASQ:
>DHhBSU6>4XiASQ:>DHhBSU6>4XiASQ:>DHhBSU6>4XiASQ:>DHhBSU6>4XiASQ:>AcWBSQ:=`800003
BUU:>1cW00=:>004BSU:>4XhBSP200002DiIBUQ>FDiHCUU:F4iICUQ>F@0300009TiIBUQ>FDiHCUU:
F4iICUQ>FDYHCUU>F4iIBUQ>FDiHCUU:F4iICUQ>FDYHCUU>F4iIBUQ>FDiHCUUl04iIBUQ>FDYHCUU:
F48HO00;@QP87>L00dGgAQQl000jOol00`00Oomoo`0ZOol00`00Oomoo`07Ool000Aoo`03001oogoo
01Yoo`05O01:>4XhBSQ:>@03BSP01DXiBSQ:>4XhBST00dXh00E:>DXhBSQ:>4Xi00=:>005BSU:>4Xh
BSQ:>@02BSP200001TYHBUU:FDYIBUPLi`A:>0800007Ool004iHCUU>F4iICUP01000025>FDiHCUU>
F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiHO000
1diH00Al048H@QQ260PLi`Y65`03O01oogoo03Uoo`03001oogoo02Uoo`03001oogoo00Moo`0017oo
00<007ooOol067oo0W`002U6>4XiASQ:>DHhBSU6>4XiASQ:>DHhBSU6>4XiASQ:>DHhBSU6>4XiASQ:
>DHhBSU6>4XiASQ:>DHhBSU6>000BSQ:FDXhBUU:>4YI7>M:>DXh008000=oo`<Li`<0000]CUQ>FDYH
CUU>F4iIBUQ>FDiHCUU:F4iICUQ>FDYHCUU>F4iIBUQ>FDiHCUU:F4iICUQ>FDYHCUU>F4iIBUQ>FDiH
CUU:F4iIO01>FDYHCUU:F4iIBUQ>FG`000<Li`0BAOM65dGgAQQ5mdHGAOM664GgAQM5mdHHAOM65dGg
AQQ5mg`0?Goo00<007ooOol0:7oo00<007ooOol01goo0004Ool00`00Oomoo`0GOol00g`0BSU:>002
BSP01DXiBSQ:>4XhBST00dXh00E:>DXhBSQ:>4Xi00=:>005BSU:>4XhBSQ:>@03BSP01TXiBSQ:>4Xh
001:F0=:F@04BUQ:FDYIBUT20004Ool40002CWT:7>L06diHCUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiH
CUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUUl0008CUP00g`0AQM65`0AAQL00g`0Oomoo`0mOol00`00
Oomoo`0XOol00`00Oomoo`06Ool000Aoo`03001oogoo01Ioo`0[O01:>DHhBSU6>4XiASQ:>DHhBSU6
>4XiASQ:>DHhBSU6>4XiASQ:>DHhBSU6>4XiASQ:>DHhBSU6>4XiASQ:>DHhBST004YIBSQ:FDXhBUU:
>4YI000017oo0`000dii00E>NTiiCWU>NDij00=>N@04CWY>NDiiCWT;7>L044YHCUU>F4iIBUQ>FDiH
CUU:F4iICUQ>FDYHCUU>F7`021cW01El04HHAOM65dGgAQQ5mdHGAOM664GgAQM5mdHHAOM65dGgAQQ5
mdHGO000@7oo00<007ooOol09goo00<007ooOol01Woo0004Ool00`00Oomoo`0EOolA7>L01DXiBSQ:
>4XhBST00dXh00E:>DXhBSQ:>4Xi00=:>003BST004YI009:F@07BUQ:FDYIBUU:F000Ool0100074ii
2QcW00i>FDiHCUU>F4iIO01>NDiICWU>FDiiCUU>NG`04dHG00=l07ooOol0?goo00<007ooOol09goo
00<007ooOol01Woo0003Ool00`00Oomoo`0FOol01G`0BUU:FDIIBUX00TYI00I6FDYJBUU:FDIIBUX2
BUT00dIIBUXLi`0@7>L01`00BSQ:FDXhBUU:>4YI00@00004Ool00000CWX3CWT01DijCWU>NDiiCWX0
0dii00E>NTiiCWU>NDij00=>N@05CWY>NDiiCWU>NP03CWT01DijCWU>NDiiCWX00dii00=>NTiiCWT0
1AcW01al04iICWU:F4iiCUU>NG`0AQQ5mdHGAOM664GgAQM5mdHHAOM65dGgAQQ5mdHGAOM664GgAQMl
04=oo`03001oogoo02Ioo`03001oogoo00Ioo`000goo00<007ooOol05Woo00=l04YIBUT084YI00<0
01cW7>L00`0000=:F@0000000P000Tij00<LidiiCWT09dii0W`000E>FDiiCUU>NDiI009l01A65`03
O01oogoo049oo`03001oogoo02Eoo`03001oogoo00Ioo`000goo00<007ooOol05Woo00=l04IIBUX0
0TYI00I6FDYJBUU:FDIIBUX2BUT01TIIBUY:FDYIAUU:FP9:F@06AUU:FTYIBUU6FDYJ0TYI00I6FDYJ
BUU:FDIIBUX300027>L3000024YiCWY:NDijBWU>NQcWCWX3CWT01DijCWU>NDiiCWX00dii00E>NTii
CWU>NDij00=>N@05CWY>NDiiCWU>NP03CWT01DijCWU>NDiiCWX00dii025>NTiiCWUl04iiCUU>NDYH
CWU>FG`0AOM664GgAQM5mdHHAOM65dGgAQQ5mdHGAOM664GgAQM5mdHHAOM65dGgO000AWoo00<007oo
Ool097oo00<007ooOol01Woo0003Ool00`00Oomoo`0GOol00g`0BUU:F@0IBUT;0002CWX01DiiCWY>
NTijCWT00dij00<LidiiCWT08dii00Ql04iiCUU>NDiICWU>FG`01acW3THG00=l07ooOol0AWoo00<0
07ooOol08goo00<007ooOol01Woo0003Ool00`00Oomoo`0GOol017`0BUU6FDYJ0TYI00I6FDYJBUU:
FDIIBUX2BUT01TIIBUY:FDYIAUU:FP9:F@04AUU:FTYIBUT27>L300005DijBWU>NTYiCWY:NAcWBWU>
NTYiCWY:NDijBWU>NTYiCWY:NAcWCWU>NP03CWT01DijCWU>NDiiCWX00dii00E>NTiiCWU>NDij00=>
N@05CWY>NDiiCWU>NP03CWT01TijCWU>NDiiCWY>N@9l000?CWU>FDiiBUQ>NDiIO01:5dXhBQM:>4XG
BSQ:5dXh00/Li`04AQM5mdHHO019Ool00`00Oomoo`0ROol00`00Oomoo`06Ool000=oo`03001oogoo
01Moo`03O01:FDYI01E:F@@000Q:NP047>M>NTijCWT3CWX01DiiCWY>NTijCWT00Tij00<LidiiCWT0
7dii00Ul04iICWU>FDiiCUU>NDiIO00054XG0QcW00=l07ooOol0B7oo00<007ooOol08goo00<007oo
Ool01Goo0002Ool00`00Oomoo`0HOol01W`0BUY:FDYIAUU:FP9:F@06AUU:FTYIBUU6FDYJ0TYI00E6
FDYJBUU:FDII00<0000NBWU>NTYiCWY:NDijBWU>NTYiCWY:NDij7>M>NTYiCWY:NDijBWU>NTYiCWY:
NDijBWU>NTYi7>M>NDij0dii00E>NTiiCWU>NDij00=>N@05CWY>NDiiCWU>NP03CWT01DijCWU>NDii
CWX00dii029>NW`0O01:F4iiCUU>NDYHCWU:5g`0BQM:>4XGBSQ:5dXhBQM:>4XGBSQ:5dXhBQM:>4XG
BSQ:5dXhBQM:>4XGBSQl04aoo`03001oogoo029oo`03001oogoo00Eoo`000Woo00<007ooOol067oo
00=l04YIBUT03dYI0`000QcW34Yj00<LidijCWT00dij00E>NDijCWY>NTii00=>NP04CWU>NTij7>LL
CWT02W`0CWU>FDiiCUU>NDiICWU:5g`05DXG0W`0CWoo00<007ooOol08Goo00<007ooOol01Goo0002
Ool00`00Oomoo`0HOol017`0BUU6FDYJ0TYI00I6FDYJBUU:FDIIBUX2BUT01DII00000000AUT00QcW
02=>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYi7>M:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDij
BWU>NTYi7>M>NDij00=>N@05CWY>NDiiCWU>NP03CWT01DijCWU>NDiiCWX00dii00e>NTiiCWU>NDij
O01>NDYHCWU>FDiiBUQ>N@02O0005TXGBSQ:5dXhBQM:>4XGBSQ:5dXhBQM:>4XGBSQ:5dXhBQM:>4XG
BSQ:5g`0DGoo00<007ooOol087oo00<007ooOol01Goo0002Ool00`00Oomoo`0HOol00dYIO01:F@09
BUT30003BUT00acWBWY:NP0=BWX00acWCWU>NP02CWX01DiiCWY>NTijCWT00dij00E>NDijCWY>NTii
009>NP037>M>NDii01E>N@9l0008CWU>FDiiCUU>NDiICWUl01I:5`03O01oogoo055oo`03001oogoo
01moo`03001oogoo00Eoo`000Woo00<007ooOol06Goo00El04YIBUU6FDYJ009:F@@00004AUU:FTYI
BUT27>L0:4YiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDij7>M>NTYiCWY:NDijBWU>NTYiCWY:
NDijBWU>NTYiCWY:NDijBWU>NTYi7>M>NDij0dii00E>NTiiCWU>NDij00=>N@05CWY>NDiiCWU>NP03
CWT08G`0CUU>NDYHCWU>FDiiBUQ>F7`07>M:5dXhBQM:>4XGBSQ:5dXhBQM:>4XGBSQ:5dXhBQM:>4XG
BSQ:5dXhBQMl001DOol00`00Oomoo`0OOol00`00Oomoo`05Ool0009oo`03001oogoo01Uoo`04O01:
FDYIBUT30006BUT27>LABWX01AcWCWY>NTijCWT00dij00E>NDijCWY>NTii00=>NP07CWU>NTijCWY>
NDij7>L04dii0W`000U>FDiiCUU>NDiICWU>FDhhO0000Thh0QcW4DXG0W`0EWoo00<007ooOol07Woo
00<007ooOol01Goo0002Ool00`00Oomoo`0IOol01g`000000000BUU6FDYJ009:F@0_AUU:FTYI7>M:
NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NAcWBWU>NTYiCWY:NDijBWU>NTYiCWY:
NDijBWU>NTYiCWY:NDijBWU>NTYiCWXLi`02CWT01DijCWU>NDiiCWX00dii00E>NTiiCWU>NDij009>
N@0@O01>NDiICWU:F4iiCUU>NDYHCUQl04iHBSM>F4XgCUP27>L03dXGBSQ:5dXhBQM:>4XGBSQ:5dXh
BQM:>4XGBSQl001IOol00`00Oomoo`0NOol00`00Oomoo`04Ool00003Ool007oo01Uoo`<000U:F@8L
iaA:NP037>M>NTii00=>NP05CWU>NTijCWY>N@03CWX01DiiCWY>NTijCWT00dij00=>NDij7>L03dii
00Ul04iiCUU>NDiICWU>FDiiCUT00W`00dhh00E:>4hhCSQ>>4Xh008Li`]:5`03O01oogoo05Uoo`03
001oogoo01eoo`03001oogoo00Aoo`0000=oo`00Ool05Woo0`000Woo00El04YIBUU6FDYJ009:F@0c
AUTLiacWCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDij7>M>NTYiCWY:NDij
BWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NQcW009>N@05CWY>NDiiCWU>NP03
CWT06DijCWUl07`0CWU>FDiiBUQ>NDiICWU:=g`0BSM>F4XgCUQ:=diHBSM>F4XgCUQ:=diH008Li`09
BQM:>4XGBSQ:5dXhBQM:>7`005eoo`03001oogoo01aoo`03001oogoo00Aoo`0000=oo`00Ool04Woo
10001Goo00=:FG`0BUT014YI00<LidYjBWX05DYj00<LidiiCWX00Tij00E>NDijCWY>NTii00=>NP05
CWU>NTijCWY>N@03CWX01diiCWY>NTijCWU>NQcW00Y>N@0<O01>FDiiCUU>NDiICWU>FDiiCSQl04Xh
0dhh00E:>4hhCSQ>>4Xh00=>>003BSQ>>4hh008Li`A:5`9l05ioo`03001oogoo01aoo`03001oogoo
00Aoo`0000=oo`00Ool03goo0`002Goo00=:FG`0BUX00TYI0QcW03E:NDijBWU>NTYiCWY:NDijBWU>
NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYi7>M:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>
NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NQcW009>N@05CWY>NDiiCWU>NP02O00024YHCWU>FDiiBUQ>
NDiICWT2O0004TXgCUQ:=diHBSM>F4XgCUQ:=diHBSM>F4XgCUQ:=diHBSM>F08Li`03BQMl07oo061o
o`03001oogoo01]oo`03001oogoo00Aoo`0000=oo`00Ool037oo0`003Goo00Al04YI7>LLiaU:NP05
7>M>NTijCWY>N@03CWX01DiiCWY>NTijCWT00dij00E>NDijCWY>NTii00=>NP06CWU>NTijCWY>NAcW
1Tii00el04iiCWTLidiICWU>FDiiCUU>NG`0CSQ:>003CSP01DXhCSQ>>4hhBSP00dhh00E:>4hhCSQ>
>4Xh00=>>09l06=oo`03001oogoo01Yoo`03001oogoo00Aoo`0000=oo`00Ool02Goo0`0047oo0QcW
03Y:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDij7>M>NTYi
CWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWTLi`=>
N@0PCWYl04ijBWU>NTYi7>M:F4iiCUU>NG`0CUQ:=diHBSM>F4XgCUQ:=diHBSM>F4XgCUQ:=diHBSM>
F4XgCUQ:=`9l06Ioo`03001oogoo01Uoo`03001oogoo00Aoo`0000<007ooOol01Woo0`004Goo0QcW
74Yj00@LidijCWY>N@=>NP05CWU>NTijCWY>N@03CWX01DiiCWY>NTijCWT00dij00E>NDijCWY>NTii
00=>NP03CWTLidii009l009>N@06CWY>NDiiCWTLidiI0W`000=>>4XhCSP00Thh00E:>4hhCSQ>>4Xh
00=>>006BSQ>>4hhCSQ:>4hh0W`0JGoo00<007ooOol067oo00<007ooOol017oo00000`00Oomoo`02
Ool4000BOol27>L0?DYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>
NTYiCWY:NDijBWU>NQcWCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>
NTYiCWY:NDijBWU>NTYi00=l0007BWU>NTYiCWY:NDijBWT00g`0019:=diHBSM>F4XgCUQ:=diHBSM>
F4XgCUQ:=diHBSM>F4XgCUP3O01/Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00003001oo`000080
01Eoo`=l01e:NP037>M>NTii00=>NP05CWU>NTijCWY>N@03CWX01DiiCWY>NTijCWT00dij00I>NDij
CWY>NTiiCWX4O0000diiCWY>N@02CWT00dijO01l0002O0001DiHCUTLidhhBSP00dhh00E:>4hhCSQ>
>4Xh00=>>003BSQ>>4hh009l06moo`03001oogoo01Qoo`03001oogoo00=oo`000P006goo17`0031:
NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NAcWBWU>NTYiCWY:
NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NTYiCWX5O0001DijBWU>NTYiCWX01G`001A>FDiH
CUU>F4iICUQ>FAcWCUQ:=diHBSM>F4XgCUQ:=diHBSM>F4Xg0g`0LWoo00<007ooOol05goo00<007oo
Ool00goo00000goo0000000NOol4O00DBWX00acWCWU>NP02CWX01DiiCWY>NTijCWT00dij00I>NDij
CWY>NTiiCWX5O0001TijCWU>NDiiCWY>N@Al000=CUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiH7>L00Thh
00E:>4hhCSQ>>4Xh00=>>09l07Ioo`03001oogoo01Ioo`03001oogoo00=oo`000goo00<007ooOol0
7goo17`001m:NDijBWU>NTYiCWY:NDijBWU>NTYiCWY:NDijBWU>NQcWCWY:NDijBWU>NTYiCWY:NDij
BWU>NTYiCWY:N@04O0001TijBWU>NTYiCWY:N@El000ICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUQ>
FDiHCUU>F1cWBSM>F4XgCUQ:=diHBSL00W`0NGoo00<007ooOol05Goo00<007ooOol00goo0004Ool0
0`00Oomoo`0ROol4O00;BWX01AcWCWY>NTijCWT00dij00=>NDijCWX01G`00dii00=>NTiiO00017`0
01M>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUQ>FAcW00=>>004BSQl07`0
O01lOol00`00Oomoo`0DOol00`00Oomoo`03Ool000Eoo`8002Ioo`Al000=BWU>NTYiCWY:NDijBWTL
idYiCWY:NDijBWT01G`000I:NDijBWU>NTYiCWX4O0007TYiCWTLidiICUQ>FDiHCUU>F4iICUQ>FDiH
CUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iI7>M>F09l07moo`03001oogoo01Aoo`03001oogoo
00=oo`001goo00<007ooOol09Goo00=l04iiO0000g`00TYj00<LidijCWX017`000@LidiiCWU>NP9>
N@El00E>N@0ICUPLidiHCUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUQ>FDiHCUU>F4iICUP0
17`000=oo`00Ool0Ogoo00<007ooOol057oo00<007ooOol00Woo0008Ool2000VOol2O0000dij7>LL
i`07O00014ijBUTLidYi17`00dii00E:NDiiCWU>NDYi009>N@0C7>M>F4iICUQ>FDiHCUU>F4iICUQ>
FDiHCUU>F4iICUQ>FDiHCUT01W`01Goo00<007ooOol0Ogoo00<007ooOol04goo00<007ooOol00Woo
000:Ool00`00Oomoo`0UOol00acWO01l0002O005CWT4O00=CWT03TiI7>M>FDiHCUU>F4iICUQ>FDiH
CUU>F4iICUP6O00;Ool00`00Oomoo`20Ool00`00Oomoo`0BOol00`00Oomoo`02Ool000]oo`8002Yo
o`Ql009>N@05BWU>NDiiCWU:N@03CWT034YiCWU>NDii7>M>FDiHCUU>F4iICUQ>F@Il011oo`03001o
ogoo089oo`03001oogoo015oo`03001oogoo009oo`003Goo00<007ooOol0;goo2G`014ii00=>F1cW
CUP01W`05Woo00<007ooOol0PWoo00<007ooOol04Goo00<007ooOol00Woo000>Ool00`00Oomoo`0g
Ool7O00LOol00`00Oomoo`23Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool000moo`8005Yoo`03001o
ogoo08Aoo`03001oogoo00moo`03001oogoo009oo`004Goo00<007ooOol0Egoo00<007ooOol0QGoo
00<007ooOol03Woo00<007ooOol00Woo000BOol2001GOol00`00Oomoo`26Ool00`00Oomoo`0>Ool0
0`00Oomoo`01Ool001Aoo`03001oogoo05Aoo`03001oogoo08Moo`03001oogoo00eoo`03001oogoo
005oo`005Goo00<007ooOol0Dgoo00<007ooOol0Qgoo00<007ooOol03Goo00<007ooOol00Goo000F
Ool2001COol00`00Oomoo`28Ool00`00Oomoo`0<Ool00`00Oomoo`01Ool001Qoo`03001oogoo051o
o`03001oogoo08Uoo`03001oogoo00]oo`03001oogoo005oo`006Goo0P00D7oo00<007ooOol0RWoo
00<007ooOol02Woo00<007ooOol00Goo000KOol00`00Oomoo`1=Ool00`00Oomoo`2;Ool00`00Oomo
o`09Ool00`00Oomoo`01Ool001aoo`8004eoo`03001oogoo08]oo`03001oogoo00Yoo`40005oo`5o
o`007Woo00<007ooOol0BWoo00<007ooOol0S7oo00<007ooOol02Goo0@000Goo0Goo000OOol00`00
Oomoo`19Ool00`00Oomoo`2=Ool00`00Oomoo`08Ool10001Ool1Ool0021oo`8004Uoo`03001oogoo
08ioo`03001oogoo00Moo`40005oo`5oo`008Woo00<007ooOol0AWoo00<007ooOol0Sgoo00<007oo
Ool01Woo0@000Goo0Goo000SOol20016Ool00`00Oomoo`2?Ool00`00Oomoo`06Ool10001Ool1Ool0
02Eoo`03001oogoo04=oo`03001oogoo091oo`03001oogoo00Eoo`40005oo`5oo`009Woo0P00@goo
00<007ooOol0TGoo00<007ooOol01Goo0@000Goo000XOol00`00Oomoo`10Ool00`00Oomoo`2BOol0
0`00Oomoo`04Ool10001Ool002Uoo`03001oogoo03moo`03001oogoo09=oo`03001oogoo00=oo`40
005oo`00:Woo0P00?goo00<007ooOol0U7oo00<007ooOol00Woo0@000Goo000/Ool00`00Oomoo`0l
Ool00`00Oomoo`2DOol00`00Oomoo`02Ool10001Ool002eoo`8003aoo`03001oogoo09Eoo`05001o
ogooOol00001Ool002moo`03001oogoo03Uoo`03001oogoo09Ioo`04001oogoo0001Ool0031oo`03
001oogoo03Qoo`03001oogoo09Moo`03001oo`00005oo`00<Goo0P00=goo00<007ooOol0VGoo0@00
0Goo0@00000cOol00`00Oomoo`0dOol00`00Oomoo`2IOol10001Ool1000003Aoo`8003Aoo`03001o
ogoo09Yoo`800000=Woo00<007ooOol0<Goo00<007ooOol0VGoo0`00000gOol2000aOol00`00Oomo
o`2EOol40003Ool003Uoo`03001oogoo02ioo`03001oogoo091oo`D000Moo`00>Woo00<007ooOol0
;Goo00<007ooOol0S7oo100037oo000kOol2000]Ool00`00Oomoo`28Ool4000@Ool003eoo`03001o
ogoo02Yoo`03001oogoo08=oo`D001Aoo`00?Woo0P00:Woo00<007ooOol0Ogoo10006Goo0010Ool0
0`00Oomoo`0WOol00`00Oomoo`1jOol5000MOol0045oo`03001oogoo02Ioo`03001oogoo07Ioo`@0
029oo`00@Woo0P009Woo00<007ooOol0LWoo10009Woo0014Ool00`00Oomoo`0SOol00`00Oomoo`1]
Ool5000ZOol004Eoo`8002=oo`03001oogoo06Uoo`@002moo`00Agoo00<007ooOol087oo00<007oo
Ool0I7oo1@00<goo0018Ool2000POol00`00Oomoo`1POol4000hOol004Yoo`03001oogoo01eoo`03
001oogoo05]oo`D003aoo`00Bgoo00<007ooOol077oo00<007ooOol0Egoo1000@Goo001<Ool2000L
Ool00`00Oomoo`1COol40015Ool004ioo`03001oogoo01Uoo`03001oogoo04ioo`D004Uoo`00Cgoo
0P006Goo00<007ooOol0BWoo1000CWoo001AOol00`00Oomoo`0FOol00`00Oomoo`15Ool5001BOol0
059oo`8001Ioo`03001oogoo045oo`@005Moo`00E7oo00<007ooOol04goo00<007ooOol0?Goo1000
Fgoo001EOol00`00Oomoo`0BOol00`00Oomoo`0hOol5001OOol005Ioo`80015oo`03001oogoo03Eo
o`@006Aoo`00F7oo00<007ooOol03Woo00<007ooOol0<7oo1@00J7oo001IOol2000>Ool00`00Oomo
o`0/Ool4001]Ool005]oo`03001oogoo00]oo`03001oogoo02Moo`D0075oo`00G7oo00<007ooOol0
2Woo00<007ooOol08goo1000MWoo001MOol2000:Ool00`00Oomoo`0OOol4001jOol005moo`03001o
ogoo00Moo`03001oogoo01Yoo`D007ioo`00H7oo0P001goo00<007ooOol05Woo1000Pgoo001ROol0
0`00Oomoo`04Ool00`00Oomoo`0AOol50027Ool006=oo`8000Aoo`03001oogoo00eoo`@008aoo`00
IGoo00D007ooOomoo`0000]oo`@0091oo`00IWoo00@007ooOol000Ioo`D009Aoo`00Igoo0`000Woo
1000VGoo001YOol3002MOol00001
\>"],
  ImageRangeCache->{{{0, 264.313}, {287, 0}} -> {0.0486402, -0.000148683, 
  0.00324458, 0.00324458}}]
}, Open]]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[%, BoxRatios \[Rule] {1, 1, 6}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Show::"gtype"\( : \ \)"\!\(Show\) is not a type of graphics."\)], 
  "Message"]
}, Open]],

Cell[BoxData[
    RowBox[{"Show", "[", 
      RowBox[{
        RowBox[{"Show", "[", 
          RowBox[{
            RowBox[{"ViewPoint", "\[Rule]", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["0.0429999999999999893`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], ",", 
                  StyleBox["0.210000000000000008`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->3], ",", 
                  RowBox[{"-", 
                    StyleBox["1.22100000000000008`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->4]}]}], "}"}]}], ",", 
            \(BoxRatios \[Rule] {1, 1, 6}\)}], "]"}], ",", 
        \(BoxRatios \[Rule] {1, 1, 6}\)}], "]"}]], "Output"],

Cell[BoxData[
    \(ViewPoint -> {0.043, \ 0.210, \ \(-1.221\)}\)], "Input"],

Cell[BoxData[
    RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
        RowBox[{
          StyleBox["0.0429999999999999893`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2], ",", 
          StyleBox["0.210000000000000008`",
            StyleBoxAutoDelete->True,
            PrintPrecision->3], ",", 
          RowBox[{"-", 
            StyleBox["1.22100000000000008`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}]}], "}"}]}]], "Output"],

Cell[CellGroupData[{

Cell["Ruffle: Kappa periodic, Tau periodic; out of phase.", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Multiply Cos and Sin by 0.6 as otherwise it looks too bunchy.  Bigger width
 than 1.5 makes nice conical overlaps.  Swapping Cos and Sin gives a curve
 that looks the same.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(clear; top = 100; kappa[s_] := 0.6\ Cos[s]; tau[s_] := 0.6\ Sin[s]; \), 
  
    \(ds := N[\(12\ \[Pi]\)\/top]; width = 1.5; pribbonfrenet\)}], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.53885 .50661 m .57891 .56312 L .55244 .57761 L .785 .76 .83 r
F
.55095 .49614 m .57891 .56312 L .53885 .50661 L .744 .746 .853 r
F
.55095 .49614 m .60275 .54679 L .57891 .56312 L F
.52411 .51397 m .55244 .57761 L .52608 .58894 L .823 .769 .802 r
F
.53885 .50661 m .55244 .57761 L .52411 .51397 L .785 .76 .83 r
F
1 0 0 r
.003 w
.55244 .57761 m
.57891 .56312 L
s
.5602 .48302 m .60275 .54679 L .55095 .49614 L .695 .725 .873 r
F
.25 g
.5 Mabswid
.55095 .49614 m
.55395 .49907 L
s
.53993 .54951 m
.55244 .57761 L
s
.5602 .48302 m .62175 .52998 L .60275 .54679 L .695 .725 .873 r
F
1 0 0 r
.003 w
.57891 .56312 m
.60275 .54679 L
s
.50745 .51803 m .52608 .58894 L .50244 .59603 L .859 .775 .767 r
F
.52411 .51397 m .52608 .58894 L .50745 .51803 L .823 .769 .802 r
F
1 0 0 r
.52608 .58894 m
.55244 .57761 L
s
.25 g
.5 Mabswid
.52496 .51587 m
.53993 .54951 L
s
.52411 .51397 m
.52496 .51587 L
s
.56711 .46797 m .62175 .52998 L .5602 .48302 L .628 .694 .891 r
F
.25 g
.5602 .48302 m
.56334 .48541 L
s
.56711 .46797 m .63469 .51397 L .62175 .52998 L .628 .694 .891 r
F
1 0 0 r
.003 w
.60275 .54679 m
.62175 .52998 L
s
.48965 .51907 m .50244 .59603 L .48326 .59842 L .896 .775 .72 r
F
.50745 .51803 m .50244 .59603 L .48965 .51907 L .859 .775 .767 r
F
1 0 0 r
.50244 .59603 m
.52608 .58894 L
s
.25 g
.5 Mabswid
.50745 .51803 m
.52608 .58894 L
s
.57287 .45192 m .63469 .51397 L .56711 .46797 L .527 .642 .906 r
F
.25 g
.56711 .46797 m
.57271 .47179 L
s
.57287 .45192 m .6415 .49996 L .63469 .51397 L .527 .642 .906 r
F
.25 g
.53885 .50661 m
.57891 .56312 L
s
.55395 .49907 m
.60275 .54679 L
s
.57352 .49318 m
.62175 .52998 L
s
1 0 0 r
.003 w
.62175 .52998 m
.63469 .51397 L
s
.25 g
.5 Mabswid
.60045 .49067 m
.63469 .51397 L
s
.47126 .5179 m .48326 .59842 L .46911 .59665 L .932 .767 .655 r
F
.48965 .51907 m .48326 .59842 L .47126 .5179 L .896 .775 .72 r
F
1 0 0 r
.003 w
.48326 .59842 m
.50244 .59603 L
s
.25 g
.5 Mabswid
.48965 .51907 m
.50244 .59603 L
s
0 g
.006 w
.50745 .51803 m
.52411 .51397 L
s
.52411 .51397 m
.53885 .50661 L
s
.53885 .50661 m
.55095 .49614 L
s
.48965 .51907 m
.50745 .51803 L
s
.55095 .49614 m
.5602 .48302 L
s
.57892 .43592 m .6415 .49996 L .57287 .45192 L .342 .539 .902 r
F
.25 g
.5 Mabswid
.57287 .45192 m
.57705 .45484 L
s
.56334 .48541 m
.57352 .49318 L
s
.57892 .43592 m .64321 .48889 L .6415 .49996 L .342 .539 .902 r
F
.25 g
.5806 .47716 m
.60045 .49067 L
s
.57271 .47179 m
.5806 .47716 L
s
1 0 0 r
.003 w
.63469 .51397 m
.6415 .49996 L
s
.25 g
.5 Mabswid
.61613 .4822 m
.6415 .49996 L
s
.60252 .47267 m
.61613 .4822 L
s
.57705 .45484 m
.60252 .47267 L
s
0 g
.006 w
.5602 .48302 m
.56711 .46797 L
s
.45262 .51588 m .46911 .59665 L .45953 .59228 L .962 .741 .556 r
F
.47126 .5179 m .46911 .59665 L .45262 .51588 L .932 .767 .655 r
F
1 0 0 r
.003 w
.46911 .59665 m
.48326 .59842 L
s
0 g
.006 w
.47126 .5179 m
.48965 .51907 L
s
.25 g
.5 Mabswid
.47126 .5179 m
.48326 .59842 L
s
0 g
.006 w
.56711 .46797 m
.57287 .45192 L
s
.35488 .58956 m .41871 .63694 L .40315 .65965 L .818 .736 .774 r
F
.35923 .57237 m .41871 .63694 L .35488 .58956 L .772 .712 .796 r
F
.35923 .57237 m .43047 .61697 L .41871 .63694 L F
.35025 .60669 m .40315 .65965 L .38445 .68311 L .859 .758 .751 r
F
.35488 .58956 m .40315 .65965 L .35025 .60669 L .818 .736 .774 r
F
.25 g
.5 Mabswid
.39298 .61784 m
.41871 .63694 L
s
1 0 0 r
.003 w
.40315 .65965 m
.41871 .63694 L
s
.45262 .51588 m .45953 .59228 L .43399 .51472 L .962 .741 .556 r
F
0 g
.006 w
.45262 .51588 m
.47126 .5179 L
s
.25 g
.5 Mabswid
.45262 .51588 m
.46911 .59665 L
s
.36488 .55605 m .43047 .61697 L .35923 .57237 L .715 .682 .817 r
F
.25 g
.35923 .57237 m
.35949 .57253 L
s
.35488 .58956 m
.35598 .59038 L
s
.36488 .55605 m .43852 .60124 L .43047 .61697 L .715 .682 .817 r
F
1 0 0 r
.003 w
.41871 .63694 m
.43047 .61697 L
s
.25 g
.5 Mabswid
.40869 .60334 m
.43047 .61697 L
s
.58638 .42116 m .64321 .48889 L .57892 .43592 L 0 .291 .79 r
F
0 g
.006 w
.57287 .45192 m
.57892 .43592 L
s
.58638 .42116 m .64163 .4813 L .64321 .48889 L 0 .291 .79 r
F
1 0 0 r
.003 w
.6415 .49996 m
.64321 .48889 L
s
.25 g
.5 Mabswid
.57892 .43592 m
.64321 .48889 L
s
.34401 .62268 m .38445 .68311 L .36411 .70506 L .896 .778 .723 r
F
.35025 .60669 m .38445 .68311 L .34401 .62268 L .859 .758 .751 r
F
1 0 0 r
.003 w
.38445 .68311 m
.40315 .65965 L
s
.25 g
.5 Mabswid
.37282 .62929 m
.40315 .65965 L
s
.35598 .59038 m
.35647 .59074 L
s
.35025 .60669 m
.35124 .60768 L
s
.43399 .51472 m .45345 .58751 L .41586 .51603 L .97 .675 .407 r
F
.43399 .51472 m .45953 .59228 L .45345 .58751 L F
0 g
.006 w
.43399 .51472 m
.45262 .51588 L
s
.25 g
.5 Mabswid
.43399 .51472 m
.45953 .59228 L
s
1 0 0 r
.003 w
.45953 .59228 m
.46911 .59665 L
s
.37312 .54146 m .43852 .60124 L .36488 .55605 L .642 .64 .833 r
F
.25 g
.5 Mabswid
.35647 .59074 m
.3568 .59099 L
s
.35949 .57253 m
.36135 .5737 L
s
.37312 .54146 m .44358 .5906 L .43852 .60124 L .642 .64 .833 r
F
1 0 0 r
.003 w
.43047 .61697 m
.43852 .60124 L
s
.25 g
.5 Mabswid
.3568 .59099 m
.39298 .61784 L
s
.42145 .59077 m
.43852 .60124 L
s
.41586 .51603 m .44965 .58456 L .39907 .52086 L .936 .588 .34 r
F
.41586 .51603 m .45345 .58751 L .44965 .58456 L F
0 g
.006 w
.41586 .51603 m
.43399 .51472 L
s
1 0 0 r
.003 w
.45345 .58751 m
.45953 .59228 L
s
.38457 .52947 m .44358 .5906 L .37312 .54146 L .559 .578 .83 r
F
.25 g
.5 Mabswid
.36488 .55605 m
.36717 .55745 L
s
.38457 .52947 m .44682 .58521 L .44358 .5906 L .559 .578 .83 r
F
1 0 0 r
.003 w
.43852 .60124 m
.44358 .5906 L
s
.25 g
.5 Mabswid
.41586 .51603 m
.44442 .57035 L
s
.44442 .57035 m
.45345 .58751 L
s
1 0 0 r
.003 w
.44358 .5906 m
.44609 .58642 L
s
.39907 .52086 m .44682 .58521 L .38457 .52947 L .624 .547 .747 r
F
.25 g
.5 Mabswid
.37312 .54146 m
.37415 .54217 L
s
.39907 .52086 m .44965 .58456 L .44682 .58521 L .624 .547 .747 r
F
0 g
.006 w
.39907 .52086 m
.41586 .51603 L
s
.25 g
.5 Mabswid
.36717 .55745 m
.41158 .58471 L
s
.36135 .5737 m
.40869 .60334 L
s
.41158 .58471 m
.42145 .59077 L
s
.43244 .58282 m
.4359 .58524 L
s
.4359 .58524 m
.44358 .5906 L
s
.42421 .57709 m
.43244 .58282 L
s
.41523 .57082 m
.42421 .57709 L
s
.37415 .54217 m
.41523 .57082 L
s
1 0 0 r
.003 w
.44609 .58642 m
.44682 .58521 L
s
.25 g
.5 Mabswid
.44204 .57498 m
.44754 .58191 L
s
.43531 .5665 m
.44204 .57498 L
s
.39907 .52086 m
.43531 .5665 L
s
.44754 .58191 m
.44965 .58456 L
s
1 0 0 r
.003 w
.44965 .58456 m
.45345 .58751 L
s
0 g
.006 w
.38457 .52947 m
.39907 .52086 L
s
.59579 .40889 m .64163 .4813 L .58638 .42116 L .602 .183 0 r
F
0 g
.57892 .43592 m
.58638 .42116 L
s
.67931 .41131 m .7005 .48405 L .6774 .48486 L .74 .73 .843 r
F
.69429 .41614 m .7005 .48405 L .67931 .41131 L .689 .728 .88 r
F
.69429 .41614 m .72663 .48109 L .7005 .48405 L F
.33553 .63637 m .36411 .70506 L .34431 .72317 L .933 .794 .684 r
F
.34401 .62268 m .36411 .70506 L .33553 .63637 L .896 .778 .723 r
F
.25 g
.5 Mabswid
.34401 .62268 m
.34621 .62598 L
s
.34621 .62598 m
.38445 .68311 L
s
1 0 0 r
.003 w
.36411 .70506 m
.38445 .68311 L
s
.25 g
.5 Mabswid
.35251 .60895 m
.37282 .62929 L
s
.35124 .60768 m
.35251 .60895 L
s
.70786 .41891 m .72663 .48109 L .69429 .41614 L .621 .716 .914 r
F
.70786 .41891 m .75295 .47666 L .72663 .48109 L F
1 0 0 r
.003 w
.7005 .48405 m
.72663 .48109 L
s
.59579 .40889 m .63904 .47726 L .64163 .4813 L .602 .183 0 r
F
1 0 0 r
.64163 .4813 m
.64321 .48889 L
s
.25 g
.5 Mabswid
.58638 .42116 m
.64163 .4813 L
s
.44228 .58114 m
.44682 .58521 L
s
.43609 .5756 m
.44228 .58114 L
s
.42866 .56895 m
.43609 .5756 L
s
.38457 .52947 m
.42866 .56895 L
s
1 0 0 r
.003 w
.44682 .58521 m
.44965 .58456 L
s
.66388 .40535 m .6774 .48486 L .6592 .4835 L .779 .726 .803 r
F
.67931 .41131 m .6774 .48486 L .66388 .40535 L .74 .73 .843 r
F
1 0 0 r
.6774 .48486 m
.7005 .48405 L
s
.25 g
.5 Mabswid
.67931 .41131 m
.7005 .48405 L
s
0 g
.006 w
.37312 .54146 m
.38457 .52947 L
s
.60712 .40025 m .63904 .47726 L .59579 .40889 L .858 .495 0 r
F
0 g
.58638 .42116 m
.59579 .40889 L
s
.71891 .41906 m .75295 .47666 L .70786 .41891 L .526 .69 .943 r
F
.71891 .41906 m .77614 .47163 L .75295 .47666 L F
.25 g
.5 Mabswid
.71423 .45619 m
.72663 .48109 L
s
.69429 .41614 m
.71423 .45619 L
s
1 0 0 r
.003 w
.72663 .48109 m
.75295 .47666 L
s
.64864 .3997 m .6592 .4835 L .64673 .48076 L .81 .715 .761 r
F
.66388 .40535 m .6592 .4835 L .64864 .3997 L .779 .726 .803 r
F
1 0 0 r
.6592 .4835 m
.6774 .48486 L
s
.25 g
.5 Mabswid
.66388 .40535 m
.6774 .48486 L
s
0 g
.006 w
.36488 .55605 m
.37312 .54146 L
s
.60712 .40025 m .63779 .4764 L .63904 .47726 L .858 .495 0 r
F
1 0 0 r
.003 w
.63904 .47726 m
.64163 .4813 L
s
.25 g
.5 Mabswid
.59579 .40889 m
.63654 .4733 L
s
.61997 .39597 m .63779 .4764 L .60712 .40025 L .546 .481 .734 r
F
0 g
.006 w
.59579 .40889 m
.60712 .40025 L
s
.63393 .39607 m .64673 .48076 L .63986 .47794 L .818 .686 .719 r
F
.64864 .3997 m .64673 .48076 L .63393 .39607 L .81 .715 .761 r
F
1 0 0 r
.003 w
.64673 .48076 m
.6592 .4835 L
s
.25 g
.5 Mabswid
.60712 .40025 m
.61135 .41075 L
s
1 0 0 r
.003 w
.63895 .4772 m
.63904 .47726 L
s
.25 g
.5 Mabswid
.64864 .3997 m
.6592 .4835 L
s
0 g
.006 w
.35923 .57237 m
.36488 .55605 L
s
.61997 .39597 m .63986 .47794 L .63779 .4764 L .546 .481 .734 r
F
.25 g
.5 Mabswid
.61135 .41075 m
.63779 .4764 L
s
.63393 .39607 m .63986 .47794 L .61997 .39597 L .818 .686 .719 r
F
.25 g
.61997 .39597 m
.62142 .40192 L
s
.62142 .40192 m
.63986 .47794 L
s
1 0 0 r
.003 w
.63779 .4764 m
.63986 .47794 L
s
0 g
.006 w
.60712 .40025 m
.61997 .39597 L
s
.25 g
.5 Mabswid
.63393 .39607 m
.64673 .48076 L
s
1 0 0 r
.003 w
.63986 .47794 m
.64673 .48076 L
s
.32494 .64668 m .34431 .72317 L .32742 .73545 L .968 .803 .624 r
F
.33553 .63637 m .34431 .72317 L .32494 .64668 L .933 .794 .684 r
F
.25 g
.5 Mabswid
.33595 .63739 m
.36411 .70506 L
s
1 0 0 r
.003 w
.34431 .72317 m
.36411 .70506 L
s
.25 g
.5 Mabswid
.33553 .63637 m
.33595 .63739 L
s
0 g
.006 w
.35488 .58956 m
.35923 .57237 L
s
.61997 .39597 m
.63393 .39607 L
s
.72655 .41632 m .77614 .47163 L .71891 .41906 L .382 .634 .954 r
F
.25 g
.5 Mabswid
.71891 .41906 m
.72184 .42176 L
s
.72655 .41632 m .79317 .46669 L .77614 .47163 L .382 .634 .954 r
F
.25 g
.72016 .43466 m
.75295 .47666 L
s
.70786 .41891 m
.72016 .43466 L
s
1 0 0 r
.003 w
.75295 .47666 m
.77614 .47163 L
s
0 g
.006 w
.35025 .60669 m
.35488 .58956 L
s
.63393 .39607 m
.64864 .3997 L
s
.34401 .62268 m
.35025 .60669 L
s
.64864 .3997 m
.66388 .40535 L
s
.33553 .63637 m
.34401 .62268 L
s
.66388 .40535 m
.67931 .41131 L
s
.31279 .65293 m .32742 .73545 L .31525 .74059 L .996 .794 .515 r
F
.32494 .64668 m .32742 .73545 L .31279 .65293 L .968 .803 .624 r
F
.25 g
.5 Mabswid
.32494 .64668 m
.34431 .72317 L
s
1 0 0 r
.003 w
.32742 .73545 m
.34431 .72317 L
s
0 g
.006 w
.32494 .64668 m
.33553 .63637 L
s
.67931 .41131 m
.69429 .41614 L
s
.73052 .41059 m .79317 .46669 L .72655 .41632 L .152 .514 .914 r
F
.25 g
.5 Mabswid
.72184 .42176 m
.726 .42558 L
s
.73052 .41059 m .80197 .46214 L .79317 .46669 L .152 .514 .914 r
F
.25 g
.726 .42558 m
.77614 .47163 L
s
1 0 0 r
.003 w
.77614 .47163 m
.79317 .46669 L
s
0 g
.006 w
.69429 .41614 m
.70786 .41891 L
s
.70786 .41891 m
.71891 .41906 L
s
.31279 .65293 m .31525 .74059 L .29963 .65504 L .996 .794 .515 r
F
0 g
.31279 .65293 m
.32494 .64668 L
s
.25 g
.5 Mabswid
.31279 .65293 m
.32742 .73545 L
s
0 g
.006 w
.71891 .41906 m
.72655 .41632 L
s
.29963 .65504 m .31525 .74059 L .30831 .73852 L .971 .72 .294 r
F
1 0 0 r
.003 w
.31525 .74059 m
.32742 .73545 L
s
.73135 .40205 m .80197 .46214 L .73052 .41059 L 0 .262 .735 r
F
.73135 .40205 m .80201 .45802 L .80197 .46214 L F
.25 g
.5 Mabswid
.72655 .41632 m
.73705 .42426 L
s
.73705 .42426 m
.79317 .46669 L
s
1 0 0 r
.003 w
.79317 .46669 m
.80197 .46214 L
s
.25 g
.5 Mabswid
.73451 .41347 m
.80197 .46214 L
s
.73052 .41059 m
.73451 .41347 L
s
.29963 .65504 m .30831 .73852 L .28577 .65367 L .971 .72 .294 r
F
0 g
.006 w
.29963 .65504 m
.31279 .65293 L
s
.25 g
.5 Mabswid
.29963 .65504 m
.31525 .74059 L
s
0 g
.006 w
.72655 .41632 m
.73052 .41059 L
s
.28577 .65367 m .30563 .73061 L .27131 .65017 L .727 .446 0 r
F
.28591 .65421 m .30831 .73852 L .30563 .73061 L F
.28585 .65398 m .30831 .73852 L .28591 .65421 L F
.27131 .65017 m .30563 .73061 L .30532 .71954 L 0 .026 .593 r
F
.27131 .65017 m .29889 .70642 L .25648 .6463 L F
.29889 .70642 m .30532 .71954 L .30026 .71196 L F
.29889 .70642 m .30026 .71196 L .25648 .6463 L F
.28577 .65367 m .28585 .65398 L .28591 .65421 L .727 .446 0 r
F
0 g
.28577 .65367 m
.29963 .65504 L
s
.25 g
.5 Mabswid
.28577 .65367 m
.28585 .65398 L
s
.28585 .65398 m
.30084 .71039 L
s
.30557 .7282 m
.30831 .73852 L
s
1 0 0 r
.003 w
.30831 .73852 m
.31525 .74059 L
s
0 g
.006 w
.27131 .65017 m
.28577 .65367 L
s
1 0 0 r
.003 w
.30563 .73061 m
.30831 .73852 L
s
.73026 .39136 m .80201 .45802 L .73135 .40205 L .655 .137 0 r
F
.73026 .39136 m .79436 .45439 L .80201 .45802 L F
1 0 0 r
.80197 .46214 m
.80201 .45802 L
s
0 g
.006 w
.73052 .41059 m
.73135 .40205 L
s
.25 g
.5 Mabswid
.73135 .40205 m
.78163 .44188 L
s
.29307 .70117 m
.30563 .73061 L
s
.25648 .6463 m .30532 .71954 L .30543 .70852 L .216 .355 .79 r
F
.25648 .6463 m .30543 .70852 L .242 .64378 L F
.25 g
.28209 .6847 m
.30532 .71954 L
s
0 g
.006 w
.25648 .6463 m
.27131 .65017 L
s
1 0 0 r
.003 w
.30532 .71954 m
.30563 .73061 L
s
.72859 .37967 m .79436 .45439 L .73026 .39136 L .888 .461 .148 r
F
.72859 .37967 m .78139 .45142 L .79436 .45439 L F
1 0 0 r
.79436 .45439 m
.80201 .45802 L
s
0 g
.006 w
.73026 .39136 m
.73135 .40205 L
s
.25 g
.5 Mabswid
.73026 .39136 m
.75533 .416 L
s
.242 .64378 m .30543 .70852 L .30467 .70054 L .414 .516 .853 r
F
1 0 0 r
.003 w
.30532 .71954 m
.30543 .70852 L
s
.242 .64378 m .30467 .70054 L .22914 .64391 L .414 .516 .853 r
F
0 g
.006 w
.242 .64378 m
.25648 .6463 L
s
.25 g
.5 Mabswid
.27807 .68059 m
.30543 .70852 L
s
.72729 .36858 m .78139 .45142 L .72859 .37967 L .925 .613 .433 r
F
0 g
.006 w
.72859 .37967 m
.73026 .39136 L
s
.22914 .64391 m .30467 .70054 L .3024 .69776 L .136 .478 .898 r
F
1 0 0 r
.003 w
.30467 .70054 m
.30543 .70852 L
s
.72729 .36858 m .76625 .44937 L .78139 .45142 L .925 .613 .433 r
F
1 0 0 r
.78139 .45142 m
.79436 .45439 L
s
.25 g
.5 Mabswid
.72859 .37967 m
.74034 .39563 L
s
.21944 .64727 m .3024 .69776 L .29841 .7014 L .797 .633 .679 r
F
.25 g
.30175 .69835 m
.30467 .70054 L
s
.22914 .64391 m .3024 .69776 L .21944 .64727 L .136 .478 .898 r
F
1 0 0 r
.003 w
.3024 .69776 m
.30467 .70054 L
s
0 g
.006 w
.22914 .64391 m
.242 .64378 L
s
1 0 0 r
.003 w
.30049 .6995 m
.3024 .69776 L
s
.21405 .65381 m .29841 .7014 L .29269 .71173 L .821 .678 .705 r
F
.25 g
.5 Mabswid
.30231 .6977 m
.3024 .69776 L
s
.21944 .64727 m .29841 .7014 L .21405 .65381 L .797 .633 .679 r
F
1 0 0 r
.003 w
.29841 .7014 m
.30049 .6995 L
s
.2133 .66313 m .29269 .71173 L .28554 .7282 L .864 .704 .682 r
F
.25 g
.5 Mabswid
.29507 .6933 m
.30231 .6977 L
s
.21405 .65381 m .29269 .71173 L .2133 .66313 L .821 .678 .705 r
F
.25 g
.28984 .69656 m
.29841 .7014 L
s
1 0 0 r
.003 w
.29269 .71173 m
.29841 .7014 L
s
.25 g
.5 Mabswid
.29118 .71081 m
.29269 .71173 L
s
.21944 .64727 m
.23322 .65566 L
s
0 g
.006 w
.21944 .64727 m
.22914 .64391 L
s
.21653 .67467 m .28554 .7282 L .27757 .74936 L .91 .725 .639 r
F
.25 g
.5 Mabswid
.28583 .68767 m
.29507 .6933 L
s
.2133 .66313 m .28554 .7282 L .21653 .67467 L .864 .704 .682 r
F
.25 g
.28106 .69161 m
.28984 .69656 L
s
.27836 .70296 m
.29118 .71081 L
s
1 0 0 r
.003 w
.28554 .7282 m
.29269 .71173 L
s
.25 g
.5 Mabswid
.2133 .66313 m
.21518 .66427 L
s
.72673 .35986 m .76625 .44937 L .72729 .36858 L .9 .675 .589 r
F
0 g
.006 w
.72729 .36858 m
.72859 .37967 L
s
.72673 .35986 m .75225 .44849 L .76625 .44937 L .9 .675 .589 r
F
1 0 0 r
.003 w
.76625 .44937 m
.78139 .45142 L
s
.25 g
.5 Mabswid
.72729 .36858 m
.73212 .3786 L
s
.22229 .68782 m .27757 .74936 L .26977 .77304 L .955 .74 .573 r
F
.25 g
.27086 .68586 m
.28106 .69161 L
s
.21653 .67467 m .27757 .74936 L .22229 .68782 L .91 .725 .639 r
F
.25 g
.21405 .65381 m
.27086 .68586 L
s
.26876 .69708 m
.27836 .70296 L
s
.26812 .71469 m
.28554 .7282 L
s
1 0 0 r
.003 w
.27757 .74936 m
.28554 .7282 L
s
.25 g
.5 Mabswid
.21789 .67572 m
.21878 .67642 L
s
.21653 .67467 m
.21789 .67572 L
s
.23322 .65566 m
.28583 .68767 L
s
0 g
.006 w
.21405 .65381 m
.21944 .64727 L
s
.72685 .35515 m .75225 .44849 L .72673 .35986 L .87 .708 .679 r
F
0 g
.72673 .35986 m
.72729 .36858 L
s
.72685 .35515 m .74219 .44897 L .75129 .44497 L .87 .708 .679 r
F
.72757 .35555 m .74219 .44897 L .72685 .35515 L .882 .758 .721 r
F
.72757 .35555 m .73805 .45079 L .74219 .44897 L F
.73805 .45079 m .73807 .45089 L .74219 .44897 L F
.75129 .44497 m .74219 .44897 L .75225 .44849 L .87 .708 .679 r
F
0 g
.72673 .35986 m
.72685 .35515 L
s
1 0 0 r
.003 w
.75225 .44849 m
.76625 .44937 L
s
.25 g
.5 Mabswid
.72673 .35986 m
.72731 .36189 L
s
.72731 .36189 m
.7288 .36708 L
s
1 0 0 r
.003 w
.74219 .44897 m
.75225 .44849 L
s
.22889 .70172 m .26977 .77304 L .26344 .79637 L .989 .743 .463 r
F
.25 g
.5 Mabswid
.25841 .70715 m
.26812 .71469 L
s
.22229 .68782 m .26977 .77304 L .22889 .70172 L .955 .74 .573 r
F
.25 g
.25925 .72896 m
.27757 .74936 L
s
1 0 0 r
.003 w
.26977 .77304 m
.27757 .74936 L
s
.25 g
.5 Mabswid
.22284 .68843 m
.224 .68972 L
s
.22229 .68782 m
.22284 .68843 L
s
.21518 .66427 m
.26876 .69708 L
s
.72901 .36134 m .73807 .45089 L .72757 .35555 L .423 .461 .795 r
F
.25 g
.72685 .35515 m
.72892 .36779 L
s
.72901 .36134 m .74081 .4542 L .73807 .45089 L .423 .461 .795 r
F
1 0 0 r
.003 w
.74026 .44987 m
.74219 .44897 L
s
.25 g
.5 Mabswid
.73805 .45079 m
.73807 .45089 L
s
.73147 .37182 m .74081 .4542 L .72901 .36134 L .568 .618 .862 r
F
.25 g
.72757 .35555 m
.72932 .37139 L
s
.73147 .37182 m .75038 .45863 L .74081 .4542 L .568 .618 .862 r
F
1 0 0 r
.003 w
.73807 .45089 m
.74081 .4542 L
s
0 g
.006 w
.2133 .66313 m
.21405 .65381 L
s
.73515 .38553 m .76567 .46389 L .75038 .45863 L .5 .62 .901 r
F
.73971 .40073 m .75269 .43231 L .73515 .38553 L .359 .582 .927 r
F
.75269 .43231 m .7573 .44351 L .75258 .43028 L F
.7573 .44351 m .75829 .44492 L .75258 .43028 L F
.7573 .44351 m .76567 .46389 L .75829 .44492 L F
.75269 .43231 m .75258 .43028 L .73515 .38553 L F
.73971 .40073 m .78447 .46994 L .76567 .46389 L F
.74411 .41589 m .77277 .45427 L .73971 .40073 L .104 .471 .893 r
F
.77277 .45427 m .78447 .46994 L .77682 .45812 L F
.77277 .45427 m .77682 .45812 L .73971 .40073 L F
.74411 .41589 m .80344 .47724 L .78447 .46994 L F
.74679 .42992 m .80344 .47724 L .74411 .41589 L 0 .216 .677 r
F
.74933 .43204 m .81856 .48647 L .80344 .47724 L F
.74913 .43187 m .74927 .43198 L .74933 .43204 L F
.74927 .43198 m .81856 .48647 L .74933 .43204 L F
.74679 .42992 m .74896 .43163 L .74913 .43187 L F
.74896 .43163 m .81856 .48647 L .74913 .43187 L F
.75346 .44645 m .82593 .498 L .81856 .48647 L .664 .12 0 r
F
.75086 .44486 m .75348 .44671 L .75346 .44645 L F
.75348 .44671 m .82593 .498 L .75346 .44645 L F
.74296 .42303 m .75038 .45863 L .74212 .42069 L .5 .62 .901 r
F
.74618 .44198 m .75106 .44541 L .75086 .44486 L .664 .12 0 r
F
.75106 .44541 m .82593 .498 L .75086 .44486 L F
.73515 .38553 m .74296 .42303 L .73147 .37182 L .5 .62 .901 r
F
.74296 .42303 m .74212 .42069 L .73147 .37182 L F
.25 g
.5 Mabswid
.74948 .45448 m
.75038 .45863 L
s
.74784 .44697 m
.74948 .45448 L
s
.74593 .4382 m
.74684 .44238 L
s
.74686 .44245 m
.74784 .44697 L
s
.73147 .37182 m
.73189 .37374 L
s
.73189 .37374 m
.74593 .4382 L
s
1 0 0 r
.003 w
.74081 .4542 m
.75038 .45863 L
s
.25 g
.5 Mabswid
.74076 .45383 m
.74081 .4542 L
s
.74024 .4497 m
.74076 .45383 L
s
.72968 .3666 m
.74024 .4497 L
s
.72901 .36134 m
.72968 .3666 L
s
.72932 .37139 m
.73805 .45079 L
s
1 0 0 r
.003 w
.75038 .45863 m
.76567 .46389 L
s
.25 g
.5 Mabswid
.73515 .38553 m
.74314 .40603 L
s
1 0 0 r
.003 w
.76567 .46389 m
.78447 .46994 L
s
0 g
.006 w
.72685 .35515 m
.72757 .35555 L
s
1 0 0 r
.003 w
.78447 .46994 m
.78782 .47123 L
s
.22889 .70172 m .26344 .79637 L .23495 .7151 L .989 .743 .463 r
F
.23495 .7151 m .26344 .79637 L .26012 .81611 L .966 .695 .268 r
F
1 0 0 r
.26344 .79637 m
.26977 .77304 L
s
.25 g
.5 Mabswid
.25149 .74114 m
.26977 .77304 L
s
.2494 .718 m
.25925 .72896 L
s
.224 .68972 m
.2494 .718 L
s
.22889 .70172 m
.23002 .7037 L
s
.21878 .67642 m
.25841 .70715 L
s
0 g
.006 w
.2133 .66313 m
.21653 .67467 L
s
.72757 .35555 m
.72901 .36134 L
s
.25 g
.5 Mabswid
.7871 .46034 m
.79252 .46595 L
s
.74411 .41589 m
.74432 .41612 L
s
0 g
.006 w
.21653 .67467 m
.22229 .68782 L
s
.22229 .68782 m
.22889 .70172 L
s
.72901 .36134 m
.73147 .37182 L
s
.23495 .7151 m .26012 .81611 L .23976 .72633 L .966 .695 .268 r
F
.23976 .72633 m .26012 .81611 L .26135 .82911 L .769 .51 0 r
F
1 0 0 r
.003 w
.26012 .81611 m
.26344 .79637 L
s
.25 g
.5 Mabswid
.24106 .72295 m
.25149 .74114 L
s
.23002 .7037 m
.23017 .70396 L
s
.23017 .70396 m
.24106 .72295 L
s
.24452 .74238 m
.26344 .79637 L
s
.24137 .7334 m
.24452 .74238 L
s
.74618 .44198 m .81856 .48647 L .74679 .42992 L .664 .12 0 r
F
.25 g
.74697 .43007 m
.74896 .43163 L
s
.74679 .42992 m
.74697 .43007 L
s
.73971 .40073 m
.76043 .43278 L
s
0 g
.006 w
.22889 .70172 m
.23495 .7151 L
s
.73147 .37182 m
.73515 .38553 L
s
.73515 .38553 m
.73971 .40073 L
s
.24324 .73374 m .26135 .82911 L .26815 .83298 L 0 0 .433 r
F
.23976 .72633 m .26135 .82911 L .24324 .73374 L .769 .51 0 r
F
0 g
.23495 .7151 m
.23976 .72633 L
s
.73971 .40073 m
.74411 .41589 L
s
.74119 .4513 m .82593 .498 L .74618 .44198 L .821 .351 .093 r
F
.25 g
.5 Mabswid
.74618 .44198 m
.75262 .4465 L
s
.74119 .4513 m .82274 .51135 L .82593 .498 L .821 .351 .093 r
F
.25 g
.74896 .43163 m
.78543 .46036 L
s
.78543 .46036 m
.81856 .48647 L
s
.74432 .41612 m
.76773 .44032 L
s
.76773 .44032 m
.7871 .46034 L
s
1 0 0 r
.003 w
.81856 .48647 m
.82593 .498 L
s
0 g
.006 w
.74411 .41589 m
.74679 .42992 L
s
.24324 .73374 m .26815 .83298 L .24556 .7361 L 0 0 .433 r
F
0 g
.23976 .72633 m
.24324 .73374 L
s
.25 g
.5 Mabswid
.24324 .73374 m
.26135 .82911 L
s
0 g
.006 w
.74618 .44198 m
.74679 .42992 L
s
.24556 .7361 m .26815 .83298 L .28028 .82682 L .084 .162 .648 r
F
1 0 0 r
.003 w
.26135 .82911 m
.26815 .83298 L
s
.24556 .7361 m .28028 .82682 L .24685 .73304 L .084 .162 .648 r
F
0 g
.006 w
.24324 .73374 m
.24556 .7361 L
s
.25 g
.5 Mabswid
.24556 .7361 m
.26815 .83298 L
s
.73161 .45716 m .82274 .51135 L .74119 .4513 L .859 .475 .315 r
F
.25 g
.74119 .4513 m
.74555 .45451 L
s
.73161 .45716 m .80817 .52508 L .82274 .51135 L .859 .475 .315 r
F
.25 g
.75262 .4465 m
.82593 .498 L
s
1 0 0 r
.003 w
.82274 .51135 m
.82593 .498 L
s
.25 g
.5 Mabswid
.74555 .45451 m
.82274 .51135 L
s
0 g
.006 w
.74119 .4513 m
.74618 .44198 L
s
.24685 .73304 m .29583 .81173 L .24701 .72513 L .357 .361 .727 r
F
.24685 .73304 m .28028 .82682 L .29583 .81173 L F
0 g
.24556 .7361 m
.24685 .73304 L
s
.25 g
.5 Mabswid
.24685 .73304 m
.28028 .82682 L
s
1 0 0 r
.003 w
.26815 .83298 m
.28028 .82682 L
s
.71817 .45915 m .80817 .52508 L .73161 .45716 L .858 .545 .458 r
F
0 g
.006 w
.73161 .45716 m
.74119 .4513 L
s
.71817 .45915 m .78369 .53728 L .80817 .52508 L .858 .545 .458 r
F
1 0 0 r
.003 w
.80817 .52508 m
.82274 .51135 L
s
.25 g
.5 Mabswid
.73161 .45716 m
.80817 .52508 L
s
.24701 .72513 m .31171 .79071 L .24595 .71372 L .522 .478 .748 r
F
.24701 .72513 m .29583 .81173 L .31171 .79071 L F
0 g
.006 w
.24685 .73304 m
.24701 .72513 L
s
.25 g
.5 Mabswid
.24701 .72513 m
.29583 .81173 L
s
1 0 0 r
.003 w
.28028 .82682 m
.29583 .81173 L
s
.24595 .71372 m .32485 .76773 L .244 .70055 L .63 .551 .747 r
F
.24595 .71372 m .31171 .79071 L .32485 .76773 L F
0 g
.006 w
.24595 .71372 m
.24701 .72513 L
s
.25 g
.5 Mabswid
.24595 .71372 m
.31171 .79071 L
s
1 0 0 r
.003 w
.29583 .81173 m
.31171 .79071 L
s
.7022 .45754 m .78369 .53728 L .71817 .45915 L .84 .59 .56 r
F
0 g
.006 w
.71817 .45915 m
.73161 .45716 L
s
.7022 .45754 m .75267 .54635 L .78369 .53728 L .84 .59 .56 r
F
1 0 0 r
.003 w
.78369 .53728 m
.80817 .52508 L
s
.25 g
.5 Mabswid
.71817 .45915 m
.78369 .53728 L
s
.244 .70055 m .32485 .76773 L .33346 .74671 L .706 .603 .739 r
F
1 0 0 r
.003 w
.31171 .79071 m
.32485 .76773 L
s
.24225 .6874 m .33346 .74671 L .33747 .73064 L .764 .644 .73 r
F
.244 .70055 m .33346 .74671 L .24225 .6874 L .706 .603 .739 r
F
1 0 0 r
.32485 .76773 m
.33346 .74671 L
s
.24247 .67568 m .33747 .73064 L .33807 .72129 L .803 .689 .739 r
F
.25 g
.5 Mabswid
.33238 .74601 m
.33346 .74671 L
s
.24225 .6874 m .33747 .73064 L .24247 .67568 L .764 .644 .73 r
F
1 0 0 r
.003 w
.33346 .74671 m
.33747 .73064 L
s
.25 g
.5 Mabswid
.33433 .72883 m
.33747 .73064 L
s
.24655 .66641 m .33807 .72129 L .33706 .71929 L .451 .714 .98 r
F
.24247 .67568 m .33807 .72129 L .24655 .66641 L .803 .689 .739 r
F
1 0 0 r
.003 w
.33747 .73064 m
.33807 .72129 L
s
.25 g
.5 Mabswid
.33611 .72011 m
.33807 .72129 L
s
.24291 .67594 m
.24551 .67745 L
s
.24247 .67568 m
.24291 .67594 L
s
.24225 .6874 m
.24261 .68763 L
s
0 g
.006 w
.244 .70055 m
.24595 .71372 L
s
.24655 .66641 m .33706 .71929 L .25572 .66014 L .451 .714 .98 r
F
.25 g
.5 Mabswid
.25808 .66185 m
.26735 .66859 L
s
.25572 .66014 m
.25808 .66185 L
s
1 0 0 r
.003 w
.33706 .71929 m
.33807 .72129 L
s
.25 g
.5 Mabswid
.25041 .66873 m
.25338 .67051 L
s
.24655 .66641 m
.25041 .66873 L
s
.24551 .67745 m
.33433 .72883 L
s
.24261 .68763 m
.33238 .74601 L
s
.244 .70055 m
.32485 .76773 L
s
0 g
.006 w
.24225 .6874 m
.244 .70055 L
s
.68499 .45352 m .75267 .54635 L .7022 .45754 L .812 .619 .641 r
F
0 g
.7022 .45754 m
.71817 .45915 L
s
.68499 .45352 m .71951 .55159 L .75267 .54635 L .812 .619 .641 r
F
1 0 0 r
.003 w
.75267 .54635 m
.78369 .53728 L
s
.25 g
.5 Mabswid
.7022 .45754 m
.75267 .54635 L
s
0 g
.006 w
.24225 .6874 m
.24247 .67568 L
s
.66736 .44905 m .71951 .55159 L .68499 .45352 L .774 .635 .708 r
F
0 g
.68499 .45352 m
.7022 .45754 L
s
.66736 .44905 m .68847 .55338 L .71951 .55159 L .774 .635 .708 r
F
1 0 0 r
.003 w
.71951 .55159 m
.75267 .54635 L
s
.25 g
.5 Mabswid
.68499 .45352 m
.71951 .55159 L
s
.59792 .46536 m .63157 .55422 L .63455 .55169 L .716 .758 .886 r
F
.58396 .48198 m .63157 .55422 L .59792 .46536 L .851 .467 0 r
F
.58396 .48198 m .63419 .56045 L .63157 .55422 L F
.61419 .45368 m .63455 .55169 L .64477 .55175 L .605 .647 .865 r
F
.59792 .46536 m .63455 .55169 L .61419 .45368 L .716 .758 .886 r
F
1 0 0 r
.003 w
.63157 .55422 m
.63455 .55169 L
s
.57287 .50231 m .63419 .56045 L .58396 .48198 L .838 .392 0 r
F
.25 g
.5 Mabswid
.59792 .46536 m
.60139 .47451 L
s
.57287 .50231 m .63997 .57109 L .63419 .56045 L .838 .392 0 r
F
1 0 0 r
.003 w
.63157 .55422 m
.63419 .56045 L
s
.64956 .44637 m .68847 .55338 L .66736 .44905 L .725 .641 .765 r
F
.64956 .44637 m .66291 .55289 L .68847 .55338 L F
0 g
.006 w
.66736 .44905 m
.68499 .45352 L
s
1 0 0 r
.003 w
.68847 .55338 m
.71951 .55159 L
s
.25 g
.5 Mabswid
.66736 .44905 m
.68847 .55338 L
s
.6317 .44748 m .64477 .55175 L .66291 .55289 L .664 .641 .817 r
F
.61419 .45368 m .64477 .55175 L .6317 .44748 L .605 .647 .865 r
F
1 0 0 r
.003 w
.63455 .55169 m
.64477 .55175 L
s
.25 g
.5 Mabswid
.61419 .45368 m
.62101 .48654 L
s
.6317 .44748 m .66291 .55289 L .64956 .44637 L .664 .641 .817 r
F
.25 g
.64956 .44637 m
.66291 .55289 L
s
1 0 0 r
.003 w
.64477 .55175 m
.66291 .55289 L
s
.25 g
.5 Mabswid
.6317 .44748 m
.63189 .44902 L
s
.63311 .54474 m
.63455 .55169 L
s
1 0 0 r
.003 w
.66291 .55289 m
.68847 .55338 L
s
.56423 .52482 m .63997 .57109 L .57287 .50231 L .898 .486 .196 r
F
.25 g
.5 Mabswid
.58396 .48198 m
.58618 .48544 L
s
.56423 .52482 m .64559 .58657 L .63997 .57109 L .898 .486 .196 r
F
1 0 0 r
.003 w
.63419 .56045 m
.63997 .57109 L
s
.25 g
.5 Mabswid
.63328 .55903 m
.63419 .56045 L
s
.63409 .56507 m
.63997 .57109 L
s
.64336 .54053 m
.64477 .55175 L
s
0 g
.006 w
.24247 .67568 m
.24655 .66641 L
s
.64956 .44637 m
.66736 .44905 L
s
.31732 .63071 m .38882 .69737 L .39019 .70128 L .805 .336 0 r
F
.55655 .54804 m .64559 .58657 L .56423 .52482 L .891 .538 .37 r
F
.25 g
.5 Mabswid
.56423 .52482 m
.57363 .53195 L
s
.57287 .50231 m
.57373 .50319 L
s
.57373 .50319 m
.60099 .53114 L
s
.62101 .48654 m
.63311 .54474 L
s
.63189 .44902 m
.64336 .54053 L
s
.55655 .54804 m .64713 .60702 L .64559 .58657 L .891 .538 .37 r
F
.25 g
.6299 .54981 m
.63157 .55422 L
s
.63045 .55461 m
.63328 .55903 L
s
1 0 0 r
.003 w
.63997 .57109 m
.64559 .58657 L
s
.25 g
.5 Mabswid
.64085 .58297 m
.64559 .58657 L
s
.31732 .63071 m .39019 .70128 L .33602 .62465 L .805 .336 0 r
F
.33602 .62465 m .39019 .70128 L .39548 .71004 L .652 .216 0 r
F
1 0 0 r
.003 w
.38882 .69737 m
.39019 .70128 L
s
.25 g
.5 Mabswid
.25338 .67051 m
.33611 .72011 L
s
.38611 .69484 m
.38882 .69737 L
s
.38471 .69353 m
.38611 .69484 L
s
0 g
.006 w
.24655 .66641 m
.25572 .66014 L
s
.6317 .44748 m
.64956 .44637 L
s
.35824 .62232 m .39548 .71004 L .40667 .72126 L 0 .131 .679 r
F
.25 g
.5 Mabswid
.38328 .69151 m
.39019 .70128 L
s
.33602 .62465 m .39548 .71004 L .35824 .62232 L .652 .216 0 r
F
.25 g
.26735 .66859 m
.33706 .71929 L
s
.54785 .57065 m .64713 .60702 L .55655 .54804 L .859 .56 .481 r
F
.25 g
.55655 .54804 m
.56152 .55128 L
s
.60099 .53114 m
.63409 .56507 L
s
.58618 .48544 m
.63045 .55461 L
s
.60139 .47451 m
.6299 .54981 L
s
.54785 .57065 m .64083 .63203 L .64713 .60702 L .859 .56 .481 r
F
.25 g
.63574 .57909 m
.64085 .58297 L
s
1 0 0 r
.003 w
.64559 .58657 m
.64713 .60702 L
s
0 g
.006 w
.61419 .45368 m
.6317 .44748 L
s
.38247 .6233 m .40667 .72126 L .42523 .73196 L .236 .375 .801 r
F
.35824 .62232 m .40667 .72126 L .38247 .6233 L 0 .131 .679 r
F
.25 g
.5 Mabswid
.38788 .69215 m
.39548 .71004 L
s
1 0 0 r
.003 w
.39548 .71004 m
.40667 .72126 L
s
.25 g
.5 Mabswid
.35824 .62232 m
.35932 .62486 L
s
.53638 .59135 m .64083 .63203 L .54785 .57065 L .82 .567 .556 r
F
.25 g
.54785 .57065 m
.54886 .57131 L
s
.56152 .55128 m
.60488 .57951 L
s
.57363 .53195 m
.63574 .57909 L
s
.53638 .59135 m .62423 .66008 L .64083 .63203 L .82 .567 .556 r
F
.25 g
.60488 .57951 m
.6288 .59508 L
s
.6288 .59508 m
.64713 .60702 L
s
1 0 0 r
.003 w
.64083 .63203 m
.64713 .60702 L
s
0 g
.006 w
.59792 .46536 m
.61419 .45368 L
s
.40745 .62646 m .42523 .73196 L .45167 .73888 L .455 .48 .796 r
F
.38247 .6233 m .42523 .73196 L .40745 .62646 L .236 .375 .801 r
F
1 0 0 r
.003 w
.40667 .72126 m
.42523 .73196 L
s
.25 g
.5 Mabswid
.38247 .6233 m
.38308 .62576 L
s
.38308 .62576 m
.38324 .62642 L
s
.38324 .62642 m
.40667 .72126 L
s
.35932 .62486 m
.38788 .69215 L
s
0 g
.006 w
.58396 .48198 m
.59792 .46536 L
s
.52121 .60879 m .62423 .66008 L .53638 .59135 L .78 .566 .61 r
F
.25 g
.5 Mabswid
.53638 .59135 m
.53908 .59346 L
s
.52121 .60879 m .59719 .68827 L .62423 .66008 L .78 .566 .61 r
F
.25 g
.54886 .57131 m
.61037 .61192 L
s
.61037 .61192 m
.64083 .63203 L
s
1 0 0 r
.003 w
.62423 .66008 m
.64083 .63203 L
s
.25 g
.5 Mabswid
.53908 .59346 m
.62423 .66008 L
s
.43245 .62997 m .45167 .73888 L .48515 .73903 L .572 .524 .763 r
F
.40745 .62646 m .45167 .73888 L .43245 .62997 L .455 .48 .796 r
F
1 0 0 r
.003 w
.42523 .73196 m
.45167 .73888 L
s
.25 g
.5 Mabswid
.40745 .62646 m
.42523 .73196 L
s
0 g
.006 w
.57287 .50231 m
.58396 .48198 L
s
.56423 .52482 m
.57287 .50231 L
s
.55655 .54804 m
.56423 .52482 L
s
.54785 .57065 m
.55655 .54804 L
s
.53638 .59135 m
.54785 .57065 L
s
.50236 .62168 m .59719 .68827 L .52121 .60879 L .739 .561 .653 r
F
0 g
.52121 .60879 m
.53638 .59135 L
s
.45703 .63158 m .48515 .73903 L .52325 .73041 L .644 .544 .727 r
F
.43245 .62997 m .48515 .73903 L .45703 .63158 L .572 .524 .763 r
F
1 0 0 r
.003 w
.45167 .73888 m
.48515 .73903 L
s
.25 g
.5 Mabswid
.43245 .62997 m
.45167 .73888 L
s
.50236 .62168 m .56214 .71286 L .59719 .68827 L .739 .561 .653 r
F
1 0 0 r
.003 w
.59719 .68827 m
.62423 .66008 L
s
.48062 .62923 m .56214 .71286 L .50236 .62168 L .696 .554 .69 r
F
0 g
.006 w
.50236 .62168 m
.52121 .60879 L
s
.25 g
.5 Mabswid
.52121 .60879 m
.52342 .61111 L
s
.52342 .61111 m
.59719 .68827 L
s
0 g
.006 w
.31732 .63071 m
.33602 .62465 L
s
.48062 .62923 m .52325 .73041 L .56214 .71286 L .696 .554 .69 r
F
1 0 0 r
.003 w
.56214 .71286 m
.59719 .68827 L
s
.45703 .63158 m .52325 .73041 L .48062 .62923 L .644 .544 .727 r
F
1 0 0 r
.48515 .73903 m
.52325 .73041 L
s
.25 g
.5 Mabswid
.50236 .62168 m
.56214 .71286 L
s
.463 .65439 m
.48515 .73903 L
s
.45843 .63694 m
.463 .65439 L
s
0 g
.006 w
.48062 .62923 m
.50236 .62168 L
s
.25 g
.5 Mabswid
.48062 .62923 m
.52325 .73041 L
s
.45703 .63158 m
.45843 .63694 L
s
0 g
.006 w
.45703 .63158 m
.48062 .62923 L
s
.43245 .62997 m
.45703 .63158 L
s
.40745 .62646 m
.43245 .62997 L
s
.38247 .6233 m
.40745 .62646 L
s
.33602 .62465 m
.35824 .62232 L
s
1 0 0 r
.003 w
.52325 .73041 m
.56214 .71286 L
s
0 g
.006 w
.35824 .62232 m
.38247 .6233 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.313, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400049000181000`40O003h00Oogoo2Woo002`Ool2
001GOol00:ioo`800003Ool0000005Ioo`00Zgoo0`000goo0P00EWoo002YOol20006Ool00`00Ool0
001EOol00:Moo`8000Qoo`03001oo`0005Eoo`00Y7oo0`002Woo00@007ooOol005Aoo`00XWoo0P00
3Goo00D007ooOomoo`0005=oo`00Wgoo0`003goo00D007ooOomoo`0005=oo`00WGoo0P004Woo00<0
07ooOol00Woo00<007ooOol0D7oo002KOol2000EOol00`00Oomoo`02Ool00`00Oomoo`1?Ool009Qo
o`<001Moo`03001oogoo009oo`03001oogoo04moo`00UWoo0P006Woo00<007ooOol00goo00<007oo
Ool0CWoo002COol3000LOol00`00Oomoo`03Ool00`00Oomoo`1>Ool0095oo`8001moo`03001oogoo
00Aoo`03001oogoo04eoo`00Sgoo0P008Goo00<007ooOol01Goo00<007ooOol0C7oo002<Ool3000S
Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool008Yoo`8002Ioo`03001oogoo00Ioo`03001oogoo04]o
o`00Qgoo0`00:7oo00<007ooOol01goo00<007ooOol0BWoo0025Ool2000[Ool00`00Oomoo`07Ool0
0`00Oomoo`1:Ool008=oo`8002eoo`03001oogoo00Qoo`03001oogoo04Uoo`00P7oo0`00;goo00<0
07ooOol027oo00<007ooOol0BGoo001nOol2000bOol00`00Oomoo`09Ool00`00Oomoo`18Ool007]o
o`<003Aoo`03001oogoo00Yoo`03001oogoo04Moo`00NGoo0P00=goo00<007ooOol02Woo00<007oo
Ool0Agoo001gOol2000iOol00`00Oomoo`0;Ool00`00Oomoo`16Ool007Aoo`<003]oo`03001oogoo
00aoo`03001oogoo04Eoo`00LWoo0P00?goo00<007ooOol02goo00<007ooOol0AGoo001_Ool30011
Ool00`00Oomoo`0<Ool00`00Oomoo`14Ool006eoo`8004Aoo`03001oogoo00aoo`03001oogoo04Ao
o`00Jgoo0P00AWoo00<007ooOol03Goo00<007ooOol0@goo001XOol30018Ool00`00Oomoo`0>Ool0
0`00Oomoo`12Ool006Ioo`8004]oo`03001oogoo00ioo`03001oogoo049oo`00Hgoo0`00CGoo00<0
07ooOol03goo00<007ooOol0@Goo001QOol2001@Ool00`00Oomoo`0@Ool00`00Oomoo`10Ool005io
o`<0059oo`03001oogoo011oo`03001oogoo041oo`00G7oo0P00EGoo00<007ooOol04Goo00<007oo
Ool0?goo001JOol2001GOol00`00Oomoo`0AOol00`00Oomoo`0oOol005Moo`<005Uoo`03001oogoo
019oo`03001oogoo03ioo`00EGoo0P00G7oo00<007ooOol04goo00<007ooOol0?Goo001BOol3001N
Ool00`00Oomoo`0COol00`00Oomoo`0mOol0051oo`80065oo`03001oogoo01Aoo`03001oogoo03ao
o`00CWoo0P00Hgoo00<007ooOol05Goo00<007ooOol0>goo001;Ool3001UOol00`00Oomoo`0EOol0
0`00Oomoo`0kOol004Uoo`8006Uoo`03001oogoo01Eoo`03001oogoo03Yoo`00AWoo0`00Jgoo00<0
07ooOol05Goo00<007ooOol0>Woo0014Ool2001^Ool00`00Oomoo`0FOol00`00Oomoo`0iOol0049o
o`80071oo`03001oogoo01Moo`03001oogoo03Qoo`00?goo0`00LWoo00<007ooOol05goo00<007oo
Ool0>7oo000mOol2001eOol00`00Oomoo`0HOol00`00Oomoo`0gOol003Yoo`<007Moo`03001oogoo
01Uoo`03001oogoo03Ioo`00>7oo0P00NWoo00<007ooOol06Goo00<007ooOol0=Woo000fOol2001l
Ool00`00Oomoo`0JOol00`00Oomoo`0eOol003=oo`<007ioo`03001oogoo01Yoo`03001oogoo03Eo
o`00<Goo0P00PGoo00<007ooOol06goo00<007ooOol0=7oo000^Ool30023Ool00`00Oomoo`0LOol0
0`00Oomoo`0cOol002aoo`8008Ioo`03001oogoo01aoo`03001oogoo03=oo`00:Woo0P00R7oo00<0
07ooOol07Goo00<007ooOol0<Woo000WOol3002:Ool00`00Oomoo`0NOol00`00Oomoo`0aOol002Eo
o`8008eoo`03001oogoo01ioo`03001oogoo035oo`008Woo0`00Sgoo00<007ooOol07goo00<007oo
Ool0<7oo000POol2002COol00`00Oomoo`0NOol00`00Oomoo`0`Ool001ioo`8009Eoo`03001oogoo
01moo`03001oogoo02moo`006goo0`00Ugoo00<007ooOol087oo00<007ooOol0;Woo000IOol2002J
Ool00`00Oomoo`0POol00`00Oomoo`0^Ool001Moo`8009aoo`03001oogoo025oo`03001oogoo02eo
o`005goo0P00W7oo00<007ooOol08Woo00<007ooOol0;7oo000GOol00`00Ool0002KOol00`00Oomo
o`0ROol00`00Oomoo`0/Ool001Moo`04001oogoo002JOol00`00Oomoo`0SOol00`00Oomoo`0[Ool0
01Ioo`03001oogoo009oo`03001oogoo09Moo`03001oogoo02=oo`03001oogoo02]oo`005Woo00<0
07ooOol00goo00<007ooOol0UWoo00<007ooOol097oo00<007ooOol0:Woo000FOol00`00Oomoo`04
Ool00`00Oomoo`2EOol00`00Oomoo`0UOol00`00Oomoo`0YOol001Ioo`03001oogoo00Eoo`03001o
ogoo09Aoo`03001oogoo02Eoo`03001oogoo02Uoo`005Woo00<007ooOol01Woo00<007ooOol0Tgoo
00<007ooOol09Woo00<007ooOol0:7oo000FOol00`00Oomoo`07Ool00`00Oomoo`2BOol00`00Oomo
o`0WOol00`00Oomoo`0WOol001Eoo`03001oogoo00Uoo`03001oogoo095oo`03001oogoo02Moo`03
001oogoo02Moo`005Goo00<007ooOol02Woo00<007ooOol0T7oo00<007ooOol0:7oo00<007ooOol0
9Woo000EOol00`00Oomoo`0;Ool00`00Oomoo`2?Ool00`00Oomoo`0XOol00`00Oomoo`0VOol001Eo
o`03001oogoo00aoo`03001oogoo08moo`03001oogoo02Qoo`03001oogoo02Eoo`005Goo00<007oo
Ool03Goo00<007ooOol0SWoo00<007ooOol0:Goo00<007ooOol097oo000EOol00`00Oomoo`0>Ool0
0`00Oomoo`2=Ool00`00Oomoo`0YOol00`00Oomoo`0TOol001Eoo`03001oogoo00moo`03001oogoo
08aoo`03001oogoo02Yoo`03001oogoo02=oo`0057oo00<007ooOol04Goo00<007ooOol0Rgoo00<0
07ooOol0:goo00<007ooOol08Woo000DOol00`00Oomoo`0BOol00`00Oomoo`2:Ool00`00Oomoo`0[
Ool00`00Oomoo`0ROol001Aoo`03001oogoo01=oo`03001oogoo08Uoo`03001oogoo02aoo`03001o
ogoo025oo`0057oo00<007ooOol057oo00<007ooOol0R7oo00<007ooOol0;7oo00<007ooOol08Goo
000DOol00`00Oomoo`0EOol00`00Oomoo`27Ool00`00Oomoo`0]Ool00`00Oomoo`0POol001Aoo`03
001oogoo01Ioo`03001oogoo08Ioo`03001oogoo02ioo`03001oogoo01moo`004goo00<007ooOol0
5goo00<007ooOol0QWoo00<007ooOol0;Woo00<007ooOol07goo000COol00`00Oomoo`0HOol00`00
Oomoo`25Ool00`00Oomoo`0_Ool00`00Oomoo`0NOol001=oo`03001oogoo01Uoo`03001oogoo08Ao
o`03001oogoo031oo`03001oogoo01eoo`004goo00<007ooOol06Woo00<007ooOol0Pgoo00<007oo
Ool0<7oo00<007ooOol07Goo000COol00`00Oomoo`0KOol00`00Oomoo`22Ool00`00Oomoo`0aOol0
0`00Oomoo`0LOol001=oo`03001oogoo01aoo`03001oogoo085oo`03001oogoo035oo`03001oogoo
01aoo`004Woo00<007ooOol07Woo00<007ooOol0P7oo00<007ooOol01goo00<007ooOol0:7oo00<0
07ooOol06goo000BOol00`00Oomoo`0OOol00`00Oomoo`1oOol00`00Oomoo`07Ool00`00Oomoo`0Y
Ool00`00Oomoo`0JOol0019oo`03001oogoo021oo`03001oogoo07moo`03001oogoo00Ioo`03001o
ogoo02Uoo`03001oogoo01Yoo`004Woo00<007ooOol08Goo00<007ooOol0OWoo00<007ooOol01Woo
00<007ooOol0:Woo00<007ooOol06Goo000BOol00`00Oomoo`0ROol00`00Oomoo`1mOol00`00Oomo
o`06Ool00acW001oo`0[Ool00`00Oomoo`0HOol0019oo`03001oogoo02=oo`03001oogoo07aoo`03
001oogoo00Ioo`037>L007oo02]oo`03001oogoo01Qoo`004Woo00<007ooOol097oo00<007ooOol0
Ngoo00<007ooOol01Woo00<Li`00Ool0;7oo00<007ooOol05goo000AOol00`00Oomoo`0VOol00`00
Oomoo`1jOol00`00Oomoo`06Ool27>L00`00Oomoo`0ZOol00`00Oomoo`0GOol0015oo`03001oogoo
02Moo`03001oogoo07Uoo`03001oogoo00Ioo`8Li`03001oogoo02]oo`03001oogoo01Ioo`004Goo
00<007ooOol0:7oo00<007ooOol0N7oo00<007ooOol01goo00<Li`00Ool0;Goo00<007ooOol05Goo
000AOol00`00Oomoo`0YOol00`00Oomoo`1gOol00`00Oomoo`07Ool27>L00`00Oomoo`0[Ool00`00
Oomoo`0EOol0015oo`03001oogoo02Yoo`03001oogoo065oo`L000ioo`03001oogoo00Moo`8Li`03
001oogoo02aoo`03001oogoo01Aoo`004Goo00<007ooOol0:goo00<007ooOol0GWoo0P0000=1mVJf
7>L00VJf00<LifKG00000P002goo00<007ooOol01goo00@LidIj001bKBioo`03001oogoo01=oo`00
47oo00<007ooOol0;Goo00<007ooOol0G7oo00H001cW@MI5md7F7>L2I[H01AcWI]QVefKH7>L00P00
2Goo00<007ooOol01goo00DLidIk000Lig9/02eoo`03001oogoo01=oo`0047oo00<007ooOol0;Woo
00<007ooOol0FWoo00L006gPJN0Lid7fAOLLi`02I[H01acWI]MVefKG7>MRf6;I00<000Ioo`03001o
ogoo00Moo`<Li`03001fKGoo02eoo`03001oogoo019oo`0047oo00<007ooOol0;goo00<007ooOol0
F7oo01@006gPJN1]h1cWAOM1eVJf7>MZ]VJf7>MRefKH7>MRnEkHH_TLiekj0`000goo00<007ooOol0
1goo0acW00<001cWMVd0;Goo00<007ooOol04Woo000@Ool00`00Oomoo`0`Ool00`00Oomoo`1FOol0
0`00B:0Li`02JN001AcW@OI1mVJf7>L00VJf00`LifKGI]MVeacWH]URf1cWG]YNnU[J7>L200000goo
001oo`07Ool020004Q`LifkE000Lig9]MVd/Ool2000COol0011oo`03001oogoo035oo`03001oogoo
05Aoo`0;001<X4RP7>MYh6gPJN0Lid7FAOLLi`02I[H03QcWI]MVf6;G7>MRf6;iG]PLie[JG_YJfAcW
E]/;000020gl7>M6NP002M/Lig9/LL@XOol300000goo001oo`0BOol0011oo`03001oogoo039oo`03
001oogoo059oo`030018X4RP0098X0077>MYh6WP7>M5md7f7>L00VJf00DLifKGI]MVeacW00=Rf@09
7>MNnUkJG_XLieKkE]/001cW00=>g0057>M2_AcW;Yh^O@027>L01TIk7>L001cWMVebKBEoo`<000Ao
o`03001oogoo015oo`0047oo00<007ooOol0<goo00<007ooOol0DGoo02`001cWC:18X4bPJN0LifWP
KN0LidGgI[HLifJf7>MRefKHI]LLiekHH_URf1cWF]UNnU[J7>MFfeKlE]/004[LC]e:g4kL7>M2_QcW
;Yh^OAcWAWXLi`000QcW00=fKG9/Ool087oo0`001goo00<007ooOol04Goo000?Ool00`00Oomoo`0e
Ool00`00Oomoo`1?Ool010000AP1>1cW0dRP00TLifgPJN0Lid7fI[HLifJf7>L00fKG00hLif;IH]QR
fAcWG_YJfUkjG]XLieKKE_/001cW0dkL00hLid:m@[dLibjN7>M6Ncil0000e1cWLVefKFg37Goo0`00
2goo00<007ooOol047oo000?Ool00`00Oomoo`0fOol00`00Oomoo`1>Ool0:0000CT1604i7>M<X4RP
C:0LifgP7>M5md7F7>MV]QcWI]MVf6;G7>MRf6;iG]PLie[JG_YJfEkj7>MFneKK000LidkLB]a>gD[L
7>Ln_D:n0QcW00Y6NVkE0000e@3D7>MbK7I]KL<LiaQoo`<000ioo`03001oogoo011oo`003goo00<0
07ooOol0=goo00<007ooOol0CGoo00H0004H0CP1604h7>L2B:0026WP7>M]h1cW@OHLifJf7>L3I]L0
3acWH]URfF;IH]PLiekJG_YJfQcWE]]Fn`00E_/Li`04C]`00acW@[e2_@027>L02TIj000LiacW0=@L
ig9]LLA]`acW57oo0`004Goo00<007ooOol047oo000?Ool00`00Oomoo`0hOol00`00Oomoo`1;Ool0
=`009Q/Li`4H0CT1604i7>M<X4RP7>MYh1cW@MIZ]QcWI[HLifKHI]MVf1cWH_URf6;i7>MNnU[JG_YJ
fAcWE]/005KK7>M:g4kLB]a>gD[L7>Ln_D:n7>M6N`00E61@H1cW0=@Lig9/LLA]`acW00moo`@001Ao
o`03001oogoo011oo`003goo00<007ooOol0>Goo00<007ooOol0BWoo00<002XL:Q`00QcW00@1>04H
0CPLi`98X0077>MYh1cW@OHLifJf7>L00fKG00lLif;HH]URfAcWF]YNnUkJG_XLieKk001FneKK7>L0
14kL00LLid:m@[dLi`00ID8Li`02D6001QcW0=@Lig9]LLA@P0aoo`<001Qoo`03001oogoo011oo`00
3goo00<007ooOol0>Woo00<007ooOol0B7oo00h002Xl:Q/Z?2HK:S`Li`4i0AP1>AcWC:0LifgP3P00
01MJfEkjF]XLieKK001FfeKk7>M>gD[LC]a:g4kM7>M2_AcW001U@QcWID5DH51P00<Li`03KL=aa4aP
00Qoo`<001]oo`03001oogoo011oo`003Woo00<007ooOol0?7oo00<007ooOol0Agoo00<002XL:Q`0
12XL00@Li`4h0AP1>0<00003BY]BVAcW00=BV@087>MJUeZGFYMJV1cWHYIRMP@00006E_/005KkE]]F
nacW1DkL00<Li`00ID800VE20QcW0e1P0acW00=l0520Ool00goo0`007Woo00<007ooOol047oo000>
Ool00`00Oomoo`0mOol00`00Oomoo`15Ool04P00?Y`LibHK:S`Z6bXl9Q/Z?1cW0CT001cWBYY>VdZJ
EYXLi`9BV@0=EYXLieZHFYMNV5ZG7>MNMF:FGWERUQcWIW@0100000EFfacWB]a>gD[L00<00008JLTL
iacWJF9U@VUR7>L^G@9@H0<Li`9l00<0025oo`03001oogoo011oo`003Woo00<007ooOol0?Woo00<0
07ooOol0A7oo00<004:L@Y`00QcW1BXL00<005/K7>L00dZK00=BVAcWDYT00U:I00<LieZGFYP00eZG
00XLif9eHYIRMV:F7>MVM000IW@Li`D00003JRi^;QcW009Yb@03KLTLifE2009U@P8Li`03:Ue@H51P
008Li`034Qal07`002=oo`03001oogoo00moo`003Woo00<007ooOol0?goo00<007ooOol0@Woo00H0
04:L?Y]2W3jL@Y`27>L032XK:S`005/LF_]K71cWCY]:VTjKDYTLi`=BV@0@7>MJUeZHFYMNV1cWHYIN
MF:FGWDLif9c001VLacWIU02JU402AcWJPe^;VX=KRhLifgYJLU]j@027>L01FE2JF9U@AcW:U`00U1P
0QcW00<B77`0Ool08Woo00<007ooOol03goo000>Ool00`00Oomoo`10Ool00`00Oomoo`11Ool00`00
@Ya2W004@Y`02BXL7>L005/KF_]K6e[k7>M:VP02BY/00e:I7>MBV@02DYT041cWFYMJUeZHFYLLif9f
HYIRMF:F7>MVM000IWAVLacW0fYA00HLifX]JRiZ;Vh^7>L2JLT00fg9ID8Li`03ID827>L010WLD60L
iacW97oo00<007ooOol03goo000>Ool00`00Oomoo`11Ool00`00Oomoo`10Ool0:@007>LLid:L?Y]2
W3jL@Y`001cWF_]K75KkFa`LidjKBYY>Ve:I7>MBVEJJDYTLieZGGYQJUeZH7>MRUUieHYINMF:F7>L0
069cIW@LifYAIU000VYA01@LifX=KRiZ3Fh^7>M]jFW9KNUYbAcWID9YHVE1JF8Lig`0D61DH1cW8goo
00<007ooOol03goo000>Ool00`00Oomoo`12Ool00`00Oomoo`0nOol01@00C[a>^djl7>L00d:L00P0
06W07>MK6e[kFa]JnacW0TZK00=:VU:I7>L00e:I00<LieZHFYL00UZG00`Lif9eHYIRMV:FHWDLi`00
IWAVLfId7>L3JU400acWKRiZ;@02JRh01Vh^7>LLifW9KLUYb@8Li`=U@P8Li`9@H0037>Moogoo021o
o`03001oogoo00moo`003Goo00<007ooOol0A7oo00<007ooOol0?Goo01D004jkC]a>^dkL7>M2W000
KL1Y`1cWE_]K75[kFaa:VQcWBYY>Ve:I7>L00e:I014LieZGFYQJUejH7>MRUUieHYINMF:F7>L006Ic
IWARLacW009ZD@0CIU1ZDAcWKRiZ3Fh^JPe^;VX=7>MYbFgYJLUYHQcWJF9U@FURID800QcW00<0eAcW
7>L087oo00<007ooOol03goo000=Ool00`00Oomoo`15Ool00`00Oomoo`0lOol01`00C[a>^djlC[]>
_00000AY`0067>MJne/KF_]K6acW0TZK00=BVAcWDYT00U:I00@LieZGFYMJV09JU`0<7>MRUV9eHYIR
MV:F001VM6IcIWAVLacW16YA00<Lifh^JRd00VX^00E^;VX]7>MYbFg9009Yb@037>MU@VE200=U@P04
7>M@H51P7>LOOol00`00Oomoo`0?Ool000eoo`03001oogoo04Ioo`03001oogoo03Yoo`08000Lidjk
C]a>^dkL000Li`=Y`00PKL0Lie/LE_]K75[k7>M:VTjKDYTLie:IEYYBVAcWFYMNV5ZGFYQJUacWGWER
UUieHYINM@00HW=VM6IcIW@Li`=ZD@0>IU1ZDAcWKRiZ3Fh^JPe^;VX=7>MYbFgYJLU]j@8Li`04ID5Y
HVE2JF827>L00e1PO01oo`0NOol00`00Oomoo`0>Ool000eoo`03001oogoo04Moo`03001oogoo03Qo
o`03001FfeKK008Li`05C[a>^`00JH0Li`04JL002AcWFa]Jne/K7>M:VdZJBY/Li`04DYT04QcWFYMJ
UeZGFYPLif:FHWIRUV9eHYHLi`00IW=VM6IcIW@Li`EZD@037>M^;VX]009Z;P05KRiZ;AcWJLU]b@03
JLT00acWID9U@P03ID800acWD61l000NOol00`00Oomoo`0>Ool000eoo`03001oogoo04Qoo`03001o
ogoo03Moo`0;001FfU[kE]]FnacW001UP6V07>M]`003JL002QcWF_]K75Kk7>M:VTjKBYYFVQcW0U:I
01AFVQcWFYQJUejHFYLLieieHYINMF:FGWERUP00IWARLfIdIW<LifI@0fYA01EVD6YA7>M^;VX=KRiZ
3Fh^JPdLifW9KNUYbFgYJLTLifE1JF9U@VURID400QcW7Woo00<007ooOol03Woo000=Ool00`00Oomo
o`18Ool00`00Oomoo`0fOol00`007>MFf`04E]/01@00JH1YP6V07>L00fW000HLie/KF_]K6dZJ7>L2
BY/00e:I7>MBV@02DYT00acWFYMJV002FYL03QcWHYIRMF:FHWIRUV9e001VLfIdIW=VM6Ic7>L6JU40
0acWKRiZ;@02JRh01Fh^JRdLifW9KLT00fW90QcW1FE200=l07ooOol06goo00<007ooOol03Woo000<
Ool00`00Oomoo`1:Ool00`00Oomoo`0cOol200003U[jF_/LieKkE]YJn`00JH1UP6V0IH1YP1cWKL02
JL002QcWFaaJne/L7>M>VdZJDYTLieJJ0U:I01DLiejHFYMJV5ZGGYPLif:FGWERUUieHYH001cWIW=V
M69cIWAVLacWIU000fYA01IVD1cWJPe^;VX=KRiZ3Fh^JPdLifW9KNUYbFgYJLU]jAcWJF9U@VURID5l
01eoo`03001oogoo00ioo`0037oo00<007ooOol0Bgoo00<007ooOol0<Goo00<005kjG_X00Ukj00EF
facWE]]Ff`0000EYP00=7>MY`6W0JL0Lie[kFa]JnacWBYY:Ve:I7>L00e:I01@LieZGFYMJUeZHFYLL
if9fHYIRMF:FHWH001cWIWAVLfIdIW=VM1cW1VYA00@LifX^KRiZ;@9Z;P05KRiZ;AcWJLU]b@03JLT0
1Fg97>MU@VE2O0007Woo00<007ooOol03Woo000<Ool00`00Oomoo`1<Ool00`00Oomoo`0^Ool20000
76<J7>MNne[jG_]JnU[k7>L006gU7>MUP6V0IH1YP6F07>MY`6g0JL0LieKkFa`LidjKBYYFVQcW0U:I
01QFVQcWFYQJUejHFYMJV1cWHYINMF:FGWERUP007>MRLfIdIW=VM69cIW@LifYAIU03JU402FI@7>MZ
3Fh^JPe^;VX=KRiZ3@027>L01FgYJLU]jFW9KNT00QcW00=l07ooOol077oo00<007ooOol03Woo000<
Ool00`00Oomoo`1=Ool00`00Oomoo`0ZOol3000016;iHaYRnAcW1Ekj00EFf`00LNE]iAcW00EYP007
7>MY`6W07>MK6e[k7>L00TZK00=:VQcWDYT00U:I00<LieZGFYP00eZG00lLif9eHYIRMV:FHWD0069f
7>MVLfIdIW=VM6Ic7>L01fYA00@LifX^KRiZ;@9Z;P05KRiZ;FX^7>M]b@03JLT00fg9JLUl000OOol0
0`00Oomoo`0=Ool000aoo`03001oogoo04ioo`03001oogoo00aooa<000Eoo`D0000GIaPLif;iHaYR
nF<JH_TLie[jG_]JnUkkF_X006gULNI]iAcWIH1YP6F0JH0Li`02JL002AcWF_]K74ZJ7>M:VTjK7>MF
VP03DYT05AcWFYMJV5ZGGYPLif:FGWERUUieHYH006:F7>MVM69cIWAVLfIdHW<Li`02JU4056I@JU5Z
DFYAIU0LifX=KRiZ3Fh^JPe^;VX=KRhLifgYJLU]jFW9O00POol00`00Oomoo`0=Ool000aoo`03001o
ogoo04moo`03001oogoo00Qoo`<0009fBP057>Mj[7Z/NZ`Li`04N_400acWMaAg5002Ma@00acWLaI_
5P0500000f/GKaPLi`03IaT021cWHaYRnF<JH_US6V;i7>L3G_X00`00KNEai@02LND00fgU7>MYP003
JH001acWJL1Y`1cWF_]:VacW009:V`037>MBVE:I009BV@0E7>MJUeZGFYQJUacWHWIRUV9eHYIRMP00
HWDLifIcIWAVLfIdIW=VM1cW00QZD@047>MZ;Vh^JRd2JRh01Fh^JReZ;QcWKLT00W`08Goo00<007oo
Ool03Goo000;Ool00`00Oomoo`1AOol00`00Oomoo`05Ool200000dhg7>MbB@02MTX00acWNZaj[002
NZ`0DAcWN_5fl7[a7>Mg57<DMaAc4acWKaIc5VlFLaHLiflHJaM_66/GKaPLif/IIaQ[6AcWHaYRnF<J
H_US6V;i7>MJnUkk001aiVgULNI]iG7VKNDLifF0JH1UP6V07>MY`1cWFaaJnacWBYY>Ve:I7>MBVEJJ
DYTLieZGGYQJUeZHFYLLieieHYINMF:F001RUUie7>MVLfIdHW=VM6IcIW@Li`03JU403fI@JU5ZDFYA
IU0LifX=KRiZ3Fh^JPe^;VX=KRil000SOol00`00Oomoo`0=Ool000]oo`03001oogoo059oo`03001o
ogoo009oo`8000A>=`057>MfBWI:MTXLi`03NZ`00acWN_5jl@02N_401AcWMaAg57LD7>L00g<F00U_
5QcWJaM_66/GJaQ[5acWIaP00VLI00PLif;iHaYRnF<JH_US6QcW0Ukj00@001cWLNE]i@=ai@03KNDL
ifV0009YP00:7>MY`6W07>MK6acWBY]:VU:I7>L3DYT00acWFYQJU`02FYL04EZH7>MRUV9fHYIRM@00
HWIRUQcWIWAVLfIdIW=VM6Ic7>L026YA00DLifX^JRi^;VX]009Z;P9l02Aoo`03001oogoo00eoo`00
2goo00<007ooOol0Dgoo00H007ooOol0048i7>L2CSL01dXfCSMfBQcWLTUfBQcW00=j[00h7>MjlGK`
N_5fl1cWLa=g57<DMa@Lig<FKaIc5QcWKaQ[5flHJaM_61cWJaUW66/IIaPLif;iHaYRnF<JH_US6QcW
001^2W8[7>MaiVgULNI]iG7VKNDLifF0JH1UP1cWJL0LieKk7>M:VTjKDYTLi`=BV@0H7>MJUeZHFYMN
V5ZG7>MNMF:FGWERUP00HYINMAcWHW=VM6IcIWARLfIdIW<LifI@0fYA00YVD6YAJU5ZDAcWKRiZ3Fh^
JPel02Ioo`03001oogoo00eoo`002goo00<007ooOol0E7oo0P0000A6FDIJAUTLi`A>=`057>MfBWI:
MTXLi`03NZ`01AcWN_5jlG[a7>L017LD00<LiflFLaH00W<F00HLif/HJaM_66/G7>L2IaT04FLHIaTL
if<JH_US6V;iHaYRnF<J001b2fh;LP/Lig7UKND00g7U00=]iAcWJH000VV00QcW00IK6acWBY]:Ve:I
7>L3DYT011cWFYMJUeZH0UZG014Lif:FHWERUV9f001RMF:FHWHLifIcIWAVLfIdIW=VM1cW00UZD@04
7>MZ;W`0O00WOol00`00Oomoo`0=Ool000]oo`03001oogoo05Eoo`060016FTHiAUY2>AcW0Thg00I:
=Thg7>MfBW997>L3NZ`09AcWM_1jlGK`7>Mc57LDLa=g51cWLaI_5W<FKaHLif/GKaQ[5flHJaLLifLH
JaUW66/I7>MS6V;iHaYRnF<JH_T006h:LR]^2W8[008Li`0]KNEaiVgULNI]iAcWIH1YP1cWKL0LidjK
7>M>VdZJ7>MBVEJJDYTLieZGGYQJUeZHFYLLieieHYINMF:F001RUUieHYHLifIdHW=VM6IcIWARLfId
7>MZDFI@00=ZD@03IU1ZDG`0009l02Uoo`03001oogoo00eoo`002goo00<007ooOol0E7oo00P004IJ
AUU6FTIIAUY6FAcW14hg00@LigI:MTXLi`9j[0057>MjlG[aN_4Li`04Ma@031cWLaIc5VlFLaHLiflH
JaM[66/GKaPLi`=W6@0AIaPLif;iHaYRnF<JH_T006h;LP]^2g8;KP]b2fh;7>M]i@03LND016gU7>MY
P6V00QcW00EJnacWBYY:VacW00ABV@0G7>MJUeZGFYMJV1cWHYIRMV:FHWD0069fHYIRMAcWIW=VM6Ic
IWAVLfIdIW<Li`03JU44O00]Ool00`00Oomoo`0<Ool000]oo`03001oogoo05=oo`0:001BVQcW7>M2
>DIJASU6FT8i7>L2CSL01TXfMTXLigI:NZ`Li`9j[00`7>MjlGK`N_4LigLDLaAg51cWLaI_5W<FKaHL
if/GKaQ[5flHJaLLifLHJaUW66/IIaPLif;iHaYRnF<J001b:fh:LR]^2W8[KPYb:fh:7>M]iG7VKNEa
iVgU7>MUP6V00acW00=>VdZJ7>L00e:I01EFVQcWFYQJUejHFYMJV1cWHYINMF:F001RUUieHYINMAcW
IW=VM69cIW@01W`0<Goo00<007ooOol037oo000:Ool00`00Oomoo`1DOol02P00CYUBVTjJ7>M6FDIJ
AUU6FTII0QcW0Thg00AfBQcWMTXLi`9j[0057>MjlG[aN_4Li`03Ma@00acWKaIc5P02LaH02AcWJaQ[
5flHJaM[61cWIaUW6003IaT03acWHaYRnF<J001Z;QcWLP]^2g8;KP]b2fh;LP]^2`027>L3LND00fgU
7>MYP0037>L2O0000acWO01l0002DYT00acWFYMJV003FYL01AcWHWERUV9f00002G`0=goo00<007oo
Ool037oo000:Ool00`00Oomoo`1COol01P00CWUBVTiiDYY>N@8Li`0<AUY6>DIJ@SU6FQcWCSM:=WI:
7>Mj[1cW0WZ/01lLigK`N_4LigLDLa=g51cWLaI_5W<FKaHLif/GKaQ[5flHJaM_61cWJaUW66/IIaQ[
6AcWHaYRn@00JRi^;`027>L046h:LR]^2W8[KPYb:fh:LR/Lig7VKNEaiVgU7>MUP1cW1Woo3G`000<0
07ooOol0?Goo00<007ooOol037oo000:Ool00`00Oomoo`1COol020007>M>VU:JCYUBVTjJDYX27>L0
1DIIAUY6FDIJ7>L00Thg00<LigI:7>L00WZ/00@Lig[aN_4Li`Ag50037>Mc5VlF009c5P077>M[5f/H
JaM_66/G7>L00VLI00QW66LIIaTLif;i001Z;Vh_0fX^00XLifh;LP]^2g8;KP]b2fh;LP/Li`=ai@04
KNDLifW07>LBOol00`00Oomoo`0mOol00`00Oomoo`0<Ool000Yoo`03001oogoo059oo`03001J^Dii
008Li`0mDYY>NE:JCWUBVT8i7>M6>DIJ@SU6FQcWCSMbBAcWNZ`LigZ/7>Mfl7[a7>Mg57<DMaAc4acW
KaIc5VlFLaHLiflHJaM_66/GKaPLif/IIaQ[6FLHJaUW61cW001^;fX^KRmZ;Vh_JRhLifh:LR]^2W8[
KPYb:fh:LR/00QcW00=]iG7VKND00QcW4Woo00<007ooOol0?Goo00<007ooOol037oo000:Ool00`00
Oomoo`1BOol03000F[UJ^EZiDYXLie:JCYUBVTjJDYY>V@8Li`06AUY6FDIJ7>M>=gI:0QcW0WZ/00<L
ig[a7>L017LD00dLig<FLaIc5VlF7>M[5flHJaM[66/G7>MW6003IaT016LHIaT006h_0fX^00A^;fX^
JRiZ;P8Li`09LP]^2g8;KP]b2fh;LP]]iAcW009ai@03KNDLig`0015oo`03001oogoo03eoo`03001o
ogoo00aoo`002Woo00<007ooOol0DGoo00<005JiF[X00UZi04MF^EZj7>LLidiiDYY>NE:JCWU6FQcW
AUY2>DIJ7>M>=acWNZ`LigZ/7>MjlGK`7>Mc4gLDLa@LiflFLaI_5W<F7>M_66/GKaQ[5flHJaLLifLH
JaUW66/IIaP006X^KRmZ;Vh_JRi^;fX^KRmZ;Vh_7>Mb:fh:LR]^2W8[KPYb:fh:7>M]iG7VKNDLig`0
011oo`03001oogoo03ioo`03001oogoo00]oo`002Goo00<007ooOol0DWoo00<001cWF[T01UZi0QcW
00EBVTjJDYY>VDIJ008Li`04AUU6FQcWCSL27>L01GZ/7>MjlG[a7>L00gLD00<Lig<FKaH00W<F00XL
if/GJaQ[5flHJaM[61cWIaUW609W6@05001V<AcWJRi^;`03JRh03Vh_JRiZ;VX^KRlLig8;KP]b2fh;
LP]^2g8;KP/27>L00g7UKNEl000@Ool00`00Oomoo`0nOol00`00Oomoo`0;Ool000Uoo`03001oogoo
059oo`05001J^AcW7>MJ^P02F[T03UJiF[YJ^E:J7>MBVTiiDYY>NE:JASTLid8iAUX27>L07GZ/7>Mj
[1cWM_0Lig<DMaAc4acWKaIc5VlFLaHLiflHJaM_66/GKaQ[5acWIaQ[6FLHJaT006IAIS000QcW00U^
;fX^KRmZ;Vh_JRi^;fX^KRl00QcW00]^2W8[KPYb:fh:LR]^2W7V7>MaiW`0011oo`03001oogoo03io
o`03001oogoo00]oo`002Goo00<007ooOol0DGoo00D005kHH]QRf5Zi008Li`IJ^@8Li`08CYYBVTjI
DYY6FAcWAUU6FP<Li`04NZ`Lig[a7>L3Ma@03AcWLaIc5W<FKaHLif/GKaQ[5f/HJaM_61cW00=W6@03
001V<FHa00=V<@037>M^;fX^009Z;P0BKRmZ;VX^JRi^;fX^7>M^2g8;KP]b2fh;LP]^2g7U7>MaiG`0
3goo00<007ooOol0?Woo00<007ooOol02goo0009Ool00`00Oomoo`1AOol02000H]UNf6;IG]QJ^EJi
7>L2F[T02eJiF[YJ^EZiE[TLidiiDYY>NE:JCWT00QcW00=6FQcWO0000QcW01afl1cWLa=g57<D7>M_
5W<FKaIc5VlF7>M[5flHJaM_66/GKaPLif/IO00006H`JU5V<6IAIS1ZD@8Li`09JRi^;fX^KRmZ;Vh_
JRi^;fX^008Li`09LR]^2W8[KPYb:fh:LR/Lig`000ioo`80041oo`03001oogoo00]oo`002Goo00<0
07ooOol0DGoo00@006;HH]UNf09Rf004H]UJ^AcW7>L6F[T27>L03E:JCYUBVTjJAUXLig`0Ooml07Z/
7>MjlAcW00=g50037>M_5W<F009c5P0:7>M[66/GKaQ[5f/HO00Lig`00009IS427>L2JRh01Fh_JRiZ
;VX^KRl00VX^0QcW00M^2g8;KP]b2fh;LP]l000;Ool30002Ool00`00Oomoo`0mOol00`00Oomoo`0;
Ool000Uoo`03001oogoo055oo`0>000LiekHH]UNf6;IG]QRfEkHF[XLieZiE[UJ^P9J^@09E[UJ^QcW
DYY>NE:JCWUBVQcW009oo`9l000<N_4LigLDLa=g51cWLaI_5W<FKaHLif/G17`00goo01L001cWIS1V
DFH`JU5V<6IAIS1ZDFH`IU4Lifh_JRi^;fX^KRmZ;Vh_JRi^;fX^008Li`05LR]^2W8[KPYl0007Ool4
0006Ool00`00Oomoo`0lOol00`00Oomoo`0;Ool000Uoo`03001oogoo055oo`06001Vn1cWH]QRfEkH
0V;H00=RfEkHF[T00QcW1UZi0QcW00=>VE:JO0001Goo0g`00WLD00<Lig<FLaH00W`000<Lig`0Ool0
1Goo00@0068cIS4Li`YV<@8Li`03JRi^;fX^009Z;P0:KRmZ;VX^JRi^;acWLP]^2g8;O004Ool3000:
Ool00`00Oomoo`0lOol00`00Oomoo`0;Ool000Qoo`03001oogoo055oo`04001VmfKhI_L27>L026;I
G]QRfEkHH]UNf6;IF[T27>L025ZjF[UJ^EJiF[YJ^AcWO009Ool2O0000acWO01l0009Ool01@00HS=R
<V8cIS000QcW01EVDFH`JU5V<6IAIS1ZDFH`IU5V<1cWJRi^;fX^KRmZ;Vh_JRi^;fX^KRl00QcW00=^
2W8[O0000`003Woo00<007ooOol0?7oo00<007ooOol02Woo0008Ool00`00Oomoo`1AOol00`00I_QV
n003I_P00acWH]UNf002H]P00f;IG]QRf002F[T00acWF[UJ^@04F[T00g`0Oomoo`0DOol02@00HS=R
<V8cHS9R<f8bIS4Li`0:IS427>L01Fh_JRiZ;VX^KRl00fX^00=^;fX^00000P004Woo00<007ooOol0
>goo00<007ooOol02Woo0008Ool00`00Oomoo`1AOol04`007>MZn6KgI_QVmf[h7>MRfEkHH]UNf6;I
G]QRfEkHF[TLieZj009J^@03E[Ul07oo01Eoo`0F7>MR<f8bHS=N<V8cHS9R<ehbJU4LifIAIS1ZDFH`
IU5V<6YAIS1VDFH`KRl27>L01FX^KRmZ;Vh_JRh00`0000=Z;Vh_O0004goo00<007ooOol0>Woo00<0
07ooOol02Woo0008Ool00`00Oomoo`1@Ool01000J_MVn1cW1FKh0QcW00ENf6;HH]QRfEkH009Rf003
H]TLiacW009J^@03O01oogoo01=oo`0=001N=1cWHS=R<V8cHS9R<f8bHS=R<VHa7>L02fHa00=Z;QcW
00000`000fX^00=^;fX^O00057oo00<007ooOol0>Goo00<007ooOol02Woo0008Ool00`00Oomoo`1@
Ool05`00KaMZmfKh7>MZn6KgI_QVmf[hI_LLiekHH]UNf6;IG]QRfEkHH]UF^AcWO00057oo0P0001MN
=5XdGS@Lif8cHS9R<ehbHS=R<V8cGS9R<acWIU5V<6YAIS1VDFH`JU5V<6IA00<000097>MZ;Vh_JRi^
;fX^KRmZ;W`001Ioo`03001oogoo03Qoo`03001oogoo00Yoo`0027oo00<007ooOol0Cgoo00L006lG
J_M[5f[gI_PLi`06I_P01QcWG]QRf6;HH]UNf09Rf003H]UNf7`001=oo`04001N=5hdFS@3GS@02QcW
HS=R<V8cHS9R<f8bHS=R<V8c0QcW16Ha0`0016Ha0QcW0VX^00A^;fX^JRil01Ioo`03001oogoo03Qo
o`03001oogoo00Yoo`001goo00<007ooOol0D7oo00<006[g00002`000QcW00MRfEkHH]UNf6;IG]Ql
000BOol2000055XcGSAJ=5hdFS=N=5XdGS@Lif8cHS9R<ehbHS=R<V8cGS9R<fH`7>L300003fIAIS1Z
DFH`IU5V<6YAIS1^;acWKRmZ;Vh_JRil000GOol00`00Oomoo`0gOol00`00Oomoo`0:Ool000Moo`03
001oogoo04aoo`H0009@`0057>L0M@1e07D0M00207D00acW6GPMN@0700000f;HO01oo`0?Ool20002
ESD00acWFSAN=002GS@035XdGSAN=5hd7>MR<f8bHS=R<V8cHS9R<`<000037>MV<FHa00YV<@057>MZ
;VX^KRml000HOol00`00Oomoo`0gOol00`00Oomoo`09Ool000Moo`03001oogoo04Uoo`<0000IID1Q
@6E0C<1@`4c0D<1<`1cW07@0U@1d09D0M02E7>LMNAUh7GTIN1ei7>LinCGH>OT04P00015F=EXeESEJ
=AcWGSAJ<ehdFSAN=5XcGSAJ=5hd7>MR<f8b00@0000AHS=N<V8cHS8LifH`JU5V<6IAIS1ZDFH`IU5V
<6YAIS1VD@027>L00g`0Oomoo`0HOol00`00Oomoo`0fOol00`00Oomoo`09Ool000Moo`03001oogoo
04Yoo`EU@0I@`0037>L0M01e0080M@0@07@LiaUi7GTIN1ei6GTLicGH>OPef3Wi=MPin1cWAQP3AQL0
2DHHCSHLidhfDSI>=U8fCSHLi`06ESD00acWGSAJ=003GS@00eXdGSAN=00300002F8bHS=R<V8cHS9R
<f8bHS=R<P027>L<IS400g`0Oomoo`0IOol00`00Oomoo`0eOol00`00Oomoo`09Ool000Moo`03001o
ogoo04]oo`0gHD1U@650ID1Q@530C<1@`4c0D<0Li`2E07@0U@1d09D0M1cW6GPMNAUh7GTIN1cW=MPi
nCGH>OTef1cWAQM:64HGBQQ65dXH7>MB=dhFDSM>5U8gCQHLieHeFSEF=EXeESEJ=AcWGSAJ<ehdFS@0
0`0001YJ=5hd7>MR<f8bHS=N<V8cHS9R<ehbHS=R<VIA7>MZDFH`IU5V<6YAIS1VDFH`JU5V<7`077oo
00<007ooOol0=Goo00<007ooOol02Goo0007Ool00`00Oomoo`1<Ool5ID05D<000acW07D0M00307D0
41cW7GTINAei6GPMNAcW>OTef3Wh=MPinCGH7>M65dHH0dHG00PLidhfDSI>=U8fCSIB=QcW1UHe00<L
iehd00000P000Uhd015J=5hdGSAN=1cWHS=R<V8cHS9R<f8bHS=R<V8cHS9V<AcW00UV<@03O01oogoo
01]oo`03001oogoo03Aoo`03001oogoo00Uoo`001goo00<007ooOol0<Woo2@0047oo034007LeHD1U
@650ID1Q@530C<1@`4c07>L0M02E07@0U@1d7>LIN1ei6GPMNAUh7>Lef3Wi=MPinCGH>OTLidXHAQM:
64HGBQPLie8gCQIB=dhFDSM>5U8g7>MJ=EHeFSEF=@0300007eXdGSAJ<ehdFSAN=5XcGSAJ=5hd7>MR
<f8bHS=N<V8cHS9R<ehbHS=R<V8c7>MZDFH`IU5V<6YAIS1VDG`001moo`03001oogoo03=oo`03001o
ogoo00Uoo`001Woo00<007ooOol0<Goo0P0000T=fc8J<QXb6QUH6GPIF1Uh018010002Woo0P0000<L
igLeMcD016E01E3001<Li`1e07D0M01e7>LMNAUh7GTINAei7>Lin3GH>OTef3Wh=MPLi`03AQL02dHH
AQMB=QcWDSI>=U8fCSIB=Thf7>L010000eHe00@LiehdGSAJ=0=N=00AFSAN=5hdHS<Lif8cHS9R<f8b
HS=R<V8cHS9R<f8bHS<Li`05IS400g`0Oomoo`0OOol00`00Oomoo`0bOol00`00Oomoo`09Ool000Io
o`03001oogoo02moo`80000<IYDLiacW3M/Ao38J<Q/EF1Ui6EPIN@0A0P0B00=M`00000000P0017oo
0P000W/c02Yg<QcWLaEg=F50ID1Q@6E0C<1@`4c0D<0Li`2E07@0U@1d09DLiaei6GPMNAUh7>Lef3Wi
=MPinCGH>OTLidXHAQM:64HGBQQ65acWCQIB=dhFDSL300007eXeESEJ=EHeFSEF=EXe7>MN=5XdGSAJ
<ehdFSAN=5XcGSAJ=1cWGS9R<f8bHS=N<V8cHS9R<ehbHS=R<V8c008Li`03IS1VDG`002=oo`03001o
ogoo035oo`03001oogoo00Uoo`001Woo00<007ooOol0;goo00P001cW7>MVUF9e7>L=f`gl0S8J00<I
F1Uh6EP00`0B00EIX5W0FJ0Lig[800@00003Oc0Lig/c009k<`047>Mg=GLeMcD4ID04D<0051cW07D0
M@1e07@LiaUi7GTIN1ei7>LinCGH>OPef3Wi=MPLidHGAQP3AQL00dHH7>MB=P030000158fCSIB=QcW
1eHe00DLiehdGSAN=5Xd00=N=00DFSAN=5hd7>MR<V8cHS9R<f8bHS=R<V8cHS9R<f8bHS=R<QcWIS5l
02=oo`03001oogoo039oo`03001oogoo00Qoo`001Woo00<007ooOol0;goo00<006JeJ[H00QcW01MR
M1cW7>LAo38J<Q/001cW6EP04P0A019IX5g0FJ0Lig[8N/TLigl`N`lLigLb009k<`0S7>Mc57LeLaEg
=F50ID1Q@6E0C<1@`4c07>L0M02E07@0UAcW7GTIN1ei6GPMNAcW>OTef3Wi=MPinAcWBQQ65dXHAQM:
60030000:E8gCQIB=dhFDSM>5QcWESEJ=EHeFSEF=EXeESEJ=AcWGSAJ=5hdFS=N=5XdGSAJ<ehdFS@L
iehbHS=R<V8cGS9R<f8bHS=N<V8cHS9R<ehbO0009Goo00<007ooOol0<Goo00<007ooOol027oo0006
Ool00`00Oomoo`0_Ool02000I[IV]FJfI[DLif9eIYD27>L01@00>]hb6QcW6EP00P0B00AI`5VPFL0L
i`9jb0057>Mo;gl_OblLi`02Nc<00acWMcEg=@02McD011cWID1U@6E0153001<Li`1d07D0MAcW6GPM
NAUi7GTIN1cW=MPinCGH>OPef3Wi7>M65`0300002dHGCSHLidhfDSI>=U8fCSIB=Thf7>L01eHe00<L
ieXdGS@00Uhd00EJ=5hdGSAN=5Xd009N=00=7>MR<V8cHS9R<f8bHS=R<V8cHS9R<f8bO0009goo00<0
07ooOol0<7oo00<007ooOol027oo0006Ool00`00Oomoo`0_Ool01P007>LLifJeJ[IV]@8Li`0bIYD0
01cW=]hjgcKN7>LIF00B015M`5VP7>Mjb7[9N/PLig/?Oc0Lig/cMc9k<acWMcEc57LeLaDLiflFID1Q
@530C<1@`1cW09D0M02E07@LiaUh7GTIN1ei7>LinCGH>OTef0@0000]BQQ65dXHAQM:61cWDSM>5U8g
CQIB=dhFDSLLieXeESEJ=EHeFSEF=EXeESDLieXcGSAJ=5hdFS=N=5XdGSAJ<ehdFS@LiehbHS=R<V8c
GS9R<f8bHS=N<W`002Uoo`03001oogoo02moo`03001oogoo00Qoo`001Goo00<007ooOol0<Goo00X0
06[E7>LLifJfI[EV]P00I[LLi`8fgP09>]hfgQcW7>L04UVPFL0Lig[9009jb0047>Mo<7l_7>L3Nc<0
0acWMcEg=@02McD00acWLaI_5P02ID03D<002acW07D0M01e7>LMNAUh7GTINAcW=MP00`0000@ef3Wh
7>M660=65`0;AQQ65acWCSIB=ThfDSI>=U8fCSHLi`09ESD00acWFSAN=002GS@01EXdGSAN=5hdFS@0
0Uhd00TLif8bHS=R<V8cHS9R<f8bO000:goo00<007ooOol0;Woo00<007ooOol027oo0005Ool00`00
Oomoo`0aOol02P00K]EZe6kE7>MZ]VJe001R]VJg0QcW00lfgS[O=]hINAcW019IX5g07>MjbG[87>Mk
3gl`7>L00g/c01DLigLeLaEg=G<D7>M_5W<FKaIU@4c0D<1<`1cW07@0U@1d7>LIN1ei6GP00`00038e
f3Wi=MPinCGH7>M65dXHAQM:64HGBQPLie8gCQIB=dhFDSM>5U8gCQHLieHeFSEF=EXeESEJ=EHeFSDL
iehdFS=N=5XdGSAJ<ehdFSAN=5XcGSAJ=1cWGS9R<f8bHS=N<W`0;Goo00<007ooOol0;Goo00<007oo
Ool027oo0005Ool00`00Oomoo`0aOol01@007>LLif[EK]D00QcW00D006JgI[MV]f:f008Li`0:>]hf
gSKN7>MI`5VP7>Mjb7[97>L2Obl00acWNc=k<`02Nc<00acWMcEg=@02McD01AcWLaIc5VlFID000e30
00@Li`1e07DLi`<000096GPMNAcW>OTef3Wh=MPinAcW00965`0>AQQ65dHGAQM661cWDSI>=U8fCSIB
=ThfDSHLi`UF=@037>MN=5Xd00=N=005FSAN=5hdGSAJ=002GS@01AcWHS9R<f8bO000;Woo00<007oo
Ool0;Goo00<007ooOol027oo0005Ool00`00Oomoo`0bOol01`00J]@Lif[DK]EZe000008Li`08H[IV
]f:fI[LLic[O=]hjg`<Li`08N/Ujb1cWN`mo<1cWNc=g<P9k<`0>7>Mc57LeLaEg=AcWLaM_5W<FKaIU
@4c0D<0Li`<0000f7>LMNAUh7GTIN1cW=MPinCGH>OTef1cWAQM:64HGBQQ65dXHAQLLidhFDSM>5U8g
CQIB=dhFDSLLieXeESEJ=EHeFSEF=EXeESEJ=AcWGSAJ<ehdFSAN=5XcGSAJ=5hdFS=N=5Xd7>MN<W`0
<7oo00<007ooOol0;Goo00<007ooOol01goo0005Ool00`00Oomoo`0bOol02@00L]=bdacWJ]E^e@00
HYINUP027>L00fJgH[IV]`027>L2=]h01UVP7>Mjb7[87>Mo<09o;`057>Mk<g/cNc<Li`05McD011cW
LaIc5W<F1000010Li`1e07DLiaUh7GTINAei7>Lin3GH>OTef3Wh=MPLi`=65`0=AQQ65dHG7>MB=Thf
DSI>=U8fCSIB=Thf7>L02EHe00@LiehdGSAJ=0=N=005FSAN=5hdGSAJ=002GS@00g`0Oomoo`0`Ool0
0`00Oomoo`0/Ool00`00Oomoo`07Ool000Eoo`03001oogoo039oo`047>L007;dL]<27>L01@007>LL
iejFHYL00QcW00=R]VJgH[H00QcW00TjgcKN7>Mjb7[97>Mo<7/?7>L00W/c00Qg<QcWLaEg=G<DMcEc
5AcW0`0003]c5W`0D<1<`1cW07@0UAcW7GTIN1ei6GPLicGH>OTef3Wi=MPinAcWBQQ65dXHAQM:64HG
7>M>5U8gCQIB=dhFDSM>5U8gCQHLieHeFSEF=EXeESEJ=EHeFSEF=AcWFSAN=5XcGSAJ=5hdFS=N=5Xd
GSAJ<g`003Aoo`03001oogoo02]oo`03001oogoo00Moo`001Goo00<007ooOol0<goo00T001cWL]=b
dfkE001JMeIG7>L00ejF0QcW0fJg00<LicKN=]h00acW00=o;gl`7>L017/c00<LigLeMcD00`0000@L
iflFLaIl009oo`0CD<0Li`1e07@LiaUi7GTIN1ei7>LinCGH>OPef3Wi=MPLidHGAQP00dHG00a664HG
7>M>=U8fCSIB=ThfDSI>=U8f7>L:ESD011cWGSAN=5Xd0ehd00AJ=5hdO01l03Ioo`03001oogoo02Yo
o`03001oogoo00Moo`0017oo00<007ooOol0=Goo00P001cWL_Abd`00EUIJMeIF0QcW00=RUejFHYL0
0QcW00]R]VJg7>LLicKN>]lLigl`N`lLigLb00=k<`<00007McEc57Le7>Mc5VlFO0000goo03A@`1cW
09D0M1cW6GPMNAUh7>Lef3Wi=MPinCGH>OTLidXHAQM:64HGBQQ65dXH7>MB=dhFDSM>5U8gCQIB=dhF
7>MF=EXeESEJ=EHeFSEF=EXeESEJ=AcWGSAJ=5hdFS=N=5XdGSAl03Qoo`03001oogoo02Yoo`03001o
ogoo00Moo`0017oo00<007ooOol0=Goo00/007[a7>Mbd`00FWMFEUYgEUMJMacW009NUP03HYINUQcW
009V]`07H[HLiacW>]hLigl_7>L0100000<LigLeMcD017Le00<Lig`0Ool017oo00lLi`1e07DLiaei
6GTMNAUh7>Lef3Wi=MPin3GH7>L00dHG00m664HGAQM65acWCSIB=ThfDSI>=U8fCSIB=Thf7>L02UHe
00LLiehdGSAN=5XdGSAl000jOol00`00Oomoo`0YOol00`00Oomoo`07Ool000Aoo`03001oogoo03Eo
o`0@7>L001cWL]<001cWFWMFEUYgEUIJMacWHYMNUV:GGYH27>L016JgH[IV]acW0`0000<Lig/cMc80
0W/c00LLig<DMcEc5GLeLaAl0006Ool0;dc07>L0M1cW6GPMNAUh7GTLicWi=MPinCGH>OTLidXHAQM:
64HGBQQ65dXHAQLLidhFDSM>5U8gCQIB=dhFDSLLieXeESEJ=EHeFSEF=EXeESEJ=EHeFSDLiehdFS@0
0W`0?7oo00<007ooOol0:7oo00<007ooOol01goo0004Ool00`00Oomoo`0fOol01@00M_4Lig;C0000
0QcW00AFEUYgEUMJM`8Li`05GYIRUUjFGYHLi`03000016Jg7>LfgQcW17/c00<LigLeMcD00WLe00=l
07ooOol01Woo011l001e7>LMNAUh7GTINAcW=MPin3GH>OTef3Wh7>M660=65`0>AQQ65dHG7>MB=Thf
DSI>=U8fCSIB=ThfDSHLi`YF=@037>MJ=7`003moo`03001oogoo02Qoo`03001oogoo00Ioo`0017oo
00<007ooOol0=Woo00lLi`00M_4Li`00DSM>=acWEUIJMeIFFWMFEQcWGYH00`0000ENUQcW7>MV]f:f
00<Li`9k<`06Mc8Lig<EMcEc57`02Woo02al002E7>LMNAUh7GTLicWi=MPinCGH>OTef1cWAQM:64HG
BQQ65dXHAQLLidhFDSM>5U8gCQIB=dhFDSM>5QcWESEJ=EHeFSEF=EXeESEJ=EHeFSEF=G`0@Goo00<0
07ooOol09goo00<007ooOol01Woo0004Ool00`00Oomoo`0fOol01Wk^001jlGKa000Li`9>=`047>MF
EUYgEUL300000acWHYINUP02GYH00f:F7>LLi`02I[L37>L01G/c7>Mg=GLeO00037oo00el01cW6GTM
NAUh7>Lef3Wi=MPin3GH>OTLi`02AQL044HHAQM65dHGAQPLie8fCSIB=ThfDSI>=U8fCSIB=QcW2EHe
0W`0@Woo00<007ooOol09goo00<007ooOol01Woo0003Ool00`00Oomoo`0hOol01`00M_5jlP00@OLL
ie8g00@0000;EUIJMeIFFWLLif:GGYIRUejFHYMNUP027>L01fJgH[HLiacWNc<Lig`000ioo`0U7>LM
NAUh7GTLicWi=MPinCGH>OTef1cWAQM:64HGBQQ65dXHAQM:61cWDSM>5U8gCQIB=dhFDSM>5U8g7>MJ
=EHeFSEF=EXeESD00W`0AGoo00<007ooOol09Woo00<007ooOol01Woo0003Ool00`00Oomoo`0hOol0
0gZW001fl@040002CSL27>L01EYgEUMJMeIFFWL00QcW0ejF00=RUUjFI[L00QcW00AR]W`0Nc=l011o
o`9l000:6GTMNAcW>OPef3Wi=MPin1cWAQP3AQL03dHHAQM65dHG7>M>=U8fCSIB=ThfDSI>=U8fCSHL
i`04ESD2O018Ool00`00Oomoo`0UOol00`00Oomoo`06Ool000=oo`03001oogoo03Uoo`<000057>Lm
eacWCSIB=`02CSL041cWFWMFEUYgEUIJMeIF7>MNUV:GGYIRUejFHYMR]QcW0W`04Woo01l007`0O00L
icGH>OTef3Wi=MPLidHGBQQ65dXHAQM:64HGBQPLie8gCQIB=dhFDSM>5U8gCQIB=dhF7>MF=@02O01;
Ool00`00Oomoo`0TOol00`00Oomoo`06Ool000=oo`03001oogoo03Ioo`<00007HP0000007>M1md7G
7>L014hg00PLieYgEUMJMeIFFWMFEacW0ejF00ERUUjFGYINUW`0019oo`0>001oogooOolLig`0=MPi
n3GH>OTef1cWAQM660=65`0;AQQ65acWCSIB=ThfDSI>=U8fCSIB=P04O01>Ool00`00Oomoo`0SOol0
0`00Oomoo`06Ool000=oo`03001oogoo03=oo`<000=oo`0:GN0001cW;GLLid7g?MLLidhfDSL2CSL0
1acWFWMFEUYgEUIJMeIF008Li`06HYMNUV:GGYIRUg`04Woo00<007ooOol00goo17`000dinAcWBQQ6
5dXHAQM:64HGBQQ65acWCQIB=`05O01COol00`00Oomoo`0ROol00`00Oomoo`06Ool000=oo`03001o
ogoo02moo`@000Ioo`03NZPLi`RD008Li`04?MM1md7G7>L4CSL02AcWFWMFEeYgEUIJMeIGFWLLi`02
GYH00f:FO01oo`0BOol00`00Oomoo`07Ool00g`07>Ml0007O0000acWO01l001HOol00`00Oomoo`0S
Ool00`00Oomoo`05Ool0009oo`03001oogoo02eoo`<000]oo`0;7>L4TacW:GHLicgF@OLLidhgCSIB
=`02CSL27>L01UIFFWMFEUYgEUIJM`8Li`03GYIl07oo019oo`03001oogoo06eoo`03001oogoo029o
o`03001oogoo00Eoo`000Woo00<007ooOol0:Woo0`003Woo00UMh1cW7>LYMQcW@OLmed7g7>L01Thg
00XLieIGFWMFEUYgEUMJMeIF7>Ml01=oo`03001oogoo06ioo`03001oogoo025oo`03001oogoo00Eo
o`000Woo00<007ooOol09goo0`004Goo00eR01cW2;@Libeg7>M1mcgF@OLLidhgCSIB=`02CSL02Dhf
7>MFEUYgEUIJMeIFFWMl000DOol00`00Oomoo`1_Ool00`00Oomoo`0POol00`00Oomoo`05Ool0009o
o`03001oogoo02Aoo`<001Aoo`04NZLLi`RD7>L2:GH01AcW@OLmed7g7>L01Thg00LLieIGFWMFEUYg
EUMl000DOol00`00Oomoo`1`Ool00`00Oomoo`0OOol00`00Oomoo`05Ool0009oo`03001oogoo021o
o`@001Qoo`0>7>L8]0BC7>LYMQcW?MM1mcgF@OLLidhgCSIB=`9>=`06CSHLiacWFWMFEW`05Goo00<0
07ooOol0L7oo00<007ooOol07goo00<007ooOol01Goo0002Ool00`00Oomoo`0MOol3000LOol03680
7>L8U1cW;GHYMQcW@MM1mcgG@OLLi`M>=`037>MJMg`001Eoo`03001oogoo075oo`03001oogoo01io
o`03001oogoo00Eoo`000Woo00<007ooOol06Woo0`007goo00aMh1cW19<LibUf;GLLid7g?MM1mcgF
7>L2CSL01dhfDSM>=dhgCSIB=acW01Ioo`03001oogoo079oo`03001oogoo01ioo`03001oogoo00Ao
o`0000=oo`00Ool06Goo0`008Woo00eR01cW29@4TacW:GH]MQcW@OM1ed7g?MLLi`07CSL00g`0Oomo
o`0DOol00`00Oomoo`1cOol00`00Oomoo`0MOol00`00Oomoo`04Ool00003Ool007oo01Ioo`<002Eo
o`0>MZLLi`BC2;@Libeg:GHLicgF@OLmed7g?MHLi`9>=`04CSIB=dhgO00GOol00`00Oomoo`1dOol0
0`00Oomoo`0LOol00`00Oomoo`04Ool00003Ool007oo019oo`@002Uoo`8Li`0329@LibUf008YMP07
7>Lmed7g@MM1mcgG7>L014hg00=l07ooOol05Goo00<007ooOol0M7oo00<007ooOol077oo00<007oo
Ool017oo00000goo001oo`0?Ool3000]Ool03f807>L8]0BC7>LYMReg7>M1mcgF@OLmed7g?MHLi`02
CSL00g`0Oomoo`0FOol00`00Oomoo`1eOol00`00Oomoo`0KOol00`00Oomoo`04Ool00003Ool007oo
00aoo`<0031oo`06GN0Li`BC29@Libef0RUf00LLid7g?MM1md7G@OLLi`02CSL00g`0Oomoo`0FOol0
0`00Oomoo`1fOol00`00Oomoo`0JOol00`00Oomoo`04Ool00003Ool007oo00Uoo`<003=oo`0AHP0L
i`Rd19<LibUf;GLYMReg7>M1mcgF@OLmed7g7>Ml000IOol00`00Oomoo`1gOol00`00Oomoo`0IOol0
0`00Oomoo`04Ool00003001oogoo00Ioo`<003Moo`0@7>L8U0RD19<LibUf;GHYMQcW@MM1mcgG@OM1
ed7gO00IOol00`00Oomoo`1hOol00`00Oomoo`0HOol00`00Oomoo`04Ool00003001oogoo009oo`@0
03Yoo`8Li`0=19<8]1cW;GLYMReg:GHLicgG@OLmeT7gO0006Woo00<007ooOol0NGoo00<007ooOol0
67oo00<007ooOol00goo00000`00Ool00002000nOol27>L229@02QcW:GHYMRUf;GHLid7g@MM1mg`0
6goo00<007ooOol0NGoo00<007ooOol067oo00<007ooOol00goo00020011Ool03UgP7>L4T`Rd19<L
ibUf;GLYMReg7>M1mcgGO00KOol00`00Oomoo`1jOol00`00Oomoo`0GOol00`00Oomoo`03Ool00003
Ool00000045oo`067>L8U0BC29@Libef0bUf00<LicgGO00077oo00<007ooOol0Ngoo00<007ooOol0
5Woo00<007ooOol00goo0003Ool00`00Oomoo`0nOol27>L02@Rd19<8]1cW;GLYMReg:GIl000MOol0
0`00Oomoo`1lOol00`00Oomoo`0EOol00`00Oomoo`03Ool000Aoo`03001oogoo03eoo`8Li`88U006
19<LibUf;GHYMW`07Woo00<007ooOol0OGoo00<007ooOol057oo00<007ooOol00goo0005Ool2000m
Ool27>L01`Rd19<8]1cW;GLYMW`001moo`03001oogoo07eoo`03001oogoo01Aoo`03001oogoo00=o
o`001goo00<007ooOol0>goo00<Li`BC29@00PRD00<Lig`0Ool07goo00<007ooOol0OWoo00<007oo
Ool057oo00<007ooOol00Woo0008Ool2000kOol27>L010BC2;@4Tg`08Goo00<007ooOol0Ogoo00<0
07ooOol04goo00<007ooOol00Woo000:Ool00`00Oomoo`0hOol00g`07>L8U002O00ROol00`00Oomo
o`20Ool00`00Oomoo`0BOol00`00Oomoo`02Ool000]oo`8003Uoo`9l02=oo`03001oogoo089oo`03
001oogoo015oo`03001oogoo009oo`003Goo00<007ooOol0Fgoo00<007ooOol0PWoo00<007ooOol0
4Goo00<007ooOol00Woo000>Ool00`00Oomoo`1JOol00`00Oomoo`23Ool00`00Oomoo`0@Ool00`00
Oomoo`02Ool000moo`8005Yoo`03001oogoo08Aoo`03001oogoo00moo`03001oogoo009oo`004Goo
00<007ooOol0Egoo00<007ooOol0QGoo00<007ooOol03Woo00<007ooOol00Woo000BOol2001GOol0
0`00Oomoo`26Ool00`00Oomoo`0>Ool00`00Oomoo`01Ool001Aoo`03001oogoo05Aoo`03001oogoo
08Moo`03001oogoo00eoo`03001oogoo005oo`005Goo00<007ooOol0Dgoo00<007ooOol0Qgoo00<0
07ooOol03Goo00<007ooOol00Goo000FOol2001COol00`00Oomoo`28Ool00`00Oomoo`0<Ool00`00
Oomoo`01Ool001Qoo`03001oogoo051oo`03001oogoo08Uoo`03001oogoo00]oo`03001oogoo005o
o`006Goo0P00D7oo00<007ooOol0RWoo00<007ooOol02Woo00<007ooOol00Goo000KOol00`00Oomo
o`1=Ool00`00Oomoo`2;Ool00`00Oomoo`09Ool00`00Oomoo`01Ool001aoo`8004eoo`03001oogoo
08]oo`03001oogoo00Yoo`40005oo`5oo`007Woo00<007ooOol0BWoo00<007ooOol0S7oo00<007oo
Ool02Goo0@000Goo0Goo000OOol00`00Oomoo`19Ool00`00Oomoo`2=Ool00`00Oomoo`08Ool10001
Ool1Ool0021oo`8004Uoo`03001oogoo08ioo`03001oogoo00Moo`40005oo`5oo`008Woo00<007oo
Ool0AWoo00<007ooOol0Sgoo00<007ooOol01Woo0@000Goo0Goo000SOol20016Ool00`00Oomoo`2?
Ool00`00Oomoo`06Ool10001Ool1Ool002Eoo`03001oogoo04=oo`03001oogoo091oo`03001oogoo
00Eoo`40005oo`5oo`009Woo0P00@goo00<007ooOol0TGoo00<007ooOol01Goo0@000Goo000XOol0
0`00Oomoo`10Ool00`00Oomoo`2BOol00`00Oomoo`04Ool10001Ool002Uoo`03001oogoo03moo`03
001oogoo09=oo`03001oogoo00=oo`40005oo`00:Woo0P00?goo00<007ooOol0U7oo00<007ooOol0
0Woo0@000Goo000/Ool00`00Oomoo`0lOol00`00Oomoo`2DOol00`00Oomoo`02Ool10001Ool002eo
o`8003aoo`03001oogoo09Eoo`05001oogooOol00001Ool002moo`03001oogoo03Uoo`03001oogoo
09Ioo`04001oogoo0001Ool0031oo`03001oogoo03Qoo`03001oogoo09Moo`03001oo`00005oo`00
<Goo0P00=goo00<007ooOol0VGoo0@000Goo0@00000cOol00`00Oomoo`0dOol00`00Oomoo`2IOol1
0001Ool1000003Aoo`8003Aoo`03001oogoo09Yoo`800000=Woo00<007ooOol0<Goo00<007ooOol0
VGoo0`00000gOol2000aOol00`00Oomoo`2EOol40003Ool003Uoo`03001oogoo02ioo`03001oogoo
091oo`D000Moo`00>Woo00<007ooOol0;Goo00<007ooOol0S7oo100037oo000kOol2000]Ool00`00
Oomoo`28Ool4000@Ool003eoo`03001oogoo02Yoo`03001oogoo08=oo`D001Aoo`00?Woo0P00:Woo
00<007ooOol0Ogoo10006Goo0010Ool00`00Oomoo`0WOol00`00Oomoo`1jOol5000MOol0045oo`03
001oogoo02Ioo`03001oogoo07Ioo`@0029oo`00@Woo0P009Woo00<007ooOol0LWoo10009Woo0014
Ool00`00Oomoo`0SOol00`00Oomoo`1]Ool5000ZOol004Eoo`8002=oo`03001oogoo06Uoo`@002mo
o`00Agoo00<007ooOol087oo00<007ooOol0I7oo1@00<goo0018Ool2000POol00`00Oomoo`1POol4
000hOol004Yoo`03001oogoo01eoo`03001oogoo05]oo`D003aoo`00Bgoo00<007ooOol077oo00<0
07ooOol0Egoo1000@Goo001<Ool2000LOol00`00Oomoo`1COol40015Ool004ioo`03001oogoo01Uo
o`03001oogoo04ioo`D004Uoo`00Cgoo0P006Goo00<007ooOol0BWoo1000CWoo001AOol00`00Oomo
o`0FOol00`00Oomoo`15Ool5001BOol0059oo`8001Ioo`03001oogoo045oo`@005Moo`00E7oo00<0
07ooOol04goo00<007ooOol0?Goo1000Fgoo001EOol00`00Oomoo`0BOol00`00Oomoo`0hOol5001O
Ool005Ioo`80015oo`03001oogoo03Eoo`@006Aoo`00F7oo00<007ooOol03Woo00<007ooOol0<7oo
1@00J7oo001IOol2000>Ool00`00Oomoo`0/Ool4001]Ool005]oo`03001oogoo00]oo`03001oogoo
02Moo`D0075oo`00G7oo00<007ooOol02Woo00<007ooOol08goo1000MWoo001MOol2000:Ool00`00
Oomoo`0OOol4001jOol005moo`03001oogoo00Moo`03001oogoo01Yoo`D007ioo`00H7oo0P001goo
00<007ooOol05Woo1000Pgoo001ROol00`00Oomoo`04Ool00`00Oomoo`0AOol50027Ool006=oo`80
00Aoo`03001oogoo00eoo`@008aoo`00IGoo00D007ooOomoo`0000]oo`@0091oo`00IWoo00@007oo
Ool000Ioo`D009Aoo`00Igoo0`000Woo1000VGoo001YOol3002MOol00001
\>"],
  ImageRangeCache->{{{0, 264.313}, {287, 0}} -> {0.0486402, -0.000148683, 
  0.00324458, 0.00324458}}]
}, Open]]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[%, ViewPoint \[Rule] {2, 1, 1.7}]\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.07132 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.044277 1.15958 -3.33067e-016 1.15958 [
[ 0 0 0 0 ]
[ 1 1.07132 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.42151 .58385 m
.39881 1.07132 L
s
.39881 1.07132 m
1 .9491 L
s
1 .9491 m
.91454 .43136 L
s
.91454 .43136 m
.42151 .58385 L
s
.11048 .24185 m
.69676 0 L
s
.69676 0 m
.74624 .57229 L
s
.74624 .57229 m
0 .7895 L
s
0 .7895 m
.11048 .24185 L
s
.42151 .58385 m
.39881 1.07132 L
s
.39881 1.07132 m
0 .7895 L
s
0 .7895 m
.11048 .24185 L
s
.11048 .24185 m
.42151 .58385 L
s
.91454 .43136 m
.69676 0 L
s
.69676 0 m
.74624 .57229 L
s
.74624 .57229 m
1 .9491 L
s
1 .9491 m
.91454 .43136 L
s
0 0 m
1 0 L
1 1.07132 L
0 1.07132 L
closepath
clip
newpath
.69391 .51989 m .7474 .51712 L .69399 .5377 L .262 .674 .967 r
F
.69391 .51989 m .7391 .5144 L .7474 .51712 L F
.6961 .50221 m .7391 .5144 L .69391 .51989 L .079 .428 .871 r
F
.69399 .5377 m .76122 .52317 L .69619 .55498 L .485 .687 .957 r
F
.69399 .5377 m .7474 .51712 L .76122 .52317 L F
0 g
.006 w
.69391 .51989 m
.69399 .5377 L
s
.25 g
.5 Mabswid
.69399 .5377 m
.69474 .53741 L
s
.69391 .51989 m
.73568 .51481 L
s
.6961 .50221 m .73799 .51274 L .7391 .5144 L .079 .428 .871 r
F
.25 g
.73568 .51481 m
.7391 .5144 L
s
.70068 .48533 m .73799 .51274 L .6961 .50221 L .464 .178 .394 r
F
0 g
.006 w
.69391 .51989 m
.6961 .50221 L
s
.69619 .55498 m .77798 .53456 L .70024 .57149 L .561 .63 .877 r
F
.69619 .55498 m .76122 .52317 L .77798 .53456 L F
.25 g
.5 Mabswid
.73861 .5205 m
.7474 .51712 L
s
0 g
.006 w
.69399 .5377 m
.69619 .55498 L
s
.25 g
.5 Mabswid
.69619 .55498 m
.69812 .55404 L
s
.70024 .57149 m .79442 .55259 L .70543 .58755 L .592 .581 .81 r
F
.70024 .57149 m .77798 .53456 L .79442 .55259 L F
.25 g
.74555 .53084 m
.76122 .52317 L
s
0 g
.006 w
.69619 .55498 m
.70024 .57149 L
s
.25 g
.5 Mabswid
.70024 .57149 m
.70236 .57049 L
s
.70236 .57049 m
.70244 .57044 L
s
.73221 .52297 m
.73861 .5205 L
s
.69474 .53741 m
.73221 .52297 L
s
.70068 .48533 m .74466 .50984 L .73799 .51274 L .464 .178 .394 r
F
.70764 .46955 m .74466 .50984 L .70068 .48533 L .551 .291 .475 r
F
.25 g
.6961 .50221 m
.70012 .50322 L
s
0 g
.006 w
.6961 .50221 m
.70068 .48533 L
s
.70543 .58755 m .80699 .57756 L .71037 .60385 L .609 .545 .758 r
F
.70543 .58755 m .79442 .55259 L .80699 .57756 L F
0 g
.70024 .57149 m
.70543 .58755 L
s
.25 g
.5 Mabswid
.70543 .58755 m
.70797 .58655 L
s
.75333 .54627 m
.77798 .53456 L
s
.70244 .57044 m
.75333 .54627 L
s
.73667 .53518 m
.74555 .53084 L
s
.69812 .55404 m
.73667 .53518 L
s
.70764 .46955 m .75864 .50345 L .74466 .50984 L .551 .291 .475 r
F
.71657 .45457 m .75864 .50345 L .70764 .46955 L .589 .377 .561 r
F
.25 g
.70068 .48533 m
.70248 .48634 L
s
0 g
.006 w
.70068 .48533 m
.70764 .46955 L
s
.71037 .60385 m .81247 .60852 L .71323 .62102 L .622 .519 .716 r
F
.71037 .60385 m .80699 .57756 L .81247 .60852 L F
0 g
.70543 .58755 m
.71037 .60385 L
s
.25 g
.5 Mabswid
.71037 .60385 m
.80699 .57756 L
s
.75739 .56713 m
.79442 .55259 L
s
.70797 .58655 m
.75739 .56713 L
s
.60205 .74709 m .63167 .75597 L .58452 .76181 L .231 0 0 r
F
.60205 .74709 m .64286 .75761 L .63167 .75597 L F
.62113 .73314 m .64286 .75761 L .60205 .74709 L .539 .019 0 r
F
.71323 .62102 m .80863 .64318 L .71216 .6391 L .632 .497 .68 r
F
.71323 .62102 m .81247 .60852 L .80863 .64318 L F
0 g
.006 w
.71037 .60385 m
.71323 .62102 L
s
.25 g
.5 Mabswid
.71323 .62102 m
.81247 .60852 L
s
.58452 .76181 m .62673 .75686 L .56916 .77681 L 0 0 0 r
F
.58452 .76181 m .63167 .75597 L .62673 .75686 L F
0 g
.006 w
.58452 .76181 m
.60205 .74709 L
s
.25 g
.5 Mabswid
.58452 .76181 m
.58704 .76149 L
s
.62113 .73314 m .66073 .7593 L .64286 .75761 L .539 .019 0 r
F
.64104 .71977 m .66073 .7593 L .62113 .73314 L .626 .223 .26 r
F
0 g
.006 w
.60205 .74709 m
.62113 .73314 L
s
.25 g
.5 Mabswid
.60289 .7473 m
.63272 .75499 L
s
.60205 .74709 m
.60289 .7473 L
s
.63148 .75599 m
.63167 .75597 L
s
.71657 .45457 m .77824 .49153 L .75864 .50345 L .589 .377 .561 r
F
.25 g
.75387 .50028 m
.75864 .50345 L
s
.7438 .50936 m
.74466 .50984 L
s
.70012 .50322 m
.73799 .51274 L
s
.72638 .43972 m .77824 .49153 L .71657 .45457 L .611 .441 .627 r
F
.25 g
.70764 .46955 m
.70825 .46995 L
s
0 g
.006 w
.70764 .46955 m
.71657 .45457 L
s
.64104 .71977 m .68482 .75794 L .66073 .7593 L .626 .223 .26 r
F
.25 g
.5 Mabswid
.63272 .75499 m
.64077 .75707 L
s
.66083 .70621 m .68482 .75794 L .64104 .71977 L .647 .324 .411 r
F
.25 g
.64077 .75707 m
.64286 .75761 L
s
.62113 .73314 m
.64921 .75168 L
s
.64921 .75168 m
.66073 .7593 L
s
0 g
.006 w
.62113 .73314 m
.64104 .71977 L
s
.56916 .77681 m .62681 .76207 L .55655 .79126 L .417 .358 .685 r
F
.56916 .77681 m .62673 .75686 L .62681 .76207 L F
0 g
.56916 .77681 m
.58452 .76181 L
s
.25 g
.5 Mabswid
.58704 .76149 m
.63148 .75599 L
s
.71216 .6391 m .79482 .67818 L .70603 .6575 L .639 .476 .646 r
F
.71216 .6391 m .80863 .64318 L .79482 .67818 L F
0 g
.006 w
.71216 .6391 m
.71323 .62102 L
s
.25 g
.5 Mabswid
.71216 .6391 m
.80863 .64318 L
s
.66083 .70621 m .71351 .75035 L .68482 .75794 L .647 .324 .411 r
F
.67924 .69154 m .71351 .75035 L .66083 .70621 L .65 .382 .5 r
F
0 g
.006 w
.64104 .71977 m
.66083 .70621 L
s
.70603 .6575 m .77228 .70969 L .69477 .67524 L .645 .452 .608 r
F
.70603 .6575 m .79482 .67818 L .77228 .70969 L F
0 g
.70603 .6575 m
.71216 .6391 L
s
.67924 .69154 m .74391 .73436 L .71351 .75035 L .65 .382 .5 r
F
.25 g
.5 Mabswid
.67689 .75102 m
.68482 .75794 L
s
.64104 .71977 m
.67689 .75102 L
s
.69477 .67524 m .74391 .73436 L .67924 .69154 L .649 .422 .561 r
F
0 g
.006 w
.66083 .70621 m
.67924 .69154 L
s
.25 g
.5 Mabswid
.66083 .70621 m
.68099 .72311 L
s
.67924 .69154 m
.68076 .69255 L
s
.70603 .6575 m
.71066 .65857 L
s
.69477 .67524 m .77228 .70969 L .74391 .73436 L .649 .422 .561 r
F
.25 g
.69793 .67664 m
.77228 .70969 L
s
.69477 .67524 m
.69793 .67664 L
s
0 g
.006 w
.67924 .69154 m
.69477 .67524 L
s
.25 g
.5 Mabswid
.71066 .65857 m
.79482 .67818 L
s
0 g
.006 w
.69477 .67524 m
.70603 .6575 L
s
.25 g
.5 Mabswid
.68076 .69255 m
.7132 .71403 L
s
.7132 .71403 m
.74391 .73436 L
s
.69831 .73762 m
.71351 .75035 L
s
.68099 .72311 m
.69831 .73762 L
s
.55655 .79126 m .63002 .77278 L .5471 .80452 L .505 .429 .704 r
F
.55655 .79126 m .62681 .76207 L .63002 .77278 L F
.25 g
.62666 .75689 m
.62673 .75686 L
s
.56916 .77681 m
.57832 .77363 L
s
0 g
.006 w
.55655 .79126 m
.56916 .77681 L
s
.72638 .43972 m .80059 .47267 L .77824 .49153 L .611 .441 .627 r
F
.25 g
.5 Mabswid
.77443 .48925 m
.77824 .49153 L
s
.74114 .50788 m
.7438 .50936 L
s
.70248 .48634 m
.74114 .50788 L
s
.73544 .42443 m .80059 .47267 L .72638 .43972 L .625 .492 .68 r
F
0 g
.006 w
.71657 .45457 m
.72638 .43972 L
s
.5471 .80452 m .63391 .78954 L .54078 .81646 L .546 .422 .662 r
F
.5471 .80452 m .63002 .77278 L .63391 .78954 L F
.25 g
.5 Mabswid
.61931 .76519 m
.62681 .76207 L
s
0 g
.006 w
.5471 .80452 m
.55655 .79126 L
s
.25 g
.5 Mabswid
.5471 .80452 m
.54895 .80381 L
s
.62835 .77342 m
.63002 .77278 L
s
.6214 .75871 m
.62666 .75689 L
s
.57832 .77363 m
.6214 .75871 L
s
.73544 .42443 m .82189 .4468 L .80059 .47267 L .625 .492 .68 r
F
.25 g
.77036 .48681 m
.77443 .48925 L
s
.71657 .45457 m
.77036 .48681 L
s
.74965 .49747 m
.75387 .50028 L
s
.70825 .46995 m
.74965 .49747 L
s
.74179 .40861 m .82189 .4468 L .73544 .42443 L .635 .537 .726 r
F
0 g
.006 w
.72638 .43972 m
.73544 .42443 L
s
.25 g
.5 Mabswid
.73544 .42443 m
.73634 .42466 L
s
1 0 0 r
.003 w
.80699 .57756 m
.81247 .60852 L
s
.79442 .55259 m
.80699 .57756 L
s
.80863 .64318 m
.81247 .60852 L
s
.77798 .53456 m
.79442 .55259 L
s
.79482 .67818 m
.80863 .64318 L
s
.76122 .52317 m
.77798 .53456 L
s
.7474 .51712 m
.76122 .52317 L
s
.77228 .70969 m
.79482 .67818 L
s
.54078 .81646 m .63577 .81204 L .53688 .82757 L .574 .405 .615 r
F
.54078 .81646 m .63391 .78954 L .63577 .81204 L F
0 g
.006 w
.54078 .81646 m
.5471 .80452 L
s
.25 g
.5 Mabswid
.54078 .81646 m
.54251 .81596 L
s
.54251 .81596 m
.54365 .81563 L
s
.61433 .77879 m
.62835 .77342 L
s
.54895 .80381 m
.61433 .77879 L
s
.61171 .76834 m
.61931 .76519 L
s
.55655 .79126 m
.61171 .76834 L
s
.74179 .40861 m .83806 .41563 L .82189 .4468 L .635 .537 .726 r
F
.25 g
.73634 .42466 m
.82189 .4468 L
s
.78499 .46574 m
.80059 .47267 L
s
.72638 .43972 m
.78499 .46574 L
s
.74371 .39279 m .83806 .41563 L .74179 .40861 L .643 .579 .768 r
F
0 g
.006 w
.73544 .42443 m
.74179 .40861 L
s
1 0 0 r
.003 w
.7391 .5144 m
.7474 .51712 L
s
.73799 .51274 m
.7391 .5144 L
s
.74391 .73436 m
.77228 .70969 L
s
.73799 .51274 m
.74466 .50984 L
s
.74466 .50984 m
.75864 .50345 L
s
.74371 .39279 m .84558 .38246 L .83806 .41563 L .643 .579 .768 r
F
.25 g
.5 Mabswid
.74179 .40861 m
.83806 .41563 L
s
.74017 .37785 m .84558 .38246 L .74371 .39279 L .648 .62 .808 r
F
0 g
.006 w
.74179 .40861 m
.74371 .39279 L
s
1 0 0 r
.003 w
.75864 .50345 m
.77824 .49153 L
s
.77824 .49153 m
.80059 .47267 L
s
.71351 .75035 m
.74391 .73436 L
s
.80059 .47267 m
.82189 .4468 L
s
.53688 .82757 m .63298 .83896 L .5339 .83858 L .597 .389 .57 r
F
.53688 .82757 m .63577 .81204 L .63298 .83896 L F
0 g
.006 w
.53688 .82757 m
.54078 .81646 L
s
.25 g
.5 Mabswid
.53688 .82757 m
.53941 .82717 L
s
.53941 .82717 m
.63577 .81204 L
s
.60939 .79663 m
.63391 .78954 L
s
.54365 .81563 m
.60939 .79663 L
s
.74017 .37785 m .84237 .3513 L .84558 .38246 L .648 .62 .808 r
F
.25 g
.74371 .39279 m
.84558 .38246 L
s
.73115 .36453 m .84237 .3513 L .74017 .37785 L .65 .663 .849 r
F
0 g
.006 w
.74017 .37785 m
.74371 .39279 L
s
1 0 0 r
.003 w
.82189 .4468 m
.83806 .41563 L
s
.68482 .75794 m
.71351 .75035 L
s
.73115 .36453 m .82819 .32579 L .84237 .3513 L .65 .663 .849 r
F
.71766 .35302 m .82819 .32579 L .73115 .36453 L .647 .711 .894 r
F
0 g
.006 w
.73115 .36453 m
.74017 .37785 L
s
1 0 0 r
.003 w
.83806 .41563 m
.84558 .38246 L
s
.71766 .35302 m .80481 .30831 L .82819 .32579 L .647 .711 .894 r
F
.70137 .34285 m .80481 .30831 L .71766 .35302 L .633 .772 .947 r
F
.25 g
.5 Mabswid
.74017 .37785 m
.84237 .3513 L
s
0 g
.006 w
.71766 .35302 m
.73115 .36453 L
s
.25 g
.5 Mabswid
.72189 .35085 m
.73573 .34375 L
s
.71766 .35302 m
.72189 .35085 L
s
1 0 0 r
.003 w
.66073 .7593 m
.68482 .75794 L
s
.5339 .83858 m .62342 .86799 L .52982 .84993 L .62 .377 .528 r
F
.5339 .83858 m .63298 .83896 L .62342 .86799 L F
0 g
.006 w
.5339 .83858 m
.53688 .82757 L
s
.25 g
.5 Mabswid
.5339 .83858 m
.63298 .83896 L
s
.70137 .34285 m .77556 .29954 L .80481 .30831 L .633 .772 .947 r
F
.68398 .33322 m .77556 .29954 L .70137 .34285 L .583 .845 .994 r
F
0 g
.006 w
.70137 .34285 m
.71766 .35302 L
s
.25 g
.5 Mabswid
.70137 .34285 m
.71557 .33456 L
s
.68398 .33322 m .74457 .29853 L .77556 .29954 L .583 .845 .994 r
F
.66674 .32352 m .74457 .29853 L .68398 .33322 L .393 .845 .913 r
F
.25 g
.73115 .36453 m
.73321 .36371 L
s
.73321 .36371 m
.82819 .32579 L
s
0 g
.006 w
.68398 .33322 m
.70137 .34285 L
s
.25 g
.5 Mabswid
.68398 .33322 m
.69548 .32664 L
s
1 0 0 r
.003 w
.62681 .76207 m
.63002 .77278 L
s
.62673 .75686 m
.62677 .75935 L
s
.62677 .75935 m
.62681 .76207 L
s
.6313 .75604 m
.63167 .75597 L
s
.62673 .75686 m
.6313 .75604 L
s
.66674 .32352 m .71585 .30315 L .74457 .29853 L .393 .845 .913 r
F
.25 g
.5 Mabswid
.72146 .31176 m
.74457 .29853 L
s
.73699 .32206 m
.77556 .29954 L
s
.73573 .34375 m
.80481 .30831 L
s
.65038 .31368 m .71585 .30315 L .66674 .32352 L .042 0 0 r
F
.25 g
.71557 .33456 m
.73699 .32206 L
s
.69548 .32664 m
.70941 .31866 L
s
0 g
.006 w
.66674 .32352 m
.68398 .33322 L
s
.25 g
.5 Mabswid
.66674 .32352 m
.66766 .32313 L
s
1 0 0 r
.003 w
.64286 .75761 m
.66073 .7593 L
s
.63002 .77278 m
.63391 .78954 L
s
.63167 .75597 m
.64286 .75761 L
s
.65117 .31355 m .69261 .31058 L .71585 .30315 L .042 0 0 r
F
.65152 .3136 m .69261 .31058 L .65117 .31355 L F
.65038 .31368 m .65152 .3136 L .65117 .31355 L F
.6354 .30423 m .69261 .31058 L .65038 .31368 L .354 0 .102 r
F
.6354 .30423 m .67686 .31789 L .69261 .31058 L F
.62238 .29586 m .6727 .31621 L .6354 .30423 L .497 .164 .332 r
F
.6727 .31621 m .67686 .31789 L .67119 .31602 L F
.6727 .31621 m .67119 .31602 L .6354 .30423 L F
.25 g
.5 Mabswid
.65038 .31368 m
.65152 .3136 L
s
0 g
.006 w
.65038 .31368 m
.66674 .32352 L
s
.25 g
.5 Mabswid
.66766 .32313 m
.66789 .32304 L
s
.66789 .32304 m
.6682 .32291 L
s
.69393 .31224 m
.70147 .30911 L
s
.70147 .30911 m
.71585 .30315 L
s
.70941 .31866 m
.72146 .31176 L
s
0 g
.006 w
.6354 .30423 m
.65038 .31368 L
s
1 0 0 r
.003 w
.84237 .3513 m
.84558 .38246 L
s
.63391 .78954 m
.63577 .81204 L
s
.52982 .84993 m .60604 .89586 L .5227 .86138 L .643 .368 .487 r
F
.52982 .84993 m .62342 .86799 L .60604 .89586 L F
0 g
.006 w
.52982 .84993 m
.5339 .83858 L
s
1 0 0 r
.003 w
.63298 .83896 m
.63577 .81204 L
s
.62238 .29586 m .66931 .32254 L .67686 .31789 L .497 .164 .332 r
F
.25 g
.5 Mabswid
.6354 .30423 m
.63944 .30556 L
s
.6682 .32291 m
.66922 .32249 L
s
.66974 .32227 m
.69393 .31224 L
s
.65152 .3136 m
.65335 .31346 L
s
.61206 .28904 m .66931 .32254 L .62238 .29586 L 0 .238 .661 r
F
0 g
.006 w
.62238 .29586 m
.6354 .30423 L
s
1 0 0 r
.003 w
.82819 .32579 m
.84237 .3513 L
s
.62342 .86799 m
.63298 .83896 L
s
.5227 .86138 m .5813 .91878 L .51136 .87199 L .667 .359 .441 r
F
.25 g
.5 Mabswid
.52982 .84993 m
.53405 .85075 L
s
.5227 .86138 m .60604 .89586 L .5813 .91878 L .667 .359 .441 r
F
.25 g
.56033 .85582 m
.62342 .86799 L
s
.53405 .85075 m
.56033 .85582 L
s
0 g
.006 w
.5227 .86138 m
.52982 .84993 L
s
.61206 .28904 m .66951 .32255 L .66931 .32254 L 0 .238 .661 r
F
.60501 .28367 m .66951 .32255 L .61206 .28904 L .519 .451 .72 r
F
0 g
.61206 .28904 m
.62238 .29586 L
s
1 0 0 r
.003 w
.80481 .30831 m
.82819 .32579 L
s
.51136 .87199 m .55142 .93326 L .49569 .88064 L .692 .344 .383 r
F
.25 g
.5 Mabswid
.5227 .86138 m
.52721 .86324 L
s
.51136 .87199 m .5813 .91878 L .55142 .93326 L .692 .344 .383 r
F
0 g
.006 w
.51136 .87199 m
.5227 .86138 L
s
1 0 0 r
.003 w
.60604 .89586 m
.62342 .86799 L
s
.60501 .28367 m .67599 .31665 L .66951 .32255 L .519 .451 .72 r
F
.25 g
.5 Mabswid
.66739 .32145 m
.66931 .32254 L
s
.60121 .27915 m .67599 .31665 L .60501 .28367 L .569 .52 .76 r
F
.25 g
.62238 .29586 m
.62867 .29944 L
s
.61206 .28904 m
.61611 .2914 L
s
0 g
.006 w
.60501 .28367 m
.61206 .28904 L
s
1 0 0 r
.003 w
.77556 .29954 m
.80481 .30831 L
s
.49569 .88064 m .51988 .93717 L .47645 .88661 L .716 .318 .293 r
F
.25 g
.5 Mabswid
.51136 .87199 m
.51522 .87457 L
s
.49569 .88064 m .55142 .93326 L .51988 .93717 L .716 .318 .293 r
F
0 g
.006 w
.49569 .88064 m
.51136 .87199 L
s
.25 g
.5 Mabswid
.49569 .88064 m
.50225 .88683 L
s
.52721 .86324 m
.60604 .89586 L
s
1 0 0 r
.003 w
.74457 .29853 m
.77556 .29954 L
s
.47645 .88661 m .49044 .9307 L .45479 .89 L .733 .264 .134 r
F
.47645 .88661 m .51988 .93717 L .49044 .9307 L F
0 g
.006 w
.47645 .88661 m
.49569 .88064 L
s
.25 g
.5 Mabswid
.47645 .88661 m
.47841 .88889 L
s
.50225 .88683 m
.55142 .93326 L
s
.51522 .87457 m
.5813 .91878 L
s
1 0 0 r
.003 w
.5813 .91878 m
.60604 .89586 L
s
.60121 .27915 m .68626 .3043 L .67599 .31665 L .569 .52 .76 r
F
.25 g
.5 Mabswid
.66509 .31159 m
.67599 .31665 L
s
.65635 .31488 m
.66951 .32255 L
s
.6573 .31571 m
.66739 .32145 L
s
.59962 .27479 m .68626 .3043 L .60121 .27915 L .6 .586 .809 r
F
.25 g
.62867 .29944 m
.6573 .31571 L
s
.61611 .2914 m
.65635 .31488 L
s
.60501 .28367 m
.60719 .28468 L
s
0 g
.006 w
.60121 .27915 m
.60501 .28367 L
s
.25 g
.5 Mabswid
.60121 .27915 m
.60505 .28029 L
s
.45479 .89 m .46588 .91656 L .43176 .89161 L .68 .133 0 r
F
.45479 .89 m .49044 .9307 L .46588 .91656 L F
0 g
.006 w
.45479 .89 m
.47645 .88661 L
s
.25 g
.5 Mabswid
.47841 .88889 m
.48773 .89974 L
s
.48773 .89974 m
.51988 .93717 L
s
1 0 0 r
.003 w
.71585 .30315 m
.74457 .29853 L
s
.43176 .89161 m .46588 .91656 L .4473 .89909 L 0 .129 .632 r
F
.43176 .89161 m .4473 .89909 L .40812 .89253 L F
0 g
.006 w
.43176 .89161 m
.45479 .89 L
s
.25 g
.5 Mabswid
.45479 .89 m
.49044 .9307 L
s
.40812 .89253 m .43425 .88276 L .38453 .89353 L .083 .319 .797 r
F
.40812 .89253 m .4473 .89909 L .43425 .88276 L F
.25 g
.44042 .89794 m
.46588 .91656 L
s
1 0 0 r
.003 w
.69261 .31058 m
.71585 .30315 L
s
.38453 .89353 m .42552 .87085 L .36184 .89469 L .318 .385 .774 r
F
.38453 .89353 m .43425 .88276 L .42552 .87085 L F
0 g
.006 w
.38453 .89353 m
.40812 .89253 L
s
.25 g
.5 Mabswid
.38453 .89353 m
.38472 .89349 L
s
.42994 .8837 m
.43425 .88276 L
s
1 0 0 r
.003 w
.67686 .31789 m
.69261 .31058 L
s
.36184 .89469 m .41976 .86505 L .34123 .89542 L .45 .442 .758 r
F
.36184 .89469 m .42552 .87085 L .41976 .86505 L F
0 g
.006 w
.36184 .89469 m
.38453 .89353 L
s
.25 g
.5 Mabswid
.36212 .89459 m
.36377 .89397 L
s
.36184 .89469 m
.36212 .89459 L
s
.42329 .87168 m
.42552 .87085 L
s
1 0 0 r
.003 w
.66998 .32212 m
.67686 .31789 L
s
.59962 .27479 m .69687 .28599 L .68626 .3043 L .6 .586 .809 r
F
.25 g
.5 Mabswid
.68521 .30399 m
.68626 .3043 L
s
.66321 .29748 m
.68521 .30399 L
s
.59837 .27032 m .69687 .28599 L .59962 .27479 L .626 .652 .856 r
F
.25 g
.60719 .28468 m
.66509 .31159 L
s
.60505 .28029 m
.66321 .29748 L
s
0 g
.006 w
.59962 .27479 m
.60121 .27915 L
s
1 0 0 r
.003 w
.66931 .32254 m
.66951 .32255 L
s
.55142 .93326 m
.5813 .91878 L
s
.66951 .32255 m
.67599 .31665 L
s
.34123 .89542 m .41566 .86574 L .32403 .89494 L .546 .879 .99 r
F
.34123 .89542 m .41976 .86505 L .41566 .86574 L F
.25 g
.5 Mabswid
.40812 .89253 m
.4473 .89909 L
s
.38472 .89349 m
.42994 .8837 L
s
.36377 .89397 m
.42329 .87168 L
s
0 g
.006 w
.34123 .89542 m
.36184 .89469 L
s
.25 g
.5 Mabswid
.34123 .89542 m
.34435 .89421 L
s
.34435 .89421 m
.34676 .89328 L
s
.34676 .89328 m
.41796 .86574 L
s
.41796 .86574 m
.41976 .86505 L
s
0 g
.006 w
.32403 .89494 m
.34123 .89542 L
s
1 0 0 r
.003 w
.67599 .31665 m
.68626 .3043 L
s
.25 g
.5 Mabswid
.32403 .89494 m
.32653 .89415 L
s
.32653 .89415 m
.33643 .89099 L
s
.33643 .89099 m
.41566 .86574 L
s
.59837 .27032 m .70381 .26374 L .69687 .28599 L .626 .652 .856 r
F
1 0 0 r
.003 w
.68626 .3043 m
.69687 .28599 L
s
.25 g
.5 Mabswid
.59962 .27479 m
.69687 .28599 L
s
.59523 .26618 m .70381 .26374 L .59837 .27032 L .647 .72 .901 r
F
0 g
.006 w
.59837 .27032 m
.59962 .27479 L
s
1 0 0 r
.003 w
.51988 .93717 m
.55142 .93326 L
s
.59523 .26618 m .70334 .2411 L .70381 .26374 L .647 .72 .901 r
F
.58828 .26336 m .70334 .2411 L .59523 .26618 L .664 .791 .942 r
F
.25 g
.5 Mabswid
.59837 .27032 m
.70381 .26374 L
s
0 g
.006 w
.59523 .26618 m
.59837 .27032 L
s
1 0 0 r
.003 w
.69687 .28599 m
.70381 .26374 L
s
.49044 .9307 m
.51988 .93717 L
s
.58828 .26336 m .69289 .22256 L .70334 .2411 L .664 .791 .942 r
F
1 0 0 r
.70334 .2411 m
.70381 .26374 L
s
.57644 .26288 m .69289 .22256 L .58828 .26336 L .671 .863 .972 r
F
0 g
.006 w
.58828 .26336 m
.59523 .26618 L
s
1 0 0 r
.003 w
.46588 .91656 m
.49044 .9307 L
s
.41566 .86574 m
.41976 .86505 L
s
.41976 .86505 m
.42552 .87085 L
s
.42552 .87085 m
.43425 .88276 L
s
.57644 .26288 m .67183 .21232 L .69289 .22256 L .671 .863 .972 r
F
.25 g
.5 Mabswid
.59523 .26618 m
.66057 .25102 L
s
.55963 .26524 m .67183 .21232 L .57644 .26288 L .655 .925 .974 r
F
.25 g
.66057 .25102 m
.70334 .2411 L
s
0 g
.006 w
.57644 .26288 m
.58828 .26336 L
s
.25 g
.5 Mabswid
.57644 .26288 m
.58106 .26043 L
s
.26305 .87513 m .36216 .84994 L .35748 .85519 L .38 0 .178 r
F
.26305 .87513 m .35032 .85671 L .25281 .86718 L F
.35032 .85671 m .34341 .8568 L .25281 .86718 L F
.35032 .85671 m .35748 .85519 L .34341 .8568 L F
.25281 .86718 m .35748 .85519 L .35121 .86379 L .469 .068 .196 r
F
.25281 .86718 m .3389 .86422 L .2477 .85797 L F
.3389 .86422 m .35121 .86379 L .32917 .86255 L F
.3389 .86422 m .32917 .86255 L .2477 .85797 L F
.24886 .85816 m .35121 .86379 L .34255 .87315 L .514 .057 .105 r
F
.25055 .85813 m .35121 .86379 L .24886 .85816 L F
.2477 .85797 m .25055 .85813 L .24886 .85816 L F
.2477 .85797 m .32603 .8705 L .24686 .84824 L F
.32603 .8705 m .34255 .87315 L .315 .86598 L F
.32603 .8705 m .315 .86598 L .24686 .84824 L F
.24811 .84872 m .34255 .87315 L .33115 .88012 L .55 .027 0 r
F
.24977 .849 m .34255 .87315 L .24811 .84872 L F
.24686 .84824 m .24977 .849 L .24811 .84872 L F
.24686 .84824 m .24926 .84915 L .24849 .83851 L F
.24926 .84915 m .31131 .87262 L .24991 .83922 L F
.31131 .87262 m .29996 .86442 L .24991 .83922 L F
.31131 .87262 m .33115 .88012 L .29996 .86442 L F
.24926 .84915 m .24991 .83922 L .24849 .83851 L F
.24927 .83899 m .33115 .88012 L .31725 .88136 L .573 0 0 r
F
.25027 .8394 m .33115 .88012 L .24927 .83899 L F
.24849 .83851 m .25027 .8394 L .24927 .83899 L F
.24849 .83851 m .31725 .88136 L .2505 .82868 L F
.25061 .82878 m .31725 .88136 L .3019 .87381 L .557 0 0 r
F
.2505 .82868 m .25075 .82888 L .25061 .82878 L F
.25075 .82888 m .31725 .88136 L .25061 .82878 L F
.2505 .82868 m .25061 .82878 L .2511 .81797 L F
.25061 .82878 m .3019 .87381 L .25131 .8182 L F
.25061 .82878 m .25131 .8182 L .2511 .81797 L F
.25 g
.34874 .85335 m
.36216 .84994 L
s
.33705 .85632 m
.34874 .85335 L
s
.32838 .85853 m
.33705 .85632 L
s
0 g
.006 w
.25281 .86718 m
.26305 .87513 L
s
1 0 0 r
.003 w
.4473 .89909 m
.46588 .91656 L
s
.69289 .22256 m
.70334 .2411 L
s
.43425 .88276 m
.4473 .89909 L
s
.55963 .26524 m .64159 .21298 L .67183 .21232 L .655 .925 .974 r
F
.25 g
.5 Mabswid
.58828 .26336 m
.61569 .25267 L
s
.53866 .27008 m .64159 .21298 L .55963 .26524 L .58 .942 .903 r
F
.25 g
.58106 .26043 m
.58767 .25693 L
s
0 g
.006 w
.55963 .26524 m
.57644 .26288 L
s
.25 g
.5 Mabswid
.55963 .26524 m
.5641 .26238 L
s
.34341 .8568 m
.35748 .85519 L
s
.33158 .85816 m
.34341 .8568 L
s
.31843 .85967 m
.33158 .85816 L
s
.30504 .8612 m
.31843 .85967 L
s
0 g
.006 w
.2477 .85797 m
.25281 .86718 L
s
.53866 .27008 m .60532 .2247 L .64159 .21298 L .58 .942 .903 r
F
.25 g
.5 Mabswid
.61569 .25267 m
.69289 .22256 L
s
.51484 .27641 m .60532 .2247 L .53866 .27008 L .386 .82 .665 r
F
0 g
.006 w
.53866 .27008 m
.55963 .26524 L
s
.51484 .27641 m .5672 .24531 L .60532 .2247 L .386 .82 .665 r
F
.25 g
.5 Mabswid
.58767 .25693 m
.67183 .21232 L
s
.4895 .28318 m .5672 .24531 L .51484 .27641 L 0 0 0 r
F
0 g
.006 w
.51484 .27641 m
.53866 .27008 L
s
1 0 0 r
.003 w
.67183 .21232 m
.69289 .22256 L
s
.4895 .28318 m .53139 .27107 L .5672 .24531 L 0 0 0 r
F
.25 g
.5 Mabswid
.55624 .25811 m
.60532 .2247 L
s
.53866 .27008 m
.55624 .25811 L
s
.5641 .26238 m
.64159 .21298 L
s
.46369 .2899 m .53139 .27107 L .4895 .28318 L .165 0 .133 r
F
.25 g
.51484 .27641 m
.51667 .27532 L
s
0 g
.006 w
.4895 .28318 m
.51484 .27641 L
s
.25 g
.5 Mabswid
.32917 .86255 m
.35121 .86379 L
s
.31576 .8618 m
.32917 .86255 L
s
.30155 .861 m
.31576 .8618 L
s
.29433 .8606 m
.30155 .861 L
s
0 g
.006 w
.24686 .84824 m
.2477 .85797 L
s
.46369 .2899 m .50124 .29783 L .53139 .27107 L .165 0 .133 r
F
.43823 .29688 m .50124 .29783 L .46369 .2899 L .32 .083 .39 r
F
.43823 .29688 m .47866 .32202 L .50124 .29783 L F
.414 .30499 m .47866 .32202 L .43823 .29688 L .412 .253 .554 r
F
.25 g
.5 Mabswid
.46463 .29009 m
.50124 .29783 L
s
.46369 .2899 m
.46463 .29009 L
s
0 g
.006 w
.43823 .29688 m
.46369 .2899 L
s
.414 .30499 m .46405 .34111 L .47866 .32202 L .412 .253 .554 r
F
.25 g
.5 Mabswid
.46786 .3153 m
.47866 .32202 L
s
.39214 .31501 m .46405 .34111 L .414 .30499 L .479 .377 .661 r
F
.25 g
.43823 .29688 m
.43946 .29764 L
s
0 g
.006 w
.414 .30499 m
.43823 .29688 L
s
1 0 0 r
.003 w
.35748 .85519 m
.36216 .84994 L
s
.39214 .31501 m .45659 .35385 L .46405 .34111 L .479 .377 .661 r
F
.37392 .32712 m .45659 .35385 L .39214 .31501 L .553 .455 .697 r
F
.25 g
.5 Mabswid
.43946 .29764 m
.46786 .3153 L
s
.414 .30499 m
.41511 .30579 L
s
0 g
.006 w
.39214 .31501 m
.414 .30499 L
s
.25 g
.5 Mabswid
.315 .86598 m
.34255 .87315 L
s
.30039 .86217 m
.315 .86598 L
s
.29027 .85954 m
.30039 .86217 L
s
0 g
.006 w
.24686 .84824 m
.24849 .83851 L
s
1 0 0 r
.003 w
.35121 .86379 m
.35748 .85519 L
s
.37392 .32712 m .45458 .36011 L .45659 .35385 L .553 .455 .697 r
F
.25 g
.5 Mabswid
.46304 .34038 m
.46405 .34111 L
s
.36034 .34074 m .45458 .36011 L .37392 .32712 L .246 0 0 r
F
.25 g
.41511 .30579 m
.45452 .33423 L
s
.45452 .33423 m
.46304 .34038 L
s
0 g
.006 w
.37392 .32712 m
.39214 .31501 L
s
1 0 0 r
.003 w
.64159 .21298 m
.67183 .21232 L
s
.34255 .87315 m
.35121 .86379 L
s
.25 g
.5 Mabswid
.28842 .85861 m
.29996 .86442 L
s
0 g
.006 w
.24849 .83851 m
.2505 .82868 L
s
.35152 .35491 m .45585 .36062 L .36034 .34074 L .434 .757 .995 r
F
.36457 .34161 m .45545 .36053 L .45458 .36011 L .246 0 0 r
F
.45545 .36053 m .45585 .36062 L .45575 .36058 L F
.45545 .36053 m .45575 .36058 L .45458 .36011 L F
.36554 .34183 m .45585 .36062 L .36457 .34161 L F
.455 .36057 m .45777 .35684 L .45585 .36062 L .434 .757 .995 r
F
.35152 .35491 m .45777 .35684 L .455 .36057 L F
.44179 .35856 m .45777 .35684 L .43182 .35637 L .496 .837 .997 r
F
.44179 .35856 m .45737 .35114 L .45777 .35684 L F
.34642 .3688 m .44179 .35856 L .35152 .35491 L F
.44179 .35856 m .43182 .35637 L .35152 .35491 L F
.34642 .3688 m .42553 .35621 L .44179 .35856 L F
.42553 .35621 m .45737 .35114 L .44179 .35856 L F
.36034 .34074 m .36554 .34183 L .36457 .34161 L .246 0 0 r
F
.25 g
.5 Mabswid
.36034 .34074 m
.36554 .34183 L
s
.36554 .34183 m
.43071 .35539 L
s
0 g
.006 w
.36034 .34074 m
.37392 .32712 L
s
.25 g
.5 Mabswid
.37392 .32712 m
.38075 .32991 L
s
.38075 .32991 m
.3869 .33243 L
s
.3869 .33243 m
.43959 .35397 L
s
.39214 .31501 m
.44277 .34553 L
s
0 g
.006 w
.35152 .35491 m
.36034 .34074 L
s
1 0 0 r
.003 w
.60532 .2247 m
.64159 .21298 L
s
.33115 .88012 m
.34255 .87315 L
s
.34309 .38234 m .43581 .35703 L .34642 .3688 L .506 .893 .957 r
F
.43581 .35703 m .44573 .353 L .34642 .3688 L F
.43581 .35703 m .45737 .35114 L .44573 .353 L F
.34309 .38234 m .45172 .34695 L .45737 .35114 L F
.33935 .39628 m .41779 .36185 L .34309 .38234 L .474 .895 .843 r
F
.41779 .36185 m .45172 .34695 L .43223 .3533 L F
.41779 .36185 m .43223 .3533 L .34309 .38234 L F
.34014 .39594 m .43885 .34851 L .45172 .34695 L F
.33935 .39628 m .3397 .39612 L .34014 .39594 L F
.3397 .39612 m .43885 .34851 L .34014 .39594 L F
.33355 .41174 m .3921 .37658 L .33935 .39628 L .4 .822 .648 r
F
.3921 .37658 m .43885 .34851 L .41017 .36228 L F
.3921 .37658 m .41017 .36228 L .33935 .39628 L F
.33799 .40908 m .41855 .3598 L .43885 .34851 L F
.33089 .42504 m .3927 .38297 L .41855 .3598 L 0 0 0 r
F
.32488 .42951 m .32758 .42766 L .33089 .42504 L F
.32758 .42766 m .3927 .38297 L .33089 .42504 L F
.33355 .41174 m .33554 .41053 L .33799 .40908 L .4 .822 .648 r
F
.33554 .41053 m .41855 .3598 L .33799 .40908 L F
.25 g
.5 Mabswid
.34642 .3688 m
.40828 .35895 L
s
.40828 .35895 m
.42118 .3569 L
s
0 g
.006 w
.34642 .3688 m
.35152 .35491 L
s
.25 g
.5 Mabswid
.35152 .35491 m
.35376 .35495 L
s
.35376 .35495 m
.42282 .35621 L
s
.44277 .34553 m
.44624 .34762 L
s
0 g
.006 w
.34309 .38234 m
.34642 .3688 L
s
1 0 0 r
.003 w
.45745 .35237 m
.46405 .34111 L
s
.2511 .81797 m .28705 .85545 L .24934 .80533 L 0 0 .514 r
F
.2511 .81797 m .3019 .87381 L .28705 .85545 L F
0 g
.006 w
.2505 .82868 m
.2511 .81797 L
s
.25 g
.5 Mabswid
.2511 .81797 m
.25131 .8182 L
s
.29169 .86119 m
.31725 .88136 L
s
.29996 .86442 m
.33115 .88012 L
s
1 0 0 r
.003 w
.5672 .24531 m
.60532 .2247 L
s
.45585 .36062 m
.45777 .35684 L
s
.46405 .34111 m
.47866 .32202 L
s
.31725 .88136 m
.33115 .88012 L
s
.25 g
.5 Mabswid
.34309 .38234 m
.40812 .36116 L
s
0 g
.006 w
.33935 .39628 m
.34309 .38234 L
s
1 0 0 r
.003 w
.47866 .32202 m
.50124 .29783 L
s
.45737 .35114 m
.45777 .35684 L
s
.53139 .27107 m
.5672 .24531 L
s
.24934 .80533 m .27529 .82623 L .24515 .7901 L 0 0 .541 r
F
.25 g
.5 Mabswid
.25131 .8182 m
.25355 .82067 L
s
.24934 .80533 m .28705 .85545 L .27529 .82623 L 0 0 .541 r
F
.25 g
.25355 .82067 m
.26159 .8295 L
s
.26159 .8295 m
.3019 .87381 L
s
0 g
.006 w
.24934 .80533 m
.2511 .81797 L
s
1 0 0 r
.003 w
.50124 .29783 m
.53139 .27107 L
s
.18439 .63544 m .2903 .62806 L .18784 .61339 L .586 .695 .917 r
F
.18439 .63544 m .29325 .63045 L .2903 .62806 L F
.18668 .65674 m .29325 .63045 L .18439 .63544 L .46 .117 .296 r
F
.18668 .65674 m .29463 .6339 L .29325 .63045 L F
.19348 .67679 m .29463 .6339 L .18668 .65674 L .303 0 .159 r
F
0 g
.006 w
.18439 .63544 m
.18668 .65674 L
s
.18784 .61339 m .28701 .62394 L .19712 .59151 L .343 .693 .982 r
F
.18784 .61339 m .2903 .62806 L .28701 .62394 L F
0 g
.18439 .63544 m
.18784 .61339 L
s
.19348 .67679 m .2934 .64117 L .29463 .6339 L .303 0 .159 r
F
.25 g
.5 Mabswid
.19505 .63495 m
.29325 .63045 L
s
.18439 .63544 m
.19505 .63495 L
s
.20288 .69584 m .2934 .64117 L .19348 .67679 L .224 0 .19 r
F
.25 g
.18668 .65674 m
.19117 .65579 L
s
0 g
.006 w
.18668 .65674 m
.19348 .67679 L
s
.25 g
.5 Mabswid
.33935 .39628 m
.3397 .39612 L
s
.19712 .59151 m .28475 .61535 L .21122 .57063 L .281 .571 .937 r
F
.19712 .59151 m .28701 .62394 L .28475 .61535 L F
.25 g
.28269 .62697 m
.2903 .62806 L
s
0 g
.006 w
.18784 .61339 m
.19712 .59151 L
s
.25 g
.5 Mabswid
.19712 .59151 m
.1984 .59197 L
s
.20288 .69584 m .28898 .65498 L .2934 .64117 L .224 0 .19 r
F
.25 g
.2841 .64448 m
.2934 .64117 L
s
.29255 .63434 m
.29463 .6339 L
s
.21304 .71462 m .28898 .65498 L .20288 .69584 L .16 0 .253 r
F
.25 g
.19348 .67679 m
.19468 .67637 L
s
0 g
.006 w
.19348 .67679 m
.20288 .69584 L
s
.24515 .7901 m .26896 .78871 L .23902 .77244 L 0 0 .513 r
F
.24515 .7901 m .27529 .82623 L .26896 .78871 L F
0 g
.24515 .7901 m
.24934 .80533 L
s
.25 g
.5 Mabswid
.24515 .7901 m
.27529 .82623 L
s
.24934 .80533 m
.28705 .85545 L
s
1 0 0 r
.003 w
.45172 .34695 m
.45737 .35114 L
s
.21304 .71462 m .2819 .67748 L .28898 .65498 L .16 0 .253 r
F
.25 g
.5 Mabswid
.28363 .65752 m
.28898 .65498 L
s
.19468 .67637 m
.2841 .64448 L
s
.19117 .65579 m
.28611 .6357 L
s
.28611 .6357 m
.29255 .63434 L
s
.22274 .73375 m .2819 .67748 L .21304 .71462 L .092 0 .323 r
F
0 g
.006 w
.20288 .69584 m
.21304 .71462 L
s
.21122 .57063 m .28507 .59983 L .22845 .55095 L .259 .435 .846 r
F
.21122 .57063 m .28475 .61535 L .28507 .59983 L F
.25 g
.5 Mabswid
.27244 .61868 m
.28701 .62394 L
s
0 g
.006 w
.19712 .59151 m
.21122 .57063 L
s
.25 g
.5 Mabswid
.21202 .57112 m
.21341 .57196 L
s
.21122 .57063 m
.21202 .57112 L
s
.18784 .61339 m
.27235 .62549 L
s
.27235 .62549 m
.28269 .62697 L
s
.23902 .77244 m .26897 .74775 L .23145 .75328 L 0 0 .459 r
F
.23902 .77244 m .26896 .78871 L .26897 .74775 L F
0 g
.006 w
.23902 .77244 m
.24515 .7901 L
s
.25 g
.5 Mabswid
.23902 .77244 m
.26896 .78871 L
s
1 0 0 r
.003 w
.3019 .87381 m
.31725 .88136 L
s
.22274 .73375 m .2742 .70912 L .2819 .67748 L .092 0 .323 r
F
.25 g
.5 Mabswid
.20288 .69584 m
.27791 .66024 L
s
.27791 .66024 m
.28363 .65752 L
s
.23145 .75328 m .2742 .70912 L .22274 .73375 L .011 0 .393 r
F
0 g
.006 w
.21304 .71462 m
.22274 .73375 L
s
.25 g
.5 Mabswid
.22274 .73375 m
.22326 .7335 L
s
.23145 .75328 m .26897 .74775 L .2742 .70912 L .011 0 .393 r
F
.25 g
.23145 .75328 m
.26897 .74775 L
s
0 g
.006 w
.22274 .73375 m
.23145 .75328 L
s
.23145 .75328 m
.23902 .77244 L
s
.25 g
.5 Mabswid
.22326 .7335 m
.2742 .70912 L
s
.21304 .71462 m
.26721 .6854 L
s
.26721 .6854 m
.2819 .67748 L
s
.22845 .55095 m .28958 .5757 L .24705 .53194 L .228 .295 .725 r
F
.22845 .55095 m .28507 .59983 L .28958 .5757 L F
.25 g
.26715 .60465 m
.28475 .61535 L
s
0 g
.006 w
.21122 .57063 m
.22845 .55095 L
s
.25 g
.5 Mabswid
.22999 .55228 m
.23005 .55233 L
s
.22845 .55095 m
.22999 .55228 L
s
.1984 .59197 m
.26177 .61483 L
s
.26177 .61483 m
.27244 .61868 L
s
.32488 .42951 m .41855 .3598 L .33355 .41174 L 0 0 0 r
F
.25 g
.33355 .41174 m
.33554 .41053 L
s
0 g
.006 w
.33355 .41174 m
.33935 .39628 L
s
.25 g
.5 Mabswid
.41017 .36228 m
.43885 .34851 L
s
.40812 .36116 m
.42178 .35671 L
s
.24705 .53194 m .29961 .54271 L .2656 .5126 L .176 .15 .588 r
F
.24705 .53194 m .28958 .5757 L .29961 .54271 L F
0 g
.006 w
.22845 .55095 m
.24705 .53194 L
s
.25 g
.5 Mabswid
.24705 .53194 m
.24825 .53317 L
s
.23005 .55233 m
.26708 .5843 L
s
.26708 .5843 m
.28507 .59983 L
s
.21341 .57196 m
.25713 .59855 L
s
.25713 .59855 m
.26715 .60465 L
s
.31331 .44953 m .3927 .38297 L .32488 .42951 L 0 0 0 r
F
.25 g
.32488 .42951 m
.32758 .42766 L
s
0 g
.006 w
.32488 .42951 m
.33355 .41174 L
s
1 0 0 r
.003 w
.43885 .34851 m
.45172 .34695 L
s
.2656 .5126 m .31586 .50251 L .28319 .49222 L .104 0 .434 r
F
.2656 .5126 m .29961 .54271 L .31586 .50251 L F
0 g
.006 w
.24705 .53194 m
.2656 .5126 L
s
.25 g
.5 Mabswid
.2656 .5126 m
.29961 .54271 L
s
.24825 .53317 m
.27173 .55733 L
s
.27173 .55733 m
.28958 .5757 L
s
1 0 0 r
.003 w
.2903 .62806 m
.29325 .63045 L
s
.29325 .63045 m
.29463 .6339 L
s
.28701 .62394 m
.2903 .62806 L
s
.31331 .44953 m .36465 .41725 L .3927 .38297 L 0 0 0 r
F
.25 g
.5 Mabswid
.33554 .41053 m
.37795 .38461 L
s
.37795 .38461 m
.41855 .3598 L
s
.3397 .39612 m
.37747 .37798 L
s
.37747 .37798 m
.41017 .36228 L
s
.29924 .47087 m .36465 .41725 L .31331 .44953 L 0 0 .063 r
F
0 g
.006 w
.31331 .44953 m
.32488 .42951 L
s
.28319 .49222 m .33807 .45891 L .29924 .47087 L .015 0 .26 r
F
.28319 .49222 m .31586 .50251 L .33807 .45891 L F
0 g
.2656 .5126 m
.28319 .49222 L
s
.25 g
.5 Mabswid
.28319 .49222 m
.31586 .50251 L
s
1 0 0 r
.003 w
.2934 .64117 m
.29463 .6339 L
s
.29924 .47087 m .33807 .45891 L .36465 .41725 L 0 0 .063 r
F
.25 g
.5 Mabswid
.29924 .47087 m
.33807 .45891 L
s
0 g
.006 w
.28319 .49222 m
.29924 .47087 L
s
.29924 .47087 m
.31331 .44953 L
s
.25 g
.5 Mabswid
.31331 .44953 m
.3159 .4479 L
s
.3159 .4479 m
.36465 .41725 L
s
.32758 .42766 m
.3927 .38297 L
s
1 0 0 r
.003 w
.28705 .85545 m
.3019 .87381 L
s
.28475 .61535 m
.28701 .62394 L
s
.28898 .65498 m
.2934 .64117 L
s
.41855 .3598 m
.43885 .34851 L
s
.28475 .61535 m
.28507 .59983 L
s
.2819 .67748 m
.28898 .65498 L
s
.27529 .82623 m
.28705 .85545 L
s
.28507 .59983 m
.28958 .5757 L
s
.2742 .70912 m
.2819 .67748 L
s
.3927 .38297 m
.41855 .3598 L
s
.26896 .78871 m
.27529 .82623 L
s
.26897 .74775 m
.2742 .70912 L
s
.28958 .5757 m
.29961 .54271 L
s
.26896 .78871 m
.26897 .74775 L
s
.36465 .41725 m
.3927 .38297 L
s
.29961 .54271 m
.31586 .50251 L
s
.33807 .45891 m
.36465 .41725 L
s
.31586 .50251 m
.33807 .45891 L
s
0 g
.25 Mabswid
.11048 .24185 m
.69676 0 L
s
.69676 0 m
.74624 .57229 L
s
.74624 .57229 m
0 .7895 L
s
0 .7895 m
.11048 .24185 L
s
.91454 .43136 m
.69676 0 L
s
.69676 0 m
.74624 .57229 L
s
.74624 .57229 m
1 .9491 L
s
1 .9491 m
.91454 .43136 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{268.813, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004<000181000`40O003h00Oogoo3Goo002iOol2
001AOol00;Moo`800003Ool00000051oo`00]7oo0`000goo0P00D7oo002bOol20006Ool00`00Ool0
001?Ool00:moo`<000Qoo`03001oo`0004moo`00[Goo0P002goo00@007ooOol004ioo`00Zgoo0P00
3Woo00<007oo0000CWoo002XOol3000@Ool01000Oomoo`00CGoo002VOol2000COol01000Oomoo`00
CGoo002SOol3000EOol01@00Oomoogoo0000C7oo002QOol2000HOol01@00Oomoogoo0000C7oo002N
Ool3000JOol00`00Oomoo`02Ool00`00Oomoo`19Ool009aoo`8001eoo`03001oogoo009oo`03001o
ogoo04Uoo`00VGoo0`007goo00<007ooOol00goo00<007ooOol0B7oo002GOol2000ROol00`00Oomo
o`03Ool00`00Oomoo`18Ool009Aoo`<002Aoo`03001oogoo00Aoo`03001oogoo04Moo`00TWoo0P00
9goo00<007ooOol017oo00<007ooOol0Agoo002@Ool2000YOol00`00Oomoo`05Ool00`00Oomoo`16
Ool008eoo`<002aoo`03001oogoo00Aoo`03001oogoo04Ioo`00Rgoo0P00;goo00<007ooOol01Goo
00<007ooOol0AGoo0028Ool3000aOol00`00Oomoo`05Ool00`00Oomoo`15Ool008Ioo`8003Aoo`03
001oogoo00Ioo`03001oogoo04Aoo`00Pgoo0`00=Woo00<007ooOol01Woo00<007ooOol0A7oo0021
Ool2000iOol00`00Oomoo`07Ool00`00Oomoo`13Ool007ioo`<003]oo`03001oogoo00Moo`03001o
ogoo04=oo`00O7oo0P00?Woo00<007ooOol027oo00<007ooOol0@Woo001iOol30010Ool00`00Oomo
o`08Ool00`00Oomoo`12Ool007Moo`8004=oo`03001oogoo00Uoo`03001oogoo045oo`00MGoo0P00
AGoo00<007ooOol02Goo00<007ooOol0@Goo001bOol30017Ool00`00Oomoo`0:Ool00`00Oomoo`10
Ool0071oo`8004]oo`03001oogoo00Uoo`03001oogoo041oo`00KGoo0`00CGoo00<007ooOol02Woo
00<007ooOol0?goo001[Ool2001@Ool00`00Oomoo`0:Ool00`00Oomoo`0oOol006Qoo`<0059oo`03
001oogoo00]oo`03001oogoo03ioo`00IWoo0P00EGoo00<007ooOol02goo00<007ooOol0?Woo001S
Ool3001GOol00`00Oomoo`0<Ool00`00Oomoo`0mOol0065oo`8005Yoo`03001oogoo00aoo`03001o
ogoo03eoo`00Ggoo0P00G7oo00<007ooOol03Goo00<007ooOol0?7oo001LOol3001NOol00`00Oomo
o`0=Ool00`00Oomoo`0lOol005Yoo`80065oo`03001oogoo00ioo`03001oogoo03]oo`00Egoo0`00
Hgoo00<007ooOol03Woo00<007ooOol0>goo001EOol2001VOol00`00Oomoo`0?Ool00`00Oomoo`0j
Ool0059oo`<006Uoo`03001oogoo00ioo`03001oogoo03Yoo`00D7oo0P00K7oo00<007ooOol03goo
00<007ooOol0>Goo001=Ool3001^Ool00`00Oomoo`0?Ool00`00Oomoo`0iOol004]oo`80075oo`03
001oogoo011oo`03001oogoo03Qoo`00B7oo0`00Lgoo00<007ooOol047oo00<007ooOol0>7oo0016
Ool2001fOol00`00Oomoo`0AOol00`00Oomoo`0gOol004Aoo`8007Qoo`03001oogoo015oo`03001o
ogoo03Moo`00@Goo0`00NWoo00<007ooOol04Woo00<007ooOol0=Woo000oOol2001mOol00`00Oomo
o`0BOol00`00Oomoo`0fOol003aoo`<007moo`03001oogoo01=oo`03001oogoo03Eoo`00>Woo0P00
PWoo00<007ooOol04goo00<007ooOol0=Goo000gOol30025Ool00`00Oomoo`0COol00`00Oomoo`0d
Ool003Eoo`8008Qoo`03001oogoo01=oo`03001oogoo03Aoo`00<Woo0`00RWoo00<007ooOol057oo
00<007ooOol0<goo000`Ool2001nOol4O00;Ool00`00Oomoo`0DOol00`00Oomoo`0cOol002eoo`<0
07Yoo`Il0004DkhLiacWDgh2O009Ool00`00Oomoo`0EOol00`00Oomoo`0bOol002]oo`8007Yoo`=l
00037>M?_U>o009C_P8Li`05DgiGOU=nEgiCOP02O007Ool00`00Oomoo`0EOol00`00Oomoo`0bOol0
02Uoo`8007Uoo`=l0003Bk`Lie>n00=C_P8Li`05EgiCOU=nDgiGOP03Dgh00eMnO01l0005Ool00`00
Oomoo`0FOol00`00Oomoo`0aOol002Ioo`<007Qoo`=l0007Bma7^acW7>MC_TnnDkl00QcW00UCOUMn
DgiGOU=nEgiCOUMnDgh00QcW00=C?E<MO00017oo00<007ooOol05Woo00<007ooOol0<Goo000TOol2
001iOol2O0001AcWAka;_4Nl7>L00e>n0QcW0U=n00IGOU=nDgiCOUMnDgh37>L01E<MDceC7E<mO000
17oo00<007ooOol05goo00<007ooOol0<7oo000QOol3001iOol2O00011cWBma7_4_L0QcW0U>n00U?
_QcWDgiGOU=nEgiCOUMnDgh00acW00UC7ELnDaeC?E<MEciC7E<mO0000goo00<007ooOol05goo00<0
07ooOol0<7oo000OOol2001jOol2O0027>L014^lAka;_1cW0e>n0QcW0e=n00=GOU=nDgh00QcW00aC
7E<mDaeC?E<MDceC7E<mDaeC?E<MO003Ool00`00Oomoo`0HOol00`00Oomoo`0_Ool001eoo`8007Yo
o`9l0005;c@LidNkBma7_0027>L02E>oDkhLiacWEgiCOUMnDgiGOP037>L03eLnDaeC?E<MEciC7E<m
DaeG?U<MDceC7ELn7>Ml0002Ool00`00Oomoo`0HOol00`00Oomoo`0_Ool001eoo`8007Qoo`9l0005
;c@LiacWAka;_0027>L2Dkh27>L015=nEgiCOU=n0acW00aC?E<MDceC7E<mDaeC?E<MDceC7E<mDad4
7>L00e;LO01oo`02Ool00`00Oomoo`0HOol00`00Oomoo`0^Ool001eoo`03001oo`0007Eoo`03001l
02ld008Li`06Bma7^d_L7>MC_Tnn0QcW00AGOU=nEgiCOP8Li`0;EciC7E<mDaeG?U<MDceC7ELnDaeC
?@047>L01TkKD]a>fe;LC]]l00=oo`03001oogoo01Qoo`03001oogoo02ioo`0077oo00D007ooOomo
o`00079oo`08001l07`0;c@LidNlBka7_08Li`03DkhLiacW00=COP<Li`08DaeC?E<MDceC7E<mDaeC
?@DLi`03D]a>g5;L009Bg005C]aBg5;LD]al0003Ool00`00Oomoo`0IOol00`00Oomoo`0]Ool001ao
o`03001oogoo009oo`03001oogoo06eoo`800008O00cEAcW7>M7_4_LAk/Li`9C_P047>MGOU=nEgh2
7>L01e<MDceC7ELnDaeC?E<M00@Li`0?D]a>fe;LC]]Bg4kKD]a>fe;LC]]Bg4kKD]a>fg`000=oo`03
001oogoo01Uoo`03001oogoo02eoo`0077oo00<007ooOol00goo00<007ooOol0JWoo0`0000Il02ld
7>M;_4NlBk`27>L01E>n7>LLieMnDgh00QcW00EC?E<MDceC7E<m00@Li`05C]aBg5;LD]a>g003D]`0
1DkLD]aBg5;LC]`00e;L00=>g5;LO0000goo00<007ooOol06Woo00<007ooOol0;7oo000LOol00`00
Oomoo`03Ool00`00Oomoo`1XOol30002O0001S=E7>M;g4NlBm`Li`D0008Li`03DaeG?U<M00@Li`0@
D]a>fe;LC]]Bg4kKD]a>fe;LC]]Bg4kKD]a>fe;LC]/67>L01G`0Oomoogoo000077oo00<007ooOol0
;7oo000LOol00`00Oomoo`04Ool00`00Oomoo`1UOol4000017`0;c@LiacW0`0000<Li`00Ool01Goo
00@001cW7>LLi`9Bg004C]aBg5;LD]`>7>L00djJCY]>VP02CYX00djKO01oo`02Ool00`00Oomoo`0K
Ool00`00Oomoo`0[Ool001]oo`03001oogoo00Ioo`03001oogoo069oo`D00003O00001cW008000eo
o`03000LiacW00DLi`0DCY]>VTjKCYY>VdjJCY]>VTjKCYY>VdjJCY]>VTjKCYY>VdjJCY]l00Aoo`03
001oogoo01]oo`03001oogoo02]oo`006goo00<007ooOol01goo00<007ooOol0Ggoo0`0000DLi`00
40=l0000015oo`03000LiacW008Li`05CY]>VTjJCYY>V`03CYX01DjKCYY>VTjJCY/00djJ00M>VdjJ
CYY>VTjKCYYl0004Ool00`00Oomoo`0LOol00`00Oomoo`0ZOol001]oo`03001oogoo00Qoo`03001o
ogoo05aoo`<0000550@@0a@440=l000DOol01000BUU:F4iI21cW00m>VTjKCYY>VdjJCY]>VTjKCYY>
VdjJCY]>VTjKO00017oo00<007ooOol077oo00<007ooOol0:Woo000KOol00`00Oomoo`09Ool00`00
Oomoo`1IOol00`0040<@0`0540<00g`0Oomoo`0DOol27>L9BUT97>L01DjJCY]>VTjJO0001Goo00<0
07ooOol07Goo00<007ooOol0:Goo000KOol00`00Oomoo`0:Ool00`00Oomoo`1FOol0210350@@0a@4
40<D110350@2O00GOol67>L00dYIBUQ>F@02BUT01TYHCUU:FDYIBUQ>F@9:F@03BUPLiacW008Li`03
O01oogoo00=oo`03001oogoo01eoo`03001oogoo02Uoo`006Woo00<007ooOol037oo00<007ooOol0
Cgoo0P000QcW2A0300=l07ooOol067oo00<001cW7>L00THG11cW3DYI00=l07ooOol01Goo00<007oo
Ool07Goo00<007ooOol0:7oo000JOol00`00Oomoo`0=Ool00`00Oomoo`1:Ool4000012A;:4`TBbA<
1AcW00@D110350Al01aoo`@Li`04BQQ65dHHAQL47>L01DiIBUU:FDYHCUT00TYI00=:F4iIO0001goo
00<007ooOol07Goo00<007ooOol0:7oo000JOol00`00Oomoo`0>Ool00`00Oomoo`16Ool010007>L0
02A<0bA;00DTC2A;94/TBbA<00<TB`0494`LiacWO00OOol47>L6AQL37>L5BUT00g`0Oomoo`06Ool0
0`00Oomoo`02Ool5O00GOol00`00Oomoo`0WOol001Yoo`03001oogoo00ioo`03001oogoo049oo`@0
000B<?4`l1cW7>LTC2A;:4`TBbA<94/XC2A;94`TBbQ<94/TC7`08Goo1QcW00I65dXHAQM664HGBQP3
7>L00diIBUUl0008Ool00`00O01l0002O0001AcWAei;GdMNBel01W`04Goo00<007ooOol09goo000J
Ool00`00Oomoo`0?Ool00`00Oomoo`0oOol01@007>L`lC3a<?000c3a00@`l33a7>LTC0<TB`0594`T
BbA;94/TC00294/00g`0Oomoo`0ROol27>L0147F?MHLiacW1dHG00<Lig`0Ool01Goo0g`000H002mL
<e`Lid]OAel3Bel00dMOBem;G`027>L2Cad4O00>Ool00`00Oomoo`0VOol001Uoo`03001oogoo015o
o`03001oogoo03aoo`80000;?G@`l1cW<?0`lC3`=?4`l33a<?0dl@027>L02BA;:4`TBbA<94/XC2A;
94al000WOol27>L02Sff@MHLiacWAQM664HGBQQ65g`017oo0g`000@cG2mL<ed0008Li`07Bem7GT]O
Aei;GdMNBel00QcW00Q?7E<NCaeC7TlMDai?7E<N0g`02goo00<007ooOol09Woo000IOol00`00Oomo
o`0BOol00`00Oomoo`0iOol20005>G@27>L00c3a<?0`l@02<?400c3`<?4`l@027>L294/01BA<94/T
BbA;O000:7oo00D001cW7>M1eSgF00<Li`965`03O00X0RP2009l0007<e`_G3=L;e`cG2mL00000T]O
00M7Gd]OBem;GdMOBelLi`0:Cad27>L00e;LO01oo`0:Ool00`00Oomoo`0UOol001Uoo`03001oogoo
01=oo`03001oogoo03Moo`0J7>LmMCUd?G@iM3ee>G@mM3Ud=?4Lic3a<?0dlC3`<?4`l3Ca<?0`lAcW
:4`TBbA<94]l02]oo`<Li`06?KI1eSff7>Ml02`30W`000H_G3=M;e`cG2mL<ed27>L01`00Bem7GT]O
Aei;GdMN008Li`09Dai?7E<NCaeC7TlMDai?7E<N008Li`05C]]Bg4kKD]al000:Ool00`00Oomoo`0U
Ool001Uoo`03001oogoo01Aoo`03001oogoo03Aoo`800003AMDLiacW00LiM004<?4Lic3a<?03<?40
133`<?4`lC3a0QcW00<TBg`0Ool0;7oo00D001cW7>LmeT7F00=l0006<e`_G3=L;e`cG2mL0QcW0T]O
00<004MOBel00T]O0QcW2DlM0QcW00MBg5;KD]a>fe;LD]]Bg002O009Ool00`00Oomoo`0TOol001Uo
o`03001oogoo01Eoo`03001oogoo035oo`800005@ME5eT7EAMI1e@027>L04ced>G@mMCUd?G@iM3ee
7>L`lC3`=?4`l33a<?0dlC3`<?4`l7`0031oo`0:000Lig`0O00_G3=L;e`cGBmL<e`27>L04TMNBem7
GT]O001;GdMNDahLie<NCaeC7TlMDai?7E<NCaeC7P8Li`0<C]]Bg4kKD]a>fe;LC]]Bg4kKD]a>fg`0
27oo00<007ooOol097oo000HOol00`00Oomoo`0GOol00`00Oomoo`0_Ool01AcWAME5eDGE@MD00dGE
00=1eDGE7>L01cUd0QcW00D`l33a<?4`lC3`008`l@03O01oogoo035oo`800008<e`_G3=L;e`cG1cW
Bem7G`=;G`03Ael004]O008Li`U?7@0@7>MBg4kKD]aBfe;LC]]Bg5;KD]a>fe;LD]]Bg1cWO008Ool0
0`00Oomoo`0SOol001Qoo`03001oogoo01Qoo`03001oogoo02eoo`0<000L01cWAMI1eDGF@ME5eT7E
AMI1eDGF0QcW00hiM3ee>G@mM3Ud?GDiM1cW<?0dlC3`<?4`l7`0=Woo0P0001D_G1cW7>M;GdMNBem7
GT]OAei;G`007>M?7E<NCaeC7TlMDai?7E<NCad00QcW00aBg4kKD]a>fe;LC]]Bg4kKD]a>fe;LC]/2
7>L00e:jCYYl0007Ool00`00Oomoo`0SOol001Qoo`03001oogoo01Uoo`03001oogoo02]oo`04000L
01`070037>L00dGE@ME5e@02AMD0147EAME5eAcW1cUd00<Lic3`<?400S3a00=l07ooOol0=Woo00@0
04]OBem7G`=;G`05AelLiacWCad00007Cad27>L02e;KD]a>fe;LD]]Bg4kKD]aBfe;LC]/00acW15:J
00=l07ooOol01Woo00<007ooOol08Woo000HOol00`00Oomoo`0IOol00`00Oomoo`0ZOol02000700H
01`0600L01P070037>L01TGF@ME5eT7EAMI1e@8Li`06?GDiM3ed>G@mMCUd0QcW00<dlG`0Ool0>Goo
0P0000=;GdMNBel00QcW00U?7E<NCad004lMDai?7E<NCad00QcW00]Bg4kKD]a>fe;LC]]Bg4kKD]a>
fe;L008Li`09CYYB^djJD[Y>VU:kCYYB^W`000Moo`03001oogoo029oo`0067oo00<007ooOol06Woo
00<007ooOol0:7oo00@001cW7>LLi`PL008Li`95e@04@ME5eDGEAMD27>L6>G@00g`0Oomoo`0kOol2
00000acWCae?7@03Cad01000Cae?7DlM0QcW00Y>fe;LD]]Bg4kKD]aBfe;LC]]Bg0<Li`YBVP03O01o
ogoo00Ioo`03001oogoo025oo`005goo00<007ooOol077oo00<007ooOol09Woo00D003LO<_hg7aP0
00@Li`06700H01`0600L01P00acW00I1eDGF@ME5eT7E7>L2O0000cUd?GEl0010Ool200004U<NCaeC
7TlM001?7E;L7>MBg4kKD]a>fe;LC]]Bg4kKD]a>f`8Li`0?D[]>VU:jCYYB^djJD[Y>VU:kCYYB^TjJ
D[]>VW`000Moo`03001oogoo025oo`005goo00<007ooOol07Goo00<007ooOol09Goo00<003Ko=_l0
1SKo1AcW11`00acW00Q5eG`0O00LicnMO00iM7`0@Woo0P000TlM00/001cW7>MBg4kKD]aBfe;LC]]B
g5;K00<Lia1BVP03O01oogoo00Ioo`03001oogoo021oo`005goo00<007ooOol07Woo00<007ooOol0
8goo00l003;n=alfoSLO<_hg7cKn=alboSLO=_hg7c;n=al011cW00XH01`0O01l03nM?ihoWD>N?iel
04Eoo`0;000Li`00C]]Bg4kKD]a>fe;LC]]Bg0027>L05DjJD[Y>VU:kCYYB^TjJD[]>VU:jCYYB^djJ
D[Y>VU:kCYYB^TjJ7>Ml0007Ool00`00Oomoo`0POol001Moo`03001oogoo01moo`03001oogoo029o
oa<Li`9l0005?ihoWCnN?idoWP02?el00g`0Oomoo`14Ool200001E;LC]]Bg5;KD]`00acW4E:J11cW
00=>NG`0Ool01goo00<007ooOol07goo000GOol00`00Oomoo`0POol00`00Oomoo`0POol03000?elk
GcmO>eloGc]O?elkGcmO>eloG`LLi`06O00oWD>N?idoGc]O0goo00<boW`0Ool0AWoo00@004kKD]a>
f`8Li`0@D[Y>VU:kCYYB^TjJD[]>VU:jCYYB^djJD[Y>VU:kCYX47>L01U9iCWQBNDihDWUl00Qoo`03
001oogoo01moo`005Woo00<007ooOol08Woo00<007ooOol07goo00@003mO?eloG`/Li`04>iXLiacW
O01BOol010007>LLiacW3U:J11cW0U9i00E>NE9iDWUBNDii009BN@03O01oogoo00Moo`03001oogoo
01ioo`005Woo00<007ooOol08goo00<007ooOol07Goo00<001cW7>L00QcW00DoWCnN?ie3WSnM00<L
i`8kVP<Li`03O01oogoo055oo`0>001oo`00CYYB^TjJD[]>VU:jCYYB^djJD[Y>VP@Li`0?DWU>N59i
CWQBNDihDWU>N59iCWQBNDihDWU>N7`000Qoo`03001oogoo01ioo`005Woo00<007ooOol097oo00<0
07ooOol077oo00L003nN?idoWSnM?ihoW@037>L3>iX37>L2O01DOol01000Oomoo`001U:J11cW00E>
NE9iDWUBNDii00=BN@05CWUBNE9iDWU>N@03DWT00diiDWUl0009Ool00`00Oomoo`0MOol001Ioo`03
001oogoo02Aoo`03001oogoo01]oo`05000oWSnM@ihoW@037>L2>iX00c^I?iXLi`037>L00g`0Oomo
o`1DOol01P00Oomoo`00D[]>VP@Li`0GDWU>N59iCWQBNDihDWU>N59iCWQBNDihDWU>N59iCWQBNDih
DWU>N59iCWQl0009Ool00`00Oomoo`0MOol001Ioo`03001oogoo02Eoo`03001oogoo01Yoo`03000o
WAcW008Li`@kVP<Li`04<e@Li`00O01HOol00`00Oomoo`027>L2DWT01DiiDWUBNE9iCWT00e9i00E>
NE9iDWUBNDii00=BN@05CWUBNE9iDWU>N@03DWT00g`0Oomoo`08Ool00`00Oomoo`0LOol001Ioo`03
001oogoo02Ioo`03001oogoo01Uoo`07000Lic^J>iXkVCnJ>iX00QcW00HcE2lc7>LLi`00O01IOol0
6`00Oomoo`00CWQBNDihDWU>N59iCWQBNDihDWU>N59iCWQBNDihDWU>N59iCWQBNDihDWU>N0047>L0
0g`0Oomoo`08Ool00`00Oomoo`0LOol001Eoo`03001oogoo02Qoo`03001oogoo01Qoo`03000kVS^J
008kVP8Li`07<c@cE7oo7>L001cWO000FWoo00H007ooOomoo`00CWT3DWT01DiiDWUBNE9iCWT00e9i
00=>NAcW7>L01acW00E>Ee9HCUMBF7`000]oo`03001oogoo01]oo`005Goo00<007ooOol0:Goo00<0
07ooOol05Woo00@003^J>iXkV@8Li`03<e@_<c=D008Li`03000Lig`005]oo`09001oogooOol0059i
CWQBNDih00TLi`0>CUMBF4iGDUQ>Ee9HCUMBF4iGDUQ>Ee9HCUMl00]oo`03001oogoo01]oo`005Goo
00<007ooOol0:Woo00<007ooOol05Goo00L003^J7>LLic<c<e@c=0027>L010007>LLig`0G7oo00D0
07ooOomoo`0000@Li`0FCUMBF4iGDUQ>Ee9HCUMBF4iGDUQ>Ee9HCUMBF4iGDUQ>Ee9HCUMBF4iGO00=
Ool00`00Oomoo`0JOol001Eoo`03001oogoo02]oo`03001oogoo01Aoo`8Li`03<e@_<c=D008Li`80
00037>L007`005eoo`0O001oogooOol0059HCUMBF4iGDUQ>Ee9HCUMBF4iGDUQ>Ee9HCUMBF4iGDUQ>
Ee9HCUMBF4iGDUQ>Ee9HO0003Goo00<007ooOol06Woo000EOol00`00Oomoo`0/Ool00`00Oomoo`0C
Ool00`00<e@c<`027>L200027>L200000g`0Oomoo`1KOol07`00Oomoo`00DUQ>Ee9HCUMBF4iGDUQ>
Ee9HCUMBF4iGDUQ>Ee9HCUMBF4iGDUQ>Ee9HCUMBF4iGDUQ>Eg`000ioo`03001oogoo01Uoo`0057oo
00<007ooOol0;Woo00<007ooOol04Goo00@003=D7>LLi`<000057>L00000001l001NOol07`00Oomo
o`00CUMBF4iGDUQ>Ee9HCUMBF4iGDUQ>Ee9HCUMBF4iGDUQ>Ee9HCUMBF4iGDUQ>Ee9HCUMBF7`000io
o`03001oogoo01Uoo`0057oo00<007ooOol0;goo00<007ooOol047oo0QcW0`000QcW0`0000=l07oo
Ool0GGoo00@007ooOol000HLi`0DDUQ>Ee9HCUMBF4iGDUQ>Ee9HCUMBF4iGDUQ>Ee9HCUMBF4iGDUQl
011oo`03001oogoo01Qoo`0057oo00<007ooOol0<7oo00<007ooOol03goo100000<Li`0000000P00
00=l07ooOol0GWoo00X007oo001B=ThFDSM>5U8fCQIB=`dLi`07DUQ>Ee9HCUMBF4iGO00047oo00<0
07ooOol067oo000DOol00`00Oomoo`0`Ool00`00Oomoo`0?Ool200027>L400000g`0Oomoo`1OOol0
0`00Ool0000DCQH67>L00g`0Oomoo`0?Ool00`00Oomoo`0GOol001Aoo`03001oogoo035oo`03001o
ogoo00eoo`8000037>L00000008000037>Ml07oo069oo`0L001>5U8gCQIB=ThFDSM>5U8fCQIB=dhF
DSI>5U8gCQIB=ThFDSM>5U8fCQIB=dhFDSI>5U8gO00BOol00`00Oomoo`0GOol001=oo`03001oogoo
03=oo`03001oogoo00aoo`8Li`<0008Li`03005l07oo069oo`03000LiacW01Q>5P03O01oogoo015o
o`03001oogoo01Ioo`004goo00<007ooOol0=7oo00<007ooOol02Woo00<Ligoo00000P0000@Li`01
005l06=oo`800003COA=mAcW00<Li`0DCQIB=dhFDSI>5U8gCQIB=ThFDSM>5U8fCQIB=dhFDSI>5U8g
CQIl01Aoo`03001oogoo01Ioo`004goo00<007ooOol0=Goo00<007ooOol02Goo0`000QcW0P0100=l
07ooOol0HWoo0P001Tge11cW3dhF00=l07ooOol04Woo0P005goo000COol00`00Oomoo`0fOol00`00
Oomoo`07Ool300000acW00400@0200400g`0Oomoo`1QOol03@00CO@004WdCOE=m4geBOA=mDgdCOE9
m4ge00@Li`0;CQIB=ThFDSM>5U8fCQIB=dhFDSIl000BOol300000goo001oo`0FOol001=oo`03001o
ogoo03Moo`03001oogoo00Eoo`80008Li`@00@03O01oogoo069oo`8Li`03001=mDge00a=m@@Li`I>
5P03O01oogoo00aoo`@000Aoo`03001oogoo01Eoo`004Woo00<007ooOol0>Goo00<007ooOol017oo
0QcW1P0100=l07ooOol0HGoo01H004fcBK<001cWCOE9m4geCOA=mDWdCOE=m4geBOA=mDgdCOE9m4ge
COA=m@@Li`03CQIl07oo00]oo`<000Qoo`03001oogoo01Eoo`004Woo00<007ooOol0>Woo00<007oo
Ool00Woo00<Li`0100401@0100=l07ooOol0HGoo00H004fcBK==/`00CK<27>LCCOD00acWO01oo`08
Ool3000<Ool00`00Oomoo`0DOol0019oo`03001oogoo03]oo`04001oogoo7>L700400g`0Oomoo`1R
Ool02000BK==/dVc0019/dfcBK<27>L04TgeCOA=mDWdCOE=m4geBOA=mDgdCOE9m4geCOA=mDWdCOEl
00Moo`<000moo`03001oogoo01Aoo`004Woo00<007ooOol0>goo00<007oo0000200100=l07ooOol0
HGoo00/LidVcCK=9/dfc001=/dVcCK=9/dfc00<Li`e=m@03O01oogoo00=oo`<0019oo`03001oogoo
01Aoo`004Woo00<007ooOol0?7oo0P001P0100<Lig`0Ool0HWoo00l004E`7>LLidfcBK<004VcCK=9
/dfcBK==/dVcCK<00QcW00]9m4geCOA=mDWdCOE=m4geBOA=mG`0009oo`@001Eoo`03001oogoo01Ao
o`004Goo00<007ooOol0?Goo00<0000100400`010QcW00=l07ooOol0HWoo00@004UaBG59L@8Li`0;
001=/dVcCK=9/dfcBK==/dVcCK=9/`027>L8COD00g`00000000IOol00`00Oomoo`0DOol0015oo`03
001oogoo03eoo`0300000@0100<Li`0300L427`006=oo`0D0019LDEaBG55L4UaAG4Li`00CK=9/dfc
BK==/dVcCK=9/dfcBK==/`8Li`06COA=mDWdCOE=m7`077oo00<007ooOol057oo000AOol00`00Oomo
o`0lOol01P00004LiacW00L41`801`03O01oogoo069oo`037>M9LDUa00E9L@0>000LidfcBK==/dVc
CK=9/dfcBK==/dVcCK=9/`8Li`9=m@03O01oogoo01aoo`03001oogoo01=oo`004Goo00<007ooOol0
?7oo00T001cW10P01`@800L42007O000I7oo00X001cW7>M9LDEaBG55L4Ua0019L@8Li`0>BK==/dVc
CK=9/dfcBK==/dVcCK=9/dfc7>Ml01moo`03001oogoo01=oo`004Goo00<007ooOol0>goo00D00007
00L01`@700<01`03O01oogoo069oo`050015;TD>ABhLi`04BG404@00BG59LDUa7>M9/dfcBK==/dVc
CK=9/dfcBK==/dVcO00087oo00<007ooOol04goo000@Ool00`00Oomoo`0kOol02P0000L4200710P0
1`@800L427`0I7oo00h0044>ABm13TD^7>M9LDEaBG4004UaAG59LDE`0QcW00U=/dVcCK=9/dfcBK==
/dVcO0008Goo00<007ooOol04goo000@Ool00`00Oomoo`0jOol01@0000L01`0710L00`0700@41g`0
Ool0069oo`0700153TD^@@i5;TD>ABh00QcW00=9L@00BG401DUa0QcW00A9/dfcBK==/`9l029oo`03
001oogoo01=oo`0047oo00<007ooOol0>Goo00/0000710P01`@800L4200710P01g`0009oo`03001o
ogoo05moo`0G000Lid4>ABi13TD_@@i5;T4>7>L004UaAG19LDEaBG55L4UaAG4LidVcCK=l000TOol0
0`00Oomoo`0COol0011oo`03001oogoo03Qoo`05000Li`0700L41`0300L00`@700Ml0003Ool00`00
Oomoo`1OOol02`00>:/LiacWABi13TD^A@i5;T4>00002DUa00<Lig`0Ool09Goo00<007ooOol04Woo
000@Ool00`00Oomoo`0gOol00`0020d<3@037>L01P@800L4200710Ql00Aoo`03001oogoo05eoo`05
000dZcR/=:/h[0027>L01D4>ABm13TD^00000QcW00I9LDE`BG55LDUaAG02O00WOol00`00Oomoo`0B
Ool000moo`03001oogoo03Qoo`0300083@P=00<83@<Li`0300Ml07oo00Eoo`03001oogoo05]oo`80
000>>:`hZcR/>:/h[3R[7>M13TD^A@h0044>ABhLi`=9L@9l02Uoo`03001oogoo019oo`003goo00<0
07ooOol0=goo00`000`=20`<3@P=30d830`=20d<3AcWO007Ool00`00Oomoo`1GOol300002Goo000L
iacW=:/h[3B[>:`dZ`027>L01DD_0015;T4>ABl00QcW00=l07ooOol0:Goo00<007ooOol04Woo000?
Ool00`00Oomoo`0fOol00`0020d83@0920d00g`0Oomoo`06Ool00`00Oomoo`1COol30004Ool00`00
2K/hZ`037>L02CR[>:`hZcR/7>L004D>ABi13P02O00/Ool00`00Oomoo`0BOol000moo`03001oogoo
03Ioo`0<000830`=20d<3@P<30d83@`=20`<3G`02Woo00<007ooOol0CWoo10001goo00H000Fj2K/5
^PVk1KX47>L00cR/=:/00002O00^Ool00`00Oomoo`0BOol000moo`03001oogoo03Eoo`0300083@P=
00T83@03O01oogoo00Uoo`03001oogoo04Yoo`<000Yoo`0:0005^`Vk1K/9^`Fk2K/5^`Vk1K/27>L0
0g`0001oo`0`Ool00`00Oomoo`0AOol000ioo`03001oogoo03Eoo`0>000@TAcW20d<3@P<30d83@`=
20`<3@P=30el00aoo`03001oogoo04Ioo`<000eoo`040009^`Fj2K/67>L011jm8[hN_P000W`0;goo
00<007ooOol04Goo000>Ool00`00Oomoo`0dOol01@00598DTQ2B7>L020P=00=l07ooOol037oo00<0
07ooOol0@Woo0`0047oo00@001cW7>LLi`8N_P0:8[hN_Qjn7[hR_Qjn7>L003jn>[d2O00]Ool00`00
Oomoo`0AOol000ioo`03001oogoo03=oo`0?000@TABB494DTQ2A7>L83@`=20`<3@P=30d837`000mo
o`03001oogoo03eoo`@001=oo`0:000R_Qjn8[hN_B:n7[hR_Qjm8[h27>L01cZm000j_Cjn>[dn_W`0
02aoo`03001oogoo015oo`003Woo00<007ooOol0<Woo00@001BB598@TP<DTP03498LiacW00@83@03
O01oogoo00ioo`03001oogoo03Yoo`<001Moo`05000N_Qjn7[hR_P027[h37>L01Sjn>[dn_P00?[hj
_@8Li`03AW]l07`002Yoo`03001oogoo015oo`003Woo00<007ooOol0<Goo010Lia2A598@TABB494D
TQ2A598@TABB7>L<3@P<30el015oo`03001oogoo03Ioo`<001Yoo`03000R_Qjm00@Li`07?[hj_Cjn
>[dn_SZm00000QcW00E6NdJK@W]6VdIk009l02Qoo`03001oogoo015oo`003Goo00<007ooOol0<Goo
00@001Tf7>L@TP<DTP07498DTQBB598@TQBB7>L00PP=00=l07ooOol047oo00<007ooOol0<Woo0`00
7Goo00/001cW7>Lj_Cjn>[dn_SZm?[hj_Cjn008Li`030016NdIk00I6N`037>Ml07oo02Moo`03001o
ogoo011oo`003Goo00<007ooOol0<7oo014001TF7CLI5QcW494DTQ2A598@TABB494DTQ2A598Lig`0
01Aoo`03001oogoo02ioo`<0021oo`09000n_SZm?[hj_Cjn>[dn_SZm008Li`09AY]2N`00AW]6Vd9k
AY]6NdJK008Li`9:F@03O01oogoo02Eoo`03001oogoo011oo`003Goo00<007ooOol0;goo00<001Tf
6CH00aTf00<Lia2B59800QBB00L@TQBB598DTQ2B599l000EOol00`00Oomoo`0YOol4000SOol01`00
>[dn_SZm?[hj_Cjn008Li`A6N`030016NdIk0096N`8Li`E:F@03O01oogoo02Aoo`03001oogoo011o
o`003Goo00<007ooOol0;Woo01<001TF7CLI5Qdf6AHM=acW598@TABB494DTQ2A598@TABB495l000F
Ool00`00Oomoo`0UOol3000XOol01000>[dn_SZm0QcW00Q6VdIkAY]2NdJKAW/0049k0acW00E6F4YI
BUU:FDIH009:F@03O01oogoo02Aoo`03001oogoo011oo`003Goo00<007ooOol0;Goo00<LiaTf6CH0
1QTf00<LiaBB49800aBB00@@TQBB599l01Qoo`03001oogoo025oo`<002]oo`04000n_QcW7>L8AW/0
0`007>M:F@0:BUT00g`0Oomoo`0SOol00`00Oomoo`0@Ool000aoo`03001oogoo02eoo`0D000M^QcW
6AHM=QTF7CLI5Qdf6AHM=acW598@TABB494DTQ2A599l01Uoo`03001oogoo01eoo`<002ioo`8Li`08
AY]2NdJKAW]6Vd9kAY]6N`8Li`04BUT004YIAUP3BUT024IHBUU:FDYIAUQ:FAcWO00TOol00`00Oomo
o`0@Ool000aoo`03001oogoo02aoo`05000M^Qfj7KXLi`086CH00acW598@TP0359800a2BO01oo`0I
Ool00`00Oomoo`0HOol4000aOol00`00AW]6N`05AW/27>L3BUT00`00BUU:F@06BUT37>L2BSL00g`0
Oomoo`0ROol00`00Oomoo`0?Ool000aoo`03001oogoo02]oo`0E000M^R6j7KXQ^Qfj7>LI5Qdf6AHM
=aTF7CHI5Qdg7>LDTQ2A598@TG`001aoo`03001oogoo01Aoo`<003Eoo`060012NdJKAW]6Vd9k0QcW
00=:FDIHBUT00TYI00D004YIBUU:FDIH00@Li`06CSQ:5dhhBQM>>7`097oo00<007ooOol03goo000<
Ool00`00Oomoo`0ZOol00`007KXM^P057KX00acW6CHI=P066CH01AcW598@TQBBO00077oo00<007oo
Ool04Goo0`00>Goo00<004IkAW/00QcW1dYI00<004YI7>L00QcW00A:FDXgBSM>=`=:=`04CSM:=dXg
O00SOol00`00Oomoo`0?Ool000aoo`03001oogoo02Uoo`0:000M^R6j7KXQ^Qfj8KXM^R6j7KX27>L0
2adf6AHM=aTF7CHI5Qdg7>LDTQ2AO0007Goo00<007ooOol03Goo0`00?7oo00<001cW7>L00dYI01M6
F4YIBUU:FDIHBUT001cWAUQ>>4XGCSQ:5dhhBQM>>4XGCSQ:5dhhBQM>>7`0029oo`03001oogoo00mo
o`002goo00<007ooOol0:Goo00<0028m7>L02Qfj00<LiaTf6CH01ATf00<Lig`0Ool07Woo00<007oo
Ool02Goo0`00?goo00<004YIBUT01dYI00DLi`00001:=dhg00=:=`05CSM:=dXgBSM>=`03BSL00dhg
BSMl000ROol00`00Oomoo`0?Ool000]oo`03001oogoo02Uoo`03000RGB8m008Li`0B8KXM^R6j7KXQ
^Qfj8KXM^R6j7>LM=QTF7CLI5Qdf6AHM=g`087oo00<007ooOol017oo1000@Woo00D004YIBUU:FDIH
009:F@@0000CCSQ:5`00BQM>>4XGCSQ:5dhhBQM>>4XGCSQ:5dhhBQM>>1cWO0008Goo00<007ooOol0
3goo000;Ool00`00Oomoo`0XOol01`008UdR?B9M8SdRGAcW00TM^P037>LI=QTf00@I=P03O01oogoo
01moo`03001oogoo00<004Moo`03001:FDYI00<000037>M>=dXg009:=`05CSL004XgBSM>=`03BSL0
14hgBSM:=dXg11cW00=>5W`0Ool08Goo00<007ooOol03Woo000;Ool00`00Oomoo`0WOol020008UdR
?B9M7S`RGB8m8Ud27>L03afj8KXM^R6j7KXQ^Qfj8KXLiadf6AHM=aTF7CIl000ROol20019Ool40002
7>L03TXGCSQ:5dhhBQM>>4XGCSP004hhBQM>>4XGCSP47>L2CQH014XECQI>5W`08Woo00<007ooOol0
3Woo000;Ool00`00Oomoo`0WOol02P008SdRGB8m8UdR?B9M8SdRGB8m0QcW1afj00DLiaTf6CHI=W`0
02=oo`03001oogoo04Eoo`<00004Ool001cW7>L2BSL01DhgBSM:=dXgCSL00dXg00=>=`00BSL00acW
2DhF00=l07ooOol087oo00<007ooOol03Woo000:Ool00`00Oomoo`0WOol05@007>LLiahl8UdR?B9M
7S`RGB8m8UdN?29M7>LQ^Qfj8KXM^R6j7KXQ^P027>L00aTFO01oo`0ROol00`00Oomoo`12Ool30005
Ool02`00CSQ:5dhhBQM>>4XGCSQ:5dhhBQL00QcW00<001cWCQH00ThF00E:5DhFCQI>5TXE00=>5P03
BQEl07oo025oo`03001oogoo00ioo`002Woo00<007ooOol09goo00<002Zn8Sd00acW00PR?B9M8SdR
GB8m8UdR?B9M0QcW1afj00<Lig`0Ool08Woo00<007ooOol0?Woo100027oo00<004XgCSL00dXg00=>
=acW7>L00QcW0dhF00<004hFCQH02dhF00=l07ooOol07goo00<007ooOol03Woo000:Ool00`00Oomo
o`0VOol01`00:]lV_R[O:[hZgahl00<Li`077S`RGB8m8UdN?29M8Sd00QcW00LQ^Qfj8KXM^R6j7KYl
000SOol00`00Oomoo`0kOol3000=Ool00`00BQLLi`037>L00dhFBQE>5P02CQH01DXECQI>5P00BQD0
0dhF00E:5DhFCQI>5TXE00=>5P03O01oogoo01moo`03001oogoo00ioo`002Woo00<007ooOol09Woo
00<002Zn:[l00bZn00@Z_bZn8UdR?@8Li`078UdR?B9M8SdRGB8m8Ud00QcW11fj00=l07ooOol08Goo
00<007ooOol0=goo100047oo00<001cWCQH02dhF00<004hFCQH02ThF00=l07ooOol087oo00<007oo
Ool03Goo000:Ool00`00Oomoo`0VOol03000:]lZ_R[O9[hZgbZn:]lV_R[O:[hRG@<Li`068UdN?29M
8SdRGAhl0QcW00<Q^QfjO0008goo00<007ooOol0=7oo0`0057oo00<004XECQH00ThF00E:5DhFCQI>
5TXE00=>5P05BQE>5P00CQI:5@03CQH01dXECQI>5ThFBQE>5W`0029oo`03001oogoo00eoo`002Goo
00<007ooOol09Woo00<002Zo:[h00RZn00DZ_bZn:[hZ_RZo00<Z_P03:[lZ_R9M00<Li`058UdR?B9M
8SdRG@027>L00g`0Oomoo`0QOol00`00Oomoo`0`Ool4000GOol00`00CQI>5P0=CQH00`00CQI>5P04
CQH47>L00g`0Oomoo`0POol00`00Oomoo`0=Ool000Uoo`03001oogoo02Ioo`@Li`0?:]lZ_R[O9[hZ
gbZn:]lV_R[O:[hZgbJn:]lR?B9M008Li`068SdRGAhl8UdR?G`08goo00<007ooOol0;Goo0`0077oo
00<004hFBQD00dhF00E:5DhFCQI>5TXE00=>5P037>L001cW00DLi`05COAAmDgdCOEl000ROol00`00
Oomoo`0=Ool000Uoo`03001oogoo02Ioo`04001:_4ZlB[`77>L01BZo:[hZ_RZn:[l00bZn00PZ_b8m
7>LLib9M8SdRGG`08goo00<007ooOol0:Woo0`007goo00<004hFCQH00ThF2AcW0Tge00<004geCOD0
1dge00=l07ooOol087oo00<007ooOol03Goo0009Ool00`00Oomoo`0VOol02`00A[a:gDJlB]e6_4[M
A[a:gDJlB]d021cW00@Z_R[O9[hZg`8Li`037Sal07oo029oo`03001oogoo02Ioo`@0029oo`03000L
iacW008Li`0FDOE=m4geCOAAmDgdCOE=m57eCOA=mDgd001=m4geCOAAmDgdCOE=m57eO00ROol00`00
Oomoo`0=Ool000Uoo`03001oogoo02Eoo`03001:_4Zl00m:_003:[lZ_QcW00HLi`03O01oogoo021o
o`03001oogoo02Aoo`<002Ioo`03001=mDge00i=m@03001=mDge00I=m@03O01oogoo025oo`03001o
ogoo00aoo`0027oo00<007ooOol09Woo01L004[MA[a:gDJlB]e6_4[MA[a:gDJlB]e6_4[MA[a:gDJl
B]e6_4[MA[a:gDJl00DLi`9l021oo`03001oogoo021oo`@002Uoo`0J001=mDgdDOE=m4geCOAAmDgd
COE=m57eCOA=mDgdDOE=m4ge001AmDgdCOE=m57eCOAl02Aoo`03001oogoo00aoo`0027oo00<007oo
Ool09Woo00<004ZlB[`01dZl3AcW00<hJ3QY=6P00SQX00<hJG`0Ool07goo00<007ooOol07Goo0`00
;7oo00<004geCOD04Dge00<004geCOD00dge00=l07ooOol08Woo00<007ooOol037oo0008Ool00`00
Oomoo`0VOol:7>L03cAX>6TdJ3QY=6PhJCAX>6TdJ3QY=6PhJCAX>6TdJ0047>L00g`0Oomoo`0NOol0
0`00Oomoo`0IOol4000_Ool06`00COAAmDgdCOE=m57eCOA=mDgdDOE=m4geCOAAmDgdCOE=m57eCO@0
04gdDOE=m4geCOAl000TOol00`00Oomoo`0<Ool000Qoo`03001oogoo02Ioo`04000hJ3QY=6P2>6P0
1SQY=6PhJ3QX>6TdJ08hJ006>6TdJ3QX>6PhJCAX1AcW0R@400<P12@4O00087oo00<007ooOol05Woo
0`00<goo00<001cW7>L02QcW24ge00<004geCOD00Tge00=l07ooOol08Woo00<007ooOol037oo0008
Ool00`00Oomoo`0VOol03`00>6TdJ3QY=6PhJCAX>6TdJ3QY=6PhJCAX>6TdJ0057>L01R0490@P12@4
80@T10<Li`03O01oogoo01ioo`03001oogoo01=oo`<003Ioo`0=001=de7dCM=Am4gCDOA=de7dCM=A
m4gCDO@02AcW00D001cW7>LLig`002Aoo`03001oogoo00aoo`001goo00<007ooOol09goo00H003AX
>6PhJ3QY=6P2>6P00cQY=6PLi`047>L290@01B0490@T12@480@00R@40QcW0QP500=l07ooOol07goo
00<007ooOol03goo1000>Goo00D004gDCMAAe4gC009=e006DMA=ddgDCMAAe4gC0TgD00aAe4gCCMA=
e57DCM==e000DMA=ddgDO00UOol00`00Oomoo`0;Ool000Moo`03001oogoo02Moo`05000hJCAX>6Td
J0057>L02b0490@P12@480@T120490@P12@480@00acW0aP500<L1G`0Ool087oo00<007ooOol037oo
0`00?7oo01/0057dCM=Am4gCDOA=de7dCM=Am4gCDOA=de7dCM=Am4gCDOA=de7dCM=Am4gCDO@0057d
O0009Woo00<007ooOol02goo0007Ool00`00Oomoo`0WOol00`007>LLi`027>L290@01B0490@T12@4
80@00b@400<P12@490@00acW1aP500=l07ooOol07goo00<007ooOol027oo1000?goo00@004gDDMA=
d`9=e006DMA=ddgDCMAAe4gC0TgD00IAe4gCCMA=e57DCM<2CM@01E7DCM==e000O0009Woo00<007oo
Ool02goo0007Ool00`00Oomoo`0WOol0400090@P12@480@T120490@P12@480@T120490@P12@40QcW
0aP500@L1AP560DH1@<Li`03O01oogoo01moo`03001oogoo00Eoo`<004=oo`0J000LiacW7>M=de7d
CM=Am4gCDOA=de7dCM=Am4gCDOA=de7dCM=Am4gCDOA=de7dCM<002Moo`03001oogoo00]oo`001goo
00<007ooOol0:7oo00D002@490@T120400<T100480@T12@490@37>L760D27>L240L00g`0Oomoo`0P
Ool01000Oomoogoo1000AGoo00D0057CCM9AdTgD00@Li`06DMA=ddgDCMAAe4gC0TgD00IAe4gCCMA=
e57DCM<2CM@00e7DO000000VOol00`00Oomoo`0;Ool000Moo`03001oogoo02Qoo`09000P12@480@T
120490@P12@400<Li`8H1@0670DH1AP560DL1AP50QcW110700=l07ooOol087oo1000B7oo00X0057C
CK9AddfbDM==/U7CCK9Am0@Li`0=CM=Am4gCDOA=de7dCM=Am4gCDOA=de7dO0000Woo00<007ooOol0
8goo00<007ooOol02goo0006Ool00`00Oomoo`0YOol00`0090@P100390@00b047>LLi`0960D27>L6
40L00g`0Oomoo`0NOol3001;Ool01P00CM9AdU7BDM==dP9AdP06DM==dU7BDM9AddgB1AcW00==e57D
CM<00TgD00=Ae4gCO0000goo00<007ooOol08goo00<007ooOol02Woo0006Ool00`00Oomoo`0ZOol0
0`0090@P10037>L00aP570DH1@0260D011`560DH1AP50QcW1a0700=l07ooOol06goo10000Woo00<0
07ooOol0B7oo01@004fbDM==/U7CCK9AddfbDM==/U7CCK9AddfbDM==/U7CCK9Addfb11cW00=Am4gC
O00017oo00<007ooOol08goo00<007ooOol02Woo0006Ool00`00Oomoo`0ZOol00`007>LLi`0:60D2
7>L940L00g`0Oomoo`0HOol30006Ool00`00Oomoo`17Ool01P007>LLie7BDM==dP9AdP06DM==dU7B
DM9AddgB0U7B00IAddgBDM9AdU7CCM82DM80157C7>LLig`01Goo00<007ooOol08Woo00<007ooOol0
2Woo0006Ool00`00Oomoo`0[Ool01@0060DH1AP570D00aP500@L1AP57>LLi`T@1`8Li`03O01oogoo
01Aoo`@000Uoo`03001oogoo04Ioo`04001=/E6aCK027>L05U7CCK9AddfbDM==/U7CCK9AddfbDM==
/U7CCK9AddfbDM==/U7CCK9Adg`01goo00<007ooOol08Goo00<007ooOol02Woo0006Ool00`00Oomo
o`0[Ool00`0060DH1@0560D27>L940L27>L00`P9O01oo`0COol3000=Ool00`00Oomoo`15Ool00`00
DK5A/@04DK427>L01DgBDM9AdU7CCM800U7B00IAddgBDM9AdU7CCM82DM801E7CCM9AdU7BO0001goo
00<007ooOol08Goo00<007ooOol02Woo0005Ool00`00Oomoo`0]Ool00`0070DH1@0260D27>L940L2
7>L010P920X42G`047oo100047oo00<007ooOol0A7oo00X004faDK5=/56aCK5A/Df`DK5=/@8Li`0A
DM==/U7CCK9AddfbDM==/U7CCK9AddfbDM==/U7CCK9l0009Ool00`00Oomoo`0POol00`00Oomoo`0:
Ool000Eoo`03001oogoo02eoo`03000H1AP5008Li`T@1`8Li`D82@03O01oogoo00]oo`<001Aoo`03
001oogoo04=oo`03000Lie6a00YA/@8Li`03DM9AddgB009AdP06DM==dU7BDM9AddgB0U7B00=l07oo
Ool02Goo00<007ooOol087oo00<007ooOol02Goo0005Ool00`00Oomoo`0^Ool27>L940L27>L020@9
20X82@P:10T82PP9O00:Ool3000GOol00`00Oomoo`12Ool00`00CFmA/@027>L02dfaDK5=/56aCK5A
/Df`DK5=/E6aCK000acW00]=/U7CCK9AddfbDM==/U7CCK9Adg`000]oo`03001oogoo021oo`03001o
ogoo00Uoo`001Goo00<007ooOol0;goo00<0010740L01Q0700<Li`P920T01PP900=l07ooOol01Goo
10006Woo00<007ooOol0@7oo0P00155_00=A/AcWDK40356a0QcW0U7B00IAddgBDM9AdU7CO00=Ool0
0`00Oomoo`0OOol00`00Oomoo`09Ool000Eoo`03001oogoo02moo`03000@1a0700@@1`8Li`0:20X4
2@P:20T82P@920X82@P:O004Ool3000NOol00`00Oomoo`0oOol02@00DHm=Ke6?CFiASde_DHm=KP02
7>L03E6aCK1A/DfaDK5=/56aCK5A/Df`DK5=/E6a008Li`05CK9AddfbDM=l000?Ool00`00Oomoo`0N
Ool00`00Oomoo`09Ool000Aoo`03001oogoo035oo`04000@1a0740L27>L;20T00g`000000002000P
Ool00`00Oomoo`0oOol00acWDFmAK`08DFl00e6a7>MA/@0=DK427>L00e7CCM9l000?Ool00`00Oomo
o`0NOol00`00Oomoo`09Ool000Aoo`03001oogoo035oo`0?000@1acW7>L82PP920X42@P:20T82P@9
20X82@P:00<002Aoo`03001oogoo03eoo`80000=DDdLiacWCFiASde_DHm=KU6?CFmASde^DHl00QcW
011=/56aCK5A/Df`DK5=/E6aCK1A/DfaDK5=/56a7>Ml015oo`03001oogoo01eoo`03001oogoo00Uo
o`0017oo00<007ooOol0<Woo00<Li`P920T01`P9100000<0300;O00097oo00<007ooOol0>goo0P00
00IA;55<CBaAC54/7>L;DFl00acWDK5A/@0;DK400g`0Oomoo`0AOol00`00Oomoo`0MOol00`00Oomo
o`08Ool000Aoo`03001oogoo039oo`0700082PP920X42@P:20T00`000QcW00D02`@<00/437`002Ao
o`03001oogoo03Yoo`097>MAC4d/DDe=;55<CBaACDd/008Li`0:DHm=Ke6?CFiASde_DHm=KU6?CFl2
7>L02e6aCK5A/Df`DK5=/E6aCK1A/DfaO00057oo00<007ooOol07Goo00<007ooOol027oo0004Ool0
0`00Oomoo`0cOol00`0020T82@0300002PP97>LLi`0<00/0300;00`02g`097oo00<007ooOol0>Goo
00d004c77>MAC4d/DDaA;55<CBaAC54/DFlLi`0;DFl00acWDK5A/@05DK42O00FOol00`00Oomoo`0L
Ool00`00Oomoo`08Ool000=oo`03001oogoo03=oo`@0000=20T82QcW7>L02`@<00/4300;10`02`@<
O00097oo00<007ooOol0=goo0P0001U<j4c7C>PLie5<CBaACDd/DDa=;55=CBaAC1cWDHm=Ke6?CFiA
Sde_DHm=KU6?CFmAS`027>L01DfaDK5=/56aO0006Goo00<007ooOol06goo00<007ooOol027oo0003
Ool00`00Oomoo`0`Ool30002Ool03P0020TLiacW00`02`0<00/0300;00`02`0<O00UOol00`00Oomo
o`0fOol00`00C<M<a`04C<L02QcWDDa=;55<DBaAC4d/DDaA;55<0QcW2e5_0QcW00=A/G`0Ool06Goo
00<007ooOol06goo00<007ooOol027oo0003Ool00`00Oomoo`0/Ool40005Ool27>L0300;10`02`@<
00/4300;10`02`@<00]l02Eoo`03001oogoo03Eoo`0R001<adcXC<M<j4c7C>Q<adcX7>MAC4d/DDe=
;55<CBaACDd/DDa=KQcWCFmASde^DHm=Ke6?CFiASde_DHm=KU6?O00LOol00`00Oomoo`0JOol00`00
Oomoo`08Ool000=oo`03001oogoo02Uoo`<000Uoo`0>00002`0<00/0300;00`02`0<00/0300;00al
02Eoo`03001oogoo03Aoo`04001001cW7>L7C<L27>L02Td/DDaA;55<CBaAC54/DDa=;1cW2E5_0W`0
7Woo00<007ooOol06Woo00<007ooOol01goo0003Ool00`00Oomoo`0UOol4000=Ool03@0000/4300;
10`02`@<00/4300;10`02g`002Eoo`03001oogoo039oo`8000=0000KA00LidcXC<M<j4c7C>Q<adcX
C<LLidd/DDe=;55<CBaACDd/DDa=;1cWCFmASde^DHm=Ke6?009l021oo`03001oogoo01Yoo`03001o
ogoo00Moo`000Woo00<007ooOol08goo0`004Goo00d0000<00/0300;00`02`0<00/0300;00al000U
Ool00`00Oomoo`0aOol00`00@0100005@0000acWC<M<a`06C<L02QcWCBaAC54/DDa=;55<DBaAC4d/
0QcW0U5_0W`08goo00<007ooOol06Goo00<007ooOol01goo0002Ool00`00Oomoo`0POol3000EOol0
1P0010`02`@<00/430DLi`03O01oogoo02=oo`03001oogoo031oo`8Li`=00005A0100400@0140002
7>L04Dc7C>Q<adcXC<M<j4c77>M=;55=CBaAC4d/DDe=;55<CB`00g`09Woo00<007ooOol067oo00<0
07ooOol01goo0002Ool00`00Oomoo`0LOol4000HOol00`007>LLi`037>L300h00`0=00il000UOol0
0`00Oomoo`0_Ool00`00700H00047>L6@0000acWC<M<a`05C<L01acWCBaAC54/DDa=;55<009l02Uo
o`03001oogoo01Qoo`03001oogoo00Moo`000Woo00<007ooOol06Goo0`007Goo00/0000=00h03@0>
00d03P0=00h03G`002Eoo`03001oogoo02eoo`800004700H01`060037>L7O0027>L02DcXC<M<j4c7
C>Q<aacWCBaAC@03O00/Ool00`00Oomoo`0GOol00`00Oomoo`07Ool0009oo`03001oogoo01Eoo`@0
021oo`0300003P0=00<03P0500d03P0>00il000UOol00`00Oomoo`0/Ool77>L010007>LLig`01Woo
2g`0<7oo00<007ooOol05goo00<007ooOol01Woo00000goo001oo`0DOol3000UOol02P0000h03@0>
00d03P0=00h03G`09Goo00<007ooOol0:goo1P001AcW00=l07ooOol0?goo00<007ooOol05goo00<0
07ooOol01Woo00000goo001oo`0@Ool4000XOol0100000h03P0=0`0>00<03@0>O0009Goo00<007oo
Ool0:Woo10001QcW00<m]SfeO000@Woo00<007ooOol05Woo00<007ooOol01Woo00000goo001oo`0=
Ool3000]Ool02@0000d03P0=00h03@0>00el000UOol00`00Oomoo`0YOol200037>L02S5D7>LLicEe
?KE1]Sfe?KHm]G`0@Woo00<007ooOol05Goo00<007ooOol01Woo00000goo001oo`0:Ool3000`Ool0
1@007>LLi`0>00d00`0>00=l07ooOol08goo00<007ooOol0:7oo00<001cW7>L00S5e0QcW00Tm]Cff
?KDm]Sfe?KHm]AcWO000@Woo00<007ooOol05Goo00<007ooOol01Woo00000goo001oo`06Ool4000c
Ool02@0000l041cW00h03@0>00el000UOol00`00Oomoo`0WOol00`007>LeM@037>L01D6f?KDm]Sfe
@KH011cW00=1]7`0Ool0@Woo00<007ooOol057oo00<007ooOol01Woo00000`00Oomoo`03Ool3000h
Ool00`0000l03`027>L00`0=00il000UOol00`00Oomoo`0VOol02P00<GDLiacW?KHm]Cff?KDm]Sfe
0QcW0T6d00E5]46d@KA1]7`004=oo`03001oogoo01Aoo`03001oogoo00Eoo`0000<007oo00000`00
>goo00D0000@00l0400?008Li`03O01oogoo02=oo`03001oogoo02Eoo`08000LiacW?KDm]Sfe@KHm
]@<Li`09@KA5]46dAKE1]4Fd@KA5]G`004=oo`03001oogoo01Aoo`03001oogoo00Eoo`000P00?goo
00<0000?01000`0?00<047`0Ool08goo00<007ooOol09Goo0QcW00Dm]Sfe?KHm]Cff008Li`03@KA5
]46d0091]007AKA1]46d@KA5]1cWO000A7oo00<007ooOol04goo00<007ooOol01Goo00000goo0000
000nOol00`007>L0000400000g`0Oomoo`0ROol00`00Oomoo`0TOol01P00?KE1]Sfe?KHm]@8Li`09
AKA1]4Fe@KA5]46dAKE1]4Fd00<Li`03BI=l07oo04Aoo`03001oogoo019oo`03001oogoo00Eoo`00
0goo00<007ooOol0?7oo00<001cW00000`0000=l07ooOol08Woo00<007ooOol08goo00@003fe?KHm
]@<Li`=1]005AKA1]46d@KA5]0037>L01DFCAI95TdFCO000AGoo00<007ooOol04Woo00<007ooOol0
1Goo0004Ool00`00Oomoo`0kOol00`007>L0000300000g`0Oomoo`0ROol00`00Oomoo`0SOol02`00
@KHLiacW@KA5]D6dAKA1]4Fe@K@011cW00U9TdFBBI=5TTVCAI99TdFBO000AGoo00<007ooOol04Goo
00<007ooOol01Goo0005Ool2000kOol00acW010Li`0300000g`0Oomoo`0ROol00`00Oomoo`0ROol0
0`007>LLi`02@K@014Fd@KA1]46d0acW0TFC00E5TTFCAI=5TdFB00=5T`03AI95Tg`004Ioo`03001o
ogoo015oo`03001oogoo00Aoo`001goo00<007ooOol0>7oo00@001cW014Li`<00003O01oogoo025o
o`03001oogoo025oo`060015]D6dAKA1]4Fe11cW0115TTVCAI99TdFBBI=5TTVCAI99TdFBBI=5TTVC
AI9l04Ioo`03001oogoo015oo`03001oogoo00Aoo`0027oo0P00>Goo00@Li`0@010Li`800003O01o
ogoo025oo`03001oogoo025oo`030011]1cW00<Li`=5T`05AI95TdFCAI=5TP03AI<01DFBAI=5TdFC
AI800acW00=l07ooOol0AGoo00<007ooOol047oo00<007ooOol017oo000:Ool00`00Oomoo`0fOol0
1`007>L0400A7>L007`002=oo`03001oogoo021oo`0A000LiacWAI99TdFBBI=5TTVCAI99TdFBBI=5
TTVCAI99T`067>L014UaBI99LG`0B7oo00<007ooOol03goo00<007ooOol017oo000;Ool2000fOol0
1`0000lLi`0@7>L007`002=oo`03001oogoo021oo`050015TdFCAI=5TP03AI<00dFBAI<Li`067>L9
BI400g`0Oomoo`16Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool000eoo`03001oogoo03=oo`07000L
i`0?7>L041cWO0008goo00<007ooOol07goo00D004VCAI99TdFB00HLi`0ABI99LDVABG59TTUaBI59
LDVBBG59TDUaBI99LDVABG5l0019Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool000ioo`03001oogoo
039oo`04001401cW7>L201000g`0Oomoo`0QOol00`00Oomoo`0OOol00`007>LLi`027>LEBI400g`0
Oomoo`19Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool000moo`80039oo`0300140400008Li`03015l
07oo029oo`03001oogoo01moo`0K0019TTUaBI59LDVBBG59TDUaBI99LDVABG59TTUaBI59LDVBBG59
TDUaBI99LDVABG59TW`004]oo`03001oogoo00ioo`03001oogoo00=oo`004Goo00<007ooOol0;Woo
00D004@0A014000?008Li`03011l07oo025oo`03001oogoo01ioo`030019TDVA01Q9T@03O01oogoo
04Yoo`03001oogoo00eoo`03001oogoo00=oo`004Woo0P00;Woo00T004@0B01004@000lLi`0@O000
8Woo00<007ooOol07Woo00<001cW7>L061cW00=l07ooOol0Bgoo00<007ooOol037oo00<007ooOol0
0goo000DOol00`00Oomoo`0[Ool00`00A0140003A000100?7>L047`08Goo00<007ooOol07Woo00<0
04e`CG0064e`00=l07ooOol0Bgoo00<007ooOol037oo00<007ooOol00goo000EOol00`00Oomoo`0Z
Ool01@00@01404@0B0000T@00QcW00=l07ooOol07goo00<007ooOol07Goo01`004e`BFm=L4U`CG19
Kde`BG1=L4U_CG19L4e`BFm=L4U`CG19Kde`BG1=L4U_CG19L4e`BFml04moo`03001oogoo00]oo`03
001oogoo00=oo`005Woo0P00:Woo00<004@0@0001D@000<Lig`0Ool04Woo00<Lig`0Ool02goo00<0
07ooOol07Goo00@001cW7>LLiaM=L003O01oogoo04ioo`03001oogoo00]oo`03001oogoo009oo`00
67oo00<007ooOol09goo00L003`RA01004@0@0180002A0000acWO01oo`0>Ool37>L00g`0Oomoo`0;
Ool00`00Oomoo`0LOol01@00CFiAKde^CG0011cW01=9Kde`BG1=L4U_CG19L4e`BFm=L4U`CG19Kde`
BG1=L4U_CG1l001AOol00`00Oomoo`0;Ool00`00Oomoo`02Ool001Uoo`8002Moo`07000l8S`R@28l
8T@0@0000d@000=l01cWOol027oo21cW00=l07ooOol02goo00<007ooOol077oo00T0055_CFiAKde^
DFm=KU5_CFh011cW3Te`00=l07ooOol0D7oo00<007ooOol02Woo00<007ooOol00Woo000KOol00`00
Oomoo`0TOol02000>2DhAS`R@2<l8T0S@003A0000g`07>LLi`077>L022`4<0D/13Q6>2DhASPUO00>
Ool00`00Oomoo`0KOol03P00DFm=KU5_CFiAKde^DFm=KU5_CFiAKde^DFl57>L02Te`BFm=L4U`CG19
Kde`BG1=L7`0Dgoo00<007ooOol02Goo00<007ooOol00Woo000LOol00`00Oomoo`0TOol00`00>2Dh
9@04>2D01C`R@294000?O0000QcW00<l8QcW7>L02QcW00=l07ooOol037oo00@001cWO01l01Uoo`03
001AKAcW008Li`0?DFm=KU5_CFiAKde^DFm=KU5_CFiAKde^DFm=KU5_00HLi`9=L003O01oogoo05=o
o`03001oogoo00Qoo`03001oogoo009oo`007Goo0P0097oo00d002`5;0@`1B`4;0D/1305;0@/1B`4
O01400037>L00d00A00l8P047>L0140S?29l07`03Goo0acW00@if3Fg>MQl01Moo`06001EKE5=EFeA
CEE]0QcW01==KU5_CFiAKde^DFm=KU5_CFiAKde^DFm=KU5_CFiAKde^DFm=KP027>L00g`0Oomoo`1C
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool001moo`03001oogoo029oo`800005;0@/1B`5;0D/1002
;0D2Ool017`0A00Lid@00QcW00M40400A01004@07>Ml000<Ool47>L01SFg>KLe]cFg7>Ml01Ioo`03
001AKE5]00IAK@<Li`0BCFiAKde^DFm=KU5_CFiAKde^DFm=KU5_CFiAKde^DFm=KW`0Egoo00<007oo
Ool027oo00<007ooOol00Goo000POol2000TOol00`00Oomoo`07Ool01G`0@00Lid@0B0000QcW00A0
04@0O01l00Yoo`DLi`04>MPe]cWH=KL27>L00bVH9GMl000COol2000035U<7>MEKE5=EFeACEE]DDeE
KE5=EFeAC@<Li`0?CFiAKde^DFm=KU5_CFiAKde^DFm=KU5_CFiAKg`005Qoo`03001oogoo00Moo`03
001oogoo005oo`008Woo00<007ooOol0;7oo0W`000@Lid@0A014009l00Uoo`DLi`04>KLe]cFg=KL3
7>L01REh9IPUN2FH9GQl00moo`<000AEB`8Li`]AK@8Li`0<DFm=KU5_CFiAKde^DFm=KU5_CFiAKg`0
FGoo00<007ooOol01goo00<007ooOol00Goo000SOol2000^Ool4O008Ool67>L00cFg>MPe]`037>L0
1bEg9IPUMbVH9GLUV2Eg008Li`03O01oogoo00Yoo`80000FFBQIBAcWFDaEBeE<ED]IC5E;7>MACEE]
DDeEKE5=EFeACEE]DDeEKE5=EFd37>L02E5_CFiAKde^DFm=KU5_CFil001JOol00`00Oomoo`06Ool0
0`00Oomoo`01Ool002Eoo`03001oogoo03Aoo`<Li`03@glLiacW00<e]`09>KLLiacW9GPUV2Eh9IPU
N2FH00@Li`041CP9>@ThO007Ool400001UTYFBQI:5TXFBTLi`IEB`8Li`eAK@<Li`05DFm=KU5_CFil
001LOol00`00Oomoo`05Ool00`00Oomoo`01Ool002Ioo`03001oogoo031oo`<Li`07Aim3OQcW7>Li
f3Fg>MP00acW00@UV2Eg:IPUM`@Li`092ET5>0UI1CP9F@Dh2ET5>7`00080000V7>L00000001Hhed4
F><LieTXFDUE:5U9FBQIBAcWFDaEBeE<ED]IC5E;ED`LieE]DDeEKE5=EFeACEE]DDeEKE5=EFeACEE]
DDeEK@8Li`03CFiAKg`005aoo`03001oogoo00Eoo`03001oogoo005oo`009goo0P00;Goo0acW0`00
0QcW0`000QcW10000acW0`001AcW00X9>0Ti1CP9>G`0E81DH5B07>MM0`=I0`05G@=I0acWFBQI:@03
FBP00eTY7>MEB`06ED/27>L?DFd00acWO01oo`1MOol00`00Oomoo`05Ool10001Ool1Ool002Uoo`03
001oogoo041oo`03001oogoo00=oo`DLi`0[O01DP51PE80Lied4F>=M15SSG@@LieU9FBQIBEDXFDUI
:5U97>MIC5E;EDaEBeU<ED]EC5E;7>MACEE]DDeEKE5=EFeACEE]DDeEKE5=EFeACEE]O000H7oo00<0
07ooOol017oo0@000Goo0Goo000ZOol20010Ool00`00Oomoo`07Ool27>L01W`0E81DH5B07>MM0`=I
0`05G@<LieTXFBQI:@03FBP00eTY7>MEB`07ED/27>L;DFd00g`0Oomoo`1OOol00`00Oomoo`04Ool1
0001Ool1Ool002aoo`03001oogoo03eoo`03001oogoo00Uoo`0X7>Ml05B0D61DP1cWG@AHhed4F>=M
11cWFDUI:5U9EBQIBETXFDTLieU<ED]EC5E;FDaEBeE<ED]IC1cWEFeACEE]DDeEKE5=EFeACEE]O01S
Ool00`00Oomoo`03Ool10001Ool1Ool002eoo`03001oogoo03aoo`03001oogoo00Yoo`077>Ml05B0
E61DP1cWG@<00eT300EM0acWFBQI:5TY00=I:003FBTLiacW00QEB`8Li`IAK@03O01oogoo06=oo`03
001oogoo009oo`40005oo`5oo`00;Woo0P00?7oo00<007ooOol02goo02@Lig`0E81@H1cWF>=M15SS
G@AHhed47>MIBETXFDUE:5U9FBQIBEDX7>MEBeE<ED]IC5E;EDaEBeU<ED/Lie5=EFeACEE]O01VOol0
0`00Oomoo`02Ool10001Ool1Ool0031oo`03001oogoo03Uoo`03001oogoo00eoo`06O01DP5AP7>MI
0ed30eT300EM0acWFBQI:5TY00=I:003FBUI:1cW00UEB`8Li`03DFel07oo06Moo`03001oogoo009o
o`40005oo`00<Goo0P00>Goo00<007ooOol03Woo0W`001]@H1cWF>=M15SSG@AHhed47>MIBETXFDUE
:5U9FBQIBEDX7>MEBeE<ED]IC5E;EDaEBeU<ED/00W`0JWoo00D007ooOomoo`00005oo`00<goo00<0
07ooOol0=Woo00<007ooOol047oo0W`000<LieT3G@<00eT300DLieTXFBQI:5TY00=I:003FBUI:1cW
00IEB`9l06aoo`05001oogooOol00001Ool003Aoo`03001oogoo03Eoo`03001oogoo019oo`9l000B
F>=M15SSG@AHhacWEBQIBETXFDUE:5U9FBQIBEDX7>MEBeE<0g`0Kgoo00@007ooOol0005oo`00=Goo
0P00=Goo00<007ooOol057oo0W`000EM0eT3F@=I0acW00=I:005FBUI:5TXFBQI:@03O01cOol00`00
Ool00001Ool003Moo`03001oogoo039oo`03001oogoo01Ioo`Al0005F><LieDXFDUI:004O01fOol0
0`00Ool00001Ool003Qoo`80039oo`03001oogoo01Yoo`El07]oo`40005oo`400000>Woo00<007oo
Ool0;goo00<007ooOol0Vgoo0P00000kOol2000_Ool00`00Oomoo`2KOol2000003eoo`03001oogoo
02]oo`03001oogoo09]oo`<00000?Woo00<007ooOol0:Woo00<007ooOol0UWoo1@000goo000oOol2
000ZOol00`00Oomoo`2AOol50008Ool0045oo`03001oogoo02Moo`03001oogoo08aoo`D000eoo`00
@Woo0P009goo00<007ooOol0Qgoo1@004Woo0014Ool00`00Oomoo`0TOol00`00Oomoo`22Ool5000G
Ool004Eoo`03001oogoo02=oo`03001oogoo07eoo`D001aoo`00AWoo0P008goo00<007ooOol0N7oo
1@008Goo0018Ool00`00Oomoo`0POol00`00Oomoo`1cOol5000VOol004Uoo`80021oo`03001oogoo
06ioo`D002]oo`00Bgoo00<007ooOol07Goo00<007ooOol0JGoo1@00<7oo001<Ool2000MOol00`00
Oomoo`1TOol5000eOol004ioo`03001oogoo01Yoo`03001oogoo05moo`D003Yoo`00Cgoo00<007oo
Ool06Goo00<007ooOol0FWoo1@00?goo001@Ool2000IOol00`00Oomoo`1EOol50014Ool0059oo`03
001oogoo01Ioo`03001oogoo051oo`D004Uoo`00Dgoo0P005Woo00<007ooOol0BWoo1P00CWoo001E
Ool00`00Oomoo`0COol00`00Oomoo`15Ool5001DOol005Ioo`03001oogoo019oo`03001oogoo041o
o`D005Uoo`00Egoo0P004Woo00<007ooOol0>goo1@00GWoo001IOol00`00Oomoo`0?Ool00`00Oomo
o`0fOol5001SOol005Yoo`8000moo`03001oogoo035oo`D006Qoo`00G7oo00<007ooOol02goo00<0
07ooOol0;Goo1@00KGoo001MOol00`00Oomoo`0:Ool00`00Oomoo`0XOol5001bOol005ioo`8000Yo
o`03001oogoo02=oo`D007Moo`00H7oo00<007ooOol01goo00<007ooOol07Woo1@00O7oo001QOol2
0007Ool00`00Oomoo`0IOol50021Ool006=oo`03001oogoo00Aoo`03001oogoo01Aoo`D008Ioo`00
I7oo0P0017oo00<007ooOol03goo1@00Rgoo001VOol01@00Oomoogoo000037oo1@00T7oo001WOol0
1000Oomoo`001goo1@00UGoo001XOol30002Ool5002JOol006Yoo`<009moo`00
\>"],
  ImageRangeCache->{{{0, 267.813}, {287, 0}} -> {0.0381793, -0.000144876, 
  0.00322013, 0.00322013}}]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(clear; top = 100; kappa[s_] := 0.6\ Cos[s]; tau[s_] := 0.6\ Sin[s]; \), 
  
    \(ds := N[\(12\ \[Pi]\)\/top]; width = 5.5; pribbonfrenet\)}], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 -1.11022e-016 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.34433 .44409 m .36135 .45572 L .3378 .45553 L .423 0 0 r
F
.48434 .44897 m .57465 .56092 L .53046 .58806 L .802 .764 .818 r
F
.33322 .46822 m .42695 .54864 L .3296 .48153 L .659 .721 .895 r
F
.48146 .55369 m .53046 .58806 L .49073 .61388 L .864 .785 .771 r
F
.4426 .61646 m .45123 .57357 L .45662 .63319 L .757 .744 .841 r
F
.44094 .50988 m .44964 .54636 L .43924 .52737 L .998 .821 .541 r
F
.44267 .49199 m .44533 .51275 L .44094 .50988 L F
.44533 .51275 m .44964 .54636 L .44094 .50988 L F
.44965 .45374 m .47596 .54817 L .45702 .57155 L .932 .81 .701 r
F
.44769 .42243 m .45321 .44696 L .44965 .45374 L F
.45321 .44696 m .47596 .54817 L .44965 .45374 L F
.41979 .4233 m .42749 .49352 L .40553 .42225 L .745 .546 0 r
F
.42749 .49352 m .42953 .51218 L .41615 .48405 L F
.42953 .51218 m .42004 .50665 L .41615 .48405 L F
.42749 .49352 m .41615 .48405 L .40553 .42225 L F
.41986 .49574 m .42558 .49965 L .42032 .49813 L .423 0 0 r
F
.41986 .49574 m .42032 .49813 L .41928 .49782 L F
.41862 .49489 m .41986 .49574 L .41928 .49782 L F
.43925 .52979 m .43185 .52977 L .43097 .52201 L .998 .821 .541 r
F
.43872 .52688 m .43097 .52201 L .41979 .4233 L F
.43911 .52713 m .43895 .52704 L .41979 .4233 L F
.43727 .52598 m .43911 .52713 L .43924 .52737 L .428 .652 .953 r
F
.43727 .52598 m .43924 .52737 L .43917 .52818 L F
.43917 .52818 m .43889 .52786 L .43872 .52688 L .998 .821 .541 r
F
.43895 .52704 m .43872 .52688 L .41979 .4233 L F
.43917 .52818 m .43872 .52688 L .43895 .52704 L F
.43391 .42371 m .43911 .52713 L .41979 .4233 L F
.43583 .46192 m .44267 .49199 L .43917 .52818 L F
.43391 .42371 m .4372 .44931 L .43583 .46192 L F
.4372 .44931 m .44267 .49199 L .43583 .46192 L F
.41562 .51064 m .42966 .51304 L .43087 .52135 L .428 .652 .953 r
F
.42837 .50154 m .43083 .52091 L .42849 .50271 L .745 .546 0 r
F
.43083 .52091 m .43097 .52201 L .43084 .52097 L F
.43083 .52091 m .43084 .52097 L .42849 .50271 L F
.3378 .45553 m .43089 .52146 L .33322 .46822 L .428 .652 .953 r
F
.42847 .50155 m .43097 .52201 L .42837 .50154 L .745 .546 0 r
F
.42587 .47833 m .43097 .52201 L .42749 .49352 L F
.42351 .45615 m .42544 .47315 L .42587 .47833 L F
.42544 .47315 m .43097 .52201 L .42587 .47833 L F
.42558 .49965 m .42834 .50154 L .42208 .50632 L .423 0 0 r
F
.43097 .52201 m .43042 .51828 L .42849 .50271 L .745 .546 0 r
F
.42849 .50271 m .42978 .51391 L .42953 .51218 L F
.43089 .52146 m .431 .5225 L .33322 .46822 L .428 .652 .953 r
F
.41562 .51064 m .43087 .52135 L .43089 .52146 L F
.42695 .54864 m .43516 .55568 L .41707 .54772 L .659 .721 .895 r
F
.43516 .55568 m .45155 .56974 L .43558 .55955 L F
.43516 .55568 m .43558 .55955 L .41707 .54772 L F
.45155 .56974 m .45148 .5705 L .43563 .56001 L F
.43558 .55955 m .43563 .56001 L .41707 .54772 L F
.45155 .56974 m .43563 .56001 L .43558 .55955 L F
.42953 .51218 m .42966 .51304 L .41562 .51064 L .428 .652 .953 r
F
.431 .5225 m .43176 .52954 L .33322 .46822 L F
.36992 .52967 m .43584 .56193 L .4426 .61646 L .757 .744 .841 r
F
.39327 .52971 m .43584 .56193 L .36992 .52967 L F
.45155 .56974 m .4548 .58663 L .45125 .57334 L .998 .821 .541 r
F
.45197 .56457 m .45324 .57446 L .45155 .56974 L F
.45324 .57446 m .4548 .58663 L .45155 .56974 L F
.45702 .57155 m .49073 .61388 L .48038 .62113 L .932 .81 .701 r
F
.46002 .58174 m .48038 .62113 L .47313 .62621 L F
.45702 .57155 m .48038 .62113 L .46002 .58174 L F
.45702 .57155 m .47313 .62621 L .45795 .58639 L F
.47596 .54817 m .49073 .61388 L .45702 .57155 L F
.4607 .41884 m .49073 .61388 L .44769 .42243 L .864 .785 .771 r
F
.45702 .57155 m .45733 .57653 L .45644 .57075 L .932 .81 .701 r
F
.45733 .57653 m .45795 .58639 L .45324 .57446 L F
.45795 .58639 m .4548 .58663 L .45324 .57446 L F
.43925 .52979 m .43958 .53648 L .43185 .52977 L .998 .821 .541 r
F
.43516 .55568 m .43828 .53593 L .45155 .56974 L .659 .721 .895 r
F
.43828 .53593 m .43958 .53648 L .45155 .56974 L F
.41305 .53672 m .43176 .52954 L .43516 .55568 L F
.33322 .46822 m .4176 .52073 L .41305 .53672 L F
.4176 .52073 m .43176 .52954 L .41305 .53672 L F
.43958 .53648 m .43225 .53335 L .43185 .52977 L .998 .821 .541 r
F
.43185 .52977 m .43225 .53335 L .42978 .51391 L .745 .546 0 r
F
.43563 .56001 m .43584 .56193 L .41707 .54772 L .659 .721 .895 r
F
.37241 .5824 m .45662 .63319 L .41748 .66705 L .822 .762 .796 r
F
.38055 .55413 m .45662 .63319 L .37241 .5824 L F
.33025 .49952 m .45662 .63319 L .32865 .50018 L F
.3296 .48153 m .45662 .63319 L .32578 .49479 L .757 .744 .841 r
F
.43225 .53335 m .44515 .64718 L .43021 .51765 L .745 .546 0 r
F
.43225 .53335 m .43021 .51765 L .42978 .51391 L F
.43185 .52977 m .42978 .51391 L .43042 .51828 L F
.43097 .52201 m .43185 .52977 L .43042 .51828 L F
.43176 .52954 m .43862 .53381 L .43516 .55568 L .659 .721 .895 r
F
.43584 .56193 m .45123 .57357 L .4426 .61646 L .757 .744 .841 r
F
.44233 .59117 m .44515 .6472 L .43668 .57242 L .998 .821 .541 r
F
.45145 .57086 m .45123 .57357 L .43584 .56193 L .659 .721 .895 r
F
.45733 .57653 m .45324 .57446 L .43391 .42371 L .932 .81 .701 r
F
.45148 .5705 m .43584 .56193 L .43563 .56001 L .659 .721 .895 r
F
.45564 .57325 m .45145 .57086 L .45148 .5705 L F
.45145 .57086 m .43584 .56193 L .45148 .5705 L F
.44515 .64718 m .46097 .63472 L .44515 .6472 L .998 .821 .541 r
F
.43925 .52979 m .4504 .58365 L .44515 .64718 L F
.4538 .57552 m .4712 .62116 L .46553 .62584 L .757 .744 .841 r
F
.45424 .58458 m .46553 .62584 L .45662 .63319 L F
.45125 .57334 m .4548 .58663 L .45123 .57357 L .998 .821 .541 r
F
.4538 .57552 m .46553 .62584 L .45424 .58458 L .757 .744 .841 r
F
.45123 .57357 m .45424 .58458 L .45662 .63319 L F
.4504 .58365 m .46097 .63472 L .44515 .64718 L .998 .821 .541 r
F
.43917 .52818 m .45125 .57334 L .43925 .52979 L F
.45125 .57334 m .45123 .57357 L .43925 .52979 L F
.45564 .57325 m .4538 .57552 L .45123 .57357 L .659 .721 .895 r
F
.45564 .57325 m .45123 .57357 L .45145 .57086 L F
.44233 .59117 m .43668 .57242 L .43225 .53335 L .998 .821 .541 r
F
.43958 .53648 m .44233 .59117 L .43225 .53335 L F
.43021 .51765 m .44515 .64718 L .42974 .51401 L .745 .546 0 r
F
.42953 .51218 m .43473 .55717 L .44455 .64922 L F
.43473 .55717 m .44515 .64718 L .44462 .64897 L F
.43473 .55717 m .44462 .64897 L .44455 .64922 L F
.44515 .64718 m .44515 .6472 L .44515 .6472 L F
.44515 .64718 m .44515 .6472 L .44455 .64922 L F
.44515 .64718 m .44515 .6472 L .44515 .64718 L F
.44515 .64718 m .44515 .64718 L .42978 .51391 L F
.42004 .50665 m .42953 .51218 L .41562 .51064 L .428 .652 .953 r
F
.43042 .51828 m .42978 .51391 L .42849 .50271 L .745 .546 0 r
F
.41862 .49489 m .42004 .50665 L .42108 .50572 L .162 .196 .649 r
F
.41615 .48405 m .41793 .49441 L .41862 .49489 L F
.41793 .49441 m .42004 .50665 L .41862 .49489 L F
.43059 .51277 m .43158 .51337 L .43061 .51281 L .428 .652 .953 r
F
.43059 .51277 m .43061 .51281 L .42004 .50665 L F
.43059 .51277 m .42004 .50665 L .42005 .50664 L F
.40348 .49613 m .43059 .51277 L .40176 .49601 L F
.34488 .45989 m .40365 .49615 L .34113 .45788 L F
.40365 .49615 m .43158 .51337 L .40348 .49613 L F
.40365 .49615 m .40348 .49613 L .34113 .45788 L F
.42835 .5016 m .43134 .50359 L .42864 .50439 L .423 0 0 r
F
.42834 .50154 m .42864 .50439 L .42208 .50632 L F
.42558 .49965 m .42208 .50632 L .39743 .49147 L F
.41862 .49489 m .42357 .49842 L .43134 .50359 L F
.42357 .49842 m .42512 .49952 L .42643 .50038 L F
.42357 .49842 m .42643 .50038 L .43134 .50359 L F
.41615 .48405 m .41693 .48747 L .41714 .48782 L .162 .196 .649 r
F
.41693 .48747 m .42108 .50572 L .41714 .48782 L F
.41714 .48782 m .42108 .50572 L .42169 .50516 L F
.40735 .4316 m .41615 .48405 L .42169 .50516 L F
.40553 .42225 m .40672 .42921 L .40735 .4316 L F
.40672 .42921 m .41615 .48405 L .40735 .4316 L F
.42018 .48409 m .42169 .50516 L .42456 .50258 L F
.40553 .42225 m .41604 .47618 L .42018 .48409 L F
.41604 .47618 m .42169 .50516 L .42018 .48409 L F
.42018 .48409 m .42357 .49842 L .41062 .47708 L F
.42357 .49842 m .42456 .50258 L .42137 .49691 L F
.40603 .48628 m .41862 .49489 L .39743 .49147 L .423 0 0 r
F
.41862 .49489 m .41928 .49782 L .39743 .49147 L F
.36135 .45572 m .40603 .48628 L .34007 .45689 L F
.40603 .48628 m .39743 .49147 L .34007 .45689 L F
.40194 .48348 m .41844 .4949 L .41862 .49489 L F
.42456 .50258 m .41197 .49046 L .42137 .49691 L .162 .196 .649 r
F
.41844 .4949 m .42512 .49952 L .42357 .49842 L .423 0 0 r
F
.41844 .4949 m .42357 .49842 L .41862 .49489 L F
.42456 .50258 m .4139 .49687 L .41197 .49046 L .162 .196 .649 r
F
.41557 .49297 m .42512 .49952 L .40194 .48348 L .423 0 0 r
F
.42137 .49691 m .41197 .49046 L .40527 .46826 L .162 .196 .649 r
F
.42357 .49842 m .42137 .49691 L .40527 .46826 L F
.40527 .46826 m .40717 .47454 L .41025 .47813 L .536 .461 .718 r
F
.40717 .47454 m .41197 .49046 L .4103 .47852 L F
.40717 .47454 m .4103 .47852 L .41025 .47813 L F
.41139 .48125 m .42205 .48768 L .41159 .48181 L .846 .471 .34 r
F
.41197 .49046 m .4112 .48074 L .41025 .47813 L .536 .461 .718 r
F
.36481 .44347 m .41047 .47873 L .34626 .44203 L .846 .471 .34 r
F
.41047 .47873 m .42205 .48768 L .41139 .48125 L F
.41197 .49046 m .41294 .49114 L .4112 .48074 L .536 .461 .718 r
F
.44769 .42243 m .45702 .57155 L .43391 .42371 L .932 .81 .701 r
F
.45702 .57155 m .45644 .57075 L .43391 .42371 L F
.43134 .50359 m .47647 .53446 L .43057 .51071 L .423 0 0 r
F
.43134 .50359 m .43057 .51071 L .42208 .50632 L F
.46556 .4504 m .51576 .55686 L .48146 .55369 L .864 .785 .771 r
F
.51576 .55686 m .53046 .58806 L .48146 .55369 L F
.47209 .44647 m .53046 .58806 L .46556 .4504 L F
.47234 .41278 m .53046 .58806 L .4607 .41884 L .802 .764 .818 r
F
.4305 .51139 m .53364 .57356 L .44035 .52792 L .428 .652 .953 r
F
.47647 .53446 m .53364 .57356 L .49639 .55111 L .423 0 0 r
F
.47647 .53446 m .49639 .55111 L .42208 .50632 L F
.43924 .52737 m .53364 .57356 L .51854 .58354 L .428 .652 .953 r
F
.42819 .50153 m .45288 .5185 L .43134 .50359 L .423 0 0 r
F
.45288 .5185 m .53524 .57509 L .46579 .5273 L F
.45288 .5185 m .46579 .5273 L .43134 .50359 L F
.42508 .4995 m .42802 .50152 L .42819 .50153 L F
.42802 .50152 m .53524 .57509 L .42819 .50153 L F
.42749 .49352 m .42847 .50155 L .42837 .50154 L .745 .546 0 r
F
.42045 .42928 m .42351 .45615 L .42749 .49352 L F
.41979 .4233 m .42017 .42665 L .42045 .42928 L F
.42017 .42665 m .42351 .45615 L .42045 .42928 L F
.42205 .48768 m .42697 .49147 L .42517 .49956 L .846 .471 .34 r
F
.43134 .50359 m .53524 .57509 L .53364 .57356 L .423 0 0 r
F
.42697 .49147 m .53524 .57509 L .42802 .50152 L .846 .471 .34 r
F
.42697 .49147 m .42802 .50152 L .42517 .49956 L F
.41557 .49297 m .42508 .4995 L .42512 .49952 L .423 0 0 r
F
.41568 .49305 m .42508 .4995 L .41557 .49297 L F
.42205 .48768 m .42517 .49956 L .41568 .49305 L .846 .471 .34 r
F
.42205 .48768 m .41568 .49305 L .41159 .48181 L F
.41047 .47873 m .42753 .49815 L .42205 .48768 L F
.4112 .48074 m .41793 .49715 L .41417 .48342 L .536 .461 .718 r
F
.42194 .49327 m .42753 .49815 L .41047 .47873 L .846 .471 .34 r
F
.41543 .46403 m .42018 .48409 L .40527 .46826 L .162 .196 .649 r
F
.42018 .48409 m .41062 .47708 L .40527 .46826 L F
.41543 .46403 m .40527 .46826 L .39128 .42186 L F
.41097 .47937 m .41417 .48342 L .4077 .45983 L .536 .461 .718 r
F
.4112 .48074 m .41417 .48342 L .41097 .47937 L F
.4139 .49687 m .41716 .4971 L .4112 .48074 L F
.41716 .4971 m .41793 .49715 L .4112 .48074 L F
.41197 .49046 m .4139 .49687 L .41294 .49114 L F
.36135 .45572 m .34007 .45689 L .3378 .45553 L .423 0 0 r
F
.37462 .4648 m .41557 .49297 L .40194 .48348 L F
.34433 .44409 m .39198 .47678 L .37462 .4648 L F
.39198 .47678 m .41557 .49297 L .37462 .4648 L F
.45795 .58639 m .49173 .60422 L .4712 .62116 L .757 .744 .841 r
F
.4538 .57552 m .46723 .58568 L .45795 .58639 L F
.46723 .58568 m .49173 .60422 L .45795 .58639 L F
.45564 .57325 m .46251 .57916 L .4538 .57552 L .659 .721 .895 r
F
.46251 .57916 m .49173 .60422 L .46723 .58568 L F
.46251 .57916 m .46723 .58568 L .4538 .57552 L F
.45564 .57325 m .51854 .58354 L .49977 .59802 L F
.46251 .57916 m .49977 .59802 L .49173 .60422 L F
.45564 .57325 m .49977 .59802 L .46251 .57916 L F
.45409 .57027 m .51854 .58354 L .45564 .57325 L F
.43924 .52737 m .45197 .56457 L .43917 .52818 L .998 .821 .541 r
F
.44964 .54636 m .45197 .56457 L .43924 .52737 L F
.45197 .56457 m .45125 .57334 L .43917 .52818 L F
.4548 .58663 m .46097 .63472 L .43925 .52979 L F
.43862 .53381 m .51854 .58354 L .45155 .56974 L .659 .721 .895 r
F
.43925 .52979 m .43097 .52201 L .43872 .52688 L .998 .821 .541 r
F
.43917 .52818 m .43925 .52979 L .43889 .52786 L F
.43727 .52598 m .45024 .54104 L .43176 .52954 L .428 .652 .953 r
F
.42776 .50094 m .524 .5867 L .42697 .49147 L .846 .471 .34 r
F
.43917 .52818 m .51854 .58354 L .45024 .54104 L .428 .652 .953 r
F
.43924 .52737 m .51854 .58354 L .43917 .52818 L F
.34433 .44409 m .41568 .49305 L .41557 .49297 L .423 0 0 r
F
.41159 .48181 m .41568 .49305 L .34433 .44409 L .846 .471 .34 r
F
.41047 .47873 m .41139 .48125 L .34626 .44203 L F
.41025 .47813 m .4112 .48074 L .4077 .45983 L .536 .461 .718 r
F
.42243 .4939 m .41793 .49715 L .42403 .49759 L F
.42194 .49327 m .42243 .4939 L .42753 .49815 L .846 .471 .34 r
F
.42243 .4939 m .42774 .50063 L .42754 .49823 L F
.42243 .4939 m .42754 .49823 L .42753 .49815 L F
.40839 .46141 m .41417 .48342 L .42243 .4939 L .536 .461 .718 r
F
.4077 .45983 m .40787 .46046 L .40839 .46141 L F
.40787 .46046 m .41417 .48342 L .40839 .46141 L F
.40589 .46614 m .41025 .47813 L .4077 .45983 L F
.39128 .42186 m .40527 .46826 L .4077 .45983 L F
.39128 .42186 m .40839 .46141 L .37739 .42336 L F
.40527 .46826 m .41025 .47813 L .40589 .46614 L F
.40839 .46141 m .42243 .4939 L .39593 .45238 L F
.40839 .46141 m .39593 .45238 L .37739 .42336 L F
.41417 .48342 m .41793 .49715 L .42243 .4939 L F
.4203 .50642 m .4305 .51139 L .43158 .51337 L .428 .652 .953 r
F
.42108 .50572 m .4305 .51139 L .4203 .50642 L F
.42953 .51218 m .44455 .64922 L .42004 .50665 L .745 .546 0 r
F
.42169 .50516 m .45252 .64402 L .45732 .64088 L .162 .196 .649 r
F
.42108 .50572 m .45252 .64402 L .42169 .50516 L F
.42005 .50664 m .42004 .50665 L .40176 .49601 L .428 .652 .953 r
F
.42143 .50727 m .42659 .53897 L .4349 .56652 L .162 .196 .649 r
F
.42659 .53897 m .44455 .64922 L .4349 .56652 L F
.4349 .56652 m .44455 .64922 L .45252 .64402 L F
.42108 .50572 m .42137 .50749 L .42143 .50727 L F
.42137 .50749 m .44455 .64922 L .42143 .50727 L F
.42004 .50665 m .44455 .64922 L .42108 .50572 L F
.36357 .47377 m .42004 .50665 L .41562 .51064 L .428 .652 .953 r
F
.42456 .50258 m .42169 .50516 L .45732 .64088 L .162 .196 .649 r
F
.37443 .47812 m .42108 .50572 L .4203 .50642 L .428 .652 .953 r
F
.3378 .45553 m .37657 .47889 L .37443 .47812 L F
.37657 .47889 m .42108 .50572 L .37443 .47812 L F
.42456 .50258 m .45732 .64088 L .4139 .49687 L .162 .196 .649 r
F
.4139 .49687 m .45732 .64088 L .41793 .49715 L .536 .461 .718 r
F
.43828 .53593 m .43862 .53381 L .43958 .53648 L .659 .721 .895 r
F
.42978 .51391 m .43021 .51765 L .42953 .51218 L .745 .546 0 r
F
.43021 .51765 m .42974 .51401 L .42953 .51218 L F
.45795 .58639 m .46097 .63472 L .4548 .58663 L .932 .81 .701 r
F
.45155 .56974 m .45409 .57027 L .45564 .57325 L .659 .721 .895 r
F
.43727 .52598 m .43176 .52954 L .431 .5225 L .428 .652 .953 r
F
.42953 .51218 m .43158 .51337 L .42966 .51304 L F
.43089 .52146 m .43727 .52598 L .431 .5225 L F
.43089 .52146 m .43911 .52713 L .43727 .52598 L F
.43087 .52135 m .43911 .52713 L .43089 .52146 L F
.43087 .52135 m .43158 .51337 L .43911 .52713 L F
.42966 .51304 m .43158 .51337 L .43087 .52135 L F
.45155 .56974 m .45564 .57325 L .45148 .5705 L .659 .721 .895 r
F
.45123 .57357 m .4538 .57552 L .45424 .58458 L .757 .744 .841 r
F
.45795 .58639 m .47313 .62621 L .46097 .63472 L .932 .81 .701 r
F
.42481 .4994 m .45732 .64088 L .47897 .62466 L .536 .461 .718 r
F
.42403 .49759 m .42438 .4991 L .42481 .4994 L F
.42438 .4991 m .45732 .64088 L .42481 .4994 L F
.41793 .49715 m .45732 .64088 L .42403 .49759 L F
.42243 .4939 m .47897 .62466 L .40592 .47989 L F
.34626 .44203 m .41139 .48125 L .34433 .44409 L .846 .471 .34 r
F
.41139 .48125 m .41159 .48181 L .34433 .44409 L F
.40193 .47583 m .40534 .47929 L .42194 .49327 L F
.40592 .47989 m .41096 .48988 L .41853 .49271 L .691 .543 .68 r
F
.40592 .47989 m .42774 .50063 L .42243 .4939 L .846 .471 .34 r
F
.39047 .46677 m .41442 .48854 L .40592 .47989 L F
.41442 .48854 m .42774 .50063 L .40592 .47989 L F
.39047 .46677 m .42243 .4939 L .42194 .49327 L F
.38682 .46047 m .42194 .49327 L .41047 .47873 L F
.40193 .47583 m .42194 .49327 L .38682 .46047 L F
.42243 .4939 m .41603 .48847 L .3807 .42853 L .536 .461 .718 r
F
.416 .48844 m .40592 .47989 L .37739 .42336 L F
.36481 .44347 m .42776 .50094 L .42774 .50063 L .846 .471 .34 r
F
.41853 .49271 m .42093 .49676 L .41856 .49274 L .691 .543 .68 r
F
.41853 .49271 m .41096 .48988 L .42093 .49676 L F
.35326 .43455 m .36481 .44347 L .34626 .44203 L .846 .471 .34 r
F
.3561 .43708 m .42776 .50094 L .36481 .44347 L F
.40185 .4646 m .41853 .49271 L .40241 .46536 L .691 .543 .68 r
F
.41853 .49271 m .41856 .49274 L .37908 .42578 L F
.42205 .48768 m .42753 .49815 L .42697 .49147 L .846 .471 .34 r
F
.42697 .49147 m .524 .5867 L .53524 .57509 L F
.41988 .48281 m .524 .5867 L .43132 .50411 L .788 .557 .587 r
F
.40245 .46542 m .43132 .50411 L .41856 .49274 L F
.40245 .46542 m .43381 .50874 L .41988 .48281 L F
.43381 .50874 m .50338 .60487 L .41988 .48281 L F
.37908 .42578 m .40245 .46542 L .43516 .50658 L .691 .543 .68 r
F
.40245 .46542 m .41856 .49274 L .4278 .50044 L F
.40245 .46542 m .4278 .50044 L .43516 .50658 L F
.43216 .50451 m .47897 .62466 L .43516 .50658 L F
.43516 .50658 m .47897 .62466 L .50338 .60487 L F
.44628 .53197 m .50338 .60487 L .43381 .50874 L .788 .557 .587 r
F
.41856 .49274 m .42093 .49676 L .42586 .50016 L .691 .543 .68 r
F
.41856 .49274 m .42586 .50016 L .43516 .50658 L F
.43911 .52713 m .44035 .52792 L .43924 .52737 L .428 .652 .953 r
F
.4305 .51139 m .44035 .52792 L .43911 .52713 L F
.43911 .52713 m .43917 .52818 L .43895 .52704 L .998 .821 .541 r
F
.41516 .49278 m .47897 .62466 L .43216 .50451 L .691 .543 .68 r
F
.37739 .42336 m .40592 .47989 L .41853 .49271 L F
.36448 .42753 m .40245 .46542 L .35326 .43455 L .788 .557 .587 r
F
.36481 .44347 m .39047 .46677 L .40534 .47929 L .846 .471 .34 r
F
.36481 .44347 m .40534 .47929 L .40193 .47583 L F
.36481 .44347 m .40193 .47583 L .38682 .46047 L F
.35326 .43455 m .3561 .43708 L .36481 .44347 L F
.40245 .46542 m .41856 .49274 L .35326 .43455 L .788 .557 .587 r
F
.372 .43504 m .44628 .53197 L .43381 .50874 L F
.372 .43504 m .43381 .50874 L .40245 .46542 L F
.37739 .42336 m .40185 .4646 L .37908 .42578 L .691 .543 .68 r
F
.40185 .4646 m .40241 .46536 L .37908 .42578 L F
.41096 .48988 m .41182 .49158 L .41516 .49278 L F
.41182 .49158 m .47897 .62466 L .41516 .49278 L F
.36448 .42753 m .3682 .43228 L .372 .43504 L .788 .557 .587 r
F
.3682 .43228 m .44628 .53197 L .372 .43504 L F
.41988 .48281 m .50338 .60487 L .524 .5867 L F
.34113 .45788 m .40348 .49613 L .36357 .47377 L .428 .652 .953 r
F
.40348 .49613 m .40176 .49601 L .36357 .47377 L F
.3378 .45553 m .34488 .45989 L .34113 .45788 L F
.32865 .50018 m .38055 .55413 L .37241 .5824 L .822 .762 .796 r
F
.32578 .49479 m .33025 .49952 L .32865 .50018 L F
.40553 .42225 m .41543 .46403 L .39128 .42186 L .162 .196 .649 r
F
.3296 .48153 m .39327 .52971 L .36992 .52967 L .757 .744 .841 r
F
.42695 .54864 m .41707 .54772 L .3296 .48153 L .659 .721 .895 r
F
.4607 .41884 m .47209 .44647 L .46556 .4504 L .864 .785 .771 r
F
.47234 .41278 m .49686 .44829 L .48434 .44897 L .802 .764 .818 r
F
.49686 .44829 m .57465 .56092 L .48434 .44897 L F
.48202 .40438 m .57465 .56092 L .47234 .41278 L .735 .744 .859 r
F
.25 g
.5 Mabswid
.47234 .41278 m
.474 .41518 L
s
.48202 .40438 m .6174 .53575 L .57465 .56092 L .735 .744 .859 r
F
1 0 0 r
.003 w
.54432 .57955 m
.57465 .56092 L
s
.53046 .58806 m
.54432 .57955 L
s
.25 g
.5 Mabswid
.4607 .41884 m
.47209 .44647 L
s
.51768 .55704 m
.52023 .56324 L
s
.52023 .56324 m
.52039 .56362 L
s
.52814 .58242 m
.53046 .58806 L
s
1 0 0 r
.003 w
.49844 .60887 m
.53046 .58806 L
s
.48956 .39404 m .6174 .53575 L .48202 .40438 L .648 .719 .9 r
F
.25 g
.5 Mabswid
.47209 .44647 m
.48947 .48862 L
s
.56673 .47958 m .65332 .51529 L .6174 .53575 L .648 .719 .9 r
F
.57016 .45372 m .65332 .51529 L .56673 .47958 L F
.49533 .38231 m .65332 .51529 L .48956 .39404 L .493 .669 .942 r
F
.60502 .34245 m .67087 .4908 L .59473 .34051 L .716 .748 .877 r
F
.66861 .49675 m .67797 .50176 L .66373 .50958 L .493 .669 .942 r
F
.57921 .43717 m .61616 .46134 L .56617 .44194 L F
.61616 .46134 m .62058 .46899 L .56617 .44194 L F
.65094 .48408 m .6549 .48942 L .56617 .44194 L F
.56617 .44194 m .66861 .49675 L .65332 .51529 L F
.50387 .38951 m .57921 .43717 L .56617 .44194 L F
.49533 .38231 m .5063 .38949 L .50387 .38951 L F
.5063 .38949 m .57921 .43717 L .50387 .38951 L F
.57164 .33279 m .57447 .38912 L .56004 .32874 L .962 .828 .665 r
F
.50022 .36986 m .67797 .50176 L .49533 .38231 L .093 .483 .896 r
F
.52988 .39187 m .575 .42121 L .57798 .42756 L F
.53944 .3968 m .59944 .43709 L .52988 .39187 L F
.51182 .37769 m .59885 .43642 L .50857 .37606 L F
.59885 .43642 m .59944 .43709 L .50857 .37606 L F
.57798 .42756 m .59944 .43709 L .61524 .45522 L F
.575 .42121 m .59944 .43709 L .57798 .42756 L F
.59523 .42593 m .61763 .44298 L .59877 .43124 L .697 .161 0 r
F
.67087 .4908 m .67047 .49184 L .59473 .34051 L .716 .748 .877 r
F
.61763 .44298 m .62897 .45161 L .61745 .44897 L .697 .161 0 r
F
.62739 .45568 m .6282 .45642 L .61817 .44968 L .093 .483 .896 r
F
.62897 .45161 m .67304 .49697 L .62739 .45568 L .798 .772 .829 r
F
.6383 .42758 m .6603 .47152 L .62897 .45161 L F
.6603 .47152 m .67304 .49697 L .62897 .45161 L F
.61763 .44298 m .61745 .44897 L .50022 .36986 L .697 .161 0 r
F
.61182 .4396 m .61329 .44491 L .60972 .43837 L .875 .798 .771 r
F
.50531 .35748 m .59523 .42593 L .50022 .36986 L .697 .161 0 r
F
.59523 .42593 m .59877 .43124 L .50022 .36986 L F
.57259 .40935 m .58622 .42264 L .59514 .42673 L F
.51409 .36424 m .57077 .4102 L .57259 .40935 L F
.5189 .36842 m .57077 .4102 L .51409 .36424 L F
.57084 .41016 m .58622 .42264 L .57259 .40935 L F
.57077 .4102 m .57295 .41195 L .57084 .41016 L F
.57295 .41195 m .58622 .42264 L .57084 .41016 L F
.58622 .42264 m .59539 .43002 L .59514 .42673 L F
.57591 .4179 m .6029 .54408 L .58283 .55576 L .962 .828 .665 r
F
.57313 .4091 m .596 .42713 L .59523 .42593 L .697 .161 0 r
F
.57259 .40935 m .59514 .42673 L .57313 .4091 L F
.59514 .42673 m .61182 .4396 L .596 .42713 L F
.59514 .42673 m .596 .42713 L .57313 .4091 L F
.596 .42713 m .61182 .4396 L .59755 .42784 L F
.596 .42713 m .59755 .42784 L .59523 .42593 L F
.50531 .35748 m .57259 .40935 L .57313 .4091 L F
.50531 .35748 m .5189 .36842 L .51409 .36424 L F
.59514 .42673 m .59539 .43002 L .61182 .4396 L F
.59523 .42593 m .61182 .4396 L .61763 .44298 L F
.61524 .45522 m .63577 .4669 L .65083 .48162 L .093 .483 .896 r
F
.61745 .44897 m .62739 .45568 L .61817 .44968 L F
.62897 .45161 m .62739 .45568 L .61745 .44897 L .697 .161 0 r
F
.61779 .44451 m .61847 .44761 L .61333 .44084 L .798 .772 .829 r
F
.60499 .44056 m .61745 .44897 L .60358 .43982 L .093 .483 .896 r
F
.61745 .44897 m .61817 .44968 L .60324 .43964 L F
.60358 .43982 m .60324 .43964 L .59944 .43709 L F
.61745 .44897 m .60324 .43964 L .60358 .43982 L F
.59944 .43709 m .6282 .45642 L .61524 .45522 L F
.51146 .34604 m .59119 .41786 L .50531 .35748 L .855 .506 .39 r
F
.65407 .44671 m .72343 .48866 L .68283 .50516 L .716 .748 .877 r
F
.65083 .48162 m .65964 .48518 L .67212 .49647 L .093 .483 .896 r
F
.66737 .49389 m .67212 .49647 L .67797 .50176 L F
.65083 .48162 m .67212 .49647 L .66737 .49389 L F
.67087 .4908 m .67379 .49738 L .67047 .49184 L .716 .748 .877 r
F
.67379 .49738 m .67304 .49697 L .67047 .49184 L F
.65964 .48518 m .67855 .50148 L .67797 .50176 L .093 .483 .896 r
F
.65094 .48408 m .67797 .50176 L .6549 .48942 L .493 .669 .942 r
F
.67379 .49738 m .6781 .50708 L .67304 .49697 L .716 .748 .877 r
F
.67379 .49738 m .68283 .50516 L .6781 .50708 L F
.6258 .38926 m .68283 .50516 L .67379 .49738 L F
.65964 .48518 m .68825 .49675 L .67855 .50148 L .093 .483 .896 r
F
.6282 .45642 m .68825 .49675 L .6466 .47305 L F
.6282 .45642 m .6466 .47305 L .61524 .45522 L F
.61329 .44491 m .60123 .43311 L .59722 .42231 L .875 .798 .771 r
F
.61329 .44491 m .59722 .42231 L .59814 .42241 L F
.61329 .44491 m .59618 .4195 L .59657 .41436 L F
.59119 .41786 m .59598 .42217 L .58581 .4223 L .855 .506 .39 r
F
.59119 .41786 m .59441 .422 L .59598 .42217 L F
.59598 .42217 m .59581 .42438 L .58581 .4223 L F
.59581 .42438 m .59539 .43002 L .58581 .4223 L F
.59119 .41786 m .58581 .4223 L .50531 .35748 L F
.56834 .41132 m .58283 .55576 L .56684 .41202 L .938 .739 .265 r
F
.57591 .4179 m .58283 .55576 L .56834 .41132 L .962 .828 .665 r
F
.48956 .39404 m .57016 .45372 L .56673 .47958 L .648 .719 .9 r
F
.5666 .41367 m .58283 .55576 L .57787 .55973 L .938 .739 .265 r
F
.54779 .38062 m .56767 .40707 L .58295 .41408 L .855 .506 .39 r
F
.55167 .3897 m .56767 .40707 L .54779 .38062 L F
.51146 .34604 m .58295 .41408 L .58362 .41378 L F
.56091 .39058 m .58362 .41378 L .58566 .41288 L F
.51146 .34604 m .58362 .41378 L .56091 .39058 L F
.59152 .42361 m .58454 .42002 L .58362 .41378 L .875 .798 .771 r
F
.59152 .42361 m .58362 .41378 L .59103 .42135 L F
.58362 .41378 m .58454 .42002 L .58265 .41421 L .962 .828 .665 r
F
.58983 .42012 m .59441 .422 L .59119 .41786 L .855 .506 .39 r
F
.59134 .42167 m .59152 .42361 L .59103 .42135 L .875 .798 .771 r
F
.58905 .42142 m .59134 .42167 L .58983 .42012 L .855 .506 .39 r
F
.59134 .42167 m .59441 .422 L .58983 .42012 L F
.58295 .41408 m .58905 .42142 L .59119 .41786 L F
.58566 .41288 m .58362 .41378 L .59119 .41786 L F
.58362 .41378 m .58295 .41408 L .5847 .41488 L F
.58362 .41378 m .5847 .41488 L .59119 .41786 L F
.58335 .33707 m .59134 .42167 L .57164 .33279 L .875 .798 .771 r
F
.59134 .42167 m .59103 .42135 L .57164 .33279 L F
.58942 .4013 m .59618 .4195 L .59346 .4219 L F
.59134 .42167 m .59346 .4219 L .59152 .42361 L F
.58942 .4013 m .59346 .4219 L .59134 .42167 L F
.59618 .4195 m .60123 .43311 L .59557 .42757 L F
.59618 .4195 m .59557 .42757 L .59152 .42361 L F
.61513 .44587 m .61329 .44491 L .61182 .4396 L .798 .772 .829 r
F
.61513 .44587 m .61182 .4396 L .61333 .44084 L F
.59885 .43642 m .60499 .44056 L .59944 .43709 L .093 .483 .896 r
F
.60499 .44056 m .60358 .43982 L .59944 .43709 L F
.61616 .46134 m .65094 .48408 L .62058 .46899 L .493 .669 .942 r
F
.61329 .44491 m .63603 .52677 L .60138 .43351 L .875 .798 .771 r
F
.60204 .43389 m .60138 .43351 L .60123 .43311 L F
.61329 .44491 m .60138 .43351 L .60204 .43389 L F
.60123 .43311 m .63603 .52677 L .59152 .42361 L F
.59539 .43002 m .59695 .43127 L .6122 .43991 L .697 .161 0 r
F
.61182 .4396 m .6122 .43991 L .61763 .44298 L F
.59539 .43002 m .6122 .43991 L .61182 .4396 L F
.61763 .44298 m .6122 .43991 L .62897 .45161 L F
.61847 .44761 m .61513 .44587 L .61333 .44084 L .798 .772 .829 r
F
.6122 .43991 m .59695 .43127 L .61779 .44451 L .697 .161 0 r
F
.6122 .43991 m .61779 .44451 L .62897 .45161 L F
.61333 .44084 m .61182 .4396 L .6082 .42658 L .798 .772 .829 r
F
.59921 .42508 m .59695 .43127 L .59539 .43002 L .855 .506 .39 r
F
.59921 .42508 m .59539 .43002 L .59581 .42438 L F
.59585 .42386 m .59634 .42449 L .59581 .42438 L F
.59598 .42217 m .59634 .42449 L .59585 .42386 L F
.59598 .42217 m .59921 .42508 L .59634 .42449 L F
.61019 .39503 m .6383 .42758 L .63471 .43682 L .798 .772 .829 r
F
.62073 .4322 m .63471 .43682 L .62739 .45568 L F
.61019 .39503 m .63471 .43682 L .62073 .4322 L F
.61847 .44761 m .62739 .45568 L .62285 .46735 L F
.59473 .34051 m .62739 .45568 L .61847 .44761 L F
.62285 .46735 m .61329 .44491 L .61513 .44587 L F
.61847 .44761 m .62285 .46735 L .61513 .44587 L F
.63577 .4669 m .68825 .49675 L .65083 .48162 L .093 .483 .896 r
F
.66861 .49675 m .66373 .50958 L .65332 .51529 L .493 .669 .942 r
F
.62739 .45568 m .6781 .50708 L .62285 .46735 L .798 .772 .829 r
F
.67304 .49697 m .6781 .50708 L .62739 .45568 L F
.62739 .45568 m .68825 .49675 L .6282 .45642 L .093 .483 .896 r
F
.62897 .45161 m .68825 .49675 L .62739 .45568 L .697 .161 0 r
F
.59695 .43127 m .68314 .50069 L .62897 .45161 L F
.59921 .42508 m .61435 .44529 L .59695 .43127 L .855 .506 .39 r
F
.61002 .42591 m .61779 .44451 L .6082 .42658 L .798 .772 .829 r
F
.61339 .42468 m .61461 .43017 L .61002 .42591 L F
.61461 .43017 m .61779 .44451 L .61002 .42591 L F
.61779 .44451 m .61333 .44084 L .6082 .42658 L F
.6082 .42658 m .61182 .4396 L .58942 .4013 L .875 .798 .771 r
F
.61182 .4396 m .60972 .43837 L .58942 .4013 L F
.62285 .46735 m .6781 .50708 L .63603 .52677 L .798 .772 .829 r
F
.59921 .42508 m .66453 .51223 L .68314 .50069 L .855 .506 .39 r
F
.59598 .42217 m .59785 .42463 L .59921 .42508 L F
.62285 .46735 m .61716 .45881 L .61329 .44491 L .798 .772 .829 r
F
.59785 .42463 m .66453 .51223 L .59921 .42508 L .855 .506 .39 r
F
.59152 .42361 m .59194 .42801 L .58454 .42002 L .875 .798 .771 r
F
.59152 .42361 m .61647 .48145 L .6029 .54408 L F
.58905 .42142 m .66453 .51223 L .59441 .422 L .855 .506 .39 r
F
.56819 .40731 m .57668 .41685 L .58295 .41408 L F
.56767 .40707 m .56815 .40759 L .56819 .40731 L F
.56815 .40759 m .57668 .41685 L .56819 .40731 L F
.57934 .41568 m .5801 .41982 L .57841 .41609 L .962 .828 .665 r
F
.5801 .41982 m .6029 .54408 L .57731 .41854 L F
.51905 .33651 m .57647 .40587 L .51146 .34604 L .794 .565 .591 r
F
.5801 .41982 m .57731 .41854 L .57665 .4153 L .962 .828 .665 r
F
.5801 .41982 m .57665 .4153 L .57659 .41206 L F
.51146 .34604 m .55167 .3897 L .54779 .38062 L .855 .506 .39 r
F
.57647 .40587 m .57668 .41685 L .51146 .34604 L .794 .565 .591 r
F
.5755 .40964 m .57731 .41854 L .57591 .4179 L .962 .828 .665 r
F
.59194 .42801 m .6029 .54408 L .58484 .422 L .875 .798 .771 r
F
.59194 .42801 m .58484 .422 L .58454 .42002 L F
.58454 .42002 m .58484 .422 L .57896 .41361 L .962 .828 .665 r
F
.58484 .422 m .6029 .54408 L .5801 .41982 L F
.58484 .422 m .5801 .41982 L .57896 .41361 L F
.62285 .46735 m .63603 .52677 L .61716 .45881 L .798 .772 .829 r
F
.58454 .42002 m .57896 .41361 L .57447 .38912 L .962 .828 .665 r
F
.57668 .41685 m .66453 .51223 L .58295 .41408 L .855 .506 .39 r
F
.58362 .41378 m .58265 .41421 L .57863 .4019 L .962 .828 .665 r
F
.57896 .41361 m .57934 .41568 L .5755 .40964 L F
.57934 .41568 m .57841 .41609 L .5755 .40964 L F
.5755 .40964 m .56778 .40577 L .56689 .39693 L F
.5755 .40964 m .56689 .39693 L .57362 .40554 L F
.56694 .39435 m .57123 .40248 L .57647 .40587 L .794 .565 .591 r
F
.5754 .40783 m .5755 .40964 L .57362 .40554 L .962 .828 .665 r
F
.57123 .40248 m .57472 .40909 L .5754 .40783 L .794 .565 .591 r
F
.57123 .40248 m .5754 .40783 L .57647 .40587 L F
.57447 .38912 m .5754 .40783 L .56611 .38917 L .962 .828 .665 r
F
.5754 .40783 m .57362 .40554 L .56611 .38917 L F
.57447 .38912 m .57896 .41361 L .5755 .40964 L F
.57647 .40587 m .66453 .51223 L .57668 .41685 L .794 .565 .591 r
F
.57659 .41206 m .57665 .4153 L .5755 .40964 L .962 .828 .665 r
F
.55052 .37452 m .55179 .3776 L .56694 .39435 L .794 .565 .591 r
F
.55179 .3776 m .5666 .41341 L .56689 .39693 L F
.55179 .3776 m .56689 .39693 L .56694 .39435 L F
.56778 .40577 m .56804 .40834 L .56568 .40132 L .938 .739 .265 r
F
.51905 .33651 m .55771 .39903 L .55052 .37452 L .794 .565 .591 r
F
.55771 .39903 m .5666 .41341 L .55052 .37452 L F
.56538 .39742 m .5666 .41341 L .51905 .33651 L .699 .55 .681 r
F
.56567 .40128 m .56568 .40132 L .56564 .4012 L .938 .739 .265 r
F
.56778 .40577 m .56568 .40132 L .56567 .40128 L F
.52802 .32975 m .56538 .39742 L .51905 .33651 L .699 .55 .681 r
F
.57731 .41854 m .6029 .54408 L .57591 .4179 L .962 .828 .665 r
F
.5755 .40964 m .57591 .4179 L .56778 .40577 L F
.61647 .48145 m .63603 .52677 L .61478 .53787 L .875 .798 .771 r
F
.61647 .48145 m .61478 .53787 L .6029 .54408 L F
.56541 .3982 m .56778 .40577 L .56564 .4012 L .938 .739 .265 r
F
.55517 .37892 m .55562 .38097 L .56538 .39742 L .699 .55 .681 r
F
.56541 .3982 m .57787 .55973 L .55562 .38097 L .938 .739 .265 r
F
.55562 .38097 m .56644 .43009 L .56541 .3982 L .699 .55 .681 r
F
.55562 .38097 m .56541 .3982 L .56538 .39742 L F
.56541 .3982 m .55562 .38097 L .5488 .32619 L .938 .739 .265 r
F
.56481 .42045 m .57787 .55973 L .56644 .43009 L .065 .119 .609 r
F
.56661 .41325 m .58283 .55576 L .5666 .41367 L .938 .739 .265 r
F
.56684 .41202 m .58283 .55576 L .56649 .41218 L F
.56644 .43009 m .57787 .55973 L .58773 .55539 L .065 .119 .609 r
F
.55878 .40634 m .57787 .55973 L .56481 .42045 L F
.56644 .43009 m .58773 .55539 L .55308 .39565 L F
.55562 .38097 m .55798 .39994 L .56337 .41612 L F
.55798 .39994 m .55878 .40634 L .56224 .41443 L F
.55798 .39994 m .56224 .41443 L .56481 .42045 L F
.52802 .32975 m .56652 .43043 L .55517 .37892 L .699 .55 .681 r
F
.5488 .32619 m .55562 .38097 L .56481 .42045 L .065 .119 .609 r
F
.55562 .38097 m .56337 .41612 L .56481 .42045 L F
.5488 .32619 m .56644 .43009 L .53805 .32631 L F
.52802 .32975 m .56654 .43103 L .56652 .43043 L .699 .55 .681 r
F
.56644 .43009 m .55308 .39565 L .53805 .32631 L .065 .119 .609 r
F
.56644 .43009 m .56652 .43043 L .56651 .43027 L .699 .55 .681 r
F
.56644 .43009 m .56651 .43027 L .56541 .3982 L F
.56004 .32874 m .56541 .3982 L .5488 .32619 L .938 .739 .265 r
F
.56004 .32874 m .56456 .37371 L .56541 .3982 L F
.56456 .37371 m .56778 .40577 L .56541 .3982 L F
.56804 .40834 m .56834 .41132 L .56786 .40953 L F
.56804 .40834 m .56786 .40953 L .56564 .4012 L F
.56834 .41132 m .56684 .41202 L .56564 .4012 L F
.57591 .4179 m .56834 .41132 L .56778 .40577 L .962 .828 .665 r
F
.56564 .4012 m .56684 .41202 L .56649 .41218 L .938 .739 .265 r
F
.56538 .39742 m .63753 .52811 L .5666 .41341 L .699 .55 .681 r
F
.56538 .39742 m .60947 .54389 L .63753 .52811 L F
.56649 .41218 m .56661 .41325 L .5666 .41367 L .938 .739 .265 r
F
.56654 .43103 m .60947 .54389 L .56538 .39742 L .699 .55 .681 r
F
.56684 .40006 m .63753 .52811 L .56694 .39435 L .794 .565 .591 r
F
.57362 .40554 m .56689 .39693 L .56611 .38917 L .962 .828 .665 r
F
.58187 .40195 m .58362 .41378 L .57863 .4019 L F
.58019 .39904 m .57863 .4019 L .57447 .38912 L F
.58187 .40195 m .57863 .4019 L .58019 .39904 L F
.57647 .40587 m .63753 .52811 L .66453 .51223 L .794 .565 .591 r
F
.57472 .40909 m .63753 .52811 L .57647 .40587 L F
.59103 .42135 m .58362 .41378 L .57164 .33279 L .875 .798 .771 r
F
.59441 .422 m .66453 .51223 L .59598 .42217 L .855 .506 .39 r
F
.59814 .42241 m .59722 .42231 L .59618 .4195 L .875 .798 .771 r
F
.59657 .41436 m .59618 .4195 L .58942 .4013 L F
.59473 .34051 m .61518 .38137 L .61019 .39503 L .798 .772 .829 r
F
.61518 .38137 m .6383 .42758 L .61019 .39503 L F
.6258 .38926 m .70533 .47023 L .65407 .44671 L .716 .748 .877 r
F
.70533 .47023 m .72343 .48866 L .65407 .44671 L F
.60502 .34245 m .63606 .38078 L .6258 .38926 L F
.63606 .38078 m .72343 .48866 L .6258 .38926 L F
.62897 .45161 m .63978 .46141 L .68825 .49675 L .697 .161 0 r
F
.63978 .46141 m .68314 .50069 L .68825 .49675 L F
.50857 .37606 m .53944 .3968 L .52988 .39187 L .093 .483 .896 r
F
.50022 .36986 m .51182 .37769 L .50857 .37606 L F
.57447 .38912 m .56611 .38917 L .56004 .32874 L .962 .828 .665 r
F
.57164 .33279 m .58187 .40195 L .57447 .38912 L F
.58335 .33707 m .6082 .42658 L .58942 .4013 L .875 .798 .771 r
F
.59473 .34051 m .61339 .42468 L .58491 .34269 L .798 .772 .829 r
F
.61339 .42468 m .6082 .42658 L .58491 .34269 L F
.58557 .33774 m .58491 .34269 L .58335 .33707 L F
.59473 .34051 m .58491 .34269 L .58557 .33774 L F
.25 g
.474 .41518 m
.49686 .44829 L
s
.49686 .44829 m
.53644 .5056 L
s
.53644 .5056 m
.57465 .56092 L
s
1 0 0 r
.003 w
.60163 .54503 m
.60605 .54243 L
s
.57465 .56092 m
.57779 .55907 L
s
.58739 .55342 m
.60163 .54503 L
s
.25 g
.5 Mabswid
.48947 .48862 m
.51768 .55704 L
s
.48202 .40438 m
.48991 .41204 L
s
.48991 .41204 m
.53626 .45701 L
s
.53626 .45701 m
.56894 .48872 L
s
.56894 .48872 m
.56905 .48883 L
s
.45861 .47098 m
.46069 .48025 L
s
.46069 .48025 m
.47083 .52534 L
s
.44769 .42243 m
.45861 .47098 L
s
.50554 .40587 m
.53598 .42841 L
s
.53598 .42841 m
.56412 .44924 L
s
.49193 .3958 m
.50554 .40587 L
s
.49001 .39437 m
.49193 .3958 L
s
.48956 .39404 m
.49001 .39437 L
s
.42373 .59841 m
.4385 .61402 L
s
.32079 .50719 m .41748 .66705 L .3792 .7019 L .879 .781 .749 r
F
.32578 .49479 m .41748 .66705 L .32079 .50719 L .822 .762 .796 r
F
.25 g
.41192 .58591 m
.42373 .59841 L
s
1 0 0 r
.003 w
.41748 .66705 m
.44371 .64435 L
s
.25 g
.5 Mabswid
.32578 .49479 m
.32647 .49553 L
s
.41707 .54772 m
.4286 .55645 L
s
.3296 .48153 m
.33099 .48258 L
s
.33099 .48258 m
.35447 .50035 L
s
.38758 .52541 m
.38871 .52626 L
s
.38871 .52626 m
.41707 .54772 L
s
.35447 .50035 m
.35647 .50187 L
s
.35647 .50187 m
.35916 .5039 L
s
.43391 .42371 m
.43424 .42628 L
s
.43424 .42628 m
.43513 .4332 L
s
.43513 .4332 m
.44057 .47561 L
s
.44057 .47561 m
.44267 .49199 L
s
.44267 .49199 m
.44432 .50487 L
s
.67685 .50459 m
.6781 .50708 L
s
1 0 0 r
.003 w
.65452 .51812 m
.6781 .50708 L
s
.6781 .50708 m
.68283 .50516 L
s
.68283 .50516 m
.69983 .49825 L
s
.25 g
.5 Mabswid
.54528 .41498 m
.55926 .42412 L
s
.51009 .39197 m
.54528 .41498 L
s
.49957 .38509 m
.51009 .39197 L
s
.49787 .38398 m
.49957 .38509 L
s
.49533 .38231 m
.49787 .38398 L
s
.61339 .34251 m .72343 .48866 L .60502 .34245 L .606 .717 .923 r
F
.61339 .34251 m .76552 .47477 L .72343 .48866 L F
.25 g
.6603 .47152 m
.66349 .4779 L
s
1 0 0 r
.003 w
.69983 .49825 m
.72343 .48866 L
s
.25 g
.5 Mabswid
.71039 .47255 m
.72343 .48866 L
s
.6082 .42658 m
.61065 .43539 L
s
.59833 .39101 m
.60097 .40051 L
s
.60097 .40051 m
.60733 .42341 L
s
.60733 .42341 m
.6082 .42658 L
s
1 0 0 r
.003 w
.6029 .54408 m
.60844 .54118 L
s
.31424 .51784 m .3792 .7019 L .34712 .7335 L .938 .802 .683 r
F
.25 g
.5 Mabswid
.32647 .49553 m
.32884 .49803 L
s
.32079 .50719 m .3792 .7019 L .31424 .51784 L .879 .781 .749 r
F
.25 g
.3733 .54506 m
.41192 .58591 L
s
.32167 .50864 m
.3223 .50968 L
s
.37258 .59282 m
.41748 .66705 L
s
1 0 0 r
.003 w
.3792 .7019 m
.41748 .66705 L
s
.25 g
.5 Mabswid
.32079 .50719 m
.32167 .50864 L
s
.41303 .51788 m
.4176 .52073 L
s
.4176 .52073 m
.4219 .5234 L
s
.33322 .46822 m
.33478 .46919 L
s
.38622 .5012 m
.41303 .51788 L
s
.59868 .51552 m
.6029 .54408 L
s
.58187 .40195 m
.58362 .41378 L
s
.58117 .39724 m
.58187 .40195 L
s
1 0 0 r
.003 w
.58734 .55314 m
.6029 .54408 L
s
.61916 .34051 m .76552 .47477 L .61339 .34251 L .412 .649 .955 r
F
.25 g
.5 Mabswid
.61561 .34444 m
.6183 .34678 L
s
.61339 .34251 m
.61561 .34444 L
s
.61916 .34051 m .798 .46772 L .76552 .47477 L .412 .649 .955 r
F
.25 g
.6383 .42758 m
.64456 .44007 L
s
.64456 .44007 m
.6603 .47152 L
s
.67056 .42337 m
.71039 .47255 L
s
1 0 0 r
.003 w
.72343 .48866 m
.76552 .47477 L
s
.25 g
.5 Mabswid
.72278 .43762 m
.76552 .47477 L
s
.41979 .4233 m
.42096 .43362 L
s
.42096 .43362 m
.42351 .45615 L
s
.42351 .45615 m
.42544 .47315 L
s
.42544 .47315 m
.42738 .49029 L
s
.4054 .49627 m
.41556 .50239 L
s
.3378 .45553 m
.34007 .45689 L
s
1 0 0 r
.003 w
.53364 .57356 m
.53524 .57509 L
s
.25 g
.5 Mabswid
.54057 .39709 m
.54314 .39883 L
s
.54314 .39883 m
.5556 .40723 L
s
.51417 .37928 m
.54057 .39709 L
s
.50564 .37352 m
.51417 .37928 L
s
.50391 .37235 m
.50564 .37352 L
s
.50022 .36986 m
.50391 .37235 L
s
1 0 0 r
.003 w
.68314 .50069 m
.68825 .49675 L
s
.22883 .53932 m .26203 .56829 L .23157 .5477 L .732 .752 .868 r
F
.23157 .5477 m .25761 .5811 L .23606 .55721 L .827 .768 .796 r
F
.31864 .64325 m .34712 .7335 L .33176 .75138 L .994 .813 .553 r
F
.32802 .65279 m .34712 .7335 L .31864 .64325 L F
.31116 .58161 m .33176 .75138 L .32434 .73191 L F
.31758 .58335 m .34712 .7335 L .31116 .58161 L F
.31424 .51784 m .34712 .7335 L .30628 .5259 L .938 .802 .683 r
F
.31916 .72986 m .32658 .75742 L .32336 .76523 L .898 .681 .17 r
F
.30792 .63518 m .32398 .74038 L .31916 .72986 L F
.32398 .74038 m .32658 .75742 L .31916 .72986 L F
.30792 .63518 m .32336 .76523 L .31766 .73124 L F
.31064 .63384 m .32658 .75742 L .30792 .63518 L F
.32434 .73191 m .33176 .75138 L .32658 .75742 L .994 .813 .553 r
F
.30628 .5259 m .32658 .75742 L .29735 .53084 L F
.32029 .7314 m .36216 .71524 L .33043 .75238 L .897 .783 .728 r
F
.31766 .73124 m .32336 .76523 L .32155 .76964 L .898 .681 .17 r
F
.29735 .53084 m .32155 .76964 L .28788 .53261 L F
.31636 .72367 m .32155 .76964 L .32318 .76939 L 0 0 .508 r
F
.30175 .62765 m .3145 .71999 L .31552 .722 L F
.29965 .61331 m .30121 .62649 L .30175 .62765 L F
.29384 .57348 m .29947 .61395 L .29965 .61331 L F
.29947 .61395 m .30121 .62649 L .29965 .61331 L F
.31116 .58161 m .32802 .65279 L .31864 .64325 L .994 .813 .553 r
F
.29214 .56185 m .29361 .57293 L .29384 .57348 L 0 0 .508 r
F
.28788 .53261 m .29202 .56176 L .29214 .56185 L F
.29202 .56176 m .29361 .57293 L .29214 .56185 L F
.33859 .60134 m .44029 .65348 L .42943 .65878 L .513 .704 .957 r
F
.29361 .57293 m .30121 .62649 L .29384 .57348 L 0 0 .508 r
F
.30741 .6636 m .31552 .722 L .31532 .71667 L F
.28939 .54272 m .30732 .66586 L .30741 .6636 L F
.28934 .54261 m .30732 .66586 L .28939 .54272 L F
.28788 .53261 m .28934 .54261 L .28939 .54272 L F
.30121 .62649 m .3145 .71999 L .30175 .62765 L F
.32029 .7314 m .33043 .75238 L .32074 .73229 L .897 .783 .728 r
F
.30832 .6394 m .31531 .71643 L .31346 .66621 L 0 0 .508 r
F
.28842 .53542 m .30742 .66332 L .30832 .6394 L F
.30742 .66332 m .31531 .71643 L .30832 .6394 L F
.28813 .5343 m .32318 .76939 L .28842 .53542 L F
.31346 .66621 m .32318 .76939 L .31925 .71779 L F
.31454 .67186 m .31925 .71779 L .31656 .6824 L F
.31346 .66621 m .31925 .71779 L .31454 .67186 L F
.31531 .71643 m .32318 .76939 L .31346 .66621 L F
.30732 .66586 m .31552 .722 L .30741 .6636 L F
.31532 .71667 m .31552 .722 L .31636 .72367 L F
.31184 .71393 m .31656 .6824 L .32029 .7314 L .897 .783 .728 r
F
.28901 .66672 m .31253 .68011 L .31184 .71393 L F
.31253 .68011 m .31656 .6824 L .31184 .71393 L F
.31223 .63293 m .39445 .68387 L .31261 .64333 L .827 .768 .796 r
F
.28788 .53261 m .28813 .5343 L .28842 .53542 L 0 0 .508 r
F
.28788 .53261 m .29874 .58934 L .27806 .53174 L F
.31005 .6484 m .31656 .6824 L .30927 .6539 L F
.31656 .6824 m .31253 .68011 L .27806 .53174 L F
.30175 .63372 m .3082 .66148 L .31005 .64838 L .384 .356 .704 r
F
.30202 .63808 m .31005 .64838 L .30099 .63858 L .827 .768 .796 r
F
.31005 .64838 m .31293 .65208 L .31074 .6496 L F
.31447 .61701 m .39445 .68387 L .31223 .63293 L F
.29735 .53084 m .31064 .63384 L .30792 .63518 L .898 .681 .17 r
F
.27821 .53216 m .30175 .63372 L .31284 .62861 L .384 .356 .704 r
F
.27806 .53174 m .27811 .53197 L .27821 .53216 L F
.27811 .53197 m .30175 .63372 L .27821 .53216 L F
.27557 .5419 m .28408 .56463 L .27324 .54103 L F
.28265 .54454 m .28408 .56463 L .27557 .5419 L F
.28265 .54454 m .31062 .62243 L .28408 .56463 L F
.31062 .62243 m .31136 .62535 L .27324 .54103 L F
.28265 .54454 m .27324 .54103 L .26792 .52926 L F
.31284 .62861 m .30556 .62327 L .26792 .52926 L F
.30175 .63372 m .31005 .64838 L .31284 .62861 L F
.31062 .62243 m .31284 .62861 L .31136 .62535 L F
.31155 .61456 m .31261 .64333 L .30202 .63808 L .827 .768 .796 r
F
.30944 .60968 m .42204 .66238 L .39445 .68387 L .732 .752 .868 r
F
.30979 .60063 m .31872 .60555 L .30944 .60968 L F
.31872 .60555 m .35519 .63109 L .30944 .60968 L F
.31275 .59812 m .42204 .66238 L .30979 .60063 L F
.26792 .52926 m .2902 .58491 L .31065 .5999 L .595 .493 .708 r
F
.2902 .58491 m .29987 .60906 L .30436 .60524 L F
.2902 .58491 m .30436 .60524 L .31065 .5999 L F
.26203 .56829 m .30436 .60524 L .25341 .56596 L .732 .752 .868 r
F
.30436 .60524 m .30944 .60968 L .30508 .60627 L F
.30663 .59708 m .30056 .59282 L .25758 .52651 L .595 .493 .708 r
F
.31872 .60555 m .42204 .66238 L .35519 .63109 L .732 .752 .868 r
F
.31015 .59111 m .42204 .66238 L .30994 .59647 L F
.30775 .58554 m .42204 .66238 L .31015 .59111 L .513 .704 .957 r
F
.30856 .58278 m .44029 .65348 L .30775 .58554 L F
.32307 .5864 m .44029 .65348 L .30856 .58278 L F
.26792 .52926 m .28285 .55395 L .25758 .52651 L .595 .493 .708 r
F
.30567 .59166 m .31065 .5999 L .30484 .59185 L F
.31065 .5999 m .30663 .59708 L .25758 .52651 L F
.30078 .58085 m .30056 .59282 L .30961 .59077 L .707 .546 .668 r
F
.27137 .54778 m .29126 .57848 L .30078 .58085 L F
.29126 .57848 m .30056 .59282 L .30078 .58085 L F
.30078 .58085 m .30856 .58278 L .30775 .58554 L .513 .704 .957 r
F
.25758 .52651 m .27137 .54778 L .31554 .58942 L .707 .546 .668 r
F
.30078 .58085 m .30775 .58554 L .3019 .58211 L .513 .704 .957 r
F
.30775 .58554 m .31015 .59111 L .30961 .59077 L F
.3019 .58211 m .30961 .59077 L .22883 .53932 L F
.30775 .58554 m .30961 .59077 L .3019 .58211 L F
.29883 .59322 m .29967 .59302 L .30979 .60063 L .732 .752 .868 r
F
.28388 .58114 m .30994 .59647 L .30984 .59932 L F
.28388 .58114 m .30984 .59932 L .30979 .60063 L F
.30436 .60524 m .30979 .60063 L .30944 .60968 L F
.26203 .56829 m .30979 .60063 L .30436 .60524 L F
.29987 .60906 m .30556 .62327 L .30827 .61085 L .595 .493 .708 r
F
.30944 .60968 m .30988 .61317 L .30508 .60627 L .732 .752 .868 r
F
.30436 .60524 m .30827 .61085 L .31065 .5999 L .595 .493 .708 r
F
.29987 .60906 m .30827 .61085 L .30436 .60524 L F
.30944 .60968 m .31155 .61456 L .30988 .61317 L .732 .752 .868 r
F
.31065 .5999 m .30827 .61085 L .31353 .60464 L .595 .493 .708 r
F
.30827 .61085 m .30556 .62327 L .30988 .61317 L F
.30944 .60968 m .39445 .68387 L .31155 .61456 L .732 .752 .868 r
F
.30827 .61085 m .30988 .61317 L .31353 .60464 L .595 .493 .708 r
F
.30508 .60627 m .30988 .61317 L .25341 .56596 L .732 .752 .868 r
F
.31293 .65208 m .36216 .71524 L .31451 .65552 L .827 .768 .796 r
F
.31293 .65208 m .38094 .6786 L .36216 .71524 L F
.38094 .6786 m .39172 .68652 L .36216 .71524 L F
.31261 .64333 m .39445 .68387 L .31293 .65208 L F
.31451 .65552 m .36216 .71524 L .32029 .7314 L .897 .783 .728 r
F
.31353 .60464 m .35734 .75259 L .38803 .7278 L .595 .493 .708 r
F
.3115 .63809 m .31276 .64125 L .31284 .62861 L .384 .356 .704 r
F
.31293 .65208 m .31451 .65552 L .31307 .65372 L .827 .768 .796 r
F
.3082 .66148 m .31084 .64978 L .31005 .64838 L .384 .356 .704 r
F
.31293 .65208 m .31307 .65372 L .31074 .6496 L .827 .768 .796 r
F
.30202 .63808 m .31261 .64333 L .31293 .65208 L F
.3082 .66148 m .31253 .68011 L .31276 .64125 L .384 .356 .704 r
F
.31284 .62861 m .31253 .68011 L .31354 .63056 L F
.31074 .6496 m .31307 .65372 L .30099 .63858 L .827 .768 .796 r
F
.31005 .64838 m .31276 .64125 L .3115 .63809 L .384 .356 .704 r
F
.31084 .64978 m .31276 .64125 L .31005 .64838 L F
.31155 .61456 m .31447 .61701 L .31223 .63293 L .827 .768 .796 r
F
.31354 .63056 m .33291 .76784 L .35734 .75259 L .384 .356 .704 r
F
.32074 .73229 m .33043 .75238 L .32379 .76206 L .961 .799 .636 r
F
.31656 .6824 m .32318 .76939 L .33291 .76784 L 0 0 .508 r
F
.31656 .6824 m .33291 .76784 L .31253 .68011 L F
.23606 .55721 m .31451 .65552 L .31656 .6824 L .897 .783 .728 r
F
.23606 .55721 m .31656 .6824 L .28901 .66672 L F
.31253 .68011 m .33291 .76784 L .31354 .63056 L .384 .356 .704 r
F
.29587 .60145 m .31155 .61456 L .30202 .63808 L .827 .768 .796 r
F
.31284 .62861 m .35734 .75259 L .30556 .62327 L .384 .356 .704 r
F
.30556 .62327 m .35734 .75259 L .31353 .60464 L .595 .493 .708 r
F
.3245 .62278 m .34134 .65575 L .30056 .59282 L F
.3245 .62278 m .30056 .59282 L .30663 .59708 L F
.30994 .59647 m .31275 .59812 L .30979 .60063 L .732 .752 .868 r
F
.31065 .5999 m .3245 .62278 L .30663 .59708 L .595 .493 .708 r
F
.3245 .62278 m .38803 .7278 L .34134 .65575 L F
.30056 .59282 m .38803 .7278 L .32575 .60891 L .707 .546 .668 r
F
.31015 .59111 m .30994 .59647 L .28388 .58114 L .732 .752 .868 r
F
.31015 .59111 m .28388 .58114 L .27289 .57344 L F
.25809 .55796 m .31015 .59111 L .26203 .56829 L F
.30775 .58554 m .33859 .60134 L .42204 .66238 L .513 .704 .957 r
F
.30961 .59077 m .32575 .60891 L .31554 .58942 L .707 .546 .668 r
F
.30056 .59282 m .32575 .60891 L .30961 .59077 L F
.27137 .54778 m .30961 .59077 L .31554 .58942 L F
.29102 .56281 m .30968 .58306 L .28292 .55797 L F
.30968 .58306 m .2951 .57385 L .24754 .5248 L F
.33859 .60134 m .42943 .65878 L .42204 .66238 L .513 .704 .957 r
F
.30628 .5259 m .31758 .58335 L .31116 .58161 L .994 .813 .553 r
F
.29789 .56735 m .44029 .65348 L .31484 .58169 L .431 0 0 r
F
.25758 .52651 m .29102 .56281 L .24754 .5248 L .707 .546 .668 r
F
.29102 .56281 m .28292 .55797 L .24754 .5248 L F
.31489 .57782 m .2951 .57385 L .32486 .58567 L .786 .554 .584 r
F
.29789 .56735 m .30797 .57355 L .30711 .57292 L .431 0 0 r
F
.30711 .57292 m .33764 .59163 L .44029 .65348 L F
.33764 .59163 m .4459 .65797 L .44259 .65532 L F
.33764 .59163 m .44259 .65532 L .44029 .65348 L F
.27529 .55341 m .2951 .57385 L .31489 .57782 L .786 .554 .584 r
F
.23224 .52763 m .29789 .56735 L .22887 .5325 L .431 0 0 r
F
.29789 .56735 m .31484 .58169 L .22887 .5325 L F
.32486 .58567 m .33643 .59997 L .4377 .67451 L .786 .554 .584 r
F
.29319 .57309 m .3095 .57957 L .30856 .58278 L .513 .704 .957 r
F
.22887 .5325 m .30856 .58278 L .30078 .58085 L F
.30973 .57877 m .32307 .5864 L .30856 .58278 L F
.38094 .6786 m .39445 .68387 L .39172 .68652 L .827 .768 .796 r
F
.31554 .58942 m .38803 .7278 L .41704 .6996 L .707 .546 .668 r
F
.30968 .58306 m .41704 .6996 L .2951 .57385 L F
.2951 .57385 m .41704 .6996 L .32486 .58567 L .786 .554 .584 r
F
.31489 .57782 m .4377 .67451 L .2842 .55919 L F
.3092 .57447 m .4459 .65797 L .30711 .57292 L .431 0 0 r
F
.2842 .55919 m .4377 .67451 L .4459 .65797 L .838 .475 .366 r
F
.31006 .5751 m .4459 .65797 L .3092 .57447 L .431 0 0 r
F
.24754 .5248 m .27529 .55341 L .31489 .57782 L .786 .554 .584 r
F
.24754 .5248 m .31489 .57782 L .23873 .52504 L F
.24097 .53291 m .31006 .5751 L .30797 .57355 L .431 0 0 r
F
.24097 .53291 m .30797 .57355 L .29789 .56735 L F
.31489 .57782 m .2842 .55919 L .23873 .52504 L .786 .554 .584 r
F
.23873 .52504 m .2842 .55919 L .33667 .59125 L .838 .475 .366 r
F
.31824 .57605 m .33667 .59125 L .4459 .65797 L F
.23873 .52504 m .33667 .59125 L .31824 .57605 L F
.33643 .59997 m .41704 .6996 L .43227 .68111 L .786 .554 .584 r
F
.33643 .59997 m .43227 .68111 L .4377 .67451 L F
.22887 .5325 m .30973 .57877 L .3095 .57957 L .513 .704 .957 r
F
.22887 .5325 m .3095 .57957 L .29319 .57309 L F
.22887 .5325 m .30078 .58085 L .22883 .53932 L F
.30078 .58085 m .3019 .58211 L .22883 .53932 L F
.26203 .56829 m .28388 .58114 L .29967 .59302 L .732 .752 .868 r
F
.26203 .56829 m .29967 .59302 L .29883 .59322 L F
.30436 .60524 m .30508 .60627 L .25341 .56596 L F
.27289 .57344 m .28388 .58114 L .26203 .56829 L F
.31005 .64838 m .31074 .6496 L .30099 .63858 L .827 .768 .796 r
F
.3145 .71999 m .32155 .76964 L .31636 .72367 L 0 0 .508 r
F
.3123 .71488 m .32029 .7314 L .31154 .71322 L .897 .783 .728 r
F
.32029 .7314 m .32074 .73229 L .31154 .71322 L F
.23606 .55721 m .2401 .56556 L .24111 .56724 L F
.2401 .56556 m .3123 .71488 L .24315 .57146 L F
.2401 .56556 m .24315 .57146 L .24111 .56724 L F
.3123 .71488 m .31154 .71322 L .24111 .56724 L F
.24111 .56724 m .32074 .73229 L .30449 .79021 L .961 .799 .636 r
F
.24111 .56724 m .30449 .79021 L .24581 .57686 L F
.24581 .57686 m .30449 .79021 L .2893 .82312 L .999 .786 .457 r
F
.24581 .57686 m .2893 .82312 L .24971 .58485 L F
.24971 .58485 m .2893 .82312 L .2891 .84541 L .805 .576 .015 r
F
.24971 .58485 m .2891 .84541 L .25287 .59029 L F
.252 .58862 m .25287 .59029 L .25282 .58996 L F
.24971 .58485 m .25287 .59029 L .252 .58862 L F
.32074 .73229 m .32379 .76206 L .30449 .79021 L .961 .799 .636 r
F
.27806 .53174 m .28265 .54454 L .26792 .52926 L .384 .356 .704 r
F
.23224 .52763 m .23745 .53081 L .24097 .53291 L .431 0 0 r
F
.23745 .53081 m .31006 .5751 L .24097 .53291 L F
.23157 .5477 m .29587 .60145 L .30202 .63808 L .827 .768 .796 r
F
.25761 .5811 m .30202 .63808 L .24437 .56762 L F
.30202 .63808 m .30099 .63858 L .24437 .56762 L F
.25761 .5811 m .24437 .56762 L .23606 .55721 L F
.22883 .53932 m .25809 .55796 L .26203 .56829 L .732 .752 .868 r
F
.26203 .56829 m .25341 .56596 L .23157 .5477 L F
.25 g
.5 Mabswid
.30725 .53083 m
.30731 .53116 L
s
.30731 .53116 m
.30743 .53175 L
s
.30743 .53175 m
.30774 .53336 L
s
.30774 .53336 m
.30831 .53625 L
s
.30831 .53625 m
.30847 .53703 L
s
.30847 .53703 m
.30872 .53831 L
s
.30872 .53831 m
.31041 .5469 L
s
.31041 .5469 m
.31584 .57452 L
s
.30628 .5259 m
.30725 .53083 L
s
.31565 .52183 m
.3175 .52707 L
s
.3175 .52707 m
.32603 .55124 L
s
.32603 .55124 m
.3391 .58827 L
s
.3391 .58827 m
.33963 .58978 L
s
.33703 .53403 m
.33862 .53667 L
s
.33862 .53667 m
.35438 .56272 L
s
.35438 .56272 m
.37258 .59282 L
s
.3223 .50968 m
.33703 .53403 L
s
.32884 .49803 m
.33288 .50231 L
s
.33288 .50231 m
.35586 .52661 L
s
.31451 .51861 m
.31565 .52183 L
s
.31424 .51784 m
.31451 .51861 L
s
.57167 .4445 m
.57568 .48444 L
s
0 g
.006 w
.44769 .42243 m
.4607 .41884 L
s
.4607 .41884 m
.47234 .41278 L
s
.47234 .41278 m
.48202 .40438 L
s
.43391 .42371 m
.44769 .42243 L
s
.48202 .40438 m
.48956 .39404 L
s
.62212 .33638 m .798 .46772 L .61916 .34051 L 0 .425 .853 r
F
.25 g
.5 Mabswid
.6183 .34678 m
.61877 .34718 L
s
.62212 .33638 m .81564 .46855 L .798 .46772 L 0 .425 .853 r
F
.25 g
.61518 .38137 m
.62819 .40737 L
s
.62882 .40862 m
.6383 .42758 L
s
.62819 .40737 m
.62882 .40862 L
s
.63363 .37778 m
.66821 .42047 L
s
.66821 .42047 m
.67056 .42337 L
s
.6638 .38634 m
.72278 .43762 L
s
1 0 0 r
.003 w
.76552 .47477 m
.798 .46772 L
s
0 g
.006 w
.41979 .4233 m
.43391 .42371 L
s
.25 g
.5 Mabswid
.42427 .53126 m
.42733 .54906 L
s
.42733 .54906 m
.43624 .60088 L
s
.43624 .60088 m
.43672 .60371 L
s
.43672 .60371 m
.44455 .64922 L
s
1 0 0 r
.003 w
.44455 .64922 m
.45732 .64088 L
s
.25 g
.5 Mabswid
.34433 .44409 m
.3451 .44461 L
s
1 0 0 r
.003 w
.524 .5867 m
.53524 .57509 L
s
0 g
.006 w
.48956 .39404 m
.49533 .38231 L
s
.40553 .42225 m
.41979 .4233 L
s
.49533 .38231 m
.50022 .36986 L
s
.39128 .42186 m
.40553 .42225 L
s
.25 g
.5 Mabswid
.50531 .35748 m
.50682 .35869 L
s
.50682 .35869 m
.5189 .36842 L
s
.5189 .36842 m
.54703 .39107 L
s
.54703 .39107 m
.55316 .39601 L
s
1 0 0 r
.003 w
.66453 .51223 m
.68314 .50069 L
s
0 g
.006 w
.50022 .36986 m
.50531 .35748 L
s
.25 g
.5 Mabswid
.45368 .6288 m
.45557 .63507 L
s
.45557 .63507 m
.45732 .64088 L
s
.37739 .42336 m .50338 .60487 L .36448 .42753 L .691 .543 .68 r
F
.25 g
.40738 .48277 m
.40989 .48775 L
s
.44401 .55537 m
.47897 .62466 L
s
.41096 .48988 m
.44401 .55537 L
s
.40989 .48775 m
.41096 .48988 L
s
0 g
.006 w
.37739 .42336 m
.39128 .42186 L
s
.25 g
.5 Mabswid
.41302 .49396 m
.41361 .49589 L
s
.41361 .49589 m
.4139 .49687 L
s
.43751 .57519 m
.45368 .6288 L
s
.4139 .49687 m
.43751 .57519 L
s
.3451 .44461 m
.38683 .47325 L
s
.39216 .47691 m
.40272 .48415 L
s
.40272 .48415 m
.41091 .48977 L
s
.38683 .47325 m
.39216 .47691 L
s
.37657 .47889 m
.38606 .48461 L
s
.34007 .45689 m
.37657 .47889 L
s
.38606 .48461 m
.4054 .49627 L
s
.37024 .49125 m
.38622 .5012 L
s
.33478 .46919 m
.37024 .49125 L
s
.35916 .5039 m
.38758 .52541 L
s
.35586 .52661 m
.3733 .54506 L
s
0 g
.006 w
.36448 .42753 m
.37739 .42336 L
s
.50531 .35748 m
.51146 .34604 L
s
.25 g
.5 Mabswid
.56828 .48271 m
.57787 .55973 L
s
.56333 .44288 m
.5668 .4708 L
s
.5668 .4708 m
.56828 .48271 L
s
.40926 .48471 m
.41615 .4935 L
s
.41615 .4935 m
.44628 .53197 L
s
.44628 .53197 m
.50338 .60487 L
s
.40218 .47567 m
.40926 .48471 L
s
.3682 .43228 m
.40218 .47567 L
s
.36448 .42753 m
.3682 .43228 L
s
0 g
.006 w
.35326 .43455 m
.36448 .42753 L
s
.25 g
.5 Mabswid
.29735 .53084 m
.29769 .53349 L
s
.29769 .53349 m
.29784 .53467 L
s
.29784 .53467 m
.29799 .53579 L
s
.29829 .53814 m
.29911 .54448 L
s
.29911 .54448 m
.30182 .56552 L
s
.29799 .53579 m
.298 .53589 L
s
.298 .53589 m
.29809 .53658 L
s
.29809 .53658 m
.29829 .53814 L
s
.51146 .34604 m
.51262 .3473 L
s
.51262 .3473 m
.54872 .3865 L
s
.54872 .3865 m
.55022 .38813 L
s
0 g
.006 w
.51146 .34604 m
.51905 .33651 L
s
.25 g
.5 Mabswid
.40132 .47738 m
.4086 .48387 L
s
.36853 .44815 m
.40132 .47738 L
s
.35326 .43455 m
.36853 .44815 L
s
0 g
.006 w
.34433 .44409 m
.35326 .43455 L
s
1 0 0 r
.003 w
.50338 .60487 m
.524 .5867 L
s
.45732 .64088 m
.47897 .62466 L
s
0 g
.006 w
.3378 .45553 m
.34433 .44409 L
s
.53805 .32631 m .60947 .54389 L .52802 .32975 L .538 .463 .72 r
F
.25 g
.5 Mabswid
.52802 .32975 m
.52863 .33135 L
s
.52863 .33135 m
.53105 .33771 L
s
0 g
.006 w
.51905 .33651 m
.52802 .32975 L
s
.25 g
.5 Mabswid
.51905 .33651 m
.54903 .38498 L
s
.56456 .37371 m
.56611 .38917 L
s
.56611 .38917 m
.56689 .39693 L
s
0 g
.006 w
.33322 .46822 m
.3378 .45553 L
s
.3296 .48153 m
.33322 .46822 L
s
1 0 0 r
.003 w
.63753 .52811 m
.66453 .51223 L
s
.53805 .32631 m .58773 .55539 L .60947 .54389 L .538 .463 .72 r
F
.25 g
.5 Mabswid
.53805 .32631 m
.5386 .32886 L
s
.55561 .40731 m
.56903 .46919 L
s
.55308 .39565 m
.55561 .40731 L
s
.5386 .32886 m
.53903 .33083 L
s
.53903 .33083 m
.55308 .39565 L
s
.56903 .46919 m
.58773 .55539 L
s
0 g
.006 w
.52802 .32975 m
.53805 .32631 L
s
.25 g
.5 Mabswid
.60502 .34245 m
.60629 .34402 L
s
.58491 .34269 m
.59833 .39101 L
s
.58335 .33707 m
.58491 .34269 L
s
.57164 .33279 m
.5756 .35959 L
s
.5756 .35959 m
.58117 .39724 L
s
.60629 .34402 m
.6159 .35588 L
s
.59473 .34051 m
.61518 .38137 L
s
.56004 .32874 m
.56034 .3317 L
s
.56034 .3317 m
.56456 .37371 L
s
.56654 .43103 m
.5668 .43172 L
s
.5668 .43172 m
.60947 .54389 L
s
.55308 .39565 m
.56285 .42132 L
s
.53105 .33771 m
.55308 .39565 L
s
.56285 .42132 m
.56654 .43103 L
s
1 0 0 r
.003 w
.57787 .55973 m
.58773 .55539 L
s
0 g
.006 w
.53805 .32631 m
.5488 .32619 L
s
1 0 0 r
.003 w
.47897 .62466 m
.50338 .60487 L
s
0 g
.006 w
.32578 .49479 m
.3296 .48153 L
s
1 0 0 r
.003 w
.58773 .55539 m
.60947 .54389 L
s
0 g
.006 w
.5488 .32619 m
.56004 .32874 L
s
.62274 .33026 m .81564 .46855 L .62212 .33638 L .656 .11 0 r
F
.25 g
.5 Mabswid
.6159 .35588 m
.62252 .36405 L
s
.64177 .3439 m .74166 .42093 L .79324 .45249 L .656 .11 0 r
F
.62524 .33205 m .64159 .34463 L .64177 .3439 L F
.62527 .33219 m .64159 .34463 L .62524 .33205 L F
.62274 .33026 m .62527 .33219 L .62524 .33205 L F
.64159 .34463 m .74166 .42093 L .64177 .3439 L F
.74166 .42093 m .81527 .47705 L .79324 .45249 L F
.62192 .3226 m .81527 .47705 L .62274 .33026 L .855 .451 .271 r
F
.68432 .37245 m .78064 .47475 L .81527 .47705 L F
.78064 .47475 m .80163 .48791 L .81527 .47705 L F
.63601 .33385 m .67351 .37255 L .68432 .37245 L F
.62192 .3226 m .6355 .33575 L .63601 .33385 L F
.6355 .33575 m .67351 .37255 L .63601 .33385 L F
.62997 .40193 m .64663 .54232 L .64191 .54983 L .938 .746 .273 r
F
.67842 .3725 m .6738 .37255 L .62192 .3226 L .834 .552 .512 r
F
.62068 .31426 m .67842 .3725 L .62192 .3226 L F
.77216 .48261 m .80768 .4917 L .78208 .49228 L .328 .626 .959 r
F
.62625 .32677 m .62625 .3268 L .62192 .3226 L .834 .552 .512 r
F
.67351 .37255 m .77621 .47197 L .68432 .37245 L .855 .451 .271 r
F
.77621 .47197 m .78064 .47475 L .68432 .37245 L F
.75896 .45454 m .67378 .37255 L .6738 .37255 L .834 .552 .512 r
F
.77648 .47141 m .75895 .45454 L .75896 .45454 L F
.75895 .45454 m .67378 .37255 L .75896 .45454 L F
.67378 .37255 m .62625 .3268 L .6738 .37255 L F
.6738 .37255 m .62625 .3268 L .62625 .32677 L F
.77648 .47141 m .77621 .47197 L .62625 .3268 L F
.67842 .3725 m .77648 .47141 L .6738 .37255 L F
.62145 .31515 m .70424 .42893 L .72868 .44024 L F
.62068 .31426 m .62168 .31563 L .62145 .31515 L F
.62168 .31563 m .70424 .42893 L .62145 .31515 L F
.62068 .31426 m .72868 .44024 L .71619 .4106 L F
.61972 .30642 m .69392 .41162 L .62068 .31426 L .771 .572 .629 r
F
.69392 .41162 m .70286 .42429 L .69042 .40997 L F
.70286 .42429 m .72868 .44024 L .70329 .42574 L .59 .724 .936 r
F
.69899 .41131 m .71688 .42875 L .70286 .42429 L F
.71688 .42875 m .72868 .44024 L .70286 .42429 L F
.72868 .44024 m .78208 .49228 L .70511 .43186 L F
.70424 .42893 m .70511 .43186 L .69728 .42571 L F
.72868 .44024 m .70511 .43186 L .70424 .42893 L F
.73087 .44544 m .78208 .49228 L .72868 .44024 L .328 .626 .959 r
F
.70424 .42893 m .70591 .43122 L .7599 .45469 L .834 .552 .512 r
F
.73087 .44544 m .77621 .47197 L .77126 .48238 L .328 .626 .959 r
F
.7638 .46419 m .77621 .47197 L .73087 .44544 L F
.70415 .42863 m .70424 .42893 L .69042 .40997 L .771 .572 .629 r
F
.70286 .42429 m .70415 .42863 L .69042 .40997 L F
.69392 .41162 m .69042 .40997 L .62068 .31426 L F
.6202 .30727 m .66651 .40742 L .67788 .40804 L F
.62024 .30756 m .66651 .40742 L .6202 .30727 L F
.61972 .30642 m .67788 .40804 L .6596 .36297 L F
.61972 .30642 m .62024 .30756 L .6202 .30727 L F
.61926 .3004 m .65936 .38891 L .61972 .30642 L .684 .549 .696 r
F
.65936 .38891 m .65893 .38883 L .61972 .30642 L F
.67049 .39708 m .67788 .40804 L .66609 .40601 L .728 .763 .881 r
F
.67049 .39708 m .66609 .40601 L .66439 .40036 L F
.67788 .40804 m .74074 .5013 L .67027 .41992 L F
.66651 .40742 m .67027 .41992 L .6591 .40702 L F
.67788 .40804 m .67027 .41992 L .66651 .40742 L F
.68175 .41758 m .74074 .5013 L .67788 .40804 L .59 .724 .936 r
F
.69193 .4088 m .66756 .40968 L .70286 .42429 L .771 .572 .629 r
F
.66651 .40742 m .66756 .40968 L .69193 .4088 L F
.66756 .40968 m .6694 .41365 L .68635 .41904 L F
.66756 .40968 m .68635 .41904 L .70286 .42429 L F
.68175 .41758 m .78208 .49228 L .74074 .5013 L .59 .724 .936 r
F
.66435 .40021 m .6653 .40339 L .61972 .30642 L .684 .549 .696 r
F
.66641 .40708 m .66651 .40742 L .66536 .40494 L F
.67788 .40804 m .66651 .40742 L .66609 .40601 L .728 .763 .881 r
F
.69044 .42034 m .78208 .49228 L .68175 .41758 L .59 .724 .936 r
F
.69899 .41131 m .70329 .42574 L .68138 .41323 L F
.72868 .44024 m .69728 .42571 L .68138 .41323 L F
.6653 .40339 m .66536 .40494 L .61972 .30642 L .684 .549 .696 r
F
.65101 .38959 m .7004 .51503 L .64796 .39317 L .832 .795 .816 r
F
.6943 .49987 m .7004 .51503 L .69443 .49987 L .728 .763 .881 r
F
.6943 .49987 m .69443 .49987 L .65101 .38959 L F
.65511 .40242 m .6943 .49987 L .65101 .38959 L F
.67027 .41992 m .74074 .5013 L .6943 .49987 L F
.6943 .49987 m .74074 .5013 L .7004 .51503 L F
.6694 .41365 m .72261 .52849 L .70286 .42429 L .771 .572 .629 r
F
.68252 .44001 m .66967 .41374 L .67026 .41393 L .684 .549 .696 r
F
.66967 .41374 m .66641 .40708 L .67026 .41393 L F
.67026 .41393 m .66641 .40708 L .6653 .40339 L F
.66641 .40708 m .66536 .40494 L .6653 .40339 L F
.65511 .40242 m .67027 .41992 L .6943 .49987 L .728 .763 .881 r
F
.66609 .40601 m .6591 .40702 L .65684 .40442 L F
.66651 .40742 m .6591 .40702 L .66609 .40601 L F
.65936 .38891 m .66407 .3993 L .65893 .38883 L .684 .549 .696 r
F
.66407 .3993 m .66435 .40021 L .65893 .38883 L F
.67049 .39708 m .65684 .40442 L .65594 .40213 L .728 .763 .881 r
F
.66407 .3993 m .66722 .40625 L .66435 .40021 L .684 .549 .696 r
F
.61926 .3004 m .64482 .39687 L .65101 .38959 L F
.61926 .3004 m .65101 .38959 L .63016 .32446 L F
.61924 .29739 m .63049 .34036 L .61926 .3004 L .534 .468 .728 r
F
.63049 .34036 m .64213 .38482 L .62904 .33652 L F
.63049 .34036 m .62904 .33652 L .61926 .3004 L F
.64923 .38509 m .65101 .38959 L .64803 .38423 L .832 .795 .816 r
F
.64213 .38482 m .64482 .39687 L .61926 .3004 L .534 .468 .728 r
F
.62108 .30441 m .63112 .34515 L .64213 .38482 L F
.64923 .38509 m .64803 .38423 L .64447 .37783 L .832 .795 .816 r
F
.62065 .30743 m .63533 .376 L .63645 .36435 L .534 .468 .728 r
F
.61924 .29739 m .63112 .34515 L .62108 .30441 L F
.61924 .29739 m .62065 .30743 L .63112 .34515 L F
.63533 .376 m .66733 .5298 L .63362 .39383 L .942 .834 .708 r
F
.63362 .39383 m .66733 .5298 L .63687 .4243 L F
.63328 .39739 m .63687 .4243 L .63224 .40826 L F
.63362 .39383 m .63687 .4243 L .63328 .39739 L F
.63913 .39377 m .66733 .5298 L .63533 .376 L .832 .795 .816 r
F
.63533 .376 m .63465 .40716 L .63913 .39377 L .534 .468 .728 r
F
.63328 .39739 m .63465 .40716 L .63533 .376 L F
.63224 .40826 m .66733 .5298 L .64663 .54232 L .942 .834 .708 r
F
.64077 .40164 m .64967 .41857 L .66733 .5298 L .832 .795 .816 r
F
.63913 .39377 m .64224 .39991 L .64077 .40164 L F
.64224 .39991 m .7004 .51503 L .64077 .40164 L F
.64311 .38189 m .7004 .51503 L .63913 .39377 L F
.63465 .40716 m .65474 .55027 L .64213 .38482 L .534 .468 .728 r
F
.63684 .42195 m .63342 .3984 L .63328 .39739 L .106 .157 .633 r
F
.62065 .30743 m .63328 .39739 L .63533 .376 L .534 .468 .728 r
F
.63178 .38617 m .63328 .39739 L .61924 .29739 L .106 .157 .633 r
F
.63092 .39596 m .63362 .39383 L .63224 .40826 L .942 .834 .708 r
F
.61956 .29816 m .63042 .376 L .61924 .29739 L .106 .157 .633 r
F
.63042 .376 m .63178 .38617 L .61924 .29739 L F
.61956 .29816 m .6206 .30977 L .62439 .33274 L F
.6206 .30977 m .63194 .43756 L .62597 .35462 L F
.6206 .30977 m .62597 .35462 L .62439 .33274 L F
.63194 .43756 m .63154 .42137 L .62439 .33274 L F
.63092 .39596 m .64663 .54232 L .62655 .35947 L .942 .834 .708 r
F
.62655 .35947 m .6273 .36633 L .62715 .3669 L .938 .746 .273 r
F
.6273 .36633 m .64663 .54232 L .62623 .37034 L F
.62439 .33274 m .63154 .42137 L .63042 .376 L .106 .157 .633 r
F
.62179 .31092 m .63092 .39596 L .62033 .30286 L .942 .834 .708 r
F
.63092 .39596 m .62655 .35947 L .62033 .30286 L F
.62179 .31092 m .62976 .34926 L .62845 .37298 L F
.62976 .34926 m .63469 .37292 L .63035 .37296 L F
.62976 .34926 m .63035 .37296 L .62845 .37298 L F
.63194 .43756 m .64191 .54983 L .63154 .42137 L .106 .157 .633 r
F
.62051 .30495 m .62655 .35947 L .62623 .37034 L .938 .746 .273 r
F
.62033 .30286 m .62655 .35947 L .62051 .30495 L F
.62655 .35947 m .62715 .3669 L .62623 .37034 L F
.62845 .37298 m .63056 .38149 L .63092 .39596 L .942 .834 .708 r
F
.63056 .38149 m .63362 .39383 L .63092 .39596 L F
.63533 .376 m .63362 .39383 L .62845 .37298 L F
.63684 .42195 m .63328 .39739 L .63178 .38617 L .106 .157 .633 r
F
.63042 .376 m .63684 .42195 L .63178 .38617 L F
.63684 .42195 m .65474 .55027 L .63342 .3984 L F
.63042 .376 m .64191 .54983 L .65474 .55027 L F
.63154 .42137 m .64191 .54983 L .63042 .376 L F
.63469 .37292 m .63533 .376 L .63012 .37371 L .942 .834 .708 r
F
.63002 .37296 m .63012 .37371 L .62845 .37298 L F
.63469 .37292 m .63012 .37371 L .63002 .37296 L F
.63645 .36435 m .63887 .39253 L .64213 .38482 L .534 .468 .728 r
F
.63533 .376 m .63887 .39253 L .63645 .36435 L F
.63887 .39253 m .63913 .39377 L .63951 .39264 L F
.63887 .39253 m .63951 .39264 L .64213 .38482 L F
.71619 .4106 m .72868 .44024 L .7599 .45469 L .834 .552 .512 r
F
.69306 .40246 m .81194 .4916 L .79561 .48231 L .328 .626 .959 r
F
.64468 .37721 m .64447 .37783 L .63069 .35302 L .832 .795 .816 r
F
.63849 .3578 m .64923 .38509 L .63069 .35302 L F
.64923 .38509 m .64447 .37783 L .64468 .37721 L F
.65101 .38959 m .64796 .39317 L .63069 .35302 L F
.66439 .40036 m .66609 .40601 L .65684 .40442 L .728 .763 .881 r
F
.65594 .40213 m .65684 .40442 L .65511 .40242 L F
.64967 .41857 m .7004 .51503 L .67387 .52688 L .832 .795 .816 r
F
.64482 .39687 m .68348 .54281 L .65666 .38294 L .684 .549 .696 r
F
.638 .35986 m .65423 .40022 L .63849 .3578 L .728 .763 .881 r
F
.65423 .40022 m .65511 .40242 L .65453 .40085 L F
.65423 .40022 m .65453 .40085 L .63849 .3578 L F
.65453 .40085 m .65101 .38959 L .63849 .3578 L F
.65511 .40242 m .65478 .40137 L .65453 .40085 L F
.65478 .40137 m .65101 .38959 L .65453 .40085 L F
.63016 .32446 m .65101 .38959 L .65666 .38294 L .684 .549 .696 r
F
.6241 .32126 m .63849 .3578 L .63069 .35302 L .832 .795 .816 r
F
.62704 .33262 m .638 .35986 L .6241 .32126 L .728 .763 .881 r
F
.638 .35986 m .63849 .3578 L .6241 .32126 L F
.62704 .33262 m .65351 .37188 L .6388 .36045 L F
.65351 .37188 m .67049 .39708 L .6388 .36045 L F
.68252 .44001 m .72261 .52849 L .66651 .40742 L .684 .549 .696 r
F
.68252 .44001 m .66651 .40742 L .66641 .40708 L F
.66722 .40625 m .66738 .4078 L .6653 .40339 L F
.66722 .40625 m .6653 .40339 L .66435 .40021 L F
.66722 .40625 m .68252 .44001 L .66738 .4078 L F
.65666 .38294 m .68348 .54281 L .72261 .52849 L F
.6388 .36045 m .67049 .39708 L .65634 .40199 L .728 .763 .881 r
F
.62704 .33262 m .65634 .40199 L .65423 .40022 L F
.62985 .34393 m .66093 .38804 L .62704 .33262 L .59 .724 .936 r
F
.66093 .38804 m .66479 .39124 L .62704 .33262 L F
.6596 .36297 m .67788 .40804 L .69193 .4088 L .771 .572 .629 r
F
.62623 .37034 m .62997 .40193 L .64191 .54983 L .938 .746 .273 r
F
.63069 .35302 m .63913 .39377 L .62999 .35035 L .832 .795 .816 r
F
.63913 .39377 m .63533 .376 L .62999 .35035 L F
.63069 .35302 m .64311 .38189 L .63913 .39377 L F
.62033 .30286 m .64191 .54983 L .61956 .29816 L .938 .746 .273 r
F
.61904 .3756 m .63992 .38937 L .62642 .37081 L .846 .473 .344 r
F
.68003 .4149 m .67788 .40804 L .62772 .33363 L .59 .724 .936 r
F
.68003 .4149 m .62772 .33363 L .62774 .3337 L F
.68175 .41758 m .68133 .41654 L .68003 .4149 L F
.68133 .41654 m .67788 .40804 L .68003 .4149 L F
.66093 .38804 m .68175 .41758 L .66479 .39124 L F
.67535 .4085 m .69044 .42034 L .68175 .41758 L F
.70591 .43122 m .76344 .51018 L .76038 .46224 L .834 .552 .512 r
F
.70591 .43122 m .76038 .46224 L .7599 .45469 L F
.70654 .42318 m .73087 .44544 L .70268 .41711 L .328 .626 .959 r
F
.69834 .41068 m .69899 .41131 L .68138 .41323 L .59 .724 .936 r
F
.69834 .41068 m .68138 .41323 L .67838 .40878 L F
.62985 .34393 m .69834 .41068 L .67535 .4085 L F
.73087 .44544 m .72868 .44024 L .62985 .34393 L .328 .626 .959 r
F
.79552 .48225 m .80768 .4917 L .7638 .46419 L F
.77621 .47197 m .80768 .4917 L .77126 .48238 L F
.77621 .47197 m .79671 .49182 L .78064 .47475 L .855 .451 .271 r
F
.77126 .48238 m .77216 .48261 L .78208 .49228 L .328 .626 .959 r
F
.77648 .47141 m .79671 .49182 L .77621 .47197 L .834 .552 .512 r
F
.77648 .47141 m .76344 .51018 L .79671 .49182 L F
.7599 .45469 m .76038 .46224 L .77648 .47141 L F
.76038 .46224 m .76344 .51018 L .77648 .47141 L F
.63139 .35444 m .70654 .42318 L .62985 .34393 L .328 .626 .959 r
F
.70654 .42318 m .70268 .41711 L .62985 .34393 L F
.63338 .35626 m .79552 .48225 L .72429 .43942 L F
.79552 .48225 m .7638 .46419 L .72429 .43942 L F
.72429 .43942 m .7638 .46419 L .73087 .44544 L F
.74722 .48718 m .75088 .49295 L .70424 .42893 L .771 .572 .629 r
F
.74722 .48718 m .70424 .42893 L .70415 .42863 L F
.70286 .42429 m .74722 .48718 L .70415 .42863 L F
.74722 .48718 m .76344 .51018 L .75088 .49295 L F
.70286 .42429 m .72261 .52849 L .76344 .51018 L F
.67838 .40878 m .68138 .41323 L .67535 .4085 L .59 .724 .936 r
F
.64213 .38482 m .68348 .54281 L .64482 .39687 L .534 .468 .728 r
F
.64967 .41857 m .67387 .52688 L .66733 .5298 L .832 .795 .816 r
F
.64213 .38482 m .65474 .55027 L .68348 .54281 L .534 .468 .728 r
F
.63992 .38937 m .76624 .47266 L .63758 .37867 L .846 .473 .344 r
F
.78064 .47475 m .79671 .49182 L .80163 .48791 L .855 .451 .271 r
F
.76624 .47266 m .84083 .52185 L .7602 .46505 L .846 .473 .344 r
F
.76624 .47266 m .7602 .46505 L .63758 .37867 L F
.63992 .38937 m .63758 .37867 L .62642 .37081 L F
.62774 .3337 m .62772 .33363 L .62704 .33262 L .59 .724 .936 r
F
.63322 .35611 m .63333 .3562 L .63338 .35626 L .328 .626 .959 r
F
.63333 .3562 m .80768 .4917 L .63338 .35626 L F
.63139 .35444 m .63303 .35572 L .63322 .35611 L F
.63303 .35572 m .80768 .4917 L .63322 .35611 L F
.63303 .35572 m .69509 .40283 L .69306 .40246 L F
.63139 .35444 m .633 .35567 L .63303 .35572 L F
.633 .35567 m .69509 .40283 L .63303 .35572 L F
.65423 .40022 m .65634 .40199 L .65511 .40242 L .728 .763 .881 r
F
.69509 .40283 m .81194 .4916 L .69306 .40246 L .328 .626 .959 r
F
.7737 .46255 m .81717 .49148 L .81194 .4916 L F
.6646 .37967 m .78617 .46876 L .7737 .46255 L F
.78617 .46876 m .81717 .49148 L .7737 .46255 L F
.66452 .37888 m .81717 .49148 L .6646 .37967 L F
.63139 .35444 m .66452 .37888 L .6646 .37967 L F
.6305 .36358 m .81717 .49148 L .63139 .35444 L 0 .276 .709 r
F
.71528 .42167 m .82436 .49179 L .7844 .46903 L F
.79561 .48231 m .81194 .4916 L .80768 .4917 L .328 .626 .959 r
F
.7844 .46903 m .83871 .50127 L .81717 .49148 L 0 .276 .709 r
F
.82436 .49179 m .83871 .50127 L .7844 .46903 L F
.6466 .38321 m .84083 .52185 L .83871 .50127 L .762 .25 0 r
F
.62642 .37081 m .64752 .38568 L .6466 .38321 L F
.64752 .38568 m .84083 .52185 L .6466 .38321 L F
.63598 .36734 m .67262 .39144 L .67059 .39105 L 0 .276 .709 r
F
.6305 .36358 m .63521 .36669 L .63598 .36734 L F
.63521 .36669 m .67262 .39144 L .63598 .36734 L F
.67059 .39105 m .72257 .4251 L .71528 .42167 L F
.72257 .4251 m .82436 .49179 L .71528 .42167 L F
.67262 .39144 m .82436 .49179 L .67059 .39105 L F
.6241 .32126 m .63069 .35302 L .62179 .31092 L .832 .795 .816 r
F
.63069 .35302 m .62999 .35035 L .62179 .31092 L F
.79324 .45249 m .81527 .47705 L .81564 .46855 L .656 .11 0 r
F
.25 g
.62252 .36405 m
.62577 .36807 L
s
.61877 .34718 m
.6208 .34896 L
s
.6208 .34896 m
.6213 .34939 L
s
.6213 .34939 m
.623 .35087 L
s
.623 .35087 m
.62435 .35204 L
s
.61916 .34051 m
.61939 .34068 L
s
.61939 .34068 m
.62049 .34146 L
s
.62049 .34146 m
.62099 .34182 L
s
.62099 .34182 m
.6232 .34339 L
s
.6232 .34339 m
.62361 .34368 L
s
.62212 .33638 m
.62301 .33699 L
s
1 0 0 r
.003 w
.81527 .47705 m
.81564 .46855 L
s
0 g
.006 w
.32079 .50719 m
.32578 .49479 L
s
.56004 .32874 m
.57164 .33279 L
s
.31424 .51784 m
.32079 .50719 L
s
1 0 0 r
.003 w
.60947 .54389 m
.63753 .52811 L
s
0 g
.006 w
.57164 .33279 m
.58335 .33707 L
s
.30628 .5259 m
.31424 .51784 L
s
.25 g
.5 Mabswid
.22883 .53932 m
.23013 .54015 L
s
0 g
.006 w
.58335 .33707 m
.59473 .34051 L
s
.29826 .53034 m
.30628 .5259 L
s
.29751 .53075 m
.29826 .53034 L
s
.29735 .53084 m
.29751 .53075 L
s
.59473 .34051 m
.60502 .34245 L
s
.25 g
.5 Mabswid
.32104 .76607 m
.32155 .76964 L
s
1 0 0 r
.003 w
.32452 .76917 m
.33291 .76784 L
s
.32155 .76964 m
.32452 .76917 L
s
.25 g
.5 Mabswid
.31154 .71322 m
.31331 .71689 L
s
.31331 .71689 m
.32074 .73229 L
s
.28606 .66041 m
.29612 .68126 L
s
.29612 .68126 m
.30084 .69105 L
s
.30084 .69105 m
.31154 .71322 L
s
1 0 0 r
.003 w
.31895 .76913 m
.32379 .76206 L
s
.30449 .79021 m
.31895 .76913 L
s
0 g
.006 w
.60502 .34245 m
.61339 .34251 L
s
.28788 .53261 m
.29735 .53084 L
s
.25 g
.5 Mabswid
.6241 .32126 m
.63072 .33808 L
s
.62704 .33262 m
.64389 .35761 L
s
0 g
.006 w
.61339 .34251 m
.61916 .34051 L
s
.28653 .53249 m
.28788 .53261 L
s
.27806 .53174 m
.28653 .53249 L
s
.25 g
.5 Mabswid
.62179 .31092 m
.62207 .3123 L
s
.62207 .3123 m
.62976 .34926 L
s
.62976 .34926 m
.62999 .35035 L
s
.62999 .35035 m
.63121 .35623 L
s
.63468 .37287 m
.63533 .376 L
s
0 g
.006 w
.61916 .34051 m
.61993 .33944 L
s
.61993 .33944 m
.62038 .33881 L
s
.62038 .33881 m
.62085 .33816 L
s
.62085 .33816 m
.62212 .33638 L
s
1 0 0 r
.003 w
.80928 .48182 m
.81527 .47705 L
s
.25 g
.5 Mabswid
.63001 .34409 m
.63021 .34428 L
s
.62985 .34393 m
.63001 .34409 L
s
.31253 .68011 m
.33291 .76784 L
s
0 g
.006 w
.62212 .33638 m
.62257 .33197 L
s
.23873 .52504 m .4459 .65797 L .23224 .52763 L .838 .475 .366 r
F
.25 g
.5 Mabswid
.23224 .52763 m
.24211 .53365 L
s
.24211 .53365 m
.28779 .56152 L
s
.28779 .56152 m
.30065 .56937 L
s
.30065 .56937 m
.31034 .57527 L
s
.31034 .57527 m
.31698 .57933 L
s
.31698 .57933 m
.31967 .58096 L
s
.35063 .59985 m
.4459 .65797 L
s
.3412 .5941 m
.35063 .59985 L
s
.33353 .58942 m
.3412 .5941 L
s
.31967 .58096 m
.33353 .58942 L
s
0 g
.006 w
.26792 .52926 m
.27806 .53174 L
s
1 0 0 r
.003 w
.44029 .65348 m
.4459 .65797 L
s
.25 g
.5 Mabswid
.22887 .5325 m
.23766 .53752 L
s
.28092 .56228 m
.28679 .56564 L
s
.28679 .56564 m
.30178 .57422 L
s
.23766 .53752 m
.28092 .56228 L
s
.30178 .57422 m
.31192 .58002 L
s
.25313 .59215 m
.25333 .59257 L
s
.25333 .59257 m
.27002 .62716 L
s
.27002 .62716 m
.28606 .66041 L
s
.2576 .55764 m
.28664 .57614 L
s
.28664 .57614 m
.29303 .58021 L
s
.23013 .54015 m
.2576 .55764 L
s
.29451 .58115 m
.30415 .58729 L
s
.29303 .58021 m
.29451 .58115 L
s
.30415 .58729 m
.30961 .59077 L
s
.23704 .55844 m
.24437 .56762 L
s
.29171 .62696 m
.30099 .63858 L
s
.27392 .60465 m
.28865 .62311 L
s
.28865 .62311 m
.29171 .62696 L
s
.25073 .57559 m
.25154 .5766 L
s
.25154 .5766 m
.26902 .59852 L
s
.26902 .59852 m
.27392 .60465 L
s
.24437 .56762 m
.25073 .57559 L
s
.30467 .64319 m
.31307 .65372 L
s
.30099 .63858 m
.30467 .64319 L
s
.23606 .55721 m
.23704 .55844 L
s
.2331 .54898 m
.25341 .56596 L
s
.23157 .5477 m
.2331 .54898 L
s
.28186 .58974 m
.28721 .59422 L
s
.28721 .59422 m
.29587 .60145 L
s
.25341 .56596 m
.26869 .57873 L
s
.26869 .57873 m
.28186 .58974 L
s
.29941 .60442 m
.30805 .61164 L
s
.29587 .60145 m
.29941 .60442 L
s
.30805 .61164 m
.30988 .61317 L
s
1 0 0 r
.003 w
.4377 .67451 m
.4459 .65797 L
s
.25 g
.5 Mabswid
.25646 .61559 m
.26225 .63666 L
s
.26225 .63666 m
.28279 .71131 L
s
.28279 .71131 m
.30449 .79021 L
s
1 0 0 r
.003 w
.2893 .82312 m
.30449 .79021 L
s
.33291 .76784 m
.35734 .75259 L
s
.25 g
.5 Mabswid
.30725 .62748 m
.33136 .68769 L
s
.33136 .68769 m
.35734 .75259 L
s
.30556 .62327 m
.30725 .62748 L
s
0 g
.006 w
.25758 .52651 m
.26792 .52926 L
s
.25 g
.5 Mabswid
.62033 .30286 m
.62053 .30469 L
s
.62075 .30668 m
.62655 .35947 L
s
.62053 .30469 m
.62075 .30668 L
s
.30477 .59933 m
.34134 .65575 L
s
.30402 .59817 m
.30477 .59933 L
s
.30056 .59282 m
.30402 .59817 L
s
.34134 .65575 m
.3735 .70537 L
s
.3735 .70537 m
.38803 .7278 L
s
0 g
.006 w
.24754 .5248 m
.25758 .52651 L
s
.62068 .31426 m
.62146 .31947 L
s
.25 g
.5 Mabswid
.30856 .5775 m
.34501 .60488 L
s
.34501 .60488 m
.36771 .62193 L
s
.36771 .62193 m
.4377 .67451 L
s
.30371 .57386 m
.30856 .5775 L
s
.30071 .5716 m
.30371 .57386 L
s
.28977 .56338 m
.30071 .5716 L
s
.28513 .55989 m
.28977 .56338 L
s
1 0 0 r
.003 w
.41704 .6996 m
.4377 .67451 L
s
.25 g
.5 Mabswid
.63139 .35444 m
.63298 .35561 L
s
.30333 .58234 m
.36053 .64132 L
s
.36053 .64132 m
.41704 .6996 L
s
.30186 .58082 m
.30333 .58234 L
s
.2951 .57385 m
.30186 .58082 L
s
0 g
.006 w
.23873 .52504 m
.24754 .5248 L
s
1 0 0 r
.003 w
.76344 .51018 m
.79594 .49224 L
s
.35734 .75259 m
.38803 .7278 L
s
.25 g
.5 Mabswid
.63194 .43756 m
.64191 .54983 L
s
.63096 .42644 m
.63194 .43756 L
s
.6206 .30977 m
.62604 .37105 L
s
.6269 .38078 m
.62773 .3901 L
s
.61956 .29816 m
.6206 .30977 L
s
.62773 .3901 m
.62842 .39792 L
s
.63015 .41741 m
.63096 .42644 L
s
.62913 .40584 m
.63015 .41741 L
s
.62842 .39792 m
.62913 .40584 L
s
1 0 0 r
.003 w
.64191 .54983 m
.65474 .55027 L
s
.25 g
.5 Mabswid
.62068 .31426 m
.62104 .31475 L
s
0 g
.006 w
.61972 .30642 m
.62068 .31426 L
s
1 0 0 r
.003 w
.38803 .7278 m
.41704 .6996 L
s
0 g
.006 w
.23224 .52763 m
.23873 .52504 L
s
.25 g
.5 Mabswid
.26612 .68362 m
.2893 .82312 L
s
.61972 .30642 m
.62024 .30756 L
s
.62024 .30756 m
.62043 .30797 L
s
0 g
.006 w
.61926 .3004 m
.61972 .30642 L
s
.22887 .5325 m
.23224 .52763 L
s
.25 g
.5 Mabswid
.61924 .29739 m
.61993 .30234 L
s
1 0 0 r
.003 w
.65474 .55027 m
.68348 .54281 L
s
.25 g
.5 Mabswid
.61926 .3004 m
.61966 .30191 L
s
.61966 .30191 m
.62002 .30325 L
s
0 g
.006 w
.61924 .29739 m
.61926 .3004 L
s
1 0 0 r
.003 w
.72261 .52849 m
.76344 .51018 L
s
0 g
.006 w
.22883 .53932 m
.22887 .5325 L
s
.62642 .37081 m .83871 .50127 L .6305 .36358 L .762 .25 0 r
F
.25 g
.5 Mabswid
.7289 .42866 m
.83871 .50127 L
s
.6305 .36358 m
.6432 .37198 L
s
.74066 .43505 m
.75884 .44846 L
s
.70752 .4106 m
.74066 .43505 L
s
.69431 .40086 m
.70752 .4106 L
s
.66452 .37888 m
.69431 .40086 L
s
.66326 .37649 m
.66943 .3825 L
s
0 g
.006 w
.61924 .29739 m
.61956 .29816 L
s
1 0 0 r
.003 w
.68348 .54281 m
.72261 .52849 L
s
0 g
.006 w
.22883 .53932 m
.23157 .5477 L
s
.61956 .29816 m
.62033 .30286 L
s
.26375 .53858 m .39011 .62939 L .27118 .53371 L .489 .715 .971 r
F
.39011 .62939 m .43296 .66018 L .38943 .62615 L F
.39011 .62939 m .38943 .62615 L .27118 .53371 L F
.43296 .66018 m .43128 .65752 L .35574 .5991 L F
.35546 .5996 m .35574 .5991 L .27118 .53371 L F
.43296 .66018 m .35574 .5991 L .35546 .5996 L F
.43296 .66018 m .45782 .67805 L .43128 .65752 L F
.26375 .53858 m .44636 .65174 L .45782 .67805 L F
.44636 .65174 m .4804 .67283 L .46834 .67562 L F
.44636 .65174 m .46834 .67562 L .45782 .67805 L F
.25976 .54556 m .4804 .67283 L .26375 .53858 L .466 0 0 r
F
.39566 .65347 m .44931 .69275 L .42473 .72024 L .93 .812 .708 r
F
.40573 .64573 m .44931 .69275 L .40635 .6613 L F
.39969 .65037 m .40635 .6613 L .39566 .65347 L F
.40573 .64573 m .40635 .6613 L .39969 .65037 L F
.25849 .56406 m .39247 .64597 L .25843 .55428 L .811 .539 .527 r
F
.39247 .64597 m .39236 .64539 L .25843 .55428 L F
.39969 .65037 m .3959 .64416 L .39153 .64131 L F
.39236 .64539 m .39153 .64131 L .25843 .55428 L F
.39969 .65037 m .39153 .64131 L .39236 .64539 L F
.38797 .62055 m .40663 .63168 L .40826 .63242 L .466 0 0 r
F
.38795 .62077 m .41236 .63509 L .38797 .62055 L F
.40826 .63242 m .41236 .63509 L .42141 .64011 L F
.38805 .61956 m .42141 .64011 L .44911 .65479 L F
.25976 .54556 m .38797 .62055 L .38805 .61956 L F
.38797 .62055 m .42141 .64011 L .38805 .61956 L F
.31786 .51092 m .38539 .57856 L .39664 .60948 L .822 .794 .826 r
F
.25976 .54556 m .38795 .62077 L .38797 .62055 L .466 0 0 r
F
.39247 .64597 m .39969 .65037 L .39236 .64539 L .811 .539 .527 r
F
.25849 .56406 m .37993 .66556 L .39401 .65474 L F
.39247 .64597 m .39401 .65474 L .39969 .65037 L F
.25849 .56406 m .39401 .65474 L .39247 .64597 L F
.35927 .60933 m .40894 .63645 L .3604 .60687 L .837 .442 .298 r
F
.40894 .63645 m .41799 .64139 L .40621 .63149 L F
.41236 .63509 m .42091 .63985 L .42236 .64255 L .822 .794 .826 r
F
.41799 .64139 m .42236 .64255 L .42738 .6519 L F
.41236 .63509 m .42236 .64255 L .41799 .64139 L F
.44911 .65479 m .42141 .64011 L .4804 .67283 L .466 0 0 r
F
.42141 .64011 m .48084 .67318 L .4804 .67283 L F
.41236 .63509 m .42091 .63985 L .42141 .64011 L F
.42091 .63985 m .48084 .67318 L .42141 .64011 L F
.39104 .58422 m .47869 .67201 L .45825 .68644 L .822 .794 .826 r
F
.42738 .6519 m .45825 .68644 L .44931 .69275 L F
.39104 .58422 m .45825 .68644 L .42738 .6519 L F
.41799 .64139 m .41236 .63509 L .40621 .63149 L .837 .442 .298 r
F
.40894 .63645 m .40621 .63149 L .36121 .60508 L F
.3604 .60687 m .36121 .60508 L .25976 .54556 L F
.40894 .63645 m .36121 .60508 L .3604 .60687 L F
.38689 .54338 m .38742 .54769 L .38903 .53956 L .037 .128 .631 r
F
.40663 .63168 m .41236 .63509 L .40826 .63242 L .466 0 0 r
F
.3694 .58221 m .42091 .63985 L .40445 .63069 L .822 .794 .826 r
F
.31786 .51092 m .36933 .57531 L .3694 .58221 L F
.36933 .57531 m .42091 .63985 L .3694 .58221 L F
.41799 .64139 m .4404 .65363 L .41236 .63509 L .837 .442 .298 r
F
.4404 .65363 m .4332 .64732 L .41236 .63509 L F
.25843 .55428 m .32887 .60034 L .36295 .61604 L F
.35927 .60933 m .36295 .61604 L .38937 .62821 L F
.38902 .62607 m .38937 .62821 L .40847 .63701 L F
.35927 .60933 m .38937 .62821 L .38902 .62607 L F
.38893 .62553 m .40847 .63701 L .40894 .63645 L F
.35927 .60933 m .38902 .62607 L .38893 .62553 L F
.38902 .62607 m .40847 .63701 L .38893 .62553 L F
.32887 .60034 m .37368 .62963 L .4072 .63853 L F
.40766 .63798 m .4072 .63853 L .41081 .63949 L F
.32887 .60034 m .4072 .63853 L .40766 .63798 L F
.32887 .60034 m .41081 .63949 L .41799 .64139 L F
.40894 .63645 m .40847 .63701 L .41799 .64139 L F
.40445 .63069 m .41236 .63509 L .44931 .69275 L .822 .794 .826 r
F
.41236 .63509 m .42738 .6519 L .44931 .69275 L F
.41081 .63949 m .44931 .69275 L .4178 .64283 L F
.37368 .62963 m .3959 .64416 L .41799 .64139 L .837 .442 .298 r
F
.4178 .64283 m .44931 .69275 L .41528 .64298 L .93 .812 .708 r
F
.39172 .64442 m .40573 .64573 L .39566 .65347 L F
.3959 .64416 m .41947 .64273 L .41799 .64139 L .837 .442 .298 r
F
.38039 .61838 m .40383 .64368 L .39172 .64442 L .93 .812 .708 r
F
.40383 .64368 m .40573 .64573 L .39172 .64442 L F
.39969 .65037 m .39915 .6549 L .40265 .65219 L .811 .539 .527 r
F
.39915 .6549 m .40163 .65591 L .40265 .65219 L F
.39566 .65347 m .42473 .72024 L .40176 .65597 L .93 .812 .708 r
F
.39708 .67233 m .39743 .6743 L .40265 .65219 L .811 .539 .527 r
F
.38756 .60734 m .41081 .63949 L .40509 .6227 L .822 .794 .826 r
F
.41081 .63949 m .4178 .64283 L .41341 .63588 L F
.41236 .63509 m .4332 .64732 L .48084 .67318 L .466 0 0 r
F
.40864 .63312 m .41341 .63588 L .40509 .6227 L .822 .794 .826 r
F
.41081 .63949 m .41341 .63588 L .40864 .63312 L F
.4332 .64732 m .49155 .68155 L .48914 .67967 L .466 0 0 r
F
.4332 .64732 m .48914 .67967 L .48084 .67318 L F
.40873 .63339 m .44931 .69275 L .38039 .61838 L .93 .812 .708 r
F
.39969 .65037 m .4873 .70393 L .3959 .64416 L .811 .539 .527 r
F
.37993 .66556 m .39627 .67921 L .39708 .67233 L F
.39401 .65474 m .39708 .67233 L .39969 .65037 L F
.37993 .66556 m .39708 .67233 L .39401 .65474 L F
.39566 .65347 m .40176 .65597 L .39903 .64832 L .93 .812 .708 r
F
.39566 .65347 m .39903 .64832 L .39295 .64508 L F
.39534 .65274 m .39566 .65347 L .3954 .65266 L F
.31786 .51092 m .38756 .60734 L .33154 .50616 L .822 .794 .826 r
F
.39664 .60948 m .39104 .58422 L .42091 .63985 L F
.38539 .57856 m .39104 .58422 L .39664 .60948 L F
.38756 .60734 m .40509 .6227 L .33154 .50616 L F
.37335 .5724 m .41341 .63588 L .34872 .54564 L .93 .812 .708 r
F
.41341 .63588 m .40873 .63339 L .34872 .54564 L F
.34872 .54564 m .40873 .63339 L .38039 .61838 L F
.33154 .50616 m .37335 .5724 L .34872 .54564 L F
.39534 .65274 m .3954 .65266 L .34747 .50401 L F
.33154 .50616 m .39534 .65274 L .34747 .50401 L F
.39915 .6549 m .39708 .67233 L .40163 .65591 L .811 .539 .527 r
F
.39708 .67233 m .39627 .67921 L .39743 .6743 L F
.40044 .6557 m .42473 .72024 L .3989 .67588 L .999 .797 .489 r
F
.25871 .5739 m .35107 .68368 L .39828 .68404 L .752 .551 .623 r
F
.35107 .68368 m .39437 .73514 L .39742 .6952 L F
.35107 .68368 m .39742 .6952 L .39828 .68404 L F
.25871 .5739 m .39828 .68404 L .25849 .56406 L F
.39759 .67363 m .42473 .72024 L .40254 .6943 L .999 .797 .489 r
F
.39759 .67363 m .40254 .6943 L .39627 .67921 L F
.39828 .68404 m .39938 .68492 L .39627 .67921 L .752 .551 .623 r
F
.39903 .64832 m .42473 .72024 L .39809 .64944 L .999 .797 .489 r
F
.39938 .68492 m .41931 .70065 L .39869 .68146 L .752 .551 .623 r
F
.39938 .68492 m .39869 .68146 L .39627 .67921 L F
.41931 .70065 m .41478 .69469 L .39627 .67921 L F
.39828 .68404 m .39627 .67921 L .25849 .56406 L F
.39627 .67921 m .40254 .6943 L .39483 .68529 L .999 .797 .489 r
F
.39828 .68404 m .40013 .68957 L .39921 .68479 L .752 .551 .623 r
F
.40013 .68957 m .40031 .69011 L .39921 .68479 L F
.39921 .68479 m .40031 .69011 L .39938 .68492 L F
.39483 .68529 m .42473 .72024 L .41159 .74944 L .999 .797 .489 r
F
.39742 .6952 m .41159 .74944 L .4014 .69619 L F
.4014 .69619 m .41159 .74944 L .40181 .69847 L .724 .488 0 r
F
.39437 .73514 m .41213 .75625 L .39828 .68404 L .752 .551 .623 r
F
.40181 .69847 m .41159 .74944 L .40223 .70087 L .724 .488 0 r
F
.41213 .75625 m .40031 .69011 L .39828 .68404 L .752 .551 .623 r
F
.40044 .6557 m .3989 .67588 L .3895 .65973 L .999 .797 .489 r
F
.39742 .6952 m .4014 .69619 L .39975 .68761 L F
.39743 .6743 m .41478 .69469 L .40265 .65219 L .811 .539 .527 r
F
.39627 .67921 m .39863 .68119 L .39743 .6743 L F
.39863 .68119 m .41478 .69469 L .39743 .6743 L F
.38706 .65555 m .39759 .67363 L .39483 .68529 L .999 .797 .489 r
F
.39709 .68636 m .39975 .68761 L .39651 .67064 L F
.39742 .6952 m .39975 .68761 L .39709 .68636 L F
.39809 .64944 m .40044 .6557 L .3895 .65973 L F
.3959 .64416 m .41656 .65768 L .41947 .64273 L .837 .442 .298 r
F
.39295 .64508 m .39903 .64832 L .34747 .50401 L .93 .812 .708 r
F
.37837 .59704 m .39809 .64944 L .38706 .65555 L .999 .797 .489 r
F
.39809 .64944 m .3895 .65973 L .38706 .65555 L F
.36841 .56264 m .39044 .62428 L .35938 .54618 L F
.39044 .62428 m .38825 .62328 L .35677 .53962 L F
.39224 .66504 m .39651 .67064 L .36464 .50418 L F
.39742 .6952 m .39651 .67064 L .39224 .66504 L F
.39569 .66658 m .39987 .68827 L .39573 .66682 L .724 .488 0 r
F
.39987 .68827 m .4014 .69619 L .39989 .68837 L F
.39987 .68827 m .39989 .68837 L .39573 .66682 L F
.41478 .69469 m .46594 .73745 L .44464 .70875 L .811 .539 .527 r
F
.41478 .69469 m .44464 .70875 L .40265 .65219 L F
.4005 .69188 m .41159 .74944 L .40164 .69837 L .724 .488 0 r
F
.25834 .58254 m .38417 .81418 L .41762 .78653 L .676 .528 .677 r
F
.41195 .75517 m .41159 .74944 L .41428 .76697 L .724 .488 0 r
F
.25834 .58254 m .41762 .78653 L .41236 .75744 L .676 .528 .677 r
F
.25834 .58254 m .41236 .75744 L .25871 .5739 L F
.41236 .75744 m .41213 .75625 L .25871 .5739 L F
.41014 .74632 m .41428 .76697 L .41542 .77442 L .724 .488 0 r
F
.40846 .73739 m .41428 .76697 L .41014 .74632 L F
.41236 .75744 m .41762 .78653 L .42941 .77679 L .676 .528 .677 r
F
.40846 .73739 m .40939 .74096 L .41195 .75517 L .724 .488 0 r
F
.40939 .74096 m .41159 .74944 L .41195 .75517 L F
.40164 .69837 m .41159 .74944 L .40846 .73739 L F
.41213 .75625 m .42608 .77284 L .40031 .69011 L .752 .551 .623 r
F
.42608 .77284 m .42941 .77679 L .42828 .77343 L F
.42608 .77284 m .42828 .77343 L .40031 .69011 L F
.41236 .75744 m .42642 .77339 L .41213 .75625 L .676 .528 .677 r
F
.42642 .77339 m .42608 .77284 L .41213 .75625 L F
.41014 .74632 m .41453 .76971 L .41241 .75011 L .724 .488 0 r
F
.41453 .76971 m .41542 .77442 L .41485 .7698 L F
.41453 .76971 m .41485 .7698 L .41241 .75011 L F
.40011 .68967 m .40181 .69847 L .4005 .69188 L F
.40181 .69847 m .40223 .70087 L .4005 .69188 L F
.39544 .66506 m .39651 .67064 L .39569 .66658 L F
.39651 .67064 m .4014 .69619 L .39569 .66658 L F
.4014 .69619 m .40181 .69847 L .39573 .66682 L F
.39938 .68492 m .42941 .77679 L .46594 .73745 L .752 .551 .623 r
F
.40031 .69011 m .42941 .77679 L .39938 .68492 L F
.39573 .66682 m .40011 .68967 L .39605 .66876 L .724 .488 0 r
F
.40011 .68967 m .4005 .69188 L .39605 .66876 L F
.37872 .57825 m .39573 .66682 L .37652 .56743 L F
.39573 .66682 m .39605 .66876 L .37652 .56743 L F
.38766 .62443 m .39544 .66506 L .38764 .6247 L F
.39544 .66506 m .39573 .66682 L .38764 .6247 L F
.39044 .62428 m .39903 .64832 L .38825 .62328 L .999 .797 .489 r
F
.39903 .64832 m .39809 .64944 L .38825 .62328 L F
.38761 .625 m .4005 .69188 L .38753 .62603 L .724 .488 0 r
F
.4005 .69188 m .40164 .69837 L .38753 .62603 L F
.38753 .62603 m .40164 .69837 L .40846 .73739 L F
.37652 .56743 m .38761 .625 L .38753 .62603 L F
.38043 .58665 m .38766 .62443 L .37872 .57825 L F
.38766 .62443 m .38764 .6247 L .37872 .57825 L F
.37247 .54507 m .38043 .58665 L .37104 .53828 L F
.38043 .58665 m .37872 .57825 L .37104 .53828 L F
.37104 .53828 m .37872 .57825 L .37652 .56743 L F
.36464 .50418 m .37247 .54507 L .37104 .53828 L F
.36464 .50418 m .41014 .74632 L .38226 .5059 L F
.41014 .74632 m .41241 .75011 L .38226 .5059 L F
.42642 .77339 m .42941 .77679 L .42608 .77284 L .676 .528 .677 r
F
.41931 .70065 m .46594 .73745 L .41478 .69469 L .752 .551 .623 r
F
.36464 .55207 m .36841 .56264 L .35677 .53962 L .999 .797 .489 r
F
.36841 .56264 m .35938 .54618 L .35677 .53962 L F
.35677 .53962 m .37837 .59704 L .38706 .65555 L F
.34747 .50401 m .36464 .55207 L .35677 .53962 L F
.34747 .50401 m .39742 .6952 L .36464 .50418 L F
.41656 .65768 m .4873 .70393 L .46424 .68313 L .837 .442 .298 r
F
.41656 .65768 m .46424 .68313 L .41947 .64273 L F
.41341 .63588 m .4178 .64283 L .40873 .63339 L .93 .812 .708 r
F
.4178 .64283 m .41528 .64298 L .40873 .63339 L F
.25843 .55428 m .36295 .61604 L .35927 .60933 L .837 .442 .298 r
F
.38742 .54769 m .40541 .69337 L .38944 .54327 L .037 .128 .631 r
F
.40541 .69337 m .41542 .77442 L .40654 .69543 L F
.40541 .69337 m .40654 .69543 L .38944 .54327 L F
.38742 .54769 m .38944 .54327 L .38903 .53956 L F
.4404 .65363 m .49155 .68155 L .4332 .64732 L .837 .442 .298 r
F
.41799 .64139 m .4873 .70393 L .49155 .68155 L F
.40265 .65219 m .46594 .73745 L .4873 .70393 L .811 .539 .527 r
F
.38967 .54277 m .41542 .77442 L .43919 .78916 L .037 .128 .631 r
F
.38903 .53956 m .38944 .54327 L .38967 .54277 L F
.38944 .54327 m .41542 .77442 L .38967 .54277 L F
.25843 .55428 m .35927 .60933 L .25976 .54556 L .837 .442 .298 r
F
.35927 .60933 m .3604 .60687 L .25976 .54556 L F
.38226 .5059 m .38689 .54338 L .38903 .53956 L .037 .128 .631 r
F
.25 g
.5 Mabswid
.27118 .53371 m
.27274 .53491 L
s
.27274 .53491 m
.27886 .53965 L
s
.27886 .53965 m
.33285 .5814 L
s
0 g
.006 w
.23157 .5477 m
.23606 .55721 L
s
.23606 .55721 m
.24111 .56724 L
s
.25282 .58996 m .2891 .84541 L .30636 .85228 L 0 0 .537 r
F
.25 g
.5 Mabswid
.25287 .59029 m
.25421 .59973 L
s
.25421 .59973 m
.25461 .6026 L
s
.25461 .6026 m
.25621 .61385 L
s
.25621 .61385 m
.2891 .84541 L
s
0 g
.006 w
.62033 .30286 m
.62179 .31092 L
s
.51105 .39891 m .59784 .60131 L .52136 .38664 L .818 .801 .836 r
F
.5242 .39851 m .55764 .4906 L .53547 .44556 L .947 .836 .701 r
F
.55764 .4906 m .55602 .48954 L .53547 .44556 L F
.56157 .50142 m .5591 .49853 L .53547 .44556 L F
.56674 .51565 m .55597 .49676 L .54822 .47738 L F
.54977 .4776 m .54822 .47738 L .53547 .44556 L F
.56674 .51565 m .54822 .47738 L .54977 .4776 L F
.52363 .393 m .54804 .46152 L .5242 .39851 L F
.54804 .46152 m .59784 .60131 L .54721 .46187 L F
.54804 .46152 m .54721 .46187 L .5242 .39851 L F
.52136 .38664 m .52363 .393 L .5242 .39851 L F
.52136 .38664 m .53547 .44556 L .53324 .37775 L F
.51306 .40329 m .53547 .44556 L .5551 .49457 L .818 .801 .836 r
F
.51105 .39891 m .5551 .49457 L .55813 .50869 L F
.55813 .50869 m .5551 .49457 L .59784 .60131 L F
.53547 .44556 m .59784 .60131 L .57706 .61924 L .947 .836 .701 r
F
.55764 .4906 m .56157 .50142 L .55602 .48954 L F
.56157 .50142 m .56674 .51565 L .5591 .49853 L F
.56674 .51565 m .59784 .60131 L .55597 .49676 L F
.53547 .44556 m .55078 .47445 L .53324 .37775 L F
.53743 .40087 m .55078 .47445 L .54678 .45578 L .949 .74 .277 r
F
.55311 .48961 m .62849 .58582 L .59784 .60131 L .818 .801 .836 r
F
.55291 .47101 m .62849 .58582 L .55311 .48961 L F
.55286 .46545 m .55388 .46707 L .55291 .47101 L F
.55388 .46707 m .62849 .58582 L .55291 .47101 L F
.52688 .4241 m .55286 .46545 L .55311 .48961 L F
.54957 .47216 m .552 .48115 L .55078 .47445 L .947 .836 .701 r
F
.53547 .44556 m .552 .48115 L .54957 .47216 L F
.53547 .44556 m .57706 .61924 L .552 .48115 L F
.54696 .47425 m .55083 .47954 L .52688 .4241 L .66 .759 .923 r
F
.55083 .47954 m .54678 .45578 L .52688 .4241 L F
.55078 .47445 m .55317 .48762 L .54829 .46752 L .949 .74 .277 r
F
.55317 .48762 m .55337 .48869 L .5531 .48757 L F
.55317 .48762 m .5531 .48757 L .54829 .46752 L F
.51105 .39891 m .52688 .4241 L .53547 .44556 L .818 .801 .836 r
F
.51105 .39891 m .53547 .44556 L .51306 .40329 L F
.52964 .45055 m .54696 .47425 L .52688 .4241 L .66 .759 .923 r
F
.52964 .45055 m .54745 .46741 L .55083 .47954 L F
.55298 .48749 m .55193 .48673 L .55076 .48054 L .949 .74 .277 r
F
.55099 .48012 m .55076 .48054 L .55002 .47664 L F
.55337 .48869 m .55076 .48054 L .55099 .48012 L F
.55337 .48869 m .55002 .47664 L .54829 .46752 L F
.54869 .46467 m .54829 .46752 L .5406 .42694 L F
.55078 .47445 m .54829 .46752 L .54869 .46467 L F
.55083 .47954 m .62849 .58582 L .54678 .45578 L .66 .759 .923 r
F
.55083 .47954 m .55432 .48141 L .55141 .48034 L F
.55469 .4816 m .57019 .48989 L .55464 .48199 L F
.57019 .48989 m .57254 .49114 L .57027 .48998 L F
.57019 .48989 m .57027 .48998 L .55464 .48199 L F
.53324 .37775 m .53743 .40087 L .5406 .42694 L .949 .74 .277 r
F
.53743 .40087 m .54678 .45578 L .5406 .42694 L F
.54908 .48365 m .57706 .61924 L .57181 .63551 L F
.54757 .46784 m .55076 .48054 L .54999 .48198 L F
.5406 .42694 m .55002 .47664 L .54757 .46784 L F
.55002 .47664 m .55076 .48054 L .54757 .46784 L F
.50271 .4137 m .52964 .45055 L .51105 .39891 L .66 .759 .923 r
F
.52964 .45055 m .52688 .4241 L .51105 .39891 L F
.51682 .42806 m .54428 .45599 L .52964 .45055 L F
.54428 .45599 m .54745 .46741 L .52964 .45055 L F
.5406 .42694 m .54999 .48198 L .5482 .47777 L .949 .74 .277 r
F
.54322 .37376 m .54572 .46115 L .54594 .37267 L F
.53324 .37775 m .53578 .39477 L .54322 .37376 L F
.53578 .39477 m .54572 .46115 L .54322 .37376 L F
.49607 .42997 m .51687 .44825 L .50271 .4137 L .356 .651 .967 r
F
.54572 .46115 m .55582 .47301 L .54594 .37267 L .949 .74 .277 r
F
.55643 .46835 m .56126 .47327 L .55607 .47106 L .66 .759 .923 r
F
.56126 .47327 m .66265 .5764 L .55786 .47726 L F
.55259 .44022 m .55582 .47301 L .55437 .44952 L 0 .034 .571 r
F
.55582 .47301 m .55675 .46592 L .55233 .41623 L F
.56126 .47327 m .55786 .47726 L .54745 .46741 L .66 .759 .923 r
F
.54745 .46741 m .57254 .49114 L .55083 .47954 L F
.57254 .49114 m .66265 .5764 L .55141 .48034 L F
.5582 .48458 m .66265 .5764 L .55643 .46835 L .356 .651 .967 r
F
.55433 .48433 m .66265 .5764 L .62849 .58582 L .66 .759 .923 r
F
.55141 .48034 m .5545 .48301 L .55433 .48433 L F
.5545 .48301 m .66265 .5764 L .55433 .48433 L F
.55582 .47301 m .55711 .48616 L .55675 .46592 L 0 .034 .571 r
F
.54594 .37267 m .56163 .47961 L .55886 .37117 L F
.56146 .48745 m .60395 .51603 L .66265 .5764 L .356 .651 .967 r
F
.56237 .48741 m .6935 .57627 L .56146 .48745 L F
.55918 .48316 m .56515 .4873 L .5582 .48458 L F
.56515 .4873 m .6935 .57627 L .56237 .48741 L F
.56515 .4873 m .56237 .48741 L .5582 .48458 L F
.57161 .46113 m .57363 .48695 L .5774 .45433 L .429 .407 .732 r
F
.56163 .47961 m .57033 .48709 L .55886 .37117 L 0 .034 .571 r
F
.55711 .48616 m .55838 .48432 L .55675 .46592 L F
.54428 .45599 m .55643 .46835 L .54745 .46741 L .66 .759 .923 r
F
.55643 .46835 m .55607 .47106 L .54745 .46741 L F
.5482 .47777 m .54999 .48198 L .54908 .48365 L .949 .74 .277 r
F
.55076 .48054 m .57706 .61924 L .54908 .48365 L F
.55432 .48141 m .55469 .4816 L .55407 .4817 L .66 .759 .923 r
F
.55469 .4816 m .55464 .48199 L .55407 .4817 L F
.55432 .48141 m .55407 .4817 L .55141 .48034 L F
.55337 .48869 m .57706 .61924 L .55193 .48673 L .949 .74 .277 r
F
.55337 .48869 m .55193 .48673 L .55298 .48749 L F
.54572 .46115 m .5482 .47777 L .55582 .47301 L F
.5482 .47777 m .57181 .63551 L .55711 .48616 L F
.5482 .47777 m .55711 .48616 L .55582 .47301 L F
.50271 .4137 m .51682 .42806 L .52964 .45055 L .66 .759 .923 r
F
.51767 .44598 m .54551 .46661 L .52211 .43343 L .356 .651 .967 r
F
.51687 .44825 m .54551 .46661 L .51767 .44598 L F
.51687 .44825 m .5582 .48458 L .54551 .46661 L F
.5582 .48458 m .55643 .46835 L .52211 .43343 L F
.51687 .44825 m .52211 .43343 L .50271 .4137 L F
.57301 .48698 m .6935 .57627 L .57084 .48707 L F
.56816 .46518 m .57033 .48709 L .57141 .46523 L .429 .407 .732 r
F
.57033 .48709 m .57363 .48695 L .57161 .46113 L F
.55811 .45557 m .56011 .48182 L .56163 .47961 L 0 .034 .571 r
F
.55675 .46592 m .55838 .48432 L .55811 .45557 L F
.5701 .4878 m .6935 .57627 L .56364 .48625 L .356 .651 .967 r
F
.56446 .48243 m .6935 .57627 L .56065 .48103 L F
.60395 .51603 m .6935 .57627 L .67403 .57635 L F
.60395 .51603 m .67403 .57635 L .66265 .5764 L F
.57397 .50014 m .6935 .57627 L .57301 .48698 L 0 .212 .632 r
F
.64637 .57166 m .6202 .64631 L .65494 .63854 L .611 .516 .722 r
F
.64637 .57166 m .65494 .63854 L .65083 .58358 L F
.64283 .56772 m .6202 .64631 L .64637 .57166 L F
.61964 .54314 m .6202 .64631 L .64373 .56461 L F
.60206 .51745 m .71388 .58809 L .59963 .51595 L 0 .212 .632 r
F
.71388 .58809 m .7139 .58811 L .71388 .58809 L F
.71388 .58809 m .71388 .58809 L .59963 .51595 L F
.57174 .37238 m .63326 .53665 L .58455 .3749 L .611 .516 .722 r
F
.57515 .50088 m .7139 .58811 L .6935 .57627 L 0 .212 .632 r
F
.56065 .48103 m .5701 .4878 L .55918 .48316 L .356 .651 .967 r
F
.5701 .4878 m .56364 .48625 L .55918 .48316 L F
.5582 .48458 m .56237 .48741 L .56146 .48745 L F
.55838 .48432 m .55897 .49094 L .56011 .48182 L 0 .034 .571 r
F
.58943 .50967 m .60751 .52106 L .57515 .50088 L 0 .212 .632 r
F
.60751 .52106 m .7139 .58811 L .62125 .52987 L F
.60751 .52106 m .62125 .52987 L .57515 .50088 L F
.55886 .37117 m .58974 .50969 L .57174 .37238 L .429 .407 .732 r
F
.59259 .52244 m .6202 .64631 L .60171 .54178 L F
.59334 .52269 m .60171 .54178 L .59864 .52442 L F
.59259 .52244 m .60171 .54178 L .59334 .52269 L F
.55897 .49094 m .57181 .63551 L .5609 .49231 L 0 .034 .571 r
F
.57163 .50028 m .58602 .64578 L .57494 .50378 L .429 .407 .732 r
F
.59864 .52442 m .6202 .64631 L .61964 .54314 L .611 .516 .722 r
F
.57363 .48695 m .57469 .50057 L .57886 .48674 L .429 .407 .732 r
F
.57397 .50014 m .58943 .50967 L .57515 .50088 L 0 .212 .632 r
F
.58026 .50395 m .58943 .50967 L .57397 .50014 L F
.57494 .50378 m .58602 .64578 L .57986 .50898 L .429 .407 .732 r
F
.56369 .49362 m .57181 .63551 L .58602 .64578 L 0 .034 .571 r
F
.56128 .48012 m .56446 .48243 L .56065 .48103 L .356 .651 .967 r
F
.56211 .47891 m .57301 .48698 L .56128 .48012 L F
.57301 .48698 m .57084 .48707 L .56128 .48012 L F
.56163 .47961 m .5625 .49295 L .56369 .49362 L 0 .034 .571 r
F
.5625 .49295 m .57181 .63551 L .56369 .49362 L F
.55897 .49094 m .56088 .49203 L .56011 .48182 L F
.57033 .48709 m .57147 .49862 L .57363 .48695 L .429 .407 .732 r
F
.57147 .49862 m .57163 .50028 L .57185 .49885 L F
.57147 .49862 m .57185 .49885 L .57363 .48695 L F
.57163 .50028 m .57494 .50378 L .57469 .50057 L F
.57185 .49885 m .57469 .50057 L .57363 .48695 L F
.57163 .50028 m .57469 .50057 L .57185 .49885 L F
.56011 .48182 m .56088 .49203 L .56163 .47961 L 0 .034 .571 r
F
.56088 .49203 m .57181 .63551 L .5625 .49295 L F
.56088 .49203 m .5625 .49295 L .56163 .47961 L F
.56163 .47961 m .56369 .49362 L .57033 .48709 L F
.56369 .49362 m .57085 .49822 L .57033 .48709 L F
.57389 .56308 m .5808 .593 L .57033 .48709 L F
.55711 .48616 m .57181 .63551 L .55838 .48432 L F
.5568 .4892 m .57397 .50014 L .55548 .48348 L 0 .212 .632 r
F
.5568 .4892 m .56635 .49513 L .56421 .49392 L F
.4901 .44671 m .5568 .4892 L .49607 .42997 L F
.54443 .48132 m .54985 .48473 L .5568 .4892 L F
.5568 .4892 m .55548 .48348 L .49607 .42997 L F
.54985 .48473 m .56635 .49513 L .5568 .4892 L F
.56369 .49362 m .57389 .56308 L .57085 .49822 L 0 .034 .571 r
F
.57389 .56308 m .58602 .64578 L .5808 .593 L F
.57305 .4993 m .57323 .49947 L .56635 .49513 L 0 .212 .632 r
F
.57469 .50057 m .57962 .50356 L .57886 .48674 L .429 .407 .732 r
F
.55838 .48432 m .56011 .48182 L .55811 .45557 L 0 .034 .571 r
F
.54381 .46742 m .56128 .48012 L .54687 .47463 L .356 .651 .967 r
F
.56128 .48012 m .55918 .48316 L .54687 .47463 L F
.50827 .43901 m .56211 .47891 L .51487 .44637 L F
.56211 .47891 m .56128 .48012 L .51487 .44637 L F
.51327 .44486 m .51487 .44637 L .51405 .44577 L F
.50827 .43901 m .51487 .44637 L .51327 .44486 L F
.54687 .47463 m .55918 .48316 L .5582 .48458 L F
.51405 .44577 m .54381 .46742 L .54687 .47463 L F
.49607 .42997 m .50827 .43901 L .51405 .44577 L F
.57397 .50014 m .57301 .48698 L .49607 .42997 L 0 .212 .632 r
F
.58974 .50969 m .59684 .51423 L .57174 .37238 L .429 .407 .732 r
F
.59314 .49333 m .59684 .51423 L .60216 .51079 L .611 .516 .722 r
F
.59684 .51423 m .61955 .52821 L .6194 .49964 L F
.58429 .50639 m .7139 .58811 L .58229 .50517 L 0 .212 .632 r
F
.58903 .50926 m .59496 .513 L .58429 .50639 L F
.59496 .513 m .7139 .58811 L .58429 .50639 L F
.64373 .56461 m .65083 .58358 L .64734 .56582 L .611 .516 .722 r
F
.65083 .58358 m .67014 .63514 L .65623 .59284 L F
.65083 .58358 m .65623 .59284 L .64734 .56582 L F
.58229 .50517 m .58943 .50967 L .58026 .50395 L 0 .212 .632 r
F
.58457 .48651 m .58476 .50667 L .58974 .50969 L .429 .407 .732 r
F
.60206 .51745 m .59963 .51595 L .58903 .50926 L 0 .212 .632 r
F
.57886 .48674 m .57962 .50356 L .58457 .48651 L .429 .407 .732 r
F
.57962 .50356 m .58084 .5043 L .58457 .48651 L F
.57986 .50898 m .58483 .51424 L .58457 .48651 L F
.59025 .51 m .58903 .50926 L .54196 .47954 L 0 .212 .632 r
F
.60206 .51745 m .58903 .50926 L .59025 .51 L F
.57962 .50356 m .57986 .50898 L .58084 .5043 L .429 .407 .732 r
F
.57986 .50898 m .58602 .64578 L .58483 .51424 L F
.59227 .52211 m .59259 .52244 L .59334 .52269 L .798 .318 .074 r
F
.59227 .52211 m .59334 .52269 L .59224 .52188 L F
.59259 .52244 m .62752 .55017 L .59334 .52269 L F
.59133 .52111 m .58602 .64578 L .60868 .64613 L .429 .407 .732 r
F
.58948 .51916 m .58602 .64578 L .59133 .52111 L F
.59334 .52269 m .59236 .52045 L .59202 .5202 L .798 .318 .074 r
F
.59334 .52269 m .59202 .5202 L .59224 .52188 L F
.58974 .50969 m .58948 .51916 L .59133 .52111 L .429 .407 .732 r
F
.58974 .50969 m .60868 .64613 L .59191 .51943 L F
.57012 .49727 m .5907 .51027 L .56963 .49699 L 0 .212 .632 r
F
.5907 .51027 m .60206 .51745 L .59025 .51 L F
.5907 .51027 m .59025 .51 L .56963 .49699 L F
.58476 .50667 m .58602 .64578 L .58974 .50969 L .429 .407 .732 r
F
.58903 .50926 m .57323 .49947 L .57305 .4993 L 0 .212 .632 r
F
.58903 .50926 m .58229 .50517 L .57323 .49947 L F
.5677 .4959 m .56635 .49513 L .54443 .48132 L F
.58903 .50926 m .56635 .49513 L .5677 .4959 L F
.54196 .47954 m .58903 .50926 L .54443 .48132 L F
.56635 .49513 m .57323 .49947 L .56421 .49392 L F
.57323 .49947 m .58229 .50517 L .56421 .49392 L F
.58229 .50517 m .58026 .50395 L .56421 .49392 L F
.54129 .47906 m .57012 .49727 L .54196 .47954 L F
.57012 .49727 m .56963 .49699 L .54196 .47954 L F
.57469 .50057 m .57494 .50378 L .57962 .50356 L .429 .407 .732 r
F
.57494 .50378 m .57986 .50898 L .57962 .50356 L F
.56421 .49392 m .58026 .50395 L .57397 .50014 L 0 .212 .632 r
F
.58974 .50969 m .59191 .51943 L .59684 .51423 L .429 .407 .732 r
F
.59191 .51943 m .59294 .52176 L .59684 .51423 L F
.59259 .52244 m .59864 .52442 L .59684 .51423 L F
.60192 .52734 m .71389 .5881 L .60206 .51745 L .798 .318 .074 r
F
.71389 .5881 m .71388 .58809 L .60206 .51745 L F
.59684 .51423 m .59864 .52442 L .61955 .52821 L .611 .516 .722 r
F
.60192 .52734 m .6519 .56735 L .71389 .5881 L .798 .318 .074 r
F
.62353 .54661 m .6519 .56735 L .60192 .52734 L F
.62752 .55017 m .63082 .55249 L .62353 .54661 L F
.63082 .55249 m .6519 .56735 L .62353 .54661 L F
.66157 .58231 m .71709 .61329 L .66337 .57875 L .836 .492 .405 r
F
.66408 .5847 m .67014 .63514 L .67124 .59151 L .707 .555 .679 r
F
.64734 .56582 m .65623 .59284 L .66337 .57875 L F
.66157 .58231 m .7097 .62808 L .71709 .61329 L .836 .492 .405 r
F
.65623 .59284 m .67014 .63514 L .66337 .57875 L .707 .555 .679 r
F
.69473 .60406 m .67014 .63514 L .71273 .61858 L F
.60976 .54061 m .6492 .56732 L .60136 .53173 L .798 .318 .074 r
F
.6492 .56732 m .71709 .61329 L .63082 .55249 L F
.6492 .56732 m .63082 .55249 L .60136 .53173 L F
.66136 .57713 m .71709 .61329 L .6492 .56732 L F
.6519 .56735 m .71709 .61329 L .71389 .5881 L F
.64982 .57004 m .71709 .61329 L .64818 .56858 L F
.67202 .56079 m .6714 .58523 L .71022 .58447 L .707 .555 .679 r
F
.6714 .58523 m .67014 .63514 L .69473 .60406 L F
.6714 .58523 m .69473 .60406 L .71022 .58447 L F
.65027 .576 m .70517 .63717 L .7097 .62808 L .836 .492 .405 r
F
.65027 .576 m .7097 .62808 L .66157 .58231 L F
.66337 .57875 m .66408 .5847 L .6714 .58523 L .707 .555 .679 r
F
.66408 .5847 m .67124 .59151 L .6714 .58523 L F
.65027 .576 m .66157 .58231 L .64982 .57004 L .836 .492 .405 r
F
.66157 .58231 m .66337 .57875 L .64982 .57004 L F
.62756 .50566 m .64734 .56582 L .67299 .52239 L .707 .555 .679 r
F
.64734 .56582 m .6714 .58523 L .67299 .52239 L F
.59864 .52442 m .61964 .54314 L .61955 .52821 L .611 .516 .722 r
F
.60192 .52734 m .60206 .51745 L .58683 .50782 L .798 .318 .074 r
F
.56065 .4919 m .5609 .49231 L .56088 .49203 L 0 .034 .571 r
F
.55897 .49094 m .5609 .49231 L .56065 .4919 L F
.50076 .45345 m .54129 .47906 L .50417 .45567 L 0 .212 .632 r
F
.54129 .47906 m .54196 .47954 L .50417 .45567 L F
.50417 .45567 m .54196 .47954 L .54443 .48132 L F
.4901 .44671 m .50076 .45345 L .50417 .45567 L F
.59236 .52045 m .58683 .50782 L .4901 .44671 L .798 .318 .074 r
F
.60192 .52734 m .58683 .50782 L .59236 .52045 L F
.59191 .51943 m .59259 .52244 L .59294 .52176 L .429 .407 .732 r
F
.59191 .51943 m .60868 .64613 L .6202 .64631 L F
.58439 .51977 m .60136 .53173 L .59259 .52244 L .798 .318 .074 r
F
.60136 .53173 m .62752 .55017 L .59259 .52244 L F
.59224 .52188 m .59202 .5202 L .4901 .44671 L F
.57248 .51137 m .58439 .51977 L .59259 .52244 L F
.57248 .51137 m .59259 .52244 L .59227 .52211 L F
.47479 .47808 m .6205 .55939 L .48341 .46304 L .836 .492 .405 r
F
.6205 .55939 m .64456 .57282 L .61981 .55596 L F
.6205 .55939 m .61981 .55596 L .48341 .46304 L F
.64456 .57282 m .65027 .576 L .64391 .5717 L F
.64456 .57282 m .64391 .5717 L .48341 .46304 L F
.64373 .56461 m .64283 .56772 L .64637 .57166 L .611 .516 .722 r
F
.61718 .54846 m .66136 .57713 L .60976 .54061 L .798 .318 .074 r
F
.66136 .57713 m .6492 .56732 L .60976 .54061 L F
.71389 .5881 m .71709 .61329 L .7139 .58811 L F
.71022 .58447 m .69473 .60406 L .72728 .61292 L .707 .555 .679 r
F
.69473 .60406 m .71273 .61858 L .72728 .61292 L F
.67299 .52239 m .67202 .56079 L .71022 .58447 L F
.54083 .49892 m .61718 .54846 L .5428 .49527 L .798 .318 .074 r
F
.61718 .54846 m .60976 .54061 L .5428 .49527 L F
.5766 .51815 m .60976 .54061 L .57248 .51137 L F
.60976 .54061 m .60136 .53173 L .57248 .51137 L F
.48341 .46304 m .59227 .52211 L .4901 .44671 L F
.59227 .52211 m .59224 .52188 L .4901 .44671 L F
.59334 .52269 m .60192 .52734 L .59236 .52045 L F
.59334 .52269 m .62752 .55017 L .60192 .52734 L F
.63326 .53665 m .64373 .56461 L .63894 .54027 L .611 .516 .722 r
F
.64373 .56461 m .64734 .56582 L .63894 .54027 L F
.5428 .49527 m .5766 .51815 L .57248 .51137 L .798 .318 .074 r
F
.63326 .53665 m .61964 .54314 L .64373 .56461 L .611 .516 .722 r
F
.6194 .49964 m .61955 .52821 L .63326 .53665 L F
.61955 .52821 m .61964 .54314 L .63326 .53665 L F
.71389 .5881 m .7139 .58811 L .71388 .58809 L .798 .318 .074 r
F
.63326 .53665 m .63894 .54027 L .58455 .3749 L .611 .516 .722 r
F
.60238 .49555 m .60216 .51079 L .6194 .49964 L F
.59314 .49333 m .60216 .51079 L .60238 .49555 L F
.65027 .576 m .64982 .57004 L .48341 .46304 L .836 .492 .405 r
F
.65083 .58358 m .65494 .63854 L .67014 .63514 L .611 .516 .722 r
F
.54163 .51538 m .69852 .65049 L .70517 .63717 L .836 .492 .405 r
F
.54163 .51538 m .70517 .63717 L .65027 .576 L F
.54041 .49969 m .64982 .57004 L .54083 .49892 L .798 .318 .074 r
F
.64982 .57004 m .64818 .56858 L .54083 .49892 L F
.57174 .37238 m .59314 .49333 L .6194 .49964 L .611 .516 .722 r
F
.58455 .3749 m .62756 .50566 L .67299 .52239 L .707 .555 .679 r
F
.57115 .46167 m .57141 .46523 L .57161 .46113 L .429 .407 .732 r
F
.56816 .46518 m .57141 .46523 L .57115 .46167 L F
.57363 .48695 m .57886 .48674 L .5774 .45433 L F
.5774 .45433 m .57886 .48674 L .58457 .48651 L F
.5525 .43237 m .55437 .44952 L .55233 .41623 L 0 .034 .571 r
F
.55259 .44022 m .55437 .44952 L .5525 .43237 L F
.56768 .41071 m .57161 .46113 L .5774 .45433 L .429 .407 .732 r
F
.49381 .46973 m .54041 .49969 L .4964 .47009 L .798 .318 .074 r
F
.54041 .49969 m .54083 .49892 L .4964 .47009 L F
.55233 .41623 m .55675 .46592 L .55811 .45557 L 0 .034 .571 r
F
.56418 .42498 m .56816 .46518 L .56768 .41071 L .429 .407 .732 r
F
.56816 .46518 m .57161 .46113 L .56768 .41071 L F
.4964 .47009 m .54083 .49892 L .5428 .49527 L .798 .318 .074 r
F
.48941 .48623 m .54014 .52608 L .54163 .51538 L .836 .492 .405 r
F
.54014 .52608 m .69852 .65049 L .54163 .51538 L F
.55886 .37117 m .56418 .42498 L .56768 .41071 L .429 .407 .732 r
F
.54594 .37267 m .55259 .44022 L .55233 .41623 L 0 .034 .571 r
F
.47479 .47808 m .4868 .48733 L .48941 .48623 L .836 .492 .405 r
F
.4868 .48733 m .69852 .65049 L .48941 .48623 L F
.48341 .46304 m .49381 .46973 L .4964 .47009 L .798 .318 .074 r
F
.25 g
.5 Mabswid
.52688 .4241 m
.54433 .45188 L
s
.51105 .39891 m
.51255 .40129 L
s
.51255 .40129 m
.52688 .4241 L
s
0 g
.006 w
.24111 .56724 m
.24581 .57686 L
s
.25 g
.5 Mabswid
.26375 .53858 m
.26404 .53876 L
s
.47807 .67139 m
.4804 .67283 L
s
.26404 .53876 m
.26635 .54019 L
s
.26635 .54019 m
.26836 .54143 L
s
1 0 0 r
.003 w
.4804 .67283 m
.49155 .68155 L
s
.25 g
.5 Mabswid
.46295 .65625 m
.47863 .67195 L
s
.39976 .59295 m
.40358 .59678 L
s
.40358 .59678 m
.42383 .61707 L
s
.42383 .61707 m
.44142 .63469 L
s
.46012 .65341 m
.46295 .65625 L
s
.44142 .63469 m
.45898 .65227 L
s
.45898 .65227 m
.46012 .65341 L
s
0 g
.006 w
.62179 .31092 m
.6241 .32126 L
s
.25 g
.5 Mabswid
.54428 .45599 m
.55643 .46835 L
s
.52211 .43343 m
.54428 .45599 L
s
.51682 .42806 m
.52211 .43343 L
s
.50271 .4137 m
.51682 .42806 L
s
.40603 .62419 m
.41341 .63588 L
s
.41341 .63588 m
.4178 .64283 L
s
0 g
.006 w
.24581 .57686 m
.24971 .58485 L
s
.6241 .32126 m
.62704 .33262 L
s
.25 g
.5 Mabswid
.62642 .37081 m
.63136 .37429 L
s
.61904 .3756 m .82092 .5507 L .84083 .52185 L .846 .473 .344 r
F
.25 g
.63136 .37429 m
.63758 .37867 L
s
.63758 .37867 m
.65183 .38871 L
s
.65183 .38871 m
.69942 .42223 L
s
.69942 .42223 m
.83325 .51651 L
s
.83325 .51651 m
.84083 .52185 L
s
.6432 .37198 m
.7289 .42866 L
s
1 0 0 r
.003 w
.83871 .50127 m
.84083 .52185 L
s
.25 g
.5 Mabswid
.63021 .34428 m
.66326 .37649 L
s
.63298 .35561 m
.66452 .37888 L
s
0 g
.006 w
.62704 .33262 m
.62985 .34393 L
s
.25 g
.5 Mabswid
.25976 .54556 m
.26287 .54738 L
s
.4332 .64732 m
.49155 .68155 L
s
.41633 .63742 m
.4332 .64732 L
s
.41325 .63561 m
.41633 .63742 L
s
1 0 0 r
.003 w
.4873 .70393 m
.49155 .68155 L
s
.25 g
.5 Mabswid
.55283 .47203 m
.56211 .47891 L
s
.54253 .4644 m
.55283 .47203 L
s
.56211 .47891 m
.57301 .48698 L
s
.50827 .43901 m
.54253 .4644 L
s
.49607 .42997 m
.50827 .43901 L
s
.25282 .58996 m .30636 .85228 L .25528 .59132 L 0 0 .537 r
F
0 g
.006 w
.24971 .58485 m
.25282 .58996 L
s
.25 g
.5 Mabswid
.25282 .58996 m
.25287 .59029 L
s
0 g
.006 w
.62985 .34393 m
.63139 .35444 L
s
.6305 .36358 m
.63139 .35444 L
s
.25528 .59132 m .33998 .84132 L .25716 .58869 L .352 .333 .699 r
F
.25528 .59132 m .30636 .85228 L .33998 .84132 L F
.25 g
.5 Mabswid
.26287 .54738 m
.3048 .57199 L
s
.26836 .54143 m
.30707 .56542 L
s
0 g
.006 w
.25282 .58996 m
.25528 .59132 L
s
.25 g
.5 Mabswid
.25744 .60235 m
.30636 .85228 L
s
.25576 .59373 m
.25744 .60235 L
s
.25531 .59145 m
.25576 .59373 L
s
.25528 .59132 m
.25531 .59145 L
s
1 0 0 r
.003 w
.2891 .84541 m
.30636 .85228 L
s
0 g
.006 w
.62642 .37081 m
.6305 .36358 L
s
.25 g
.5 Mabswid
.563 .54606 m
.57181 .63551 L
s
.55259 .44022 m
.55524 .46714 L
s
.54605 .37376 m
.55259 .44022 L
s
.54594 .37267 m
.54605 .37376 L
s
1 0 0 r
.003 w
.57181 .63551 m
.58602 .64578 L
s
.25716 .58869 m .38417 .81418 L .25834 .58254 L .561 .469 .707 r
F
.25716 .58869 m .33998 .84132 L .38417 .81418 L F
.25 g
.5 Mabswid
.35092 .5926 m
.36701 .60257 L
s
.36701 .60257 m
.37442 .60716 L
s
.35772 .60303 m
.36121 .60508 L
s
.36121 .60508 m
.37617 .61386 L
s
.3048 .57199 m
.33235 .58815 L
s
.33235 .58815 m
.35772 .60303 L
s
.30707 .56542 m
.33155 .58059 L
s
.33155 .58059 m
.35092 .5926 L
s
0 g
.006 w
.25528 .59132 m
.25716 .58869 L
s
.25 g
.5 Mabswid
.30138 .72356 m
.33998 .84132 L
s
.25856 .59295 m
.30138 .72356 L
s
.25849 .59273 m
.25856 .59295 L
s
.25797 .59115 m
.25849 .59273 L
s
.25716 .58869 m
.25797 .59115 L
s
1 0 0 r
.003 w
.30636 .85228 m
.33998 .84132 L
s
0 g
.006 w
.25716 .58869 m
.25834 .58254 L
s
.25 g
.5 Mabswid
.41656 .65768 m
.4873 .70393 L
s
.41219 .65482 m
.41656 .65768 L
s
.37368 .62963 m
.38165 .63485 L
s
.32887 .60034 m
.33428 .60387 L
s
.33428 .60387 m
.36778 .62578 L
s
.36778 .62578 m
.37368 .62963 L
s
.25843 .55428 m
.25869 .55445 L
s
.25869 .55445 m
.32887 .60034 L
s
1 0 0 r
.003 w
.46594 .73745 m
.4873 .70393 L
s
.25 g
.5 Mabswid
.35391 .75848 m
.38417 .81418 L
s
.32125 .69835 m
.35391 .75848 L
s
.314 .685 m
.32125 .69835 L
s
.25893 .58363 m
.3067 .67158 L
s
.3067 .67158 m
.314 .685 L
s
.25876 .58332 m
.25893 .58363 L
s
.25834 .58254 m
.25876 .58332 L
s
0 g
.006 w
.25865 .57533 m
.25871 .5739 L
s
.25834 .58254 m
.25865 .57533 L
s
.25 g
.5 Mabswid
.54129 .47906 m
.57012 .49727 L
s
.71388 .58809 m
.7139 .58811 L
s
.71148 .58658 m
.71388 .58809 L
s
.4901 .44671 m
.50076 .45345 L
s
1 0 0 r
.003 w
.7139 .58811 m
.7143 .59128 L
s
.60895 .37764 m .82092 .5507 L .61904 .3756 L .82 .543 .52 r
F
.25 g
.5 Mabswid
.61904 .3756 m
.61983 .37629 L
s
0 g
.006 w
.61904 .3756 m
.62642 .37081 L
s
.60895 .37764 m .78086 .58301 L .82092 .5507 L .82 .543 .52 r
F
1 0 0 r
.003 w
.82092 .5507 m
.84083 .52185 L
s
.25 g
.5 Mabswid
.7268 .46906 m
.82092 .5507 L
s
.66975 .41959 m
.7268 .46906 L
s
.61983 .37629 m
.66975 .41959 L
s
0 g
.006 w
.6111 .37721 m
.61904 .3756 L
s
.25 g
.5 Mabswid
.39437 .73514 m
.40877 .75226 L
s
.40877 .75226 m
.41197 .75606 L
s
.36624 .7017 m
.39437 .73514 L
s
.35107 .68368 m
.36624 .7017 L
s
.32927 .65777 m
.34805 .68009 L
s
.34805 .68009 m
.35107 .68368 L
s
.28567 .60594 m
.32927 .65777 L
s
.25871 .5739 m
.28567 .60594 L
s
0 g
.006 w
.25849 .56406 m
.25871 .5739 L
s
1 0 0 r
.003 w
.33998 .84132 m
.38417 .81418 L
s
.59714 .37712 m .78086 .58301 L .60895 .37764 L .771 .563 .617 r
F
.25 g
.5 Mabswid
.60895 .37764 m
.64102 .41596 L
s
0 g
.006 w
.60895 .37764 m
.6111 .37721 L
s
.25 g
.5 Mabswid
.4213 .70013 m
.46594 .73745 L
s
.37993 .66556 m
.38535 .67009 L
s
.38535 .67009 m
.3924 .67598 L
s
.34822 .63906 m
.37993 .66556 L
s
.33648 .62924 m
.33826 .63073 L
s
.33826 .63073 m
.34822 .63906 L
s
.29979 .59858 m
.33648 .62924 L
s
.25849 .56406 m
.29979 .59858 L
s
1 0 0 r
.003 w
.4354 .77033 m
.46594 .73745 L
s
.25 g
.5 Mabswid
.5808 .593 m
.58602 .64578 L
s
.57724 .55703 m
.5808 .593 L
s
.56816 .46518 m
.5701 .48483 L
s
.56418 .42498 m
.56816 .46518 L
s
.55886 .37117 m
.56418 .42498 L
s
1 0 0 r
.003 w
.58602 .64578 m
.6202 .64631 L
s
0 g
.006 w
.25843 .55428 m
.25849 .56406 L
s
.59714 .37712 m .72728 .61292 L .78086 .58301 L .771 .563 .617 r
F
1 0 0 r
.003 w
.78086 .58301 m
.82092 .5507 L
s
.25 g
.5 Mabswid
.7575 .5551 m
.78086 .58301 L
s
.58455 .3749 m .72728 .61292 L .59714 .37712 L .707 .555 .679 r
F
.25 g
.64102 .41596 m
.69704 .48288 L
s
.69704 .48288 m
.7575 .5551 L
s
.59848 .51519 m
.60206 .51745 L
s
.5907 .51027 m
.59848 .51519 L
s
0 g
.006 w
.59714 .37712 m
.60895 .37764 L
s
.25 g
.5 Mabswid
.71231 .5858 m
.72728 .61292 L
s
.71231 .5858 m
.71231 .5858 L
s
.69208 .54914 m
.71231 .5858 L
s
.67987 .52702 m
.69208 .54914 L
s
.6488 .47072 m
.67987 .52702 L
s
.61785 .41466 m
.62483 .42729 L
s
.62483 .42729 m
.6488 .47072 L
s
.59714 .37712 m
.61785 .41466 L
s
.57012 .49727 m
.58683 .50782 L
s
.58683 .50782 m
.5907 .51027 L
s
0 g
.006 w
.58455 .3749 m
.59714 .37712 L
s
1 0 0 r
.003 w
.38417 .81418 m
.41849 .78582 L
s
.41849 .78582 m
.42505 .78039 L
s
.25 g
.5 Mabswid
.41241 .75011 m
.41485 .7698 L
s
.41485 .7698 m
.41542 .77442 L
s
1 0 0 r
.003 w
.41542 .77442 m
.41673 .77523 L
s
0 g
.006 w
.25843 .55428 m
.25976 .54556 L
s
.25 g
.5 Mabswid
.63894 .54027 m
.64734 .56582 L
s
.66727 .62641 m
.67014 .63514 L
s
.62756 .50566 m
.63894 .54027 L
s
.61406 .46463 m
.62756 .50566 L
s
.58494 .37608 m
.61348 .46287 L
s
.61348 .46287 m
.61406 .46463 L
s
.58455 .3749 m
.58494 .37608 L
s
0 g
.006 w
.57174 .37238 m
.58455 .3749 L
s
1 0 0 r
.003 w
.72728 .61292 m
.78086 .58301 L
s
.25 g
.5 Mabswid
.55846 .5113 m
.64982 .57004 L
s
.54041 .49969 m
.55846 .5113 L
s
.64982 .57004 m
.66337 .57875 L
s
.48411 .46349 m
.49381 .46973 L
s
.48341 .46304 m
.48411 .46349 L
s
1 0 0 r
.003 w
.7097 .62808 m
.71486 .61775 L
s
.25 g
.5 Mabswid
.60869 .58127 m
.6202 .64631 L
s
.59314 .49333 m
.59682 .51414 L
s
.581 .4247 m
.59195 .48662 L
s
.59195 .48662 m
.59314 .49333 L
s
.57177 .3725 m
.581 .4247 L
s
.57174 .37238 m
.57177 .3725 L
s
1 0 0 r
.003 w
.6202 .64631 m
.67014 .63514 L
s
0 g
.006 w
.25976 .54556 m
.26375 .53858 L
s
.55886 .37117 m
.57174 .37238 L
s
.26375 .53858 m
.27118 .53371 L
s
1 0 0 r
.003 w
.71273 .61858 m
.72728 .61292 L
s
.70349 .62217 m
.71273 .61858 L
s
.67014 .63514 m
.67576 .63295 L
s
0 g
.006 w
.54594 .37267 m
.55886 .37117 L
s
.53324 .37775 m
.54594 .37267 L
s
.39992 .50787 m .43919 .78916 L .48219 .78878 L .413 .391 .725 r
F
.38226 .5059 m .43919 .78916 L .39992 .50787 L .037 .128 .631 r
F
.25 g
.5 Mabswid
.39489 .60813 m
.41241 .75011 L
s
.39106 .57713 m
.39489 .60813 L
s
1 0 0 r
.003 w
.41673 .77523 m
.43919 .78916 L
s
.25 g
.5 Mabswid
.38226 .5059 m
.38242 .50716 L
s
.38242 .50716 m
.38247 .50757 L
s
.38247 .50757 m
.38255 .50821 L
s
.38255 .50821 m
.38689 .54338 L
s
.38689 .54338 m
.39106 .57713 L
s
0 g
.006 w
.52136 .38664 m
.53324 .37775 L
s
.46359 .49085 m .69852 .65049 L .47479 .47808 L .797 .541 .551 r
F
.25 g
.5 Mabswid
.47479 .47808 m
.47762 .48026 L
s
.50076 .45345 m
.54129 .47906 L
s
.46359 .49085 m .65819 .69465 L .69852 .65049 L .797 .541 .551 r
F
.25 g
.49381 .46973 m
.54041 .49969 L
s
1 0 0 r
.003 w
.69852 .65049 m
.7097 .62808 L
s
.25 g
.5 Mabswid
.47762 .48026 m
.69852 .65049 L
s
0 g
.006 w
.51105 .39891 m
.52136 .38664 L
s
.50271 .4137 m
.51105 .39891 L
s
.49607 .42997 m
.50271 .4137 L
s
.4901 .44671 m
.49607 .42997 L
s
.48341 .46304 m
.4901 .44671 L
s
.47479 .47808 m
.48341 .46304 L
s
.31786 .51092 m
.33154 .50616 L
s
.44987 .50046 m .65819 .69465 L .46359 .49085 L .743 .548 .631 r
F
0 g
.46359 .49085 m
.47479 .47808 L
s
.44987 .50046 m .6018 .73768 L .65819 .69465 L .743 .548 .631 r
F
1 0 0 r
.003 w
.65819 .69465 m
.69852 .65049 L
s
.4342 .50632 m .6018 .73768 L .44987 .50046 L .675 .532 .683 r
F
.25 g
.5 Mabswid
.46359 .49085 m
.46512 .49246 L
s
0 g
.006 w
.44987 .50046 m
.46359 .49085 L
s
.4342 .50632 m .53941 .77104 L .6018 .73768 L .675 .532 .683 r
F
.25 g
.5 Mabswid
.40081 .51423 m
.40301 .53003 L
s
.40301 .53003 m
.43919 .78916 L
s
.41735 .5085 m .53941 .77104 L .4342 .50632 L .579 .489 .717 r
F
0 g
.006 w
.4342 .50632 m
.44987 .50046 L
s
.41735 .5085 m .48219 .78878 L .53941 .77104 L .579 .489 .717 r
F
.25 g
.5 Mabswid
.49259 .52122 m
.65819 .69465 L
s
.39992 .50787 m .48219 .78878 L .41735 .5085 L .413 .391 .725 r
F
1 0 0 r
.003 w
.43919 .78916 m
.48219 .78878 L
s
.25 g
.5 Mabswid
.46512 .49246 m
.49259 .52122 L
s
.44987 .50046 m
.6018 .73768 L
s
.4358 .51032 m
.53941 .77104 L
s
.4342 .50632 m
.4358 .51032 L
s
0 g
.006 w
.41735 .5085 m
.4342 .50632 L
s
.25 g
.5 Mabswid
.41735 .5085 m
.41751 .50921 L
s
.41751 .50921 m
.41823 .51229 L
s
.41823 .51229 m
.4233 .53424 L
s
.4233 .53424 m
.48219 .78878 L
s
.40005 .50878 m
.40081 .51423 L
s
.39992 .50787 m
.39996 .50816 L
s
.39996 .50816 m
.40005 .50878 L
s
0 g
.006 w
.39992 .50787 m
.41735 .5085 L
s
.33154 .50616 m
.34747 .50401 L
s
.38226 .5059 m
.39992 .50787 L
s
.36464 .50418 m
.38226 .5059 L
s
.34747 .50401 m
.36464 .50418 L
s
1 0 0 r
.003 w
.48219 .78878 m
.53941 .77104 L
s
.6018 .73768 m
.65819 .69465 L
s
.53941 .77104 m
.6018 .73768 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.313, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400049000181000`40O003h00Oogoo2Woo002`Ool2
001GOol00:ioo`800003Ool0000005Ioo`00Zgoo0`000goo0P00EWoo002YOol20006Ool00`00Ool0
001EOol00:Moo`8000Qoo`03001oo`0005Eoo`00Y7oo0`002Woo00@007ooOol005Aoo`00XWoo0P00
3Goo00D007ooOomoo`0005=oo`00Wgoo0`003goo00D007ooOomoo`0005=oo`00WGoo0P004Woo00<0
07ooOol00Woo00<007ooOol0D7oo002KOol2000EOol00`00Oomoo`02Ool00`00Oomoo`1?Ool009Qo
o`<001Moo`03001oogoo009oo`03001oogoo04moo`00UWoo0P006Woo00<007ooOol00goo00<007oo
Ool0CWoo002COol3000LOol00`00Oomoo`03Ool00`00Oomoo`1>Ool0095oo`8001moo`03001oogoo
00Aoo`03001oogoo04eoo`00Sgoo0P008Goo00<007ooOol01Goo00<007ooOol0C7oo002<Ool3000S
Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool008Yoo`8002Ioo`03001oogoo00Ioo`03001oogoo04]o
o`00Qgoo0`00:7oo00<007ooOol01goo00<007ooOol0BWoo0025Ool2000[Ool00`00Oomoo`07Ool0
0`00Oomoo`1:Ool008=oo`8002eoo`03001oogoo00Qoo`03001oogoo04Uoo`00P7oo0`00;goo00<0
07ooOol027oo00<007ooOol0BGoo001nOol2000bOol00`00Oomoo`09Ool00`00Oomoo`18Ool007]o
o`<003Aoo`03001oogoo00Yoo`03001oogoo04Moo`00NGoo0P00=goo00<007ooOol02Woo00<007oo
Ool0Agoo001gOol2000iOol00`00Oomoo`0;Ool00`00Oomoo`16Ool007Aoo`<003]oo`03001oogoo
00aoo`03001oogoo04Eoo`00LWoo0P00?goo00<007ooOol02goo00<007ooOol0AGoo001_Ool30011
Ool00`00Oomoo`0<Ool00`00Oomoo`14Ool006eoo`8004Aoo`03001oogoo00aoo`03001oogoo04Ao
o`00Jgoo0P00AWoo00<007ooOol03Goo00<007ooOol0@goo001XOol30018Ool00`00Oomoo`0>Ool0
0`00Oomoo`12Ool006Ioo`8004]oo`03001oogoo00ioo`03001oogoo049oo`00Hgoo0`00CGoo00<0
07ooOol03goo00<007ooOol0@Goo001QOol2001@Ool00`00Oomoo`0@Ool00`00Oomoo`10Ool005io
o`<0059oo`03001oogoo011oo`03001oogoo041oo`00G7oo0P00EGoo00<007ooOol04Goo00<007oo
Ool0?goo001JOol2001GOol00`00Oomoo`0AOol00`00Oomoo`0oOol005Moo`<005Uoo`03001oogoo
019oo`03001oogoo03ioo`00EGoo0P00G7oo00<007ooOol04goo00<007ooOol0?Goo001BOol3001N
Ool00`00Oomoo`0COol00`00Oomoo`0mOol0051oo`80065oo`03001oogoo01Aoo`03001oogoo03ao
o`00CWoo0P00Hgoo00<007ooOol05Goo00<007ooOol0>goo001;Ool3001UOol00`00Oomoo`0EOol0
0`00Oomoo`0kOol004Uoo`8006Uoo`03001oogoo01Eoo`03001oogoo03Yoo`00AWoo0`00Jgoo00<0
07ooOol05Goo00<007ooOol0>Woo0014Ool2001^Ool00`00Oomoo`0FOol00`00Oomoo`0iOol0049o
o`80071oo`03001oogoo01Moo`03001oogoo03Qoo`00?goo0`00LWoo00<007ooOol05goo00<007oo
Ool0>7oo000mOol2001eOol00`00Oomoo`0HOol00`00Oomoo`0gOol003Yoo`<007Moo`03001oogoo
01Uoo`03001oogoo03Ioo`00>7oo0P00NWoo00<007ooOol06Goo00<007ooOol0=Woo000fOol2001l
Ool00`00Oomoo`0JOol00`00Oomoo`0eOol003=oo`<007ioo`03001oogoo01Yoo`03001oogoo03Eo
o`00<Goo0P00PGoo00<007ooOol06goo00<007ooOol0=7oo000^Ool30023Ool00`00Oomoo`0LOol0
0`00Oomoo`0cOol002aoo`8008Ioo`03001oogoo01aoo`03001oogoo03=oo`00:Woo0P00R7oo00<0
07ooOol07Goo00<007ooOol0<Woo000WOol3002:Ool00`00Oomoo`0NOol00`00Oomoo`0aOol002Eo
o`8008eoo`03001oogoo01ioo`03001oogoo035oo`008Woo0`00Sgoo00<007ooOol07goo00<007oo
Ool0<7oo000POol2002COol00`00Oomoo`0NOol00`00Oomoo`0`Ool001ioo`8009Eoo`03001oogoo
01moo`03001oogoo02moo`006goo0`00Ugoo00<007ooOol087oo00<007ooOol0;Woo000IOol2002J
Ool00`00Oomoo`0POol00`00Oomoo`0^Ool001Moo`8009aoo`03001oogoo025oo`03001oogoo02eo
o`005goo0P00W7oo00<007ooOol08Woo00<007ooOol0;7oo000GOol00`00Ool0002KOol00`00Oomo
o`0ROol00`00Oomoo`0/Ool001Moo`04001oogoo002JOol00`00Oomoo`0SOol00`00Oomoo`0[Ool0
01Ioo`03001oogoo009oo`03001oogoo09Moo`03001oogoo02=oo`03001oogoo02]oo`005Woo00<0
07ooOol00goo00<007ooOol0UWoo00<007ooOol097oo00<007ooOol0:Woo000FOol00`00Oomoo`04
Ool00`00Oomoo`2EOol00`00Oomoo`0UOol00`00Oomoo`0YOol001Ioo`03001oogoo00Eoo`03001o
ogoo09Aoo`03001oogoo02Eoo`03001oogoo02Uoo`005Woo00<007ooOol01Woo00<007ooOol0Tgoo
00<007ooOol09Woo00<007ooOol0:7oo000FOol00`00Oomoo`07Ool00`00Oomoo`2BOol00`00Oomo
o`0WOol00`00Oomoo`0WOol001Eoo`03001oogoo00Uoo`03001oogoo095oo`03001oogoo02Moo`03
001oogoo02Moo`005Goo00<007ooOol02Woo00<007ooOol0T7oo00<007ooOol0:7oo00<007ooOol0
9Woo000EOol00`00Oomoo`0;Ool00`00Oomoo`2?Ool00`00Oomoo`0XOol00`00Oomoo`0VOol001Eo
o`03001oogoo00aoo`03001oogoo08moo`03001oogoo02Qoo`03001oogoo02Eoo`005Goo00<007oo
Ool03Goo00<007ooOol0Ngoo00<007ooOol047oo00<007ooOol0:Goo00<007ooOol097oo000EOol0
0`00Oomoo`0>Ool00`00Oomoo`1jOol00`00Oomoo`0@Ool00`00Oomoo`0YOol00`00Oomoo`0TOol0
01Eoo`03001oogoo00moo`03001oogoo07Uoo`03000Ligoo011oo`03001oogoo02Yoo`03001oogoo
02=oo`0057oo00<007ooOol04Goo00<007ooOol0N7oo0P004Goo00<007ooOol0:goo00<007ooOol0
8Woo000DOol00`00Oomoo`0BOol00`00Oomoo`1gOol00gKW001oo`0@Ool00`00Oomoo`0[Ool00`00
Oomoo`0ROol001Aoo`03001oogoo01=oo`03001oogoo07Ioo`03M^P007oo011oo`03001oogoo02ao
o`03001oogoo025oo`0057oo00<007ooOol057oo00<007ooOol0MGoo00=fi`00DSD047oo00<007oo
Ool0;7oo00<007ooOol08Goo000DOol00`00Oomoo`0EOol00`00Oomoo`1dOol00gKX000Li`0@Ool0
0`00Oomoo`0]Ool00`00Oomoo`0POol001Aoo`03001oogoo01Ioo`03001oogoo05eoo`P000moo`03
7>L0069C00moo`03001oogoo02ioo`03001oogoo01moo`004goo00<007ooOol05goo00<007ooOol0
Fgoo0P0000A1eQcW17<4LP9fi`04M^PLi`00000=Ool011cW001F=F9C3Woo00<007ooOol0;Woo00<0
07ooOol07goo000COol00`00Oomoo`0HOol00`00Oomoo`1HOol03QcW0011eQcW@MHLi`Ab17=figKX
M^LLigLdNeD2000;Ool01AcW000LiehcHU<03Goo00<007ooOol0;goo00<007ooOol07Woo000COol0
0`00Oomoo`0IOol00`00Oomoo`1FOol01`00IS8LieHe7>M1eQcW0084LP04M^QfigKW7>L2Ne@00acW
KcP000020007Ool01`007>LLi`00ESER<fX`00aoo`03001oogoo031oo`03001oogoo01eoo`004goo
00<007ooOol06Woo00<007ooOol0EGoo00D0068b7>MF=1cW0091eP0=7>L4L`AbM^QfiacWMcAkEAcW
KcQ_=acWHaT020000QcW00D001cWHUAN<fX`00]oo`03001oogoo031oo`03001oogoo01eoo`004goo
00<007ooOol06goo00<007ooOol0Dgoo00T0068bHS9R<QcWESDLid7F7>L00PAb00=figKX7>L00W]D
00XLiflgKcPLifLJHaUW6QcWOom:g0<Li`08M^LLi`00B]dLif9CHS=Z<0Yoo`03001oogoo035oo`03
001oogoo01aoo`004goo00<007ooOol077oo00<007ooOol0DGoo01T006W[7>MR<FHb7>MJ=AcWAMHL
i`Ac179fj7KW7>Mg=7]EOolLif/gKcPLifLJHaTLi`02F_/00acWC]e:g0027>L01`007>MF=QcWHUAN
<fX`00Uoo`03001oogoo035oo`03001oogoo01aoo`004Woo00<007ooOol07Woo00<007ooOol0D7oo
00@006W[JN/Li`9R<P067>M1eQcW7>L4LPAc0WKW01AkE1cWNeAkE1cWKcQ_=acWHaUW6V<I7>MoodkM
7>M:gD[L7>L002In0QcW00AN<f9CJRmZ<0Qoo`03001oogoo039oo`03001oogoo01]oo`004Woo00<0
07ooOol07goo00<007ooOol0CWoo00P006h<JN]^36W[7>MR<EXe0QcW0151eQcW179fj7KWM^PLig]E
Mc@LiflgKcPLifLJHaUW6QcW009Jn`077>M:g4kM7>L001cW:Wh00QcW00AN<f9DIRmZ<0Moo`03001o
ogoo03=oo`03001oogoo01Yoo`004Woo00<007ooOol087oo00<007ooOol0CGoo00<001cWJN`00fW[
00/Lif8b7>LLid7F7>L4LWKWM^QfiacW009kE00B7>M_>6lhIaXLifLJHaUW6QcWOomJnacWM^LLi`00
0AHLibIn0QcW00AN<f9CJRmZ<0Moo`03001oogoo039oo`03001oogoo01Yoo`004Woo00<007ooOol0
8Goo00<007ooOol0Bgoo00<005B0F:000QcW00EYjfh<HS8Lif8a00<Li`0A1784LgKWM^PLig]EMc@L
if/gKcQ_=acWHaUW6V<I7>MFn`02F_/27>L00`000AD15P027>L01bIm7>MN<f9DIRmZ<6VW00Eoo`03
001oogoo03=oo`03001oogoo01Uoo`004Woo00<007ooOol08Woo00<007ooOol0BWoo00<005B0E800
0UB000HLifW[JN/LifHbESD27>L01D7F179figKW7>L00W]D00/LiflhKcM_>1cWIaYS6FLJHaTLigoo
009Jn`0:001Lh1cW7>L15P4E7>LVOQcWGS<2JRl00fX`JLMoo`03Ool00`00Oomoo`0dOol00`00Oomo
o`0HOol0019oo`03001oogoo02=oo`03001oogoo04Qoo`0<0009o1cWF:1DP5RPE80LifW[KP`LifHb
2P00011_=flhJcLLif<IIaYS6FLJ7>MJneKkF_/001cWG>1Ph08Li`090ADLibIm7>MN<fX`IRmZ<6VW
00=oo`03001oogoo03Aoo`03001oogoo01Qoo`004Woo00<007ooOol097oo00<007ooOol0Agoo00@0
00Wk2O`Li`ADP0067>L00000001fj1cW0P0A00HLic6F=IHeUQcWBQH<00000fW:G>0Li`02G>000`4F
7>LLi`037>L01FH_JRmZ;fX`JLL00Woo00<007ooOol0=Goo00<007ooOol05goo000AOol00`00Oomo
o`0VOol00`00Oomoo`15Ool08P002M/9o0GK2O`LieRPE81HX000N^Qfig[XM^LLi`0A018LicFG<IHe
UacWCQI:5QcWESAJ=EHd7>MN<V8c7>MZ<6H?0QcW00UYjVW:7>MLh63PG>015QcW0AH00QcW00MV;fX`
IRmZ<6VWKLP0000gOol00`00Oomoo`0GOol0015oo`03001oogoo02Moo`03001oogoo04Aoo`06000L
iacW2O`9n`Wl0QcW00<007MEM^P00gKX00lLi`0A014LicFF=ILaUQcWBQI>5TXF7>MF=EXe7>L00f8c
00<LifH`IS000QcW0VW:0QcW0UcP00<15QcW7>L00QcW00IV;fX_JRmZ<6W7000hOol00`00Oomoo`0F
Ool0015oo`03001oogoo02Qoo`03001oogoo04=oo`0Y0005f`Wl7>L9o0GK2O`007]FMeEjj7KWN^Qf
iacW01404PAb7>LaUSFG<IHLidXFCQHLieXeESAJ=AcWHS=N<V8c7>MZ<6H?JNXLif/iJLYYjP027>L0
35cPH>015AcW0ADLifH_JS1V;fX`001]b3Qoo`03001oogoo01Eoo`004Goo00<007ooOol0:Goo00<0
07ooOol0@Goo00P003jm?[eoo`Wl7>L9o0000WME00=gEWMEM^P00WKX00D04AcW01404AcW008eUP0:
=ILLidhFBQHLieHdFSEF=AcWGS82HS<00fH`7>MV<002IS002AcW@MIYbVW:Fa/LiecPH>015@047>L2
JRl01000JLMYb51P=Woo00<007ooOol05Goo000AOol00`00Oomoo`0ZOol00`00Oomoo`10Ool0;@00
7>LjWCjm>Yd9o1cW001W>G]FMeEkEWKWN^QfieRP7>L04P0A7>LaUSFG<IHLidXFCQI:5QcWESAJ=EHd
7>MN<V8cGS9V<1cWJS1V3fH`7>MF=UHeJNYYbP027>L01F3PG>015QcW0AH00QcW00D006X`JJM]b6VW
03Ioo`03001oogoo01Aoo`004Goo00<007ooOol0:goo00<007ooOol0?Woo00@005;L?[dLi`<n_@03
001W>VLj00=gE@Afj0077>L04@0A7>LeUc6F=IH00QcW00U:5ThF7>MJ=EHdFSER<acWGS800V8c00<L
ifH_IS000VH`0QcW00mK6fW:JLYK6acWH>1Lh04F7>L15VH_001Z;fX`JLL00VW800=@H7ooOol0<goo
00<007ooOol04goo000@Ool00`00Oomoo`0]Ool00`00Oomoo`0lOol0=P00D]a>fe;LC]/LicZM000L
if/jIcUkEWMENeIfig[XM^Mjj1cW01804AcW<IHeUc6F7>M:5ThFBQHLieHdFSEF=5Xe7>MR<ehbHS=N
<QcWIPmZ<6H?IS1YbQcWJLYF=VW:JNXLif3PG>1Ph08Li`08000LifH_JS1YYfg8JJM@H3Aoo`03001o
ogoo01=oo`0047oo00<007ooOol0;Woo00<007ooOol0>Woo00<005kk7>L00e;L00U>g000D_aC7AcW
IcYgEGMFMeD017KX00@Li`0A014Li`8eUP0>=ILLidhFBQI>5TXF7>MF=EXeESAR<acWHS=N<P9R<`03
7>MV;fH`009V<004JLXLifW:ESD2JLX27>L3G>001P000ADLiacWJS1Ya`9Yb003D61oogoo039oo`03
001oogoo019oo`0047oo00<007ooOol0;goo00<007ooOol0>7oo034005kkF_YNnacWD]a>fe;L001C
7E;l7>MW>F/jMeEkEWKWN^Qfig[X7>L04P0A7>LaUSFG<IHLidXFCQI:5ThF7>MJ=EHdFSEF=1cWGS9R
<ehbHS=N<QcWIPmZ<6H?IS1YbP027>L026WZGS=YjT[M7>MLh63P00027>L026X`7>MZ<6VWKLQYYe1P
C60bOol00`00Oomoo`0BOol0011oo`03001oogoo031oo`03001oogoo03Eoo`80000>7>MJnUkjF_YN
nacWD]`005<MD_aC7E;l7>MW>P9gE@05MeIfj7KXM^PLi`0201400d7F7>LaUP02=IH02acWBQI>5TXF
7>MF=5XeESEJ=EHd7>L00V8c00EN<V8cIS0LifH_00=V<09YbP037>MYbUhc009YbP0:7>MLh000G>1P
h1cW0AHLifX`JLL3JLP00e1POomoo`0_Ool2000COol0011oo`03001oogoo035oo`03001oogoo035o
o`<0000IH_UW6U[j7>MJnUkkF_YNnacW000Lie<MD_aC7E;l7>MgEG]FMeEjj7KWN^PLi`0B01400QcW
02DeUc6F=ILLidhFBQI>5TXF7>MF=1cWESAJ=Ehb7>MN<V8cGS9R<fH?7>MV3fX`IPmV<6H?JNXLifWZ
JLY:oFW:7>L0063PG>1Ph0037>L01VX`JJM]b6VWKLQ<H2eoo`<00003Ool007oo019oo`0047oo00<0
07ooOol0<Woo00<007ooOol06goo3@001Goo0`0000a[5acWIaUW6F<IG_XLiekkF_YNnU[j0002:Yh0
1QcWDaeBo5<M7>MgEP9gE@=fj0037>L04@0A008Li`0?=IHeUc6F7>M:5ThFBQI>5QcWFSEF=5XeESEJ
=AcW00=R<`05GS9R<fH`7>MV;`03IS000fH_JLXLi`02JLX014[MJLX001cW0UcP00IPh5cP7>LLifX`
JLL3JLP2D60XOol30004Ool00`00Oomoo`0AOol0011oo`03001oogoo03=oo`03001oogoo01Qoo`80
000=EQA1eT7EAMH@/a3D4;<De5X0GR1J01cWOc001@0004Ac=AcWJaM_66/G7>MRnFLIH_UNnacWG_]J
nUkk000^WRZM;YhLie<MD_aC7AcWNeIgEG[XM^Mjj00A7>L04D7F7>LeUc6F=ILLidhFBQI>5TXFFSDL
ieXeESAJ=EHdHS<Lif8cGS9R<ehbHS=V3acWIPmZ<6H?IS1V3fWZ7>MYjVW:JNYN<`000QcW00=Lh63P
G>000acW00IYYfg8JJM]b4aPD60TOol30007Ool00`00Oomoo`0AOol000moo`03001oogoo03Eoo`03
001oogoo01Eoo`8000AF=@=1eP044;@@e12d4=@2GR002Gl`7>Mo<7m@McDLigLeMcHLi`02KaP03Goo
7>MW6FLIOomS6Ekj7>MNne[j000ZWRjN008ZWP067>MC7E;lDadLigMF0gKX00H04AcW01404AcW<IH2
=IH03QcWBQI>5V8bCQI:5QcWESEJ=EHdFSEF=F8c7>L3HS<01EhbHS<LifH`IRl00fH`00=V;fW:7>L0
0fW:00H006W:JLXLiecPH>02G>027>L01FW7JLQYb6W8JLL00U1P7goo0`002goo00<007ooOol047oo
000?Ool00`00Oomoo`0fOol00`00Oomoo`0BOol200001V8aIS8LieHeEQAF=@91eP0L@MDDe12c4=@@
/ehPFP1oDAcWOe5o<7Lf7>Mg=W<eOolLiflHJaM_61cWIaYRnFLIF_XLie[jG_/2000012ZN;YhZWBjN
0QcW035Bo1cWMeEjj7KWN^P04AcW01404QcW=ILaUSFG7>M>5TXFCQI:5ThF7>MJ=EHdFSEF=5XeGS8L
iehbHS=N<V8cGS9R<acWIS1V3fX`IPmV<6H?JNXLifWZJLX006W:JS1YbP027>L00f3PG>1Ph0027>L0
1FVWKLQYYfg8JJL00U1P6goo0`003Woo00<007ooOol047oo000?Ool00`00Oomoo`0gOol00`00Oomo
o`0@Ool00`00JLXLi`03HS8011cWESEF=EHe0d7F00<@e12d4=@00UhP00Io<1cWOc1oD7Le7>L3McD0
31cWJaM_66lH7>MS6FLIOomW6E[j7>L00080d`03000ZWRjN00<ZWP037>MBo1cW00=fj00H014Li`0A
014LicFF=ILaUSFF7>M>5TXFCQI:5UXe7>MJ=EHeIaYF=5XeHS<Liehb0f8c00EN<VH`7>MV<6H_00=V
<005IRmYbQcWJLX00005JLX00acWH>1Lh002G>000acWJLMYb002JLP00fW7D61@H00GOol3000AOol0
0`00Oomoo`0@Ool000moo`03001oogoo03Qoo`03001oogoo00ioo`0<JLX006W9JLXLif8bHS5F=AcW
ESEF55He0T7F01X@/aCD4;=N85X0GR0LigmAOc1oDAcWMcIc=GLf7>M_66/GKaPLifLIH_Uoof;iIaUJ
nP000`3C00H002ZN;YhZWBjN:Yh27>L0=W]FM^Mjj00A7>L04@0B7>LeUc6F=ILaUQcWBQI>5V8aCQI:
5QcWESAJ=EHdFSEF=68c7>MR<ehbHS=N<V8cGS9Z<1cWIS1V3fX`IPmV<6H?JS0Li`00JLYYjVW:JNYV
;fWZ7>MPh5cPH>1Lh08Li`04KLQYYfg8JJL3D60AOol4000DOol00`00Oomoo`0@Ool000moo`03001o
ogoo03Uoo`03001oogoo00eoo`03001YbVW:009YbP047>MR<V8b7>L4ESD01D7F4=@@]13D4;@00UhP
00TLigl`Oe1ooacWMcEg=WLe7>L00VlH00QooflH7>MW6F<IOomW6@001@3C0P0000@^WRZN:YhZWP8L
i`9fj006014Li`0A0151eQcW0SFF018eUacWCQI:5ThFBQI>5QcWFSEF=5XeESEJ=EHdHS<Lif8cGS83
HS<01EhbIS0LifH`IRl00fH`00AV;fH`000Li`IYbP8Li`=Lh003H>0LiacW009Yb004JLMYb51PD60=
Ool3000HOol00`00Oomoo`0@Ool000moo`03001oogoo03Yoo`03001oogoo00]oo`0[000`01cW7>MY
bVW9JLXLif8bHS4LieHDESEF54GF@MH@e12c5=AJ05hP7>MoDGl`OolLigLfLcEg=Woo7>M[5gooJaLL
if;iIaUoofLJ000Li`3C0=@00`3C00D0e000;YhZWBjN008Li`06M^Mjj4kK7>L04@0B0QcW030aUSFG
<IHLidXFCQI:5ThFBQIJ=AcWFSEF=5XeESAJ=EHd7>MN<V8cGS9R<ehbHS=N<VX`7>MV<6H?JS1V3fH`
IPl006W:7>MYbVWZJLYYjVW:JS1YbQcWG>1Ph5cPH>027>L016VWKLQYYfg80U1P00=<H7ooOol01Woo
0`006goo00<007ooOol047oo000>Ool00`00Oomoo`0lOol00`00Oomoo`0:Ool01@00=00`03@07>L0
0fW:00@Lif8bHS8Li`=F=@04@MH@]13D4;@2GR001AcWOc1oD7l`7>L00gLe00IooacWKaQooflH7>L2
IaT017oo001U8@3C0QcW1@3C0P000RZN0QcW0WKX00<Li`0A01400QcW01<eUc6F=IHLidhFBQI>5V8b
CQIF=1cWESEJ=EHdFSEF=EXeGS8Li`02HS<01UhbHS=R<f8cGS8Li`9V<008IRmV<6H`IS0006H`JLXL
i`MYbP8Li`9Lh003H>1Lh1cW009Yb003JLMYb51P009@H0Aoo`<001ioo`03001oogoo011oo`003Woo
00<007ooOol0?Goo00<007ooOol027oo02`003@0<00d0300=00LifW:JLUYbQcWHS9R<AcWEQAF=EHD
AMH@/a3DFP1N81cWOe5o<7mALcDLig<eMcIooacWJaM_66/GKaPLifLJH_T0064QID9Q8@3C0QcW0`3C
00/0e03C000ZWBjN7>Mjj7KW7>L04@0B008Li`0c<IHeUc6FCQHLidhFBQI>5TXFCQHLieXeESAJ=EHd
KPaF=5Xe7>MR<ehbHS=N<V8cGS9R<ehb7>MV3fH`IPmZ<6H?001V3fX`JLXLifW:JNYYbVWZJLYYjVH_
JNXLif3PG>1Ph5cP008Li`03KLQYYfg8009@H004C61@H000000QOol00`00Oomoo`0@Ool000ioo`03
001oogoo03ioo`03001oogoo00Moo`07000LiacW<00d0300=0000QcW0VW:00@Lif8bESDLi`9F=@0<
@MH@e12d4=AN81cWOc1oD7l`McDLigLf0WLe00<LiflHJaL00VlH00/Lif<I001Q8FDQHB5U8F4QIB40
dacW00D0d`800004:YhLigKX7>L201427>L2=IH04SFG<IHLidXFCQI:5V8bBQIJ=AcWFSEF=EXeESAJ
=EHeHS<Li`=R<`06GS9R<f8cHS=V;acW0VH`00QV;fH`001V<6H_IS1YbQcW26W:0QcW00MLh63PG>1L
h1cWJLQYa`02JLP3D60SOol00`00Oomoo`0?Ool000ioo`03001oogoo03moo`03001oogoo00Eoo`04
000bWCJN<Yd27>L01c@0<00d03007>MYbFW:008Li`0QEQ@LieHDESD@/aCD4;=N81cWOe5o<7mALcDL
ig<eMcIc=FlH7>M_66/GKaQ[5acW001U@V4QID9Q8FE2HB5U@P3C008Li`80d`050=@0d`3C000^WP02
7>L0>P0A018LiacW<IHeUc6F=ILLidhFBQI>5V8aCQIF=1cWESAJ=EHdFSEF=5XeES@LiehbHS=N<V8c
GS9R<ehbHS=V3acWIPmV<6H?001V3fH`IPmZ<6W:7>MYbVWZJLYYjVW:JNYYbVX`JLXLiecPH>1Lh63P
0QcW00IYYfg8JJM@H4aPD60ROol00`00Oomoo`0?Ool000ioo`03001oogoo041oo`03001oogoo00Ao
o`0<000fWCJM=YhbWCJM7>Ld0300=00`01cW0fW:0QcW0eHe00T@]13DGR1N81cWOe1o<7Lf7>L00WLe
00Ug=Woo7>M_67ooJaM_6000JN`00QcW00QQ8FDQHB5U8F4QIB5Q8@3C0QcW103C0P000QcW0P0A00<L
icFG<IH00SFF018LidXFCQI:5ThFBQI>5QcWFSEF=5XeESEJ=EHdFSER<acWGS83HS<01UhbHS=R<f8c
IRlLi`9V<005001V<6H`IS1V;`02IS000acWJLYYbP07JLX00acWG>1Ph003G>027>L2JLP4D6000g`0
Oomoo`0MOol00`00Oomoo`0?Ool000ioo`03001oogoo045oo`03001oogoo00=oo`07000bWCJN<Ydf
WS:M=Yh00QcW00<`03@0<0000QcW0VW:0QcW02EF=EHDESD@/ehPFP0Ligl`Oe5o<1cWLcEg=W<eOolL
iflHOom_66/G001Uk6W/IN/Lif4QID9Q8FE2HB5U@V4QG_/0dacW0=<0e0030=<0>00001404P0A7>La
USFG<IHeUacWCQI:5ThFBQIV<TXFFSDLieXeESAJ=EHdFSEF=5Xe7>MR<ehbHS=N<V8cGS9R<ehbHS=V
3acWIPl006H?JS1V3fH`IPmZ<6H?7>MYbVWZJLYYjVW:JNYYbVWZJLX27>L0363PG>1Ph5cPH>0Lifg8
JJM@H4aPD61l01moo`03001oogoo00moo`003Woo00<007ooOol0@Woo00H007ooOomoo`00D]`27>L2
=Yd013JN<YdfWCJM0QcW00@d0300=00Li`9YbP8Li`9F=@094=@@]7oo7>MoD7l`Oe0LigLf00=g=@05
7>M[5gooKaP00005JN`27>L026DQHB5U8F4QIB5Q8FDQ0=<27>L40=<011cW01404AcW0SFF01HeUc6F
7>M:5ThFBQI>5TXFCQIF=1cWESEJ=EHdFSEF=@bCESAR<acWHS=N<P=R<`09GS9R<f8cHS<LifH`001V
<6H_00=V<004IRmV<6H`7>L:JLX00acWH>1Lh002G>000f3P7>LLi`02JLP00e1PO01oo`0NOol00`00
Oomoo`0?Ool000eoo`03001oogoo04Aoo`07001oogoo001Bg5;KD]`00QcW00/bWCJN<YdfWS:M=YhL
ic@0<00d01cW009YbP8Li`0UESEF513DFP0Ligl`Oe5o<1cWLcEg=W<eMcHLiflHOom_60007>MUjfW/
INaYk6G[JN`LifE2HB5U@V4QID9Q8FE2HB40dacW0=@00`3C03T0000A7>LaUSFG<IHeUdXF7>M:5ThF
BQI>5TXFCQHLieXeESAJ=EHdFSEF=5XeES@LiehbHS=N<V8cGS9R<ehbHS=N<V8c7>L006H?IS1V3fX`
IPmV<6H?JS1V3acWJLYYjVW:JNYYbVWZJLYYjVW:JNX00QcW00ULh63PG>1Ph5cP7>MYYfg8O0007goo
00<007ooOol03goo000=Ool00`00Oomoo`15Ool01000Ool005;K0e;L00EooacW7>LfWS:M008fW@05
=YhLiacW<00d00027>L00fW:7>LLi`02ESD01UhP7>MoD7l`Oe0Li`9g=@03McIg=AcW009_6004001V
<FW/7>L6JN`27>L0264QIB5Q8FDQHB5U8F4Q0=<27>L30=<010007>LeUc6F0SFF01<eUacWCQI:5ThF
BQIR<TXF7>MF=5XeESEJ=EHdFSEF=EXeES@Li`02HS<01EhbHS=R<f8cGS800V8c00=V<000IS000VH`
00EV;fH`IS1V<6H_009V<0037>MYbVW:00UYbP067>MLh5cPG>1Ph5cP0QcW87oo00<007ooOol03goo
000=Ool00`00Oomoo`16Ool200001acWD]]Bg5;KD]aooe;L008Li`0O<YdfWS:M=YhbWAcW<00d0300
7>MYbQcWEQAF=EX07>Mo<7mAOc1g=QcWMcIc=GLfOolLi`00IS5R46HaJaL00QcW015Yk6G/JNaUjfW/
IN`Lif4QID9Q8FE2HB5U@V4QID80dacW00<0d`0^7>L003FG<IHeUc6F7>M:5ThFBQI>5TXFCQIF=1cW
ESAJ=EHdFSEF=5XeESAJ=AcWHS=N<V8cGS9R<ehbHS=N<V8cGS8001cWJS1V3fH`IPmZ<6H?IS1V3fX`
IPl27>L02VWZJLYYjVW:JNYYbVWZJLYYjVW:0QcW00IPh5cPH>1Lh63P7>LPOol00`00Oomoo`0>Ool0
00eoo`03001oogoo04Ioo`05001NnUkj7>MBf`03D]`01E;KD]aBg1cW<Yd00SJM00HfWS:M7>LLic@0
<0037>L2ESD01QcWOe1o<7m@McDLi`=g=@0:McH006HaHQ5V<F8@IS5R4FW/7>L6JN`27>L02FDQHB5U
8F4QIB5Q8FDQHB4Li`030=<2=IH05SFG<IHeUQcWCQI:5ThFBQI>5V8bCQHLieXeESAJ=EHeFSEF=5Xe
ESEJ=AcW0f8c00EN<V8cHS=R<ehb009R<`03000LifH`009V<005IRmV<6H`IS1V;`02IS000fW:7>MY
bP0:JLX011cWG>1Lh63P0UcP0QcW7Woo00<007ooOol03Woo000=Ool00`00Oomoo`16Ool01000G_UR
nUkj0QcW00IBg5;KD]aBfe;LD]/27>L01CJN<YdfWS:M=Yh00QcW02T`03@07>MF=EHDIS9o<7mAOc1g
=QcWMcIc=GLf000Lif8@IS5R46HaHQ1V<F8@JN`LifW/INaYk6G[JNaUk6W/7>MU@V4QID9Q8FE2HB5U
@V4Q008Li`0m0=<aUSFG<IHeUc6F7>M:5ThFBQI>5TXFFSE:5QcWESAJ=EHdFSEF=5XeESA1eeHd7>MN
<V8cGS9R<ehbHS=N<V8cGS9R<`00IS0LifX`IPmV<6H?JS1V3fH`IPmZ<6H?IS0LifWZJLYYjVW:JNYY
bVWZJLYYjVW:JNX00QcW00ILh63PG>1Ph5cP7>LMOol00`00Oomoo`0>Ool000eoo`03001oogoo04Eo
o`03000Liekj00ANnP057>MBg5;LD]aBf`03D]`27>L00cJM=YhbW@02=Yd011cW<00LiacW0UHe00IR
<Wl`Oomg=AcWMcD20002GS<02AcWHQ1V<F8AIS5R46HaHQ5W6@027>L6JN`27>L08f4QIB5Q8FDQHB5U
8F4QIB4LicFG<IH0dcFF=ILLidhFBQI>5TXFCQI:5ThF7>MJ=EHeFSEF=5XeESEJ=EHdFSEF=AcWGS80
0f8c00UN<V8cHS=R<ehb001R<acWIRl00fH`00EV;fH`IS1V<6H_00=V<0037>MYbVW:00UYbP04OolL
iecPH>03G>027>LKOol00`00Oomoo`0>Ool000aoo`03001oogoo04Ioo`06001[6AcWG_YNnF;j0Ukj
0QcW00eBfe;LD]]Bg5;KD]aBfacW<YdfWS:M=YhbW@047>L09eHeEQAV<VW:Oe4001cWFS=N<eXcGSAJ
<acWHQ1V<F8@IS5R46HaHQ1V<FG[7>MUk6W/IN]Yk6G/JNaUjacWHB5U@V4QID9Q8FE2HB5U@P027>L0
AC6F=ILaUQcWBQI>5TXFCQI:5ThFESA>5QcWFSEF=5XeESAJ=EHdFSE1eUXe7>MR<ehbHS=N<V8cGS9R
<ehbHS<0068cGS8LifH?JS1V3fH`IPmZ<6H?IS1V3fX`IPmV<1cWJNYYbVWZJLYYjVW:JNYYbVWZJLYY
jVW:7>MLh63PG>1Ph5cPH>1l000JOol00`00Oomoo`0>Ool000aoo`03001oogoo04Eoo`03001W6FLH
0100008Li`05=YhbWCJM=YdfWP027>L00eHe0000000200000eHEDQDLi`05GS<03AcWHQ1V<F8AIS5R
46HaHQ5V<FW/7>MYk6LI00EYk08Li`08IB5Q8FDQHB5U8F4QIB5Q8@8Li`8eUP0F7>M:5ThFBQI>5TXF
ESE:5QcWESAJ=EHeFSEF=5XeESEJ=D7FFSDLif8cGS83HS<02EhbHS=R<`00GS9R<fH`7>MV;`03IS00
1FH_IS1V<6H`IRl00fH`00<LifW:JLX02VW:0QcW00EPh5cPG>1Lh7`001Yoo`03001oogoo00ioo`00
37oo00<007ooOol0AGoo0`0000Yc=GLfLcEg=Wl^Obmo;Wl_ObiMh0=Ih003GN0Li`Ac00X0000=AOIF
5AcWEQEB55HE7>MN=5XcGS=J<ehdFS<00QcW015V<F8@IS5R46HaHQ1V<F;i7>MUk6W/IN]Yk6G/JNaU
jfW/008Li`08HB5U@V4QID9Q8FE2HB5U@P<Li`10CQI:5ThFBQI>5TXFCQHLieXeESAJ=EHdFSEF=5Xe
ESAJ=EHd7>MN<V8cGS9R<ehbHS=N<V8c001R<ehbHS=V3acWIPmZ<6H?IS1V3fX`IPmV<6H?JS1V3fH`
7>MYjVW:JNYYbVWZJLYYjVW:JNYYbVWZJLYYjQcWH>1Lh63PO00JOol00`00Oomoo`0>Ool000aoo`03
001oogoo04Aoo`80009W>@03IcYg=GLf009g=P04Obio;gl_Obl5FN001AcW17<4L`Ac7>L0136F00/L
idWfAOI9mTGf7>MB5EHEDQEF5AcW00MN<`097>MV<F8AIS5R46HaHQ5V<F8@008Li`QYk00O7>MQ8FDQ
HB5U8F4QIB5Q8FDQHB4LidXFCQI:5ThFBQI>5UHeCQHLieXeESAJ=EHeFSEF=5XeESE1eUHd7>L00V8c
00IN<V8cHS=R<ehb0002HS<01EhbHS=V<1cWIRl00fH`00EV;fH`IS1V<6H_00=V<08Li`aYbP8Li`9L
h003O01oogoo01Qoo`03001oogoo00eoo`0037oo00<007ooOol0A7oo010006lGIaU[>VLIMcIc=GLf
LcEo;gl^Obmo;Wl_FN1Mh09Ih0067>L4M0Ac17<LicFG0c6F02HLidGfBOI5mDWfDQ@Lie8DEQEB55HE
7>MN=5XcGS=J<ehdFS=N<acWIS5R46HaHQ1V<F8@IS5R46W/7>MYk6G[JNaUk6W/IN]Yk6G/0QcW00QU
@V4QID9Q8FE2HB5U@V4Q0QcW03m>5TXFCQI:5ThFBQHLieHdFSEF=5XeESAJ=EHdFSEF=5Xe7>MR<ehb
HS=N<V8cGS9R<`00HS=N<V8cGS9R<fH?7>MV3fX`IPmV<6H?JS1V3fH`IPmZ<6H?IS1V3acWJLYYjVW:
JNYYbVWZJLYYjVW:JNYYbVWZJLXLiecPO0006Woo00<007ooOol03Goo000<Ool00`00Oomoo`13Ool0
10007>M_5fLj0fLi00=g=WLeMcH00Wl_00=o;Wl_Obl015WP00DLi`Ac17<4LacW00@aUP0<7>M9mTGf
BOI5mTWf7>MF5E8EEQEB5AcW25hc00/LifHaHQ5V<F8@IS5R4FHaHQ1W6AcW00=Yk0037>MYk6W/00=Y
k00M7>MU8F4QIB5Q8FDQHB5U8F4QCQI:5ThFBQI>5TXFESDLieXeESEJ=EHdFSEF=EXeESAJ=D7FFSDL
i`03HS<01EhbHS=R<`00GS800f8c00EN<V8c7>MV<6H_00=V<005IRmV<6H`IS1V;`03IS000fH_7>MY
bP0<JLX00acWO01oo`0IOol00`00Oomoo`0=Ool000]oo`03001oogoo035oo`@000ioo`0@001g=AcW
LaM_5f/jIaU[>W<eMcIc=Gl_Obio;gl^Obl3FN001UgP7>L4L`Ac17@4L`8aUP0Q=ILaUS6F7>M9mTGf
BOI5mEHE7>MF5E8DEQEB51cWFS=N=5XcGS=J<ehdFS=N<acWIS5R46HaHQ1V<F8@IS5R46Ha008Li`08
IN]Yk6G/N^QUjfW/INaYk08Li`15HB5U@V4QID9Q8FE2BQI>5V4QCQI:5ThFBQI>5QcWFSEF=5XeESAJ
=EHdFSEF=5Xe@MHLiehbHS=N<V8cGS9R<`00HS=N<V8cGS9R<ehbHS<LifH`IPmZ<6H?IS1V3fX`IPmV
<6H?JS1V3fH`IPlLifW:JNYYbVWZJLYYjVW:JNYYbVWZJLYYjW`001]oo`03001oogoo00eoo`002goo
00<007ooOol0;goo0P0000AYbf8aHS9F=0D000Qoo`04001g=GLe7>L3KaL00fLjIcUW>@02McH01GLe
Obmo;gl_Obh01EWP00@Li`Ac17<4L`DaUP0=7>M5mTWfAOI9mU8E7>MB5EHEDQEF5E8E7>L01ehc00eV
<AcWIS5R4FHaHQ1V<F8AIS5R46HaJN`Li`04JN`00`0AJNaYk002JN`27>L06VDQHB5U8F4QCQI:5ThF
BQI>5TXFCQI:5QcWESAJ=EHeFSEF=5XeESEJ=EHdFSEF=AcWGS83HS<01Ehb001R<f8cGS800f8c00EN
<VH`7>MV<6H_00=V<005IRmV<6H`IS1V;`03IS000fH_7>MYbP09JLX00g`0Oomoo`0JOol00`00Oomo
o`0=Ool000]oo`03001oogoo02ioo`0<000`01cWILYYjfG:IS9F55XeBOE9mReE200001=g=AcWMcEg
=1cWKaIc5flGJcYW6GLfLcEg=Wl^Obmo;Wl_FN1Mh003FN001AcW17<4L`Ac7>L00c6F06leUacWBOI5
mDWfAOI9mQcWEQEB55HEDQAF5AcWGS=J<ehdFS=N<eXcGSAJ<fHa7>MV<F8@IS5R46HaHQ1V<F8@IS5U
k1cWIN]Yk6G/JNaUj`0BINaYk6G[JN`LifE2HB5U@V4QCQI:5ThFBQI>5TXFCQHLieXeESAJ=EHdFSEF
=5XeESAJ=EHd@MMF=1cWGS9R<ehbHS<0068cGS9R<ehbHS=N<V8cGS9Z<1cWIS1V3fX`IPmV<6H?JS1V
3fH`IPmZ<6H?IS1V3acWJLYYjVW:JNYYbVWZJLYYjVW:O00077oo00<007ooOol03Goo000;Ool00`00
Oomoo`0^Ool010007>Ld01cW0VW;00MYbV8bHS9J=DWe000Li`0300l01W:TLZDLiacWMcDLi`9g=@07
7>M_5flGKaMW>FLjMcD00WLf00Ao;gl^Obmo;`EIh0057>L4L`Ac17<Li`04<IH03QcWAOI9mTGfBOI5
mUHE7>MF5E8EEQEB5EHE7>L8GS<03FHa7>MV<F8AIS5R46HaHQ5V<F8@IS5R4AcW00EYk003IcYYk6W/
009Yk08Li`0IHB5U8F4QCQI:5ThFBQI>5TXFCQHLieXeESAJ=EHeFSEF=5XeESEJ=EHdFSDLif8cGS80
0V8c00<005hbHS<00V8c00UN<V8cHS=R<ehbIS0LifH`IRl00fH`00EV;fH`IS1V<6H_00=V<003IRlL
ifW:00IYbP03O01oogoo01]oo`03001oogoo00eoo`002goo00<007ooOol0;Woo00@003kM000`008L
i`03JN]UbVW[0080000K>]haMQcW01003g:UKZ@Lig/`Oc4LigLeMcAg=AcWKaM_5W<GIaU[>W<eMcIc
=Gl_Obio;gl^009Ih009GN1Ih1cW17<4M0Ac7>LaUSFG008aUP0S7>M9mTGfBOI5mDWfAOHLie8DEQEB
55HEDQAF5AcWGS=J<ehdFS=N<eXcGSAJ<fHa7>MV<F8@IS5R46HaHQ1V<F8@IS5R40027>L0@6W/INaY
k6G[JN`aUVW/IN]Yk6G/7>MQ8FE2HB5>5TXFCQI:5ThFBQHLieHdFSEF=5XeESAJ=EHdFSEF=5XeESAJ
=AcWHS=N<V8c001R<ehbHS=N<V8cGS9R<ehbHS=N<VX`7>MV<6H?JS1V3fH`IPmZ<6H?IS1V3fX`IPmV
<6H?0QcW00EYjVW:JNYYbW`001ioo`03001oogoo00eoo`002goo00<007ooOol0;goo1000018d01cW
7>L003P07>LngS[N?]hLi`0?KZAbY7la7>MoogLe7>L2McD00acWKaM_5`02KaL016LiMcIg=GLf0Wl_
00=o;Wl_FN000eWP00DLi`Ac17<4LacW00@aUP0?7>M5mTWfAOI9mTGfBOIB5AcWDQEF5E8EEQEB5AcW
00UN<`0>IS4LifHaHQ5V<F8@IS5R4FHaHQ1V<F8AJN`Li`IYk004=IMYk6W/JN`27>L05FDQHB5>5TXF
CQI:5ThF7>MJ=EHeFSEF=5XeESEJ=EHdFSEF=EXeO00Li`02HS<01Ehb001R<f8cGS800f8c00IN<V8c
HS=R<ehb7>L2IS001FH_IS1V<6H`IRl00fH`00MV;fH`IS1V<6H_IS0Li`02JLX00g`0Oomoo`0NOol0
0`00Oomoo`0<Ool000]oo`03001oogoo02moo`04001Nn`00@]h200001300000LicP00QcW00hjgSkN
7>LLifjTLZDLigooMc@LigLdMcEg=1cW0VlG00Y_5V/jIaUg=W<eObmo;Wl_ObiMh0=Ih0067>L4L`Ac
17<eUacW0S6F02HeUc6F7>M5mDWfAOI9mTGeEQDLieHEDQAF5E8DEQEB51cWFS=N<eXcGSAJ<ehcFS=N
=5XcIS4LifHaHQ1V<F8@IS5R46HaHQ1V<F8@0QcW00]Yk6G/JNaUjfW/INaYk36FJNaUk6W/008Li`0g
HB5>5TXFCQI:5ThF7>MJ=EHdFSEF=5XeESAJ=EHdFSEF=5XeES@LiehbHS<0068cGS9R<ehbHS=N<V8c
GS9R<ehbHS=N<QcWIPmV<6H?JS1V3fH`IPmZ<6H?IS1V3fX`IPmV<6H?JS0LifWZO00087oo00<007oo
Ool037oo000:Ool00`00Oomoo`0`Ool00`00F_]Jn`02000013kM000003P00QcW00/h01cW7>LngP0?
7>MooacWOc5g=AcW00=g=@037>M_5flG009_5`04IcUg=WLfObh3Obl4FN000acW17<4L`0217<00acW
<IHaUP02<IH03acWBOI5mTWfAOI9mTGf7>MB5EHEDQEF5E8EEQDLi`0:GS<03AcWHQ1V<F8AIS5R46Ha
HQ5V<F8@IS5R4FHa008Li`IYk003<II>5VW/009Yk00D7>MQ8DhFBQI>5TXF7>MF=5XeESEJ=EHdFSEF
=EXeESAJ=EHeOolLi`9R<`03001N<V8c009R<`05GS9R<f8cHS=N<P03HS<01FH_7>MV<6H`IRl00fH`
00EV;fH`IS1V<6H_00=V<003IRmV<7`0025oo`03001oogoo00aoo`002Woo00<007ooOol0<Goo00@0
05[jG_]JnP<00004IJQYbC@07>L2>0027>L033[N7>LLiglaMc@LigLdMcEg=1cWKaIc5`9_5`07I_Q[
>W<eMcIo;Wl_Obh00UWP00EMh5WP7>MNn@Ad0084L`037>LeUc6F008aUP0d7>M5mTWfAOE9mTGfBOIB
51cWDQAF5E8DEQEB55HE7>MN=5XcGS=J<ehdFS=N<eXcGSAJ<acWHQ1V<F8@IS5R46HaHQ1V<F8@IS5R
46HaIN/LifG/JNaUjfW/INaYk6G[CQI:5VW/IN/27>L0<ThFBQI>5TXF7>MF=5XeESAJ=EHdFSEF=5Xe
ESAJ=EHdFSDLif8cGS8005hbHS=N<V8cGS9R<ehbHS=N<V8cGS9R<fH?7>MV3fH`IPmZ<6H?IS1V3fX`
IPmV<6H?JS1V3fH`O00ROol00`00Oomoo`0<Ool000Yoo`03001oogoo035oo`<0009Jn`06G_/001cW
7>MYZFVX0QcW0SP00acW00=o<7la7>L017Le00<LiflGKaL00VlG00DLigLfMcIo;gl^009o;`=Ih003
7>MNnPAc0084L`037>LaUS6F008aUP0A7>M9mTGfBOI5mTWfAOI9mQcWEQEB5EHEDQEF5E8EEQDLi`0:
GS<03AcWHQ1V<F8AIS5R46HaHQ5V<F8@IS5R4FHa008Li`QYk00KBQIYk6W/JN`LifDQBQI>5QcWFSEF
=5XeESEJ=EHdFSEF=EXeESAJ=EHe7>MN<V8c001R<ehb00=R<`05GS9R<f8cHS=N<P03HS<01FH_7>MV
<6H`IRl00fH`00MV;fH`IS1V<6H_IS1l000SOol00`00Oomoo`0<Ool000Yoo`03001oogoo035oo`0=
LaL006/I001Nne[j001R3fH`7>MYbFFXJLT00QcW00<d03kN7>L00QcW00Ug=AcWMcEg=7Le7>M_5flF
LaL00VlG00IW6GLfObio;gl^Obl3FN001UgP7>L4L`Ac17@Li`8aUP0i=ILaUS6F7>M9mTGfBOI5mDWf
AOHLie8DEQEB55HEDQAF5E8D7>MJ<ehdFS=N<eXcGSAJ<ehcFS=N=5Xc7>MR46HaHQ1V<F8@IS5R46Ha
HQ1V<F8@IS5R41cWINaYk6G[JNaUk6W/IN]Yk6G/CQIUjfW/008Li`0]BQI>5QcWFSEF=5XeESAJ=EHd
FSEF=5XeESAJ=Goo7>MN<P00GS9R<ehbHS=N<V8cGS9R<ehbHS=N<V8cGS9R<fH?7>MV3fH`IPmZ<6H?
IS1V3fX`IPmV<7`002Aoo`03001oogoo00aoo`002Woo00<007ooOol0<Woo00H006LHJaT005[k0003
IQ027>L016VXJJUYZ1cW0SP000@ngQcW7>LLi`=g=@037>M_5flG00=_5`03IaUg=Gl_009o;`03ObiI
h5WP009Ih0057>L4L`Ac17<Li`05<IH04AcWAOI9mTGfBOI5mTWfDQDLie8EEQEB5EHEDQEF5E8E7>L0
2ehc00hLif8@IS5R4FHaHQ1V<F8AIS5R46HaHQ5V<F8@0QcW26W/00A>5VW/JNaYk0<Li`0?ESEJ=EHd
FSEF=EXeESAJ=EHeFSEF=5XeESDLi`0000=R<`05GS9R<f8cHS=N<P03HS<01EhbHS=R<f8c7>L00fH`
00MV;fH`IS1V<6H_IS1l000UOol00`00Oomoo`0<Ool000Yoo`03001oogoo039oo`80000=IaQ[6@00
000LifH`HPmV<6H?7>MUZ6W9IJP00QcW0SP00QcW00Eg=GLdMcEg=1cW009_5`0:KaIc5flGMcIc=Gl_
Obio;eWPGN02FN001QcW17@4L`Ac7>LeU`<aUP1R=ILLidWfAOE9mTGfBOI5mDWf7>MF5E8DEQEB55HE
DQAF5E8D7>MJ<ehdFS=N<eXcGSAJ<ehcFS=N=5Xc7>MR46HaHQ1V<F8@IS5R46HaHQ1V<F8@IS5R46W/
7>MYk6G[JNaUk6W/IN]Yk6G/JNa:5VW/INaYk1cWFSEF=5XeESAJ=EHdFSEF=5XeESAJ=EHdFSDLi`00
GS9R<ehbHS=N<V8cGS9R<ehbHS=N<V8cGS9R<ehbHS<LifX`IPmV<6H?JS1V3`9l02Moo`03001oogoo
00]oo`002Goo00<007ooOol0=7oo0P0000AW66/I001N<`8Li`=V408Li`04JJUYZ6VY7>L2>0000ckN
7>LLi`02McD00acWKaM_5`04KaL017LfObio;gl_15WP00<LifLH17<00PAc00<Lic6F<IH00S6F018L
idGfBOI5mTWfAOI9mTGfEQDLieHEDQEF5E8EEQEB5EHE7>L<GS<041cWHQ1V<F8AIS5R46HaHQ5V<F8@
IS5R4FHaHQ1V<AcW3FW/014LieXeESEJ=EHdFSEF=EXeESAJ=EHeFSEF=5Xe001R<ehb00=R<`05GS9R
<f8cHS=N<P03HS<01EhbHS=R<fH`7>L00fH`00=V;g`0Ool0:7oo00<007ooOol02goo0009Ool00`00
Oomoo`0dOol01P00KaH006LH000Li`9N<`097>MR3fH`IPmV<1cWJLUUZ6W9008Li`8h008Li`04Mc@L
iflFLaL2KaL01VlFLaMc=Gl_Obio;`=Ih009GN0Lif/I17<4M0Ac7>LaUSFG00<aUP0]7>M5mTWfAOE9
mTGfBOI5mAcWDQAF5E8DEQEB55HEDQAF5AcWGS=J<ehdFS=N<eXcGSAJ<ehcFS=N=5Xc7>MR46HaHQ1V
<F8@IS5R46HaHQ1V<F8@IS5R46Ha008Li`0<IN]Yk6G/JNaUjfW/INaYk6G[JNaUk6W/0QcW029F=5Xe
ESAJ=EHdFSEF=5XeESAJ=EHd000Lif8cGS9R<ehbHS=N<V8cGS9R<ehbHS=N<V8cGS9R<ehbIS0LifX`
IPml02Yoo`03001oogoo00]oo`002Goo00<007ooOol0=7oo00=o3@00KaH00P0000EF5AcWGS=N<acW
00AV408Li`03JJQYZFVX008Li`8h008Li`M_5`04McIo;gl^Obl3FN000acWIaP4L`0217<00acW<IHa
UP03<IH04acWBOI5mTWfAOI9mTGfBOHLieHEDQEF5E8EEQEB5EHEDQEF5AcW00aN<`0?7>MR46HaHQ5V
<F8@IS5R4FHaHQ1V<F8AIS5R46Ha008Li`eYk00=7>MF=EXeESAJ=EHeFSEF=5XeESEJ=@007>L00V8c
00EN<V8cHS=R<ehb00=R<`05GS9R<f8cHS=N<P02HS<00acWIRml000[Ool00`00Oomoo`0;Ool000Uo
o`03001oogoo03Aoo`08Obio3@00IaP0058D7>MN<P9N<`0;7>MR3fH`IPmV<68?7>MUZ6W9IJQYb@02
7>L01S@07>LLiflGKaIc5`9_5`06KaIg=Wl^Obmo;UgP0UWP00<Lif/I17<00PAc04dLic6F<IHaUSFG
<IHLidGeBOI5mTWfAOE9mTGfEQDLieHEDQAF5E8DEQEB55HEDQ@LieXcGS=J<ehdFS=N<eXcGSAJ<ehc
FS=N=5Xc7>MR46HaHQ1V<F8@IS5R46HaHQ1V<F8@IS5R46HaHQ0LifG[JNaUk6W/IN]Yk6G/JNaUjfW/
INaYk5HdFSEF=5XeESAJ=EHdFSEF=5Xe0080000DES@LiehbHS=N<V8cGS9R<ehbHS=N<V8cGS9R<ehb
HS=N<V8cGS9l02aoo`03001oogoo00]oo`002Goo00<007ooOol0=Goo00Mo3P000015eAcWEQDLi`03
GS<00acWIQ1V4003IQ027>L01FVYJJQYZFVX7>L00SP00QcW1FlG0gl_0eWP00<Li`Ac17<00PAc00<L
ic6F<IH00c6F01@LidWfAOI9mTGfBOI5mTWfAOHLie8EEQEB5EHEDQEF5E8EEQEB5AcW3Ehc010Lif8@
IS5R4FHaHQ1V<F8AIS5R46HaHQ5V<F8@IS5R4@8Li`]Yk006ESAJ=EHeFSEF=5Xe0`0000EJ=EHe001N
<QcW009R<`05GS9R<f8cHS=N<P03HS<015hbHS=R<f8c0W`0;Goo00<007ooOol02goo0009Ool00`00
Oomoo`0eOol00gl=7>L000027>L015HEDQ@Liehb0Uhc0QcW00YV<6H?IS1R3fH`7>MYbFFXJLUUZ08L
i`05>01_5acWKaIc5`02KaL00gl^Obmo;P02FN002EgP17<LiacW17@4LacW<IHeU`03<IH0@3FG7>M9
mTGeBOI5mTWfAOE9mU8D7>MB55HEDQAF5E8DEQEB55HEDQ@LieXcGS=J<ehdFS=N<eXcGSAJ<ehcFS=N
=5Xc7>MR46HaHQ1V<F8@IS5R46HaHQ1V<F8@IS5R46HaHQ1Yk1cWJNaUk6W/IN]Yk6G/JNaUjfW/INaY
k5Hd100001AJ=EHdFSEF=5XeES@001cWHS=N<V8cGS9R<ehbHS=N<V8cGS9R<ehb0W`0;goo00<007oo
Ool02goo0009Ool00`00Oomoo`0eOol01Wl>010LiacWAMHLi`9F5@037>MN<ehc009N<`037>MV46H@
00=V408Li`04JJQYZFVXJJT27>L00cP07>LLi`02KaL00gLfObio;`04FN001QcWIcX4L`Ac<IHLi`Da
UP0D7>M5mTWfAOI9mTGfBOI5mTWf7>MF5E8EEQEB5EHEDQEF5E8EEQDLi`eN<`0CHQ4Lif8@IS5R4FHa
HQ1V<F8AIS5R46HaHQ5V<F8@IS5R4FW/7>L026W/0`0000eF=5XeESEJ=EHdFSEF=EXeESAJ=@00HS<L
i`03HS<01UhbHS=R<f8cGS9R<`9l035oo`03001oogoo00]oo`0027oo00<007ooOol0=Woo00Ao3@0@
:EE5eP8Li`05DQAF5AcWGS=N<P03GS<03AcWIS1V3fH`HPmV<6H?7>MUZ6W9IJQYbFFX008Li`07>00L
iacWKaMo;gl^Obl00eWP00HLifLI17<4L`Ad7>L2<IH0?3FG<IHaUQcWBOI5mTWfAOE9mTGfBOI5mAcW
DQAF5E8DEQEB55HEDQAF5E8DEQDLiehdFS=N<eXcGSAJ<ehcFS=N=5XcGS=J<ehdHQ0Lif8@IS5R46Ha
HQ1V<F8@IS5R46HaHQ1V<F8@IS5R46Ha7>MYk6G/JNaUj`<0000IIN]Yk6G/JNaF=5XeESAJ=EHdFSEF
=5XeESAJ=@007>MN<V8cGS9R<ehbHS=N<V8cO000=7oo00<007ooOol02Woo0008Ool00`00Oomoo`0f
Ool02Wl>IT0044GE7>M5eAcWDQAF5AcW1Ehc00<LifH@IQ0016H@0QcW00EYZFVXJJUYZ6VY008Li`05
KaLLigl_Obmo;P03FN000acWIcT4L`0217<00acW<IHaUP03<IH05QcWAOI9mTGfBOI5mTWfAOI9mU8E
7>MB5EHEDQEF5E8EEQEB5EHEDQEF5AcW3Ehc01=R4AcWHQ1V<F8AIS5R46HaHQ5V<F8@IS5R4FHaHQ1V
<F8AIS4Li`030008JN`03EHdFSEF=EXeESAJ=EHeFSEF=5Xe000Liehb00=R<`03GS9l07`003Eoo`03
001oogoo00Yoo`0027oo00<007ooOol0=Woo00=o3Gl^01000QcW00Q5eQcWEQEB55HE7>MN<ehb0ehc
00PLifH`IPmV<68?IS1V3fH`0QcW011UZ6W9IJQYbFFX7>Ld01cWObio;eWPGN1Ih1cW17<4M084L`03
7>LeUc6F008aUP0d=ILaUQcWAOE9mTGfBOI5mDWfAOI9mQcWEQEB55HEDQAF5E8DEQEB55HEDQ@LieXc
GSAJ<ehcFS=N=5XcGS=J<ehdFS=N<eXcGSAR41cWHQ1V<F8@IS5R46HaHQ1V<F8@IS5R46HaHQ030000
6VG[7>MUk6W/IN]Yk6G/JNaUjfW/INaYk5HdFSEF=5XeESAJ=EHdFSEF=5Xe001R<ehbHS<2O00gOol0
0`00Oomoo`0:Ool000Qoo`03001oogoo03Moo`0;O`d041cWAMHLidGF7>MF5E8DEQDLi`05GS<00acW
IQ1V4005IQ001fVX7>MYZ6VYJJQYZFVX008Li`9o;`=Ih0037>L4LfLi0084L`037>LaUS6F00@aUP0F
7>M9mTGfBOI5mTWfAOI9mTGfEQDLieHEDQEF5E8EEQEB5EHEDQEF5E8E7>L>GS<02QcWIS5R46HaHQ5V
<F8@IS5R4FHa100000IR46HaHQ5V<F8@7>L:JN`02eHdFSEF=EXeESAJ=EHeFSEF=68c00000W`0>Goo
00<007ooOol02Woo0008Ool00`00Oomoo`0gOol03Wl^010]ETGE7>M1eEHE7>MF5E8DEQDLiehcGS83
GS<27>L01fH?IS1R3fH`IPmV<68?00<Li`06IJQYbFFXJLTLigl_0eWP00HLi`AcJcX4L`Ad7>L2<IH0
;cFG<IHaUS6F7>M5mTWfAOE9mTGfBOI5mDWfAOHLie8DEQEB55HEDQAF5E8DEQEB55HEDQ@LieXcGSAJ
<ehcFS=N=5XcGS=J<ehdFS=N<eXcGS@LifHaHQ1V<F8@IS400`0000YV<F8@IS5R46HaHQ1V<F8@IS5R
408Li`0AJNaUjfW/INaYk6G[JNaUk6W/ESAJ=EHdFSEF=5XeESAJ=@02O0000`00Oomoo`0hOol00`00
Oomoo`0:Ool000Qoo`03001oogoo03Moo`03O`dLibUE008Li`03AMI5eAcW009F5@03DQAF5AcW00IN
<`037>MV46H@00EV4009JJTLifVYJJQYZFVXObmo;Wl_009Ih0037>L4LfLi0084L`037>LaUS6F00@a
UP0G7>M9mTGfBOI5mTWfAOI9mTGfBOHLieHEDQEF5E8EEQEB5EHEDQEF5E8EEQDLi`0?GS<00acWIS40
0002000046HaHQ1V<F8AIS5R46HaHQ5V<F8@IS5R4FHaHQ1Yk1cW2FW/00=F=5XeESD017`00Woo00<0
07ooOol0>7oo00<007ooOol02Woo0007Ool00`00Oomoo`0hOol047l^7>L041cWAMHLidGFDQ@Lie8D
EQEB55HE7>MN<ehb0ehc00YN<QcWIPmV<68?IS1V3fH`HPmV<08Li`0:IJQYbFFXObmo;UgPFN04LacW
17@217<00c6F7>LaUP02<IH09cFG<IHLidGeBOI5mTWfAOE9mTGfBOI5mEHE7>MF5E8DEQEB55HEDQAF
5E8DEQEB55HE7>MN<eXcGSAJ<ehcFS=N=5XcGS=J<ehdFS=N<`0300007FHaHQ1V<F8@IS5R46HaHQ1V
<F8@IS5R46HaHQ1V<F8@IS5R46Ha7>MYk6G[JNaUk6W/IN]Yk6G/JN`00W`000=Uk7`0Ool017oo00<0
07ooOol0=goo00<007ooOol02Woo0007Ool00`00Oomoo`0hOol02Gl=7>L041cWAMDLidGEAMHLi`03
EQD00e8DEQDLi`06GS<00acWIQ1V4006IQ0016VX7>MYZ6VY0Wl_0eWP00<Li`Ac17<00PAc00<Lic6F
<IH0136F01LLidGfBOI5mTWfAOI9mTGfBOI5mQcWDQEF5E8EEQEB5EHEDQEF5E8EEQEB5AcW00YN<`<0
00=N<`0E7>MV<F8@IS5R4FHaHQ1V<F8AIS5R46HaHQ5V<F8@IS5R4FHaHQ1V<AcW00YYk003O01oogoo
00Eoo`03001oogoo03Moo`03001oogoo00Uoo`001goo00<007ooOol0>Goo015R800A7>L]EQcWAMI5
eEHE7>MF5E8DEQEB55HE7>MN<ehb00=N<`0?GS8LiacWIS1R3fH`IPmV<68?IS1V3acWIJQo;gl^009I
h009GN0Li`AcLcD4M0Ac7>LaUSFG00<aUP0N=ILLidWfAOE9mTGfBOI5mDWfAOI9mU8D7>MB55HEDQAF
5E8DEQEB55HEDQAF5E8D7>MJ<ehcFS=N=5Xc100001]N<eXcGSAJ<ehcFS=N=1cWIS5R46HaHQ1V<F8@
IS5R46HaHQ1V<F8@IS5R46HaHQ1V<F8@IS400QcW00UUjfW/INaYk6G[JNaUk6W/O00027oo00<007oo
Ool0=Woo00<007ooOol02Goo0007Ool00`00Oomoo`0iOol02Wl>010LibUE7>M5eDGFAMDLie8D0eHE
00=B51cWGS<01ehc0QcW1fH@0QcW00Mo;eWPFN1Ih1cW17=g=P0217<00acW<IHaUP04<IH06QcWAOI9
mTGfBOI5mTWfAOI9mTGfBOHLieHEDQEF5E8EEQEB5EHEDQEF5E8EEQEB5AcWGS<3000<GS<05QcWIS5R
46HaHQ5V<F8@IS5R4FHaHQ1V<F8AIS5R46HaHQ5V<F8@IS5R4AcW1VW/00=l07ooOol027oo00<007oo
Ool0=Goo00<007ooOol02Goo0007Ool00`00Oomoo`0iOol047l=7>LYEAcWAMDLid7EAMI5eAcWDQAF
5E8DEQEB51cW0Uhc019N<UhcGS=N<ehbGS=V3acWHPmV<6H?IS1R3fH`IPmV<7l^GN02FN000acW17Ac
=@0217<01AcW<IHaUS6F=IL00S6F01LLidWfAOI9mTGeBOI5mTWfAOE9mTGf7>MB55HEDQAF5E8DEQEB
55HEDQAF5E8D00<0000/FS=N<eXcGSAJ<ehcFS=N=5XcGS=J<ehdFS=N<eXcGS@LifHaHQ1V<F8@IS5R
46HaHQ1V<F8@IS5R46HaHQ1V<F8@IS5R46HaHQ0LifG[JNaUk6W/IN]l00Yoo`03001oogoo03Eoo`03
001oogoo00Uoo`001goo00<007ooOol0>Goo00ao3QcW:EDLibUE7>M5eTGEAMHLieHEDQ@3EQD00e8D
7>MN<`07GS<00eHd7>MV4006IQ001Gl_ObiIh5WP7>L010Ac00<Lic6F<IH01C6F01<LidWfAOI9mTGf
BOI5mTWfAOI9mU8E7>MB5EHEDQEF5E8EEQEB5@0300000e8EEQDLi`0AGS<05AcWIS5R46HaHQ5V<F8@
IS5R4FHaHQ1V<F8AIS5R46HaHQ5V<F8@IS5R4@027>L2JN`00g`0Oomoo`0:Ool00`00Oomoo`0dOol0
0`00Oomoo`09Ool000Moo`03001oogoo03Uoo`0BO`dLi`0@7>LYEAcWAME5eT7EAMHLieHEDQAF5E8D
EQEB51cW0Uhc01=N<UhcGS=N<ehbGS=F51cWHPmV<6H?IS1R3fH`Obio;eWPGN0Li`0217<01@Ad17<L
ic6F=IL00c6F018eUc6F7>M5mDWfAOI9mTGeBOI5mTWfAOE9mQcWEQEB55HEDQ@30000<E8DEQEB55HE
DQAF5AcWGSAJ<ehcFS=N=5XcGS=J<ehdFS=N<eXcGSAJ<ehcFS=N=1cWIS5R46HaHQ1V<F8@IS5R46Ha
HQ1V<F8@IS5R46HaHQ1V<F8@IS5R46Ha7>MYk7`000eoo`03001oogoo03=oo`03001oogoo00Uoo`00
1Woo00<007ooOol0>goo00dLi`0@7>LYEDGE7>M5eDGFAMEF5AcWEQEB5003EQD00e8D7>MN<`07GS<0
0eHd7>MV4004IQ02Obl2FN0011cW17<4LfVX0PAc00<Lic6F<IH0136F00`LidWfAOI9mTGfBOI5mTWf
AOI9mTGf7>L400002U8EEQEB5EHEDQEF5E8EEQEB5AcW4Uhc01LLifHaHQ1V<F8AIS5R46HaHQ5V<F8@
IS5R4FHaHQ1V<F8AIS5R46HaHQ5V<G`000moo`03001oogoo039oo`03001oogoo00Uoo`001Woo00<0
07ooOol0>goo01<Li`0@7>LYEBeF7>M5eTGEAMI1eAcWDQAF5E8DEQEB55HEDQ@Li`02GS<01EhbGS=N
<ehcGS800Uhc0QcW00EV<6H?IS1R3gl_009Ih00717<Li`AcJLT4L`Ad7>L00S6F00deUc6F<IHaUQcW
AOI9mTGeBOI5mTWfAOE9mP030000=QcWDQAF5E8DEQEB55HEDQAF5E8DEQEB55HEDQ@LieXcGSAJ<ehc
FS=N=5XcGS=J<ehdFS=N<eXcGSAJ<ehcFS=N=1cWIS5R46HaHQ1V<F8@IS5R46HaHQ1V<F8@IS5R46Ha
HQ1V<F8@IS5l015oo`03001oogoo035oo`03001oogoo00Uoo`001Woo00<007ooOol0>goo00ao3AcW
:EDLibUE7>M5eDGFAME5eU8D7>L2EQD01U8DEQEF5EHEGS<Li`UN<`03IQ0LifH@009V4007ObiIh5WP
17<Li`Ac7>L00PAc00<Lic6F<IH01C6F00DLidGfBOI5mTWf00<0000CBOI5mTWf7>MF5E8EEQEB5EHE
DQEF5E8EEQEB5EHEDQEF5E8E7>L04Uhc01<LifHaHQ1V<F8AIS5R46HaHQ5V<F8@IS5R4FHaHQ1V<F8A
IS5l000BOol00`00Oomoo`0bOol00`00Oomoo`08Ool000Ioo`03001oogoo03]oo`0EObhLibeF7>L]
ETGE7>M1eDGFAME5eQcWEQEB55HEDQAF5E8DEQEN<QcW009N<`05GS9N<ehcGS=N<P02GS<02eXe7>MV
<6H?Obmo;UgPFN0Li`Ac17@00PAc00<LicFG<IH00S6F00DeUc6F<IHLidWf00<0000jBOI5mTWfAOE9
mTGfEQDLieHEDQAF5E8DEQEB55HEDQAF5E8DEQEB55HE7>MN<eXcGSAJ<ehcFS=N=5XcGS=J<ehdFS=N
<eXcGSAJ<ehcFS=N=1cWIS5R46HaHQ1V<F8@IS5R46HaHQ1V<F8@IS5R46HaO00DOol00`00Oomoo`0a
Ool00`00Oomoo`08Ool000Ioo`03001oogoo03]oo`04O`dLi`0@7>L2:ED01acWAMI5eDGFAMEF5AcW
00=F5@05DQAF5EHEEQDLi`0:GS<01EXe7>MV46H@Obl00UWP00<Li`Ac17<00PAc00<Lic6F<IH0136F
0`0001Y9mTGfBOI5mTWfAOI9mTGfBOI5mQcWDQEF5E8EEQEB5EHEDQEF5E8EEQEB5EHEDQEF5AcW4Uhc
011V<AcWIS5R46HaHQ5V<F8@IS5R4FHaHQ1V<F8AIS5l01Ioo`03001oogoo031oo`03001oogoo00Qo
o`001Woo00<007ooOol0>goo01Io;QcW014LibeF:EDLidGEAMI1eDGFAMDLie8DEQEB55HEDQAF5E8D
EQDLi`=N<`05GS9N<ehcGS=N<P02GS<015Xe7>MV<7l^0UWP00HLi`Ac17=R3`Ad7>L2<IH40000?SFG
7>M9mTGeBOI5mTWfAOE9mTGfBOI5mDWf7>MF5E8DEQEB55HEDQAF5E8DEQEB55HEDQAF5E8DEQDLiehc
FS=N=5XcGS=J<ehdFS=N<eXcGSAJ<ehcFS=N=5XcGS=J<acWHQ1V<F8@IS5R46HaHQ1V<F8@IS5R46Ha
O00HOol00`00Oomoo`0_Ool00`00Oomoo`08Ool000Eoo`03001oogoo03eoo`037>L041cW008YE@09
AMDLidGEAMI5eDGFEQDLie8D00=F5@05DQAF5EHEEQDLi`0:GS<00acWIQ1o;`02FN001AcW17<4LfH@
17<00`001S6F01`LidWfAOI9mTGfBOI5mTWfAOI9mTGfBOHLieHEDQEF5E8EEQEB5EHEDQEF5E8EEQEB
5EHEDQDLia=N<`0<7>MR4FHaHQ1V<F8AIS5R46HaHQ5V<G`06Woo00<007ooOol0;Woo00<007ooOol0
27oo0005Ool00`00Oomoo`0mOol05acW010LibeF:ED]EQcWAMI5eDGF@ME5eQcWEQEB55HEDQAF5E8D
EQEB51cWGS800ehc00EN<UhcGS=N<ehb009N<`8Li`04GN1Ih1cW17<300000`Ac7>LaUP02<IH0?cFG
<IHaUS6F7>M5mTWfAOE9mTGfBOI5mDWfAOI9mTGe7>MB55HEDQAF5E8DEQEB55HEDQAF5E8DEQEB55HE
DQ@LieXcGS=J<ehdFS=N<eXcGSAJ<ehcFS=N=5XcGS=J<ehdFS=N<eXc7>MR46HaHQ1V<F8@IS5R46Ha
HQ1l000KOol00`00Oomoo`0]Ool00`00Oomoo`08Ool000Eoo`03001oogoo03eoo`04IT0LibUE7>L2
:ED02QcWAME5eTGEAMI5eDGF7>MF5E8D0eHE00AB55HEEQDLi`aN<`04FN000000000417<00acW<IHa
UP05<IH07QcWBOI5mTWfAOI9mTGfBOI5mTWfAOI9mU8E7>MB5EHEDQEF5E8EEQEB5EHEDQEF5E8EEQEB
5EHEDQDLia=N<`097>MR4FHaHQ1V<F8AIS5R47`001aoo`03001oogoo02eoo`03001oogoo00Qoo`00
1Goo00<007ooOol0?Goo01Uo3AcW010LibUE;EI5eAcW@ME5eTGEAMI1eAcWDQAF5E8DEQEB55HEDQAF
5E8D7>MN<P03GS<01EhbGS=N<ehcGS800`0000=Ih0Ad7>L00PAc00D4M0Ac7>LaUSFG00<aUP0k=ILa
UQcWAOE9mTGfBOI5mDWfAOI9mTGeBOI5mTWf7>MF5E8DEQEB55HEDQAF5E8DEQEB55HEDQAF5E8DEQDL
iehdFS=N<eXcGSAJ<ehcFS=N=5XcGS=J<ehdFS=N<eXcGSAJ<ehcFS<Lif8@IS5R46HaHQ1l000NOol0
0`00Oomoo`0]Ool00`00Oomoo`07Ool000Eoo`03001oogoo03eoo`04O`hLi`0@7>L3:ED01acWAMI5
eDGFAME5eQcW00=F5@05DQAF5EHEEQEB5002EQD00acWGS=N<`02GS<40002GS<017l_FN04LacW0PAc
00=V40Ac7>L0236F01hLidGfBOI5mTWfAOI9mTGfBOI5mTWfAOHLie8EEQEB5EHEDQEF5E8EEQEB5EHE
DQEF5E8EEQEB5EHE7>LDGS<01AcWHQ5V<F8@O00087oo00<007ooOol0;7oo00<007ooOol01goo0005
Ool00`00Oomoo`0nOol06AcW010LibUE;EHYEAcWAME5eT7EAMI5eDGF7>MF5E8DEQEB55HEDQAF5E8D
EQEB51cW00<00003GS=N<Uhc009N<`0:GS9o;eWP17<Li`Ad17=V<0Ac7>L3<IH0>cFG<IHaUS6F=ILL
idWfAOE9mTGfBOI5mDWfAOI9mTGeBOI5mQcWDQAF5E8DEQEB55HEDQAF5E8DEQEB55HEDQAF5E8DEQDL
iehdFS=N<eXcGSAJ<ehcFS=N=5XcGS=J<ehdFS=N<eXcGSAJ<ehcFS<Lif8@O0008Woo00<007ooOol0
:goo00<007ooOol01goo0005Ool00`00Oomoo`0nOol00acW010Li`03:ED02AcWAMI5eDGFAME5eTGE
7>MB5003EQD0158DEQEF5EHE0`002Ehc00Ao;UWPFN0Li`@4L`037>LaUS6F00HaUP0O7>M5mTWfAOI9
mTGfBOI5mTWfAOI9mTGfBOHLieHEDQEF5E8EEQEB5EHEDQEF5E8EEQEB5EHEDQEF5E8E7>L05Ehc00=l
07ooOol08Woo00<007ooOol0:Woo00<007ooOol01goo0004Ool00`00Oomoo`0oOol04acW010]EQcW
;EHYEBeF7>M5eTGEAMI1eDGFAMDLie8DEQEB55HE00<00006EQEB55HE7>MN<ehb0ehc00MN<UhcGS=N
<eWPGN0Li`0217<01@Ad17<Lic6F=IL00c6F03LeUc6F<IHLidWfAOI9mTGeBOI5mTWfAOE9mTGfBOI5
mEHE7>MF5E8DEQEB55HEDQAF5E8DEQEB55HEDQAF5E8DEQEB51cWFS=N=5XcGS=J<ehdFS=N<eXcGSAJ
<ehcFS=N=5XcGS=J<ehdFS=l000UOol00`00Oomoo`0ZOol00`00Oomoo`07Ool000Aoo`03001oogoo
03moo`047>L042UE7>L3:ED021cWAME5eTGEAMI5eDGFAMD400000eHEDQAF5@02EQD00e8DEQDLi`08
GS<2FN000acW17<4L`0317<00acW<IHaUP06<IH07acWBOI5mTWfAOI9mTGfBOI5mTWfAOI9mTGf7>MB
5EHEDQEF5E8EEQEB5EHEDQEF5E8EEQEB5EHEDQEF5AcW019N<`03O01oogoo02Eoo`03001oogoo02Uo
o`03001oogoo00Moo`0017oo00<007ooOol0?goo00aV@AcW014LibeF:ED]EQcWAMI1eDGFAMD30000
3acWEQEB55HEDQAF5E8DEQEB55HEDQAF5AcWGS=N<P03GS<01UhbGS=N<eWP7>L4M084L`03GS84M1cW
008aUP0e=ILaUS6F<IHeUc6F7>M5mDWfAOI9mTGeBOI5mTWfAOE9mTGfBOHLieHEDQAF5E8DEQEB55HE
DQAF5E8DEQEB55HEDQAF5E8DEQDLiehcFS=N=5XcGS=J<ehdFS=N<eXcGSAJ<ehcFS=N=002O00YOol0
0`00Oomoo`0XOol00`00Oomoo`07Ool000Aoo`03001oogoo03moo`04O`dLi`0@7>L4:ED02acW0000
0000AME5eTGEAMHLieHEDQ@00eHE00MB55HEEQEF5E8DEQDLi`07GS<00eWP17<Li`0217<00ehc17<L
i`08<IH08AcWBOI5mTWfAOI9mTGfBOI5mTWfAOI9mTGfBOHLieHEDQEF5E8EEQEB5EHEDQEF5E8EEQEB
5EHEDQEF5E8EEQDLi`0=GS<00g`0Oomoo`0ZOol00`00Oomoo`0XOol00`00Oomoo`06Ool000Aoo`03
001oogoo041oo`057>L041cW;EHYE@0300005dGEAMI1eDGFAME5eT7E7>MB55HEDQAF5E8DEQEB55HE
DQAF5E8DEQDLiehcGS800ehc00IN<UgP17<Li`Ac17@217<00acW=ILaUP02<IH0<SFG<IHaUS6F7>M5
mTWfAOE9mTGfBOI5mDWfAOI9mTGeBOI5mQcWDQAF5E8DEQEB55HEDQAF5E8DEQEB55HEDQAF5E8DEQEB
51cWFS=N<eXcGSAJ<ehcFS=N=5XcGS=J<ehdO00^Ool00`00Oomoo`0WOol00`00Oomoo`06Ool000Ao
o`03001oogoo041oo`037>L040000080008YE@0:7>M5eTGEAMI5eDGFAME5eTGE7>L2EQD01E8DEQEF
5EHEDQ@00eHE00=B55HE7>L01Ehc00=Ih0Ac7>L010Ac00<Lic6F<IH01S6F028LidWfAOI9mTGfBOI5
mTWfAOI9mTGfBOI5mTWfDQDLie8EEQEB5EHEDQEF5E8EEQEB5EHEDQEF5E8EEQEB5EHEDQDLi`YN<`03
O01oogoo02eoo`03001oogoo02Moo`03001oogoo00Ioo`000goo00<007ooOol0?goo100001`YEAcW
:ED]ERUEAMHLidGFAME5eT7EAMI5eDGF7>MF5E8DEQEB55HEDQAF5E8DEQEB55HEDQ@Li`9N<`06GS9N
<ehcFN04LacW0`Ac00D4M1cW<IHaUSFG00<aUP0^=ILaUS6F7>M9mTGfBOI5mDWfAOI9mTGeBOI5mTWf
AOE9mQcWEQEB55HEDQAF5E8DEQEB55HEDQAF5E8DEQEB55HEDQAF5E8D7>MJ<ehcFS=N=5XcGS=J<ehd
O00aOol00`00Oomoo`0VOol00`00Oomoo`06Ool000=oo`03001oogoo03aoo`<0009oo`047>L0400@
7>L4:ED02QcWAME5eTGEAMI5eDGFAME5eQcW0eHE00EB55HEEQEF5E8D00=F5@03DQ@Liehc00=N<`9I
h0077>L4L`Ac17=N<c6F7>L0236F028LidGfBOI5mTWfAOI9mTGfBOI5mTWfAOI9mTGf7>MB5EHEDQEF
5E8EEQEB5EHEDQEF5E8EEQEB5EHEDQEF5E8EEQDLi`MN<`03O01oogoo035oo`03001oogoo02Eoo`03
001oogoo00Ioo`000goo00<007ooOol0>Goo0`001Goo020Li`0@010LibUE;EHYEBeF7>M5eT7EAMI5
eDGF@ME5eTGEAMHLieHEDQAF5E8DEQEB55HEDQAF5E8DEQEB51cW0Uhc00IN<UhcFN0Li`Ac17@317<0
1AcW<IHaUS6F=IL00c6F02PeUacWBOI5mDWfAOI9mTGeBOI5mTWfAOE9mTGfBOI5mAcWDQAF5E8DEQEB
55HEDQAF5E8DEQEB55HEDQAF5E8DEQEB55HE7>MN=5XcGS=J<`9l03Eoo`03001oogoo02Aoo`03001o
ogoo00Ioo`000goo00<007ooOol0=Woo0`002Goo00<Li`0@7>L012UE00a5eQcWAMI5eDGFAME5eTGE
AMI5eAcWDQ@3EQD01E8DEQEF5EHEDQ@00eHE00=B51cWGS<00Uhc00=Ih1cW17<010Ac00<Lic6F<IH0
1S6F02@LidGfBOI5mTWfAOI9mTGfBOI5mTWfAOI9mTGfBOHLieHEDQEF5E8EEQEB5EHEDQEF5E8EEQEB
5EHEDQEF5E8EEQEB5EHE7>L2GS<00g`0Oomoo`0fOol00`00Oomoo`0SOol00`00Oomoo`06Ool000=o
o`03001oogoo03=oo`<000aoo`0Q7>L041cW:ED]ERUE;EHYEAcWAME5eT7EAMI5eDGF@ME5eTGE7>MB
55HEDQAF5E8DEQEB55HEDQAF5E8DEQEB51cW009N<`03FN0Li`Ac0084L`0517@4LacW<IHeU`03<IH0
:CFG<IHaUS6F7>M5mTWfAOE9mTGfBOI5mDWfAOI9mTGeBOI5mQcWDQAF5E8DEQEB55HEDQAF5E8DEQEB
55HEDQAF5E8DEQEB55HEDQ@LieXcO000>Woo00<007ooOol08Woo00<007ooOol01Woo0003Ool00`00
Oomoo`0_Ool4000?Ool011cW010YEAcW12UE00dLidGFAME5eTGEAMI5eDGFAME5eQcWEQEB5003EQD0
1E8DEQEF5EHEDQ@00eHE00IB51cWGS=N<`Ac7>L417<00acW<IHaUP07<IH08QcWBOI5mTWfAOI9mTGf
BOI5mTWfAOI9mTGfBOI5mQcWDQEF5E8EEQEB5EHEDQEF5E8EEQEB5EHEDQEF5E8EEQEB5EHE0W`0>goo
00<007ooOol08goo00<007ooOol01Goo0002Ool00`00Oomoo`0]Ool3000COol09acW01004AcW;EHY
EBeF:EE5eQcWAMI5eDGF@ME5eTGEAMI1eDGF7>MF5E8DEQEB55HEDQAF5E8DEQEB55HEDQAF5E8D7>MN
<`Ac7>L4M00217<00ehb7>LaUP02<IH09SFG<IHaUS6F=ILaUQcWAOE9mTGfBOI5mDWfAOI9mTGeBOI5
mTWfAOE9mQcWEQEB55HEDQAF5E8DEQEB55HEDQAF5E8DEQEB55HEDQ@2O00nOol00`00Oomoo`0ROol0
0`00Oomoo`05Ool0009oo`03001oogoo02Yoo`<001Ioo`047>L0400@7>L5:ED02acWAME5eTGEAMI5
eDGFAME5eTGE7>L00UHE00EB55HEEQEF5E8D00=F5@08DQAF5EHEEQEN<acW17<Li`@4L`037>LaUS6F
00LaUP0N7>M9mTGfBOI5mTWfAOI9mTGfBOI5mTWfAOI9mTGfBOHLieHEDQEF5E8EEQEB5EHEDQEF5E8E
EQEB5EHE0W`0@Goo00<007ooOol08Goo00<007ooOol01Goo0002Ool00`00Oomoo`0WOol3000IOol0
91cW010041cW;EHYEBeF:ED]EQcWAMI1eDGFAME5eT7EAMI5eDGF@MDLie8DEQEB55HEDQAF5E8DEQEB
55HEDQAF5E8DEQEN<P8Li`84L`0517@4L`Ac7>LeU`03<IH083FG<IHaUS6F=ILLidWfAOE9mTGfBOI5
mDWfAOI9mTGeBOI5mTWfAODLie8DEQEB55HEDQAF5E8DEQEB55HEDQ@2O014Ool00`00Oomoo`0POol0
0`00Oomoo`05Ool0009oo`03001oogoo02Aoo`<001aoo`047>L0400@7>L5:ED034GF7>M5eTGEAMI5
eDGFAME5eTGEAMHLi`=F5@05DQAF5EHEEQEB5003EQD0158DEQEF5EHE0QcW1@Ac00<Lic6F<IH01c6F
01TLidGfBOI5mTWfAOI9mTGfBOI5mTWfAOI9mTGfBOHLieHEDQEF5E8EEQEB5EHEDQEF5@02O017Ool0
0`00Oomoo`0OOol00`00Oomoo`05Ool0009oo`03001oogoo021oo`@0021oo`0V7>L04AcW;EHYEBeF
:ED]ERUE7>M5eDGF@ME5eTGEAMI1eDGFAME5eQcWEQEB55HEDQAF5E8DEQEB55HEDQAF5E8DEQEB55HE
7>L4M0<4L`0517@Lic6F<IHeU`03<IH06SFG<IHaUQcWBOI5mTWfAOE9mTGfBOI5mDWfAOI9mTGeBOI5
mTWf7>MF5E8DEQEB55HEDQ@2O019Ool00`00Oomoo`0OOol00`00Oomoo`05Ool0009oo`03001oogoo
01eoo`<002Aoo`047>L042UE7>L5:ED03AcWAMI5eDGFAME5eTGEAMI5eDGFAMEF5AcW00=F5@05DQAF
5EHEEQEB5003EQD0158DEQEF5AcW10Ac00=N<acW<IH0236F01DLidGfBOI5mTWfAOI9mTGfBOI5mTWf
AOI9mTGfBOI5mQcWDQEF5E8EEQD00W`0C7oo00<007ooOol07Woo00<007ooOol01Goo0002Ool00`00
Oomoo`0JOol3000WOol09AcW010041cW:ED]ERUE;EHYEDGF7>M5eTGEAMI1eDGFAME5eT7EAMI5eAcW
DQAF5E8DEQEB55HEDQAF5E8DEQEB55HEDQAF5AcW0084L`0517@4L`Ac7>LeU`03<IH063FG<IHaUS6F
=ILaUQcWAOE9mTGfBOI5mDWfAOI9mTGeBOI5mTWfAOE9mTGf7>MB509l04moo`03001oogoo01ioo`03
001oogoo00Aoo`0000=oo`00Ool06Goo0`00:Woo00@Li`0@010Li`HYE@0>7>M5eDGFAME5eTGEAMI5
eDGFAME5eTGE7>MB50=F5@05DQAF5EHEEQEB5003EQD00e8D7>L4L`0417<00acW<IHaUP08<IH03acW
BOI5mTWfAOI9mTGfBOI5mTWfAOI9mTGfBOI5mP03O01BOol00`00Oomoo`0MOol00`00Oomoo`04Ool0
0003Ool007oo01Ioo`<002eoo`0T7>L04@0@7>LYEBeF:ED]ERUE;EHLidGF@ME5eTGEAMI1eDGFAME5
eT7EAMHLieHEDQAF5E8DEQEB55HEDQAF5E8DEQEB55HE0W`00`Ac00D4M1cW<IHaUSFG00<aUP0@=ILa
US6F<IHLidGfBOI5mDWfAOI9mTGeBOI5mTWfAOD3O01FOol00`00Oomoo`0LOol00`00Oomoo`04Ool0
0003Ool007oo019oo`@0031oo`047>L0400@7>L6:ED044GF7>M5eTGEAMI5eDGFAME5eTGEAMI5eDGF
7>MF5E8D0eHE00EB55HEEQEF5E8D00=F5@0317=l07`000<4L`037>LaUS6F00LaUP097>M9mTGfBOI5
mTWfAOI9mTGf00=l05Uoo`03001oogoo01aoo`03001oogoo00Aoo`0000=oo`00Ool03goo0`00=7oo
02LLi`0@010]EQcW;EHYEBeF:ED]ERUE7>M5eDGF@ME5eTGEAMI1eDGFAME5eT7E7>MB55HEDQAF5E8D
EQEB55HEDQAF5E8DEQEB55HEDQ@00W`00PAc00DLic6F<IHaUSFG00<aUP08=ILaUS6F7>M9mTGfBOI5
m@=l05eoo`03001oogoo01]oo`03001oogoo00Aoo`0000=oo`00Ool037oo0`00>7oo00@Li`0@010L
i`HYE@0>7>M5eTGEAMI5eDGFAME5eTGEAMI5eDGFAMDLi`9F5@05DQAF5EHEEQEB5003EQD0158DEQEl
07`00Woo0W`000<Lic6F<IH0236F00<LidGfO0000W`0HGoo00<007ooOol06Woo00<007ooOol017oo
00000goo001oo`09Ool3000kOol091cW010041cW;EHYEBeF:ED]ERUE7>M1eDGFAME5eT7EAMI5eDGF
@ME5eTGEAMHLieHEDQAF5E8DEQEB55HEDQAF5E8DEQEl00Ioo`el06Eoo`03001oogoo01Uoo`03001o
ogoo00Aoo`0000<007ooOol01Woo0`00?Woo00@Li`0@010Li`LYE@0>7>M5eDGFAME5eTGEAMI5eDGF
AME5eTGEAMHLi`=F5@07DQAF5EHEEQEB55HEO000NWoo00<007ooOol067oo00<007ooOol017oo0000
0`00Oomoo`02Ool40011Ool08acW01004AcW;EHYEBeF:ED]ERUE;EHLidGF@ME5eTGEAMI1eDGFAME5
eT7EAMI5eAcWDQAF5E8DEQEB55HEDQAF5G`00000Ngoo00<007ooOol067oo00<007ooOol00goo0000
0`00Ool000020015Ool011cW010041cW1bUE010LidGEAMI5eDGFAME5eTGEAMI5eDGFAME5eTGE7>MB
50=F5@05DQAl07`0Ool0001kOol00`00Oomoo`0HOol00`00Oomoo`03Ool0008004Qoo`0O7>L0400@
010LibUE;EHYEBeF:ED]ERUE7>M5eDGF@ME5eTGEAMI1eDGFAME5eT7EAMHLieHEDQAF5E8DO0000goo
00<007ooOol0NWoo00<007ooOol05goo00<007ooOol00goo00000goo00000018Ool011cW010041cW
1bUE018LidGFAME5eTGEAMI5eDGFAME5eTGEAMI5eDGF7>MF5E8DO004Ool00`00Oomoo`1kOol00`00
Oomoo`0FOol00`00Oomoo`03Ool000=oo`03001oogoo04Eoo`0L7>L04@0@7>LYEBeF:ED]ERUE;EHY
EAcW@ME5eTGEAMI1eDGFAME5eT7EAMI5eDGF@MDLie8DO005Ool00`00Oomoo`1lOol00`00Oomoo`0E
Ool00`00Oomoo`03Ool000Aoo`03001oogoo04Aoo`047>L0400@7>L8:ED03acWAME5eTGEAMI5eDGF
AME5eTGEAMI5eDGFAMEl0006Ool00`00Oomoo`1mOol00`00Oomoo`0DOol00`00Oomoo`03Ool000Eo
o`8004Aoo`0H7>L0400@7>LYEBeF:ED]ERUE;EHYEBeF7>M5eT7EAMI5eDGF@ME5eTGEAMI1eDGF0W`0
1goo00<007ooOol0OGoo00<007ooOol057oo00<007ooOol00goo0007Ool00`00Oomoo`11Ool01AcW
010042UE7>L01bUE00XLidGEAMI5eDGFAME5eTGEAMI5e@9l00Uoo`03001oogoo07ioo`03001oogoo
01Aoo`03001oogoo009oo`0027oo0P00@Goo01HLi`0A010041cW;EHYEBeF:ED]ERUE;EHYEAcWAME5
eT7EAMI5eDGF@MEl00]oo`03001oogoo07moo`03001oogoo01=oo`03001oogoo009oo`002Woo00<0
07ooOol0?Woo00DLi`0@010041cW00PYE@067>M5eTGEAMI5eDGF0W`037oo00<007ooOol0P7oo00<0
07ooOol04Woo00<007ooOol00Woo000;Ool2000oOol041cW01004AcW;EHYEBeF:ED]ERUE;EHYEAcW
@ME5eTGE0W`03Goo00<007ooOol0PWoo00<007ooOol04Goo00<007ooOol00Woo000=Ool00`00Oomo
o`0lOol011cW010041cW2BUE00<Lig`0O0003goo00<007ooOol0PWoo00<007ooOol04Goo00<007oo
Ool00Woo000>Ool00`00Oomoo`0kOol031cW010041cW;EHYEBeF:ED]ERUE;EHYE@9l015oo`03001o
ogoo08=oo`03001oogoo011oo`03001oogoo009oo`003goo0P00>goo00El000@010041cW00@YE@=l
01=oo`03001oogoo08Aoo`03001oogoo00moo`03001oogoo009oo`004Goo00<007ooOol0>Goo0W`0
00<041cW:ED00g`05Woo00<007ooOol0QGoo00<007ooOol03Woo00<007ooOol00Woo000BOol2000k
Ool3O00IOol00`00Oomoo`26Ool00`00Oomoo`0>Ool00`00Oomoo`01Ool001Aoo`03001oogoo05Ao
o`03001oogoo08Moo`03001oogoo00eoo`03001oogoo005oo`005Goo00<007ooOol0Dgoo00<007oo
Ool0Qgoo00<007ooOol03Goo00<007ooOol00Goo000FOol2001COol00`00Oomoo`28Ool00`00Oomo
o`0<Ool00`00Oomoo`01Ool001Qoo`03001oogoo051oo`03001oogoo08Uoo`03001oogoo00]oo`03
001oogoo005oo`006Goo0P00D7oo00<007ooOol0RWoo00<007ooOol02Woo00<007ooOol00Goo000K
Ool00`00Oomoo`1=Ool00`00Oomoo`2;Ool00`00Oomoo`09Ool00`00Oomoo`01Ool001aoo`8004eo
o`03001oogoo08]oo`03001oogoo00Yoo`40005oo`5oo`007Woo00<007ooOol0BWoo00<007ooOol0
S7oo00<007ooOol02Goo0@000Goo0Goo000OOol00`00Oomoo`19Ool00`00Oomoo`2=Ool00`00Oomo
o`08Ool10001Ool1Ool0021oo`8004Uoo`03001oogoo08ioo`03001oogoo00Moo`40005oo`5oo`00
8Woo00<007ooOol0AWoo00<007ooOol0Sgoo00<007ooOol01Woo0@000Goo0Goo000SOol20016Ool0
0`00Oomoo`2?Ool00`00Oomoo`06Ool10001Ool1Ool002Eoo`03001oogoo04=oo`03001oogoo091o
o`03001oogoo00Eoo`40005oo`5oo`009Woo0P00@goo00<007ooOol0TGoo00<007ooOol01Goo0@00
0Goo000XOol00`00Oomoo`10Ool00`00Oomoo`2BOol00`00Oomoo`04Ool10001Ool002Uoo`03001o
ogoo03moo`03001oogoo09=oo`03001oogoo00=oo`40005oo`00:Woo0P00?goo00<007ooOol0U7oo
00<007ooOol00Woo0@000Goo000/Ool00`00Oomoo`0lOol00`00Oomoo`2DOol00`00Oomoo`02Ool1
0001Ool002eoo`8003aoo`03001oogoo09Eoo`05001oogooOol00001Ool002moo`03001oogoo03Uo
o`03001oogoo09Ioo`04001oogoo0001Ool0031oo`03001oogoo03Qoo`03001oogoo09Moo`03001o
o`00005oo`00<Goo0P00=goo00<007ooOol0VGoo0@000Goo0@00000cOol00`00Oomoo`0dOol00`00
Oomoo`2IOol10001Ool1000003Aoo`8003Aoo`03001oogoo09Yoo`800000=Woo00<007ooOol0<Goo
00<007ooOol0VGoo0`00000gOol2000aOol00`00Oomoo`2EOol40003Ool003Uoo`03001oogoo02io
o`03001oogoo091oo`D000Moo`00>Woo00<007ooOol0;Goo00<007ooOol0S7oo100037oo000kOol2
000]Ool00`00Oomoo`28Ool4000@Ool003eoo`03001oogoo02Yoo`03001oogoo08=oo`D001Aoo`00
?Woo0P00:Woo00<007ooOol0Ogoo10006Goo0010Ool00`00Oomoo`0WOol00`00Oomoo`1jOol5000M
Ool0045oo`03001oogoo02Ioo`03001oogoo07Ioo`@0029oo`00@Woo0P009Woo00<007ooOol0LWoo
10009Woo0014Ool00`00Oomoo`0SOol00`00Oomoo`1]Ool5000ZOol004Eoo`8002=oo`03001oogoo
06Uoo`@002moo`00Agoo00<007ooOol087oo00<007ooOol0I7oo1@00<goo0018Ool2000POol00`00
Oomoo`1POol4000hOol004Yoo`03001oogoo01eoo`03001oogoo05]oo`D003aoo`00Bgoo00<007oo
Ool077oo00<007ooOol0Egoo1000@Goo001<Ool2000LOol00`00Oomoo`1COol40015Ool004ioo`03
001oogoo01Uoo`03001oogoo04ioo`D004Uoo`00Cgoo0P006Goo00<007ooOol0BWoo1000CWoo001A
Ool00`00Oomoo`0FOol00`00Oomoo`15Ool5001BOol0059oo`8001Ioo`03001oogoo045oo`@005Mo
o`00E7oo00<007ooOol04goo00<007ooOol0?Goo1000Fgoo001EOol00`00Oomoo`0BOol00`00Oomo
o`0hOol5001OOol005Ioo`80015oo`03001oogoo03Eoo`@006Aoo`00F7oo00<007ooOol03Woo00<0
07ooOol0<7oo1@00J7oo001IOol2000>Ool00`00Oomoo`0/Ool4001]Ool005]oo`03001oogoo00]o
o`03001oogoo02Moo`D0075oo`00G7oo00<007ooOol02Woo00<007ooOol08goo1000MWoo001MOol2
000:Ool00`00Oomoo`0OOol4001jOol005moo`03001oogoo00Moo`03001oogoo01Yoo`D007ioo`00
H7oo0P001goo00<007ooOol05Woo1000Pgoo001ROol00`00Oomoo`04Ool00`00Oomoo`0AOol50027
Ool006=oo`8000Aoo`03001oogoo00eoo`@008aoo`00IGoo00D007ooOomoo`0000]oo`@0091oo`00
IWoo00@007ooOol000Ioo`D009Aoo`00Igoo0`000Woo1000VGoo001YOol3002MOol00001
\>"],
  ImageRangeCache->{{{0, 264.313}, {287, 0}} -> {0.0486402, -0.000148683, 
  0.00324458, 0.00324458}}]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[%, ViewPoint \[Rule] {1.382, 2.896, \(-1.075\)}]\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99535 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.101947 1.13454 -0.13919 1.13454 [
[ 0 0 0 0 ]
[ 1 .99535 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.61257 0 m
.60136 .57937 L
s
.60136 .57937 m
.94883 .82632 L
s
.94883 .82632 m
1 .10791 L
s
1 .10791 m
.61257 0 L
s
0 .04482 m
.2463 .18451 L
s
.2463 .18451 m
.2702 .99535 L
s
.2702 .99535 m
.03924 .68322 L
s
.03924 .68322 m
0 .04482 L
s
.61257 0 m
.60136 .57937 L
s
.60136 .57937 m
.03924 .68322 L
s
.03924 .68322 m
0 .04482 L
s
0 .04482 m
.61257 0 L
s
1 .10791 m
.2463 .18451 L
s
.2463 .18451 m
.2702 .99535 L
s
.2702 .99535 m
.94883 .82632 L
s
.94883 .82632 m
1 .10791 L
s
0 0 m
1 0 L
1 .99535 L
0 .99535 L
closepath
clip
newpath
.35441 .44222 m .45112 .51537 L .34398 .44512 L .124 .351 .815 r
F
.45797 .55296 m .46483 .55945 L .45725 .55564 L .406 .416 .758 r
F
.46054 .61188 m .47372 .62899 L .46167 .61456 L .535 .452 .708 r
F
.47372 .62899 m .47361 .62913 L .32733 .4536 L F
.50562 .42865 m .47323 .61723 L .4916 .42838 L .842 .634 .622 r
F
.47323 .61723 m .47208 .61674 L .4916 .42838 L F
.50562 .42865 m .50864 .59966 L .48859 .57141 L F
.50562 .42865 m .48008 .64273 L .47323 .61723 L F
.46054 .61188 m .47186 .61665 L .47372 .62899 L .535 .452 .708 r
F
.48859 .57141 m .50961 .65443 L .48008 .64273 L .842 .634 .622 r
F
.47186 .61665 m .48432 .62191 L .47372 .62899 L .535 .452 .708 r
F
.41531 .62684 m .47386 .63223 L .43467 .66497 L .621 .486 .677 r
F
.47386 .63223 m .47402 .63431 L .43467 .66497 L F
.46188 .61505 m .47639 .63246 L .41531 .62684 L F
.47421 .59428 m .47231 .61242 L .46952 .57688 L .953 .734 .569 r
F
.43293 .56233 m .45717 .55788 L .45611 .58921 L .535 .452 .708 r
F
.407 .53227 m .43838 .54829 L .43293 .56233 L F
.43838 .54829 m .45717 .55788 L .43293 .56233 L F
.44502 .54495 m .46352 .56112 L .407 .53227 L F
.32733 .4536 m .46188 .61505 L .41531 .62684 L .621 .486 .677 r
F
.47231 .61242 m .47186 .61665 L .46952 .57688 L .953 .734 .569 r
F
.3661 .48919 m .47019 .60553 L .46054 .61188 L .535 .452 .708 r
F
.33515 .44899 m .37088 .49041 L .3661 .48919 L F
.37088 .49041 m .47019 .60553 L .3661 .48919 L F
.47769 .42707 m .45869 .5128 L .46385 .42596 L .949 .802 .352 r
F
.45112 .51537 m .45767 .51804 L .45816 .5207 L .124 .351 .815 r
F
.45233 .51431 m .45263 .51444 L .45112 .51537 L F
.45869 .5128 m .45761 .5177 L .45276 .51129 L .949 .802 .352 r
F
.45761 .5177 m .45238 .51427 L .45276 .51129 L F
.46346 .50382 m .46027 .53217 L .45846 .51974 L F
.46495 .50393 m .46027 .53217 L .46346 .50382 L F
.45869 .5128 m .45276 .51129 L .46385 .42596 L F
.45644 .50183 m .45477 .5122 L .45911 .50515 L 0 0 .14 r
F
.45477 .5122 m .4583 .50913 L .45911 .50515 L F
.45797 .55296 m .46218 .5496 L .46483 .55945 L .406 .416 .758 r
F
.44053 .53646 m .45783 .54696 L .45797 .55296 L F
.45783 .54696 m .46218 .5496 L .45797 .55296 L F
.46027 .53217 m .45783 .54696 L .45839 .52192 L .949 .802 .352 r
F
.45783 .54696 m .45771 .54207 L .45839 .52192 L F
.46207 .54953 m .46041 .54853 L .47769 .42707 L .953 .734 .569 r
F
.44767 .52545 m .4547 .52181 L .45746 .53207 L .406 .416 .758 r
F
.39299 .48844 m .45071 .51965 L .44767 .52545 L F
.45071 .51965 m .4547 .52181 L .44767 .52545 L F
.45263 .51444 m .45761 .5177 L .45112 .51537 L .124 .351 .815 r
F
.45761 .5177 m .45767 .51804 L .45112 .51537 L F
.45276 .51129 m .45238 .51427 L .45644 .50183 L 0 0 .14 r
F
.45238 .51427 m .453 .51373 L .45644 .50183 L F
.4916 .42838 m .46218 .5496 L .47769 .42707 L .953 .734 .569 r
F
.46218 .5496 m .46194 .5506 L .46207 .54953 L F
.46218 .5496 m .46207 .54953 L .47769 .42707 L F
.45816 .5207 m .45735 .52738 L .45726 .52358 L .949 .802 .352 r
F
.46027 .53217 m .45839 .52192 L .45846 .51974 L F
.45827 .52128 m .45738 .52852 L .45816 .5207 L F
.45738 .52852 m .45735 .52738 L .45816 .5207 L F
.45771 .54207 m .45738 .52852 L .45846 .51974 L F
.47803 .55928 m .47789 .55916 L .4916 .42838 L .842 .634 .622 r
F
.47986 .54039 m .47421 .59428 L .46483 .55945 L .953 .734 .569 r
F
.4916 .42838 m .47986 .54039 L .4727 .54947 L F
.4916 .42838 m .4727 .54947 L .46548 .53599 L F
.45717 .55788 m .46352 .56112 L .45611 .58921 L .535 .452 .708 r
F
.46483 .55945 m .46352 .56112 L .45725 .55564 L .406 .416 .758 r
F
.44053 .53646 m .45797 .55296 L .44219 .5396 L F
.45797 .55296 m .45725 .55564 L .33515 .44899 L F
.45755 .56869 m .45502 .5639 L .47769 .42707 L .953 .734 .569 r
F
.47769 .42707 m .46666 .49362 L .45816 .5207 L .949 .802 .352 r
F
.4547 .52181 m .45731 .5258 L .45746 .53207 L .406 .416 .758 r
F
.4547 .52181 m .45726 .52358 L .45731 .5258 L F
.39299 .48844 m .45746 .53207 L .45779 .54572 L F
.45112 .51537 m .45816 .5207 L .45094 .51921 L .124 .351 .815 r
F
.45816 .5207 m .45726 .52358 L .45094 .51921 L F
.45761 .5177 m .45816 .5207 L .45403 .53386 L .949 .802 .352 r
F
.47769 .42707 m .45816 .5207 L .45761 .5177 L F
.4592 .50835 m .50524 .53741 L .45739 .51652 L .124 .351 .815 r
F
.45657 .51204 m .45739 .51652 L .45433 .51518 L F
.4592 .50835 m .45739 .51652 L .45657 .51204 L F
.45338 .5134 m .45433 .51518 L .45233 .51431 L F
.4592 .50835 m .45433 .51518 L .45338 .5134 L F
.46548 .53599 m .4727 .54947 L .45755 .56869 L .953 .734 .569 r
F
.45746 .53207 m .47994 .56038 L .46218 .5496 L .406 .416 .758 r
F
.45731 .5258 m .47994 .56038 L .45746 .53207 L F
.34398 .44512 m .46218 .5496 L .44053 .53646 L F
.33515 .44899 m .46054 .61188 L .32733 .4536 L .535 .452 .708 r
F
.46054 .61188 m .46167 .61456 L .32733 .4536 L F
.45747 .54911 m .44708 .61182 L .45738 .52852 L .949 .802 .352 r
F
.45747 .54911 m .45738 .52852 L .45771 .54207 L F
.45738 .52852 m .44708 .61182 L .45735 .52738 L F
.51947 .42671 m .50961 .65443 L .50562 .42865 L .754 .571 .649 r
F
.45731 .5258 m .51334 .56243 L .47994 .56038 L .406 .416 .758 r
F
.45726 .52358 m .51334 .56243 L .45731 .5258 L F
.47249 .61237 m .47231 .61242 L .47789 .55916 L .842 .634 .622 r
F
.47021 .63482 m .47789 .55916 L .47803 .55928 L F
.46218 .5496 m .47994 .56038 L .46483 .55945 L .406 .416 .758 r
F
.45277 .51453 m .45273 .51467 L .45238 .51427 L .949 .802 .352 r
F
.45761 .5177 m .45273 .51467 L .45277 .51453 L F
.45761 .5177 m .45716 .51972 L .45273 .51467 L F
.45716 .51972 m .45199 .5172 L .45238 .51427 L F
.45263 .51444 m .50524 .53741 L .45888 .51853 L .124 .351 .815 r
F
.45199 .5172 m .45483 .51181 L .45644 .50183 L 0 0 .14 r
F
.45433 .49922 m .45276 .51129 L .45644 .50183 L F
.45726 .52358 m .44708 .61182 L .45403 .53386 L .949 .802 .352 r
F
.45735 .52738 m .44708 .61182 L .45726 .52358 L F
.43867 .51071 m .4547 .52181 L .39299 .48844 L .406 .416 .758 r
F
.45716 .51972 m .44387 .57972 L .45199 .5172 L .949 .802 .352 r
F
.45761 .5177 m .45888 .51853 L .45767 .51804 L .124 .351 .815 r
F
.45846 .51974 m .45827 .52128 L .45816 .5207 L .949 .802 .352 r
F
.45816 .5207 m .50524 .53741 L .51334 .56243 L .124 .351 .815 r
F
.45767 .51804 m .50524 .53741 L .45816 .5207 L F
.45403 .53386 m .44954 .58418 L .44387 .57972 L .949 .802 .352 r
F
.45816 .5207 m .51334 .56243 L .45726 .52358 L .124 .351 .815 r
F
.45911 .50515 m .44944 .55249 L .45948 .5189 L 0 0 .14 r
F
.45199 .50017 m .45911 .50515 L .45316 .50454 L .505 0 0 r
F
.45911 .50515 m .4592 .50835 L .45316 .50454 L F
.45815 .46981 m .45433 .49922 L .45911 .50515 L 0 0 .14 r
F
.45911 .50515 m .50524 .53741 L .4592 .50835 L .505 0 0 r
F
.45911 .50515 m .48268 .52588 L .50524 .53741 L F
.43928 .50193 m .4592 .50835 L .44615 .51161 L .124 .351 .815 r
F
.45316 .50454 m .4592 .50835 L .43928 .50193 L F
.45199 .5172 m .44387 .57972 L .45483 .51181 L 0 0 .14 r
F
.4592 .50835 m .45233 .51431 L .44615 .51161 L .124 .351 .815 r
F
.46007 .50635 m .45911 .50515 L .45948 .5189 L 0 0 .14 r
F
.45962 .5159 m .45948 .5189 L .45916 .51571 L F
.45962 .5159 m .45916 .51571 L .45805 .50489 L F
.46007 .50635 m .45962 .5159 L .45805 .50489 L F
.45477 .5122 m .44387 .57972 L .4583 .50913 L F
.45646 .5033 m .45768 .50463 L .45911 .50515 L .505 0 0 r
F
.45768 .50463 m .45902 .50559 L .45911 .50515 L F
.45948 .5189 m .4558 .5144 L .45503 .50272 L 0 0 .14 r
F
.45199 .50017 m .45576 .50325 L .45646 .5033 L .505 0 0 r
F
.43369 .48737 m .45199 .50017 L .44194 .49746 L F
.45199 .50017 m .45316 .50454 L .44194 .49746 L F
.43369 .48737 m .45503 .50272 L .45199 .50017 L F
.45503 .50272 m .45576 .50325 L .45199 .50017 L F
.45948 .5189 m .45503 .50272 L .45805 .50489 L 0 0 .14 r
F
.45503 .50272 m .45518 .50492 L .45838 .50553 L .255 0 .301 r
F
.46628 .51215 m .4558 .5144 L .48056 .52411 L F
.45518 .50492 m .4558 .5144 L .46628 .51215 L F
.45518 .50492 m .46628 .51215 L .45838 .50553 L F
.45149 .50293 m .46581 .51346 L .45894 .506 L .505 0 0 r
F
.45565 .50324 m .45894 .506 L .45646 .5033 L F
.45149 .50293 m .45894 .506 L .45565 .50324 L F
.46156 .50819 m .48268 .52588 L .45911 .50515 L F
.48263 .52585 m .48268 .52588 L .46156 .50819 L F
.46385 .42596 m .45911 .50515 L .46007 .50635 L 0 0 .14 r
F
.46385 .42596 m .45815 .46981 L .45911 .50515 L F
.46385 .42596 m .46007 .50635 L .44997 .426 L F
.46007 .50635 m .45805 .50489 L .44997 .426 L F
.45768 .50463 m .45894 .506 L .45902 .50559 L .505 0 0 r
F
.45894 .506 m .46156 .50819 L .45911 .50515 L F
.45838 .50553 m .46628 .51215 L .47902 .50942 L .255 0 .301 r
F
.45805 .50489 m .45503 .50272 L .44997 .426 L 0 0 .14 r
F
.46666 .49362 m .46495 .50393 L .46346 .50382 L .949 .802 .352 r
F
.44997 .426 m .45503 .50272 L .47902 .50942 L .255 0 .301 r
F
.3665 .44039 m .43369 .48737 L .35441 .44222 L .505 0 0 r
F
.43369 .48737 m .44194 .49746 L .35441 .44222 L F
.3665 .44039 m .45149 .50293 L .45576 .50325 L F
.3665 .44039 m .45576 .50325 L .43369 .48737 L F
.45503 .50272 m .45838 .50553 L .47902 .50942 L .255 0 .301 r
F
.44944 .55249 m .44913 .55923 L .45948 .5189 L 0 0 .14 r
F
.45779 .54572 m .45746 .53207 L .46218 .5496 L .406 .416 .758 r
F
.45783 .54696 m .45747 .54911 L .45771 .54207 L .949 .802 .352 r
F
.45948 .5189 m .44387 .57972 L .45808 .54887 L 0 0 .14 r
F
.45948 .5189 m .45808 .54887 L .4558 .5144 L F
.4558 .5144 m .46373 .54396 L .48471 .52574 L .255 0 .301 r
F
.46581 .51346 m .48263 .52585 L .46156 .50819 L .505 0 0 r
F
.45894 .506 m .46581 .51346 L .46156 .50819 L F
.47902 .50942 m .46628 .51215 L .48471 .52574 L .255 0 .301 r
F
.46628 .51215 m .48056 .52411 L .48471 .52574 L F
.43138 .4908 m .45316 .50454 L .43928 .50193 L .124 .351 .815 r
F
.45238 .51427 m .45199 .5172 L .453 .51373 L 0 0 .14 r
F
.34398 .44512 m .43867 .51071 L .39299 .48844 L .406 .416 .758 r
F
.46194 .5506 m .4602 .55002 L .46041 .54853 L .953 .734 .569 r
F
.46194 .5506 m .46041 .54853 L .46207 .54953 L F
.47019 .60553 m .47186 .61665 L .46054 .61188 L .535 .452 .708 r
F
.45611 .58921 m .46352 .56112 L .47019 .60553 L F
.47186 .61665 m .46956 .63857 L .46954 .60119 L .953 .734 .569 r
F
.47186 .61665 m .46954 .60119 L .46952 .57688 L F
.47021 .63482 m .47001 .63434 L .47231 .61242 L .842 .634 .622 r
F
.47021 .63482 m .47231 .61242 L .47249 .61237 L F
.47019 .60553 m .48432 .62191 L .47186 .61665 L .535 .452 .708 r
F
.44615 .51161 m .45233 .51431 L .45112 .51537 L .124 .351 .815 r
F
.33515 .44899 m .44502 .54495 L .407 .53227 L .535 .452 .708 r
F
.46194 .5506 m .45755 .56869 L .4602 .55002 L .953 .734 .569 r
F
.50864 .59966 m .50961 .65443 L .48859 .57141 L .842 .634 .622 r
F
.47019 .60553 m .50366 .59618 L .48432 .62191 L .535 .452 .708 r
F
.46952 .57688 m .46954 .60119 L .46483 .55945 L .953 .734 .569 r
F
.46954 .60119 m .46587 .57675 L .46483 .55945 L F
.46483 .55945 m .46587 .57675 L .46352 .56112 L F
.46352 .56112 m .50366 .59618 L .47019 .60553 L .535 .452 .708 r
F
.46954 .60119 m .46956 .63857 L .46587 .57675 L .953 .734 .569 r
F
.47386 .63223 m .47639 .63246 L .47402 .63431 L .621 .486 .677 r
F
.35441 .44222 m .43138 .4908 L .44615 .51161 L .124 .351 .815 r
F
.47372 .62899 m .47598 .62747 L .47639 .63246 L .535 .452 .708 r
F
.47598 .62747 m .47708 .63155 L .47639 .63246 L F
.47372 .62899 m .47639 .63246 L .47361 .62913 L F
.47323 .61723 m .48008 .64273 L .46956 .63857 L .842 .634 .622 r
F
.47598 .62747 m .48432 .62191 L .47708 .63155 L .535 .452 .708 r
F
.46352 .56112 m .46937 .63527 L .45755 .56869 L .953 .734 .569 r
F
.46587 .57675 m .46937 .63527 L .46352 .56112 L F
.47323 .61723 m .47021 .63482 L .47208 .61674 L .842 .634 .622 r
F
.47021 .63482 m .46956 .63857 L .47001 .63434 L F
.46937 .63527 m .46956 .63857 L .46907 .63569 L .953 .734 .569 r
F
.46937 .63527 m .46907 .63569 L .45755 .56869 L F
.46483 .55945 m .51334 .56243 L .50366 .59618 L .406 .416 .758 r
F
.46483 .55945 m .50366 .59618 L .46352 .56112 L F
.45755 .56869 m .46956 .63857 L .44708 .61182 L .953 .734 .569 r
F
.45755 .56869 m .44708 .61182 L .45502 .5639 L F
.34398 .44512 m .44053 .53646 L .33515 .44899 L .406 .416 .758 r
F
.44053 .53646 m .44219 .5396 L .33515 .44899 L F
.44954 .58418 m .44708 .61182 L .44573 .59831 L .949 .802 .352 r
F
.44954 .58418 m .44573 .59831 L .44387 .57972 L F
.45112 .51537 m .45094 .51921 L .34398 .44512 L .124 .351 .815 r
F
.44944 .55249 m .44387 .57972 L .44913 .55923 L 0 0 .14 r
F
.4558 .5144 m .45808 .54887 L .46373 .54396 L .255 0 .301 r
F
.44997 .426 m .48471 .52574 L .43613 .4276 L F
.51947 .42671 m .56215 .6559 L .50961 .65443 L .754 .571 .649 r
F
.43613 .4276 m .51648 .5155 L .42271 .43075 L .494 .108 .237 r
F
.43613 .4276 m .48471 .52574 L .51648 .5155 L F
.25 g
.5 Mabswid
.43613 .4276 m
.437 .42936 L
s
.46525 .48644 m
.47586 .50787 L
s
.47586 .50787 m
.48471 .52574 L
s
.437 .42936 m
.455 .46572 L
s
.455 .46572 m
.46053 .47689 L
s
.46053 .47689 m
.46165 .47916 L
s
.46165 .47916 m
.46525 .48644 L
s
0 g
.006 w
.42271 .43075 m
.43613 .4276 L
s
.25 g
.5 Mabswid
.46528 .46922 m
.47768 .48043 L
s
.47768 .48043 m
.51648 .5155 L
s
.44981 .45524 m
.46075 .46512 L
s
.46075 .46512 m
.46356 .46767 L
s
.46498 .46895 m
.46528 .46922 L
s
.46356 .46767 m
.46498 .46895 L
s
0 g
.006 w
.43613 .4276 m
.44997 .426 L
s
.25 g
.5 Mabswid
.45523 .50568 m
.4558 .5144 L
s
.45481 .49934 m
.45503 .50272 L
s
.45416 .48944 m
.45481 .49934 L
s
.45323 .47536 m
.45416 .48944 L
s
.45222 .46011 m
.45323 .47536 L
s
.4558 .5144 m
.45808 .54887 L
s
0 g
.006 w
.44997 .426 m
.46385 .42596 L
s
.25 g
.5 Mabswid
.45149 .50293 m
.46581 .51346 L
s
.46581 .51346 m
.46675 .51416 L
s
.46675 .51416 m
.46914 .51592 L
s
.46914 .51592 m
.48263 .52585 L
s
0 g
.006 w
.35441 .44222 m
.3665 .44039 L
s
.25 g
.5 Mabswid
.44194 .49746 m
.45316 .50454 L
s
.45316 .50454 m
.45524 .50586 L
s
0 g
.006 w
.34398 .44512 m
.35441 .44222 L
s
.25 g
.5 Mabswid
.45052 .52856 m
.45199 .5172 L
s
.45199 .5172 m
.45238 .51427 L
s
.44387 .57972 m
.45052 .52856 L
s
.45433 .49922 m
.45464 .49682 L
s
.45402 .5016 m
.45433 .49922 L
s
0 g
.006 w
.46385 .42596 m
.47769 .42707 L
s
.25 g
.5 Mabswid
.47124 .466 m
.47769 .42707 L
s
.45502 .5639 m
.45719 .55079 L
s
.44708 .61182 m
.45502 .5639 L
s
0 g
.006 w
.47769 .42707 m
.4916 .42838 L
s
.25 g
.5 Mabswid
.47391 .53512 m
.51334 .56243 L
s
.43867 .51071 m
.45094 .51921 L
s
.45094 .51921 m
.45167 .51971 L
s
.34398 .44512 m
.34518 .44595 L
s
0 g
.006 w
.33515 .44899 m
.34398 .44512 L
s
.25 g
.5 Mabswid
.48596 .48211 m
.4916 .42838 L
s
.47001 .63434 m
.47186 .61665 L
s
.46956 .63857 m
.47001 .63434 L
s
0 g
.006 w
.4916 .42838 m
.50562 .42865 L
s
.25 g
.5 Mabswid
.33515 .44899 m
.33651 .45017 L
s
.46352 .56112 m
.50366 .59618 L
s
.44103 .54147 m
.44502 .54495 L
s
.44502 .54495 m
.44804 .5476 L
s
.50562 .42865 m
.50668 .48874 L
s
.50668 .48874 m
.50697 .50509 L
s
.50721 .51849 m
.50767 .54493 L
s
.50864 .59966 m
.50961 .65443 L
s
.50829 .58002 m
.50864 .59966 L
s
.32733 .4536 m .43467 .66497 L .31959 .45839 L .621 .486 .677 r
F
.25 g
.32733 .4536 m
.32851 .45502 L
s
0 g
.006 w
.32733 .4536 m
.33515 .44899 L
s
.25 g
.5 Mabswid
.42271 .43075 m
.44981 .45524 L
s
.53252 .4218 m .56215 .6559 L .51947 .42671 L .684 .529 .67 r
F
0 g
.006 w
.50562 .42865 m
.51947 .42671 L
s
.53252 .4218 m .61984 .64191 L .56215 .6559 L .684 .529 .67 r
F
.54402 .41374 m .61984 .64191 L .53252 .4218 L .621 .498 .692 r
F
0 g
.51947 .42671 m
.53252 .4218 L
s
.31959 .45839 m .38361 .68825 L .31109 .46239 L .692 .524 .655 r
F
.31959 .45839 m .43467 .66497 L .38361 .68825 L F
.25 g
.5 Mabswid
.32851 .45502 m
.3646 .49832 L
s
.38388 .49155 m
.4061 .51096 L
s
.38623 .47439 m
.40195 .48528 L
s
.34518 .44595 m
.38623 .47439 L
s
.38861 .4638 m
.39964 .47077 L
s
.35441 .44222 m
.38861 .4638 L
s
.39143 .45874 m
.39881 .46417 L
s
.3665 .44039 m
.39143 .45874 L
s
0 g
.006 w
.31959 .45839 m
.32733 .4536 L
s
.25 g
.5 Mabswid
.31959 .45839 m
.32051 .46006 L
s
.32051 .46006 m
.33394 .48416 L
s
.41377 .47518 m
.45149 .50293 L
s
.40982 .47227 m
.41377 .47518 L
s
.40486 .46862 m
.40982 .47227 L
s
.39881 .46417 m
.40486 .46862 L
s
.42234 .48509 m
.44194 .49746 L
s
.41042 .47757 m
.42234 .48509 L
s
.39964 .47077 m
.41042 .47757 L
s
.42021 .49792 m
.43867 .51071 L
s
.40195 .48528 m
.42021 .49792 L
s
.4061 .51096 m
.44103 .54147 L
s
.42885 .57542 m
.44543 .59531 L
s
.54402 .41374 m .67453 .61378 L .61984 .64191 L .621 .498 .692 r
F
.25 g
.51947 .42671 m
.52523 .45766 L
s
.55347 .40297 m .67453 .61378 L .54402 .41374 L .557 .474 .716 r
F
.25 g
.53252 .4218 m
.53533 .4289 L
s
0 g
.006 w
.53252 .4218 m
.54402 .41374 L
s
.25 g
.5 Mabswid
.54402 .41374 m
.54597 .41673 L
s
.56667 .42596 m .71861 .57482 L .67453 .61378 L .557 .474 .716 r
F
.56905 .41918 m .71861 .57482 L .56667 .42596 L F
.56093 .39032 m .71861 .57482 L .55347 .40297 L .483 .452 .747 r
F
.5734 .40492 m .62223 .44031 L .62446 .46466 L F
.6308 .28968 m .62963 .32048 L .62286 .29309 L .77 .576 .637 r
F
.57792 .40315 m .67211 .47425 L .57577 .40658 L .483 .452 .747 r
F
.67211 .47425 m .67313 .47721 L .5734 .40492 L F
.6461 .28083 m .65682 .31729 L .63877 .28599 L .609 .495 .698 r
F
.667 .47277 m .72976 .51827 L .66792 .48679 L .483 .452 .747 r
F
.72976 .51827 m .73188 .52245 L .62446 .46466 L F
.67211 .47425 m .74604 .53007 L .67313 .47721 L F
.62446 .46466 m .74604 .53007 L .71861 .57482 L F
.56703 .3767 m .74604 .53007 L .56093 .39032 L .377 .429 .788 r
F
.66137 .45753 m .72378 .47673 L .74604 .53007 L F
.62178 .42361 m .65382 .42835 L .66137 .45753 L F
.58036 .38813 m .6196 .40962 L .62178 .42361 L F
.6196 .40962 m .65382 .42835 L .62178 .42361 L F
.59271 .32359 m .61836 .35494 L .58543 .33591 L .492 .103 .229 r
F
.62273 .33151 m .62267 .35045 L .62052 .33619 L .895 .668 .587 r
F
.62267 .35045 m .62263 .36021 L .62185 .3513 L F
.62267 .35045 m .62185 .3513 L .62052 .33619 L F
.61924 .4073 m .65333 .42727 L .61953 .40914 L .377 .429 .788 r
F
.65333 .42727 m .65382 .42835 L .6124 .40567 L F
.61267 .40546 m .6124 .40567 L .58036 .38813 L F
.65333 .42727 m .6124 .40567 L .61267 .40546 L F
.63877 .28599 m .64832 .37682 L .6308 .28968 L .681 .526 .669 r
F
.65333 .42727 m .67457 .43971 L .65382 .42835 L .377 .429 .788 r
F
.62223 .44031 m .667 .47277 L .62446 .46466 L .483 .452 .747 r
F
.667 .47277 m .66792 .48679 L .62446 .46466 L F
.6671 .42713 m .71305 .45843 L .67206 .43549 L .18 .391 .833 r
F
.71305 .45843 m .7127 .46205 L .56703 .3767 L F
.67457 .43971 m .72995 .47216 L .66137 .45753 L .377 .429 .788 r
F
.73625 .46277 m .7712 .49767 L .76309 .50091 L .609 .495 .698 r
F
.73625 .46277 m .76309 .50091 L .7482 .48688 L F
.69102 .37148 m .74422 .45091 L .74187 .45442 L F
.69102 .37148 m .74187 .45442 L .72715 .44439 L F
.69079 .43276 m .68728 .43193 L .68509 .4255 L F
.71305 .45843 m .69079 .43276 L .73097 .47064 L .18 .391 .833 r
F
.6671 .42713 m .68722 .43192 L .71305 .45843 L F
.68722 .43192 m .69079 .43276 L .71305 .45843 L F
.72995 .47216 m .73733 .4809 L .66137 .45753 L .377 .429 .788 r
F
.71077 .5007 m .70915 .49797 L .68722 .43192 L .609 .495 .698 r
F
.68728 .43193 m .68722 .43192 L .68509 .4255 L F
.71077 .5007 m .68722 .43192 L .68728 .43193 L F
.64988 .39169 m .64872 .39103 L .64357 .38064 L .681 .526 .669 r
F
.58543 .33591 m .62769 .36626 L .57872 .34912 L .578 .034 0 r
F
.64845 .37805 m .65815 .39745 L .64988 .39169 L .681 .526 .669 r
F
.64832 .37682 m .64898 .3782 L .64845 .37805 L F
.64898 .3782 m .65815 .39745 L .64845 .37805 L F
.64783 .38924 m .6445 .38731 L .64357 .38064 L F
.64743 .39071 m .64932 .39137 L .65394 .39452 L 0 .246 .704 r
F
.63563 .38382 m .64517 .38908 L .64743 .39071 L F
.64517 .38908 m .64932 .39137 L .64743 .39071 L F
.62769 .36626 m .6364 .37252 L .62721 .37727 L .578 .034 0 r
F
.6364 .37252 m .63538 .38201 L .62721 .37727 L F
.62772 .37085 m .64053 .38573 L .62751 .37633 L .77 .576 .637 r
F
.62769 .36626 m .62721 .37727 L .60031 .36165 L .578 .034 0 r
F
.59943 .35637 m .60031 .36165 L .57872 .34912 L F
.62769 .36626 m .60031 .36165 L .59943 .35637 L F
.62076 .37514 m .63452 .38296 L .63563 .38382 L 0 .246 .704 r
F
.65627 .39711 m .65394 .39452 L .66857 .40472 L F
.62076 .37514 m .64743 .39071 L .65627 .39711 L F
.64743 .39071 m .65394 .39452 L .65627 .39711 L F
.63927 .35005 m .64471 .38875 L .63648 .3515 L .77 .576 .637 r
F
.63452 .38296 m .64932 .39137 L .63563 .38382 L 0 .246 .704 r
F
.64471 .38875 m .64053 .38573 L .62963 .32048 L .77 .576 .637 r
F
.62772 .37085 m .62751 .37633 L .62265 .36644 L F
.63839 .37291 m .64053 .38573 L .62772 .37085 L F
.64872 .39103 m .6445 .38731 L .64783 .38924 L .681 .526 .669 r
F
.57872 .34912 m .65627 .39711 L .5727 .36283 L 0 .246 .704 r
F
.65627 .39711 m .65618 .39987 L .5727 .36283 L F
.64674 .38991 m .6445 .38731 L .64872 .39103 L .681 .526 .669 r
F
.65011 .39382 m .64533 .39321 L .6445 .38731 L F
.6436 .38795 m .6367 .38277 L .64932 .39137 L 0 .246 .704 r
F
.62751 .37633 m .62266 .37371 L .62265 .36644 L .77 .576 .637 r
F
.63206 .38105 m .63543 .38205 L .6436 .38795 L 0 .246 .704 r
F
.61535 .37104 m .6284 .3782 L .63206 .38105 L F
.6284 .3782 m .63543 .38205 L .63206 .38105 L F
.59373 .3581 m .61425 .36989 L .61535 .37104 L F
.60031 .36165 m .61395 .36957 L .59373 .3581 L F
.61987 .36649 m .61994 .37161 L .61917 .36651 L .895 .668 .587 r
F
.61395 .36957 m .62721 .37727 L .61425 .36989 L 0 .246 .704 r
F
.62721 .37727 m .6275 .3775 L .61425 .36989 L F
.61425 .36989 m .63543 .38205 L .61535 .37104 L F
.59531 .34407 m .61077 .3605 L .61283 .35855 L .578 .034 0 r
F
.58543 .33591 m .59617 .34633 L .59531 .34407 L F
.59617 .34633 m .61077 .3605 L .59531 .34407 L F
.58989 .35603 m .61563 .37134 L .61706 .37285 L 0 .246 .704 r
F
.59373 .3581 m .64932 .39137 L .58989 .35603 L F
.61395 .36957 m .61425 .36989 L .59373 .3581 L F
.58517 .37021 m .62719 .39086 L .61804 .38968 L .18 .391 .833 r
F
.5727 .36283 m .58583 .36958 L .58517 .37021 L F
.58583 .36958 m .62719 .39086 L .58517 .37021 L F
.61994 .37161 m .61686 .36921 L .61677 .36658 L .895 .668 .587 r
F
.61461 .35687 m .62353 .36638 L .62769 .36626 L .578 .034 0 r
F
.61319 .35822 m .62261 .36641 L .61461 .35687 L F
.62261 .36641 m .62772 .37085 L .62353 .36638 L F
.62261 .36641 m .62353 .36638 L .61461 .35687 L F
.61283 .35855 m .61805 .36654 L .62236 .36642 L F
.61994 .37161 m .61677 .36658 L .61917 .36651 L .895 .668 .587 r
F
.61077 .3605 m .61988 .36934 L .61283 .35855 L .578 .034 0 r
F
.59475 .3426 m .61283 .35855 L .59747 .34455 L F
.59531 .34407 m .61283 .35855 L .59475 .3426 L F
.61283 .35855 m .61319 .35822 L .59747 .34455 L F
.59747 .34455 m .61319 .35822 L .61461 .35687 L F
.62263 .37369 m .62259 .37367 L .62261 .36641 L .77 .576 .637 r
F
.61706 .37285 m .64932 .39137 L .62076 .37514 L 0 .246 .704 r
F
.61563 .37134 m .64932 .39137 L .61706 .37285 L F
.65627 .39711 m .66857 .40472 L .65618 .39987 L F
.68509 .4255 m .66846 .40535 L .66857 .40472 L .681 .526 .669 r
F
.6703 .40592 m .66857 .40472 L .66873 .40385 L F
.68509 .4255 m .66857 .40472 L .6703 .40592 L F
.66857 .40472 m .66847 .40532 L .65618 .39987 L 0 .246 .704 r
F
.66873 .40385 m .66857 .40472 L .64832 .37682 L .681 .526 .669 r
F
.68509 .4255 m .68722 .43192 L .66846 .40535 L F
.66847 .40532 m .66734 .41152 L .65599 .40568 L 0 .246 .704 r
F
.65618 .39987 m .65599 .40568 L .62719 .39086 L F
.65618 .39987 m .62719 .39086 L .62527 .38615 L F
.61804 .38968 m .65726 .40716 L .66721 .4188 L .18 .391 .833 r
F
.62719 .39086 m .65599 .40568 L .61804 .38968 L F
.66847 .40532 m .65599 .40568 L .65618 .39987 L 0 .246 .704 r
F
.6367 .38277 m .63923 .38427 L .64932 .39137 L F
.66748 .40395 m .65815 .39745 L .64832 .37682 L .681 .526 .669 r
F
.66857 .40472 m .66748 .40395 L .64832 .37682 L F
.64832 .37682 m .64988 .39169 L .64357 .38064 L F
.71305 .45843 m .73097 .47064 L .7127 .46205 L .18 .391 .833 r
F
.73097 .47064 m .72995 .47216 L .7127 .46205 L F
.68595 .41633 m .75646 .50356 L .68764 .42206 L .609 .495 .698 r
F
.6364 .37252 m .64013 .37521 L .63538 .38201 L .578 .034 0 r
F
.6606 .33012 m .72715 .44439 L .68595 .41633 L .609 .495 .698 r
F
.64832 .37682 m .64357 .38064 L .6308 .28968 L .681 .526 .669 r
F
.64596 .35437 m .68509 .4255 L .64832 .37682 L F
.63877 .28599 m .65236 .32692 L .64596 .35437 L F
.65236 .32692 m .68509 .4255 L .64596 .35437 L F
.64013 .37521 m .64096 .3758 L .6367 .38277 L .578 .034 0 r
F
.67929 .39367 m .68595 .41633 L .67572 .38992 L .609 .495 .698 r
F
.68595 .41633 m .68764 .42206 L .68531 .41595 L F
.68595 .41633 m .68531 .41595 L .6587 .34602 L F
.72715 .44439 m .75646 .50356 L .68595 .41633 L F
.68722 .43192 m .66245 .4065 L .65815 .39745 L .681 .526 .669 r
F
.68722 .43192 m .65815 .39745 L .66748 .40395 L F
.68764 .42206 m .68509 .4255 L .6587 .34602 L .609 .495 .698 r
F
.67225 .40699 m .7202 .43666 L .66932 .41253 L 0 .246 .704 r
F
.66534 .31967 m .72715 .44439 L .6606 .33012 L .609 .495 .698 r
F
.7202 .43666 m .73977 .44877 L .72401 .44066 L 0 .246 .704 r
F
.7202 .43666 m .72401 .44066 L .66932 .41253 L F
.65682 .31729 m .67929 .39367 L .6587 .34602 L .609 .495 .698 r
F
.67929 .39367 m .67572 .38992 L .6587 .34602 L F
.67225 .40699 m .70945 .425 L .7372 .44676 L 0 .246 .704 r
F
.7202 .43666 m .7372 .44676 L .73977 .44877 L F
.67225 .40699 m .7372 .44676 L .7202 .43666 L F
.64096 .3758 m .70945 .425 L .63902 .38412 L .578 .034 0 r
F
.64096 .3758 m .63902 .38412 L .6367 .38277 L F
.64013 .37521 m .6367 .38277 L .63538 .38201 L F
.6461 .28083 m .66534 .31967 L .6606 .33012 L .609 .495 .698 r
F
.63923 .38427 m .70283 .4218 L .64988 .39169 L 0 .246 .704 r
F
.63923 .38427 m .64988 .39169 L .64932 .39137 L F
.65599 .40568 m .66734 .41152 L .65726 .40716 L .18 .391 .833 r
F
.66734 .41152 m .66932 .41253 L .66758 .41176 L F
.66734 .41152 m .66758 .41176 L .65726 .40716 L F
.65599 .40568 m .65726 .40716 L .61804 .38968 L F
.62721 .37727 m .6367 .38277 L .6275 .3775 L 0 .246 .704 r
F
.62266 .37237 m .62261 .36641 L .62265 .36644 L .77 .576 .637 r
F
.58497 .37119 m .66763 .41929 L .6671 .42713 L .18 .391 .833 r
F
.66763 .41929 m .69079 .43276 L .67618 .42929 L F
.66763 .41929 m .67618 .42929 L .6671 .42713 L F
.58692 .37125 m .69079 .43276 L .58497 .37119 L F
.5727 .36283 m .6671 .42713 L .56703 .3767 L F
.6671 .42713 m .67206 .43549 L .56703 .3767 L F
.65432 .45718 m .65401 .46644 L .64091 .38804 L .77 .576 .637 r
F
.64099 .38813 m .64091 .38804 L .64053 .38573 L F
.65432 .45718 m .64091 .38804 L .64099 .38813 L F
.62527 .38615 m .62719 .39086 L .5727 .36283 L 0 .246 .704 r
F
.62291 .49778 m .62263 .37237 L .62266 .37237 L .77 .576 .637 r
F
.62263 .37237 m .62261 .36641 L .62266 .37237 L F
.5727 .36283 m .58692 .37125 L .58497 .37119 L .18 .391 .833 r
F
.63638 .38273 m .65401 .46644 L .62751 .37633 L .77 .576 .637 r
F
.64053 .38573 m .64091 .38804 L .63638 .38273 L F
.64091 .38804 m .65401 .46644 L .63638 .38273 L F
.65011 .39382 m .65761 .46524 L .64533 .39321 L .681 .526 .669 r
F
.65761 .46524 m .66406 .52655 L .65432 .45718 L F
.65761 .46524 m .65432 .45718 L .64533 .39321 L F
.65401 .46644 m .66406 .52655 L .65347 .48305 L .77 .576 .637 r
F
.65401 .46644 m .65347 .48305 L .62751 .37633 L F
.67225 .40699 m .66932 .41253 L .66734 .41152 L 0 .246 .704 r
F
.67225 .40699 m .66734 .41152 L .66847 .40532 L F
.66721 .4188 m .66907 .41329 L .68431 .42893 L .18 .391 .833 r
F
.65726 .40716 m .66932 .41253 L .66721 .4188 L F
.68722 .43192 m .71633 .5196 L .66666 .41532 L .681 .526 .669 r
F
.66734 .41152 m .66666 .41532 L .66245 .4065 L F
.68722 .43192 m .66666 .41532 L .66734 .41152 L F
.66857 .40472 m .66846 .40535 L .66748 .40395 L F
.63923 .38427 m .70945 .425 L .70283 .4218 L 0 .246 .704 r
F
.6367 .38277 m .63902 .38412 L .63923 .38427 L F
.63902 .38412 m .70945 .425 L .63923 .38427 L F
.65394 .39452 m .70283 .4218 L .67225 .40699 L F
.64932 .39137 m .64988 .39169 L .65394 .39452 L F
.64988 .39169 m .70283 .4218 L .65394 .39452 L F
.66857 .40472 m .67225 .40699 L .66847 .40532 L F
.68431 .42893 m .66932 .41253 L .69079 .43276 L .18 .391 .833 r
F
.66907 .41329 m .66932 .41253 L .68431 .42893 L F
.64471 .38875 m .64533 .39321 L .64053 .38573 L .77 .576 .637 r
F
.64533 .39321 m .65432 .45718 L .64099 .38813 L F
.64533 .39321 m .64099 .38813 L .64053 .38573 L F
.61283 .35855 m .62236 .36642 L .61319 .35822 L .578 .034 0 r
F
.62261 .36641 m .62259 .37367 L .62153 .36644 L .895 .668 .587 r
F
.62236 .36642 m .62772 .37085 L .62261 .36641 L .578 .034 0 r
F
.62236 .36642 m .62261 .36641 L .61319 .35822 L F
.62263 .36021 m .62261 .36641 L .61968 .35376 L .895 .668 .587 r
F
.62261 .36641 m .62153 .36644 L .61968 .35376 L F
.60797 .36313 m .60712 .36239 L .60731 .36009 L .985 .787 .386 r
F
.58543 .33591 m .59531 .34407 L .59475 .3426 L .578 .034 0 r
F
.61836 .35494 m .61703 .36657 L .58543 .33591 L .492 .103 .229 r
F
.59966 .33209 m .60136 .33876 L .61192 .34707 L F
.60136 .33876 m .60702 .36091 L .61003 .3524 L F
.60136 .33876 m .61003 .3524 L .61192 .34707 L F
.58326 .38621 m .61924 .4073 L .58036 .38813 L .377 .429 .788 r
F
.61924 .4073 m .61953 .40914 L .58036 .38813 L F
.61432 .35916 m .5961 .5002 L .61003 .3524 L .895 .668 .587 r
F
.61028 .34971 m .60912 .36205 L .60955 .34498 L .985 .787 .386 r
F
.60912 .36205 m .60891 .36427 L .60898 .36218 L F
.60912 .36205 m .60898 .36218 L .60955 .34498 L F
.60891 .36427 m .5961 .5002 L .60796 .36327 L F
.60891 .36427 m .60796 .36327 L .60955 .34498 L F
.61192 .34707 m .6082 .36554 L .61836 .35494 L .492 .103 .229 r
F
.62286 .29309 m .61432 .35916 L .6152 .29754 L .895 .668 .587 r
F
.60797 .36313 m .60731 .36009 L .60819 .3576 L .985 .787 .386 r
F
.60796 .36327 m .6079 .3632 L .60797 .36313 L F
.6079 .3632 m .60712 .36239 L .60797 .36313 L F
.60955 .34498 m .60798 .36313 L .60858 .34775 L F
.59271 .32359 m .601 .34606 L .59966 .33209 L .492 .103 .229 r
F
.60796 .36327 m .5961 .5002 L .60712 .36239 L .985 .787 .386 r
F
.601 .34606 m .60676 .36164 L .59966 .33209 L .492 .103 .229 r
F
.60676 .36164 m .60702 .36091 L .59966 .33209 L F
.60022 .31276 m .60892 .3452 L .59271 .32359 L .283 .016 .319 r
F
.60892 .3452 m .60676 .36164 L .59271 .32359 L F
.60785 .35338 m .60712 .36239 L .60672 .36196 L .985 .787 .386 r
F
.60712 .36239 m .5961 .5002 L .60586 .36106 L F
.60676 .36164 m .6082 .36554 L .60702 .36091 L .492 .103 .229 r
F
.60955 .34498 m .60858 .34775 L .60922 .34289 L .985 .787 .386 r
F
.60798 .36313 m .60796 .36327 L .60797 .36313 L F
.60401 .32689 m .60314 .37308 L .60892 .3452 L .283 .016 .319 r
F
.6152 .29754 m .60641 .35731 L .60772 .30398 L .985 .787 .386 r
F
.60641 .35731 m .58919 .4744 L .60376 .34041 L F
.60641 .35731 m .60376 .34041 L .60772 .30398 L F
.60223 .35439 m .60201 .35648 L .60224 .35449 L 0 0 .188 r
F
.60223 .35439 m .60224 .35449 L .60373 .34168 L F
.60376 .34041 m .60223 .35439 L .60373 .34168 L F
.60201 .35648 m .60157 .36051 L .60202 .35661 L F
.60201 .35648 m .60202 .35661 L .60749 .30938 L F
.60157 .36051 m .58919 .4744 L .60176 .36102 L F
.60157 .36051 m .60176 .36102 L .60749 .30938 L F
.60257 .35371 m .58919 .4744 L .60367 .35267 L F
.60798 .36313 m .60797 .36313 L .60863 .34661 L .985 .787 .386 r
F
.60863 .3466 m .60863 .34661 L .60887 .34061 L F
.60798 .36313 m .60863 .34661 L .60863 .3466 L F
.60702 .36091 m .6082 .36554 L .6105 .35108 L .492 .103 .229 r
F
.6105 .35108 m .6082 .36554 L .61192 .34707 L F
.61432 .35916 m .61003 .3524 L .6152 .29754 L .895 .668 .587 r
F
.60819 .3576 m .60731 .36009 L .60887 .34061 L .985 .787 .386 r
F
.61605 .34581 m .61677 .36658 L .61337 .36649 L .895 .668 .587 r
F
.61677 .36658 m .61686 .36921 L .6136 .36667 L F
.61677 .36658 m .6136 .36667 L .61337 .36649 L F
.62291 .49778 m .62219 .49343 L .62259 .37367 L .77 .576 .637 r
F
.62291 .49778 m .62259 .37367 L .62263 .37369 L F
.61994 .37161 m .6221 .51914 L .61686 .36921 L .895 .668 .587 r
F
.61337 .36649 m .6221 .51914 L .5961 .5002 L F
.61686 .36921 m .6221 .51914 L .61337 .36649 L F
.62751 .37633 m .62291 .49778 L .62266 .37371 L .77 .576 .637 r
F
.62751 .37633 m .63339 .40048 L .62291 .49778 L F
.63339 .40048 m .66406 .52655 L .62291 .49778 L F
.62259 .37367 m .62219 .49343 L .61994 .37161 L .895 .668 .587 r
F
.62219 .49343 m .62184 .50141 L .61994 .37161 L F
.61917 .36651 m .61677 .36658 L .61605 .34581 L F
.62259 .37367 m .61994 .37161 L .61968 .35376 L F
.62236 .36642 m .61988 .36934 L .62772 .37085 L .578 .034 0 r
F
.61805 .36654 m .61988 .36934 L .62236 .36642 L F
.61968 .35376 m .61987 .36649 L .61605 .34581 L .895 .668 .587 r
F
.61987 .36649 m .61917 .36651 L .61605 .34581 L F
.6364 .37252 m .62009 .36954 L .64096 .3758 L .578 .034 0 r
F
.61988 .36934 m .62009 .36954 L .6364 .37252 L F
.63543 .38205 m .6367 .38277 L .6436 .38795 L 0 .246 .704 r
F
.65011 .39382 m .64674 .38991 L .64872 .39103 L .681 .526 .669 r
F
.64988 .39169 m .66245 .4065 L .65011 .39382 L F
.65815 .39745 m .66245 .4065 L .64988 .39169 L F
.64988 .39169 m .65011 .39382 L .64872 .39103 L F
.65382 .42835 m .67457 .43971 L .66496 .45269 L .377 .429 .788 r
F
.65382 .42835 m .66496 .45269 L .66137 .45753 L F
.65011 .39382 m .70861 .5034 L .66406 .52655 L .681 .526 .669 r
F
.66245 .4065 m .70861 .5034 L .65011 .39382 L F
.62009 .36954 m .66984 .41783 L .64096 .3758 L .578 .034 0 r
F
.61836 .35494 m .62106 .37048 L .61703 .36657 L .492 .103 .229 r
F
.62769 .36626 m .62772 .37085 L .6364 .37252 L .578 .034 0 r
F
.62353 .36638 m .62772 .37085 L .62769 .36626 L F
.62265 .36644 m .62261 .36641 L .62263 .36021 L .77 .576 .637 r
F
.62826 .35649 m .62772 .37085 L .62263 .36021 L F
.62772 .37085 m .62265 .36644 L .62263 .36021 L F
.62963 .32048 m .63839 .37291 L .62772 .37085 L F
.62263 .36021 m .61968 .35376 L .61921 .32133 L .895 .668 .587 r
F
.62826 .35649 m .62263 .36021 L .62273 .33151 L .77 .576 .637 r
F
.61836 .35494 m .66984 .41783 L .62106 .37048 L .492 .103 .229 r
F
.6082 .36554 m .63081 .42677 L .61836 .35494 L F
.60892 .3452 m .63081 .42677 L .60676 .36164 L .283 .016 .319 r
F
.60641 .35731 m .60785 .35338 L .60586 .36106 L .985 .787 .386 r
F
.60824 .3485 m .60785 .35338 L .60641 .35731 L F
.60785 .35338 m .60672 .36196 L .60586 .36106 L F
.60922 .34289 m .60858 .34775 L .60887 .34061 L F
.60586 .36106 m .5961 .5002 L .58919 .4744 L F
.60314 .37308 m .60174 .4477 L .60892 .3452 L .283 .016 .319 r
F
.60678 .32652 m .6035 .35409 L .60499 .3695 L 0 0 .188 r
F
.6035 .35409 m .60246 .36284 L .60329 .36504 L F
.6035 .35409 m .60329 .36504 L .60499 .3695 L F
.60499 .3695 m .58919 .4744 L .60174 .4477 L F
.60246 .36284 m .58919 .4744 L .60499 .3695 L F
.60101 .38335 m .60174 .4477 L .60314 .37308 L .283 .016 .319 r
F
.60058 .32018 m .60101 .38335 L .60314 .37308 L F
.60022 .31276 m .60028 .31829 L .60058 .32018 L F
.60028 .31829 m .60101 .38335 L .60058 .32018 L F
.60517 .33029 m .60257 .35371 L .60678 .32652 L 0 0 .188 r
F
.60257 .35371 m .60367 .35267 L .60678 .32652 L F
.60022 .31276 m .60314 .37308 L .60401 .32689 L .283 .016 .319 r
F
.60697 .31088 m .60376 .34041 L .60749 .30938 L 0 0 .188 r
F
.60376 .34041 m .60373 .34168 L .60749 .30938 L F
.60892 .3452 m .60174 .4477 L .63081 .42677 L .283 .016 .319 r
F
.60887 .34061 m .60824 .3485 L .60641 .35731 L .985 .787 .386 r
F
.57872 .34912 m .59373 .3581 L .58989 .35603 L 0 .246 .704 r
F
.65432 .45718 m .66406 .52655 L .65401 .46644 L .77 .576 .637 r
F
.57872 .34912 m .60031 .36165 L .59373 .3581 L 0 .246 .704 r
F
.62179 .35912 m .63081 .42677 L .66984 .41783 L .492 .103 .229 r
F
.61836 .35494 m .61931 .3604 L .62179 .35912 L F
.61931 .3604 m .63081 .42677 L .62179 .35912 L F
.63723 .3355 m .63927 .35005 L .62963 .32048 L .77 .576 .637 r
F
.63927 .35005 m .63648 .3515 L .62963 .32048 L F
.62291 .49778 m .6221 .51914 L .62219 .49343 L F
.62291 .49778 m .66406 .52655 L .6221 .51914 L F
.66857 .40472 m .65394 .39452 L .67225 .40699 L 0 .246 .704 r
F
.68764 .42206 m .69079 .43276 L .68509 .4255 L .609 .495 .698 r
F
.72715 .44439 m .74187 .45442 L .73625 .46277 L F
.7482 .48688 m .76309 .50091 L .75646 .50356 L F
.72378 .47673 m .7532 .48578 L .74922 .5104 L .377 .429 .788 r
F
.72378 .47673 m .74922 .5104 L .74604 .53007 L F
.68764 .42206 m .75646 .50356 L .71633 .5196 L .609 .495 .698 r
F
.66932 .41253 m .73977 .44877 L .73097 .47064 L .18 .391 .833 r
F
.64096 .3758 m .66984 .41783 L .70945 .425 L .578 .034 0 r
F
.62219 .49343 m .6221 .51914 L .62184 .50141 L .895 .668 .587 r
F
.69079 .43276 m .71077 .5007 L .68728 .43193 L .609 .495 .698 r
F
.6461 .28083 m .69454 .3648 L .69102 .37148 L F
.69454 .3648 m .74422 .45091 L .69102 .37148 L F
.74422 .45091 m .7712 .49767 L .73625 .46277 L F
.73097 .47064 m .73977 .44877 L .7532 .48578 L .18 .391 .833 r
F
.73097 .47064 m .7532 .48578 L .72995 .47216 L F
.72995 .47216 m .7532 .48578 L .73733 .4809 L .377 .429 .788 r
F
.71077 .5007 m .71633 .5196 L .70915 .49797 L .609 .495 .698 r
F
.70861 .5034 m .71633 .5196 L .70689 .52085 L .681 .526 .669 r
F
.70861 .5034 m .70689 .52085 L .66406 .52655 L F
.62147 .32788 m .62052 .33619 L .61921 .32133 L .895 .668 .587 r
F
.62273 .33151 m .62052 .33619 L .62147 .32788 L F
.61212 .33029 m .61028 .34971 L .61145 .32305 L .985 .787 .386 r
F
.61028 .34971 m .60955 .34498 L .61145 .32305 L F
.61145 .32305 m .60955 .34498 L .60887 .34061 L F
.61921 .32133 m .61968 .35376 L .61605 .34581 L .895 .668 .587 r
F
.56703 .3767 m .58326 .38621 L .58036 .38813 L .377 .429 .788 r
F
.62963 .32048 m .62826 .35649 L .62273 .33151 L .77 .576 .637 r
F
.65682 .31729 m .6587 .34602 L .63877 .28599 L .609 .495 .698 r
F
.72976 .51827 m .74604 .53007 L .73188 .52245 L .483 .452 .747 r
F
.6308 .28968 m .63723 .3355 L .62963 .32048 L .77 .576 .637 r
F
.62963 .32048 m .62273 .33151 L .62286 .29309 L F
.57507 .401 m .57792 .40315 L .5734 .40492 L .483 .452 .747 r
F
.57792 .40315 m .57577 .40658 L .5734 .40492 L F
.62286 .29309 m .62273 .33151 L .61921 .32133 L .895 .668 .587 r
F
.6152 .29754 m .61212 .33029 L .61145 .32305 L .985 .787 .386 r
F
.56093 .39032 m .57507 .401 L .5734 .40492 L .483 .452 .747 r
F
.60749 .30938 m .60517 .33029 L .60678 .32652 L 0 0 .188 r
F
.60772 .30398 m .60697 .31088 L .60749 .30938 L F
.55347 .40297 m .56905 .41918 L .56667 .42596 L .557 .474 .716 r
F
.25 g
.56525 .41523 m
.56905 .41918 L
s
.56905 .41918 m
.59253 .44362 L
s
.6713 .52559 m
.67319 .52756 L
s
.67319 .52756 m
.71861 .57482 L
s
.55347 .40297 m
.55585 .40545 L
s
.55585 .40545 m
.56525 .41523 L
s
0 g
.006 w
.54402 .41374 m
.55347 .40297 L
s
.25 g
.5 Mabswid
.54597 .41673 m
.5619 .44115 L
s
.5619 .44115 m
.59308 .48894 L
s
.60435 .50621 m
.67453 .61378 L
s
.53533 .4289 m
.55242 .47197 L
s
.55242 .47197 m
.61984 .64191 L
s
.52523 .45766 m
.56215 .6559 L
s
0 g
.006 w
.55347 .40297 m
.56093 .39032 L
s
.25 g
.5 Mabswid
.58892 .41145 m
.59549 .41641 L
s
.72669 .51546 m
.74604 .53007 L
s
.56402 .39266 m
.58892 .41145 L
s
.56093 .39032 m
.56402 .39266 L
s
0 g
.006 w
.56093 .39032 m
.56703 .3767 L
s
.24169 .41821 m .24261 .41909 L .23238 .40669 L .381 .012 .208 r
F
.31109 .46239 m .31472 .50872 L .3015 .4644 L .76 .568 .638 r
F
.31472 .50872 m .30544 .49718 L .3015 .4644 L F
.31109 .46239 m .38361 .68825 L .32955 .69819 L F
.3015 .4644 m .27974 .6924 L .29107 .46341 L .833 .625 .621 r
F
.3015 .4644 m .32955 .69819 L .27974 .6924 L F
.29107 .46341 m .2417 .67071 L .28039 .459 L .916 .702 .598 r
F
.28039 .459 m .22193 .63579 L .27006 .4514 L .994 .802 .541 r
F
.27006 .4514 m .23892 .54692 L .26031 .4414 L .894 .819 .346 r
F
.22339 .39591 m .37679 .49744 L .21546 .3862 L .511 0 0 r
F
.29107 .46341 m .29032 .47848 L .28814 .47569 L .916 .702 .598 r
F
.2667 .43836 m .38104 .5178 L .36722 .54453 L .429 .42 .748 r
F
.23892 .54692 m .23707 .53813 L .26031 .4414 L .894 .819 .346 r
F
.20571 .52653 m .22896 .5676 L .20613 .60269 L .866 .64 .594 r
F
.26074 .51844 m .2417 .67071 L .22193 .63579 L .994 .802 .541 r
F
.27197 .48447 m .26454 .5302 L .26074 .51844 L F
.26454 .5302 m .2417 .67071 L .26074 .51844 L F
.2253 .39717 m .25301 .41604 L .28469 .43688 L .511 0 0 r
F
.28526 .43721 m .28469 .43688 L .28841 .43932 L F
.2253 .39717 m .28469 .43688 L .28526 .43721 L F
.26031 .4414 m .25638 .45775 L .25809 .45821 L 0 0 .007 r
F
.26031 .4414 m .26024 .44196 L .25096 .43002 L F
.27415 .48886 m .2417 .67071 L .27197 .48447 L .994 .802 .541 r
F
.27917 .46566 m .24802 .63611 L .27841 .46499 L F
.24802 .63611 m .2417 .67071 L .24802 .63531 L F
.24802 .63611 m .24802 .63531 L .27841 .46499 L F
.25809 .45821 m .25079 .48697 L .25392 .489 L 0 0 .007 r
F
.25809 .45821 m .25392 .489 L .25408 .48856 L F
.25638 .45775 m .24955 .48617 L .25809 .45821 L F
.22896 .5676 m .2319 .57279 L .2175 .60331 L .866 .64 .594 r
F
.24955 .48617 m .23707 .53813 L .25079 .48697 L 0 0 .007 r
F
.24848 .52449 m .23966 .56145 L .23936 .5554 L .894 .819 .346 r
F
.26942 .45358 m .24444 .54955 L .24848 .52449 L F
.27006 .4514 m .2695 .45356 L .26942 .45358 L F
.2695 .45356 m .24444 .54955 L .26942 .45358 L F
.24955 .48617 m .25079 .48697 L .25809 .45821 L 0 0 .007 r
F
.26024 .44196 m .25408 .48856 L .25096 .43002 L F
.25408 .48856 m .25398 .48838 L .25096 .43002 L F
.25408 .48856 m .25488 .48995 L .25392 .489 L .682 .512 .649 r
F
.25408 .48856 m .25392 .489 L .25402 .48906 L 0 0 .007 r
F
.25398 .48838 m .24897 .47743 L .25096 .43002 L F
.2529 .4865 m .25408 .48856 L .25392 .489 L .682 .512 .649 r
F
.25402 .48906 m .2529 .4865 L .25398 .48838 L 0 0 .007 r
F
.2529 .4865 m .24897 .47743 L .25398 .48838 L F
.24984 .47817 m .26289 .46253 L .25408 .48856 L .682 .512 .649 r
F
.23778 .55044 m .22305 .61064 L .23549 .55746 L .894 .819 .346 r
F
.23892 .54692 m .22958 .58851 L .23778 .55044 L F
.25068 .51085 m .23923 .55299 L .23892 .54692 L F
.23923 .55299 m .22958 .58851 L .23892 .54692 L F
.24848 .52449 m .22958 .58851 L .25068 .51085 L F
.24444 .54955 m .22193 .63579 L .24848 .52449 L F
.2879 .47671 m .27974 .6924 L .2417 .67071 L .916 .702 .598 r
F
.28809 .47693 m .27974 .6924 L .2879 .47671 L F
.29032 .47848 m .27974 .6924 L .28814 .47569 L F
.23885 .54546 m .29632 .59355 L .25019 .60508 L .774 .568 .62 r
F
.2376 .53889 m .23982 .54095 L .23885 .54546 L F
.23982 .54095 m .29632 .59355 L .23885 .54546 L F
.24097 .5566 m .24274 .56499 L .23875 .54352 L F
.25096 .43002 m .25063 .43792 L .2576 .44866 L .119 0 .191 r
F
.2529 .4865 m .25392 .489 L .25402 .48906 L .682 .512 .649 r
F
.25402 .48906 m .24888 .47947 L .24897 .47743 L 0 0 .007 r
F
.27006 .4514 m .24848 .52449 L .25068 .51085 L .894 .819 .346 r
F
.31472 .50872 m .32955 .69819 L .30544 .49718 L .76 .568 .638 r
F
.25392 .489 m .33743 .57171 L .29632 .59355 L .682 .512 .649 r
F
.25392 .489 m .254 .4892 L .25402 .48906 L F
.254 .4892 m .29632 .59355 L .25402 .48906 L F
.27841 .46499 m .27415 .48886 L .27197 .48447 L .994 .802 .541 r
F
.2599 .4537 m .29607 .48431 L .33743 .57171 L .578 .465 .688 r
F
.29607 .48431 m .36722 .54453 L .33743 .57171 L F
.26387 .45974 m .33743 .57171 L .26498 .46004 L F
.26498 .46004 m .33743 .57171 L .25488 .48995 L .682 .512 .649 r
F
.26498 .46004 m .25488 .48995 L .25408 .48856 L F
.25402 .48906 m .26059 .50419 L .25473 .48952 L F
.25402 .48906 m .29632 .59355 L .26059 .50419 L F
.25473 .48952 m .29632 .59355 L .2376 .53889 L .774 .568 .62 r
F
.25402 .48906 m .23798 .53943 L .25392 .48984 L 0 0 .007 r
F
.23883 .545 m .23799 .53945 L .23773 .53907 L .774 .568 .62 r
F
.23781 .54001 m .23885 .54546 L .23783 .53995 L F
.23781 .54001 m .23783 .53995 L .23765 .53896 L F
.2376 .53889 m .23781 .54001 L .23765 .53896 L F
.23798 .53943 m .23799 .53945 L .25392 .48984 L 0 0 .007 r
F
.23885 .54546 m .23883 .545 L .23773 .53907 L .774 .568 .62 r
F
.25079 .48697 m .23761 .5389 L .25402 .48906 L 0 0 .007 r
F
.23761 .5389 m .23798 .53943 L .25402 .48906 L F
.25326 .43648 m .25658 .44582 L .24544 .4274 L .119 0 .191 r
F
.25658 .44582 m .25092 .44084 L .24544 .4274 L F
.25096 .43002 m .25326 .43648 L .24169 .41821 L F
.25326 .43648 m .24544 .4274 L .24169 .41821 L F
.24169 .41821 m .24653 .43008 L .24648 .42279 L .381 .012 .208 r
F
.24808 .43388 m .24977 .43803 L .26141 .43826 L F
.25142 .42753 m .26205 .43827 L .26265 .43828 L F
.2601 .45571 m .26217 .46151 L .25837 .4561 L .119 0 .191 r
F
.25658 .44582 m .25974 .45467 L .25092 .44084 L F
.25974 .45467 m .2601 .45571 L .25637 .44966 L F
.25974 .45467 m .25637 .44966 L .25092 .44084 L F
.25513 .44643 m .26103 .44672 L .2599 .4537 L .578 .465 .688 r
F
.2601 .45571 m .25837 .4561 L .25092 .44084 L .119 0 .191 r
F
.25837 .4561 m .25546 .45196 L .25092 .44084 L F
.28039 .459 m .27917 .46566 L .27841 .46499 L .994 .802 .541 r
F
.28814 .47569 m .28809 .47693 L .2879 .47671 L .916 .702 .598 r
F
.26103 .44672 m .36722 .54453 L .2599 .4537 L .578 .465 .688 r
F
.25513 .44643 m .26387 .45974 L .25862 .45024 L F
.26387 .45974 m .26498 .46004 L .25862 .45024 L F
.25862 .45024 m .26417 .4588 L .24211 .45925 L .682 .512 .649 r
F
.25837 .4561 m .25725 .45636 L .25546 .45196 L .119 0 .191 r
F
.25071 .43805 m .2553 .44512 L .26265 .43828 L .381 .012 .208 r
F
.24977 .43803 m .2553 .44512 L .25071 .43805 L F
.24977 .43803 m .25339 .44689 L .2553 .44512 L F
.25339 .44689 m .25889 .44543 L .26265 .43828 L F
.25946 .44527 m .26103 .44672 L .25513 .44643 L .578 .465 .688 r
F
.26134 .44477 m .36722 .54453 L .26103 .44672 L F
.267 .44327 m .36722 .54453 L .26134 .44477 L F
.25546 .45196 m .26475 .44689 L .26405 .44405 L .381 .012 .208 r
F
.25889 .44543 m .26405 .44405 L .26265 .43828 L F
.26234 .43857 m .26103 .44672 L .24655 .43338 L .578 .465 .688 r
F
.25546 .45196 m .26405 .44405 L .25889 .44543 L .381 .012 .208 r
F
.2253 .39717 m .28841 .43932 L .29977 .44646 L .511 0 0 r
F
.27061 .43003 m .37679 .49744 L .38104 .5178 L .105 .346 .815 r
F
.25301 .41604 m .29006 .4404 L .27061 .43003 L F
.29006 .4404 m .37679 .49744 L .27061 .43003 L F
.25686 .42797 m .27806 .43859 L .2667 .43836 L .429 .42 .748 r
F
.25484 .42162 m .26256 .43008 L .27382 .43424 L .544 .068 .076 r
F
.23238 .40669 m .23889 .41311 L .25484 .42162 L F
.27111 .43324 m .27806 .43859 L .25686 .42797 L .429 .42 .748 r
F
.23889 .41311 m .24139 .41558 L .25484 .42162 L .544 .068 .076 r
F
.27806 .43859 m .38104 .5178 L .2667 .43836 L .429 .42 .748 r
F
.25686 .42797 m .28206 .45459 L .25998 .43047 L F
.28206 .45459 m .30826 .48225 L .27331 .44441 L F
.24139 .41558 m .26378 .43351 L .25484 .42162 L .544 .068 .076 r
F
.26378 .43351 m .27091 .43923 L .26617 .43403 L F
.26378 .43351 m .26617 .43403 L .25484 .42162 L F
.23238 .40669 m .27382 .43424 L .22339 .39591 L F
.27382 .43424 m .25833 .42041 L .22339 .39591 L F
.25301 .41604 m .38104 .5178 L .2726 .42938 L .105 .346 .815 r
F
.2726 .42938 m .38104 .5178 L .23701 .40701 L .429 .42 .748 r
F
.27382 .43424 m .35543 .48851 L .25833 .42041 L .544 .068 .076 r
F
.29977 .44646 m .28841 .43932 L .37679 .49744 L .511 0 0 r
F
.21546 .3862 m .37679 .49744 L .25301 .41604 L .105 .346 .815 r
F
.21546 .3862 m .25301 .41604 L .20941 .37786 L F
.25301 .41604 m .36578 .49283 L .37679 .49744 L .511 0 0 r
F
.25301 .41604 m .2726 .42938 L .20941 .37786 L .105 .346 .815 r
F
.22339 .39591 m .35543 .48851 L .36578 .49283 L .511 0 0 r
F
.22339 .39591 m .36578 .49283 L .2253 .39717 L F
.21887 .38557 m .22392 .38969 L .24051 .40921 L .429 .42 .748 r
F
.22392 .38969 m .2726 .42938 L .25833 .42041 L F
.22392 .38969 m .25833 .42041 L .24051 .40921 L F
.23701 .40701 m .27111 .43324 L .25686 .42797 L F
.24284 .41176 m .24355 .41218 L .20568 .37117 L F
.28206 .45459 m .24355 .41218 L .24284 .41176 L F
.28206 .45459 m .27331 .44441 L .24355 .41218 L F
.20941 .37786 m .25686 .42797 L .20568 .37117 L F
.25686 .42797 m .25998 .43047 L .20568 .37117 L F
.30826 .48225 m .28055 .45152 L .25303 .42198 L F
.25586 .42551 m .25303 .42198 L .20568 .37117 L F
.30826 .48225 m .25303 .42198 L .25586 .42551 L F
.24261 .41909 m .24788 .42414 L .23358 .40787 L .381 .012 .208 r
F
.24788 .42414 m .24053 .41473 L .23358 .40787 L F
.24261 .41909 m .23358 .40787 L .23238 .40669 L F
.24434 .41265 m .26378 .43351 L .22551 .40135 L .578 .465 .688 r
F
.26378 .43351 m .2717 .44202 L .26147 .43301 L F
.30826 .48225 m .36722 .54453 L .28055 .45152 L .429 .42 .748 r
F
.2717 .44202 m .36722 .54453 L .27354 .44988 L .578 .465 .688 r
F
.2717 .44202 m .27354 .44988 L .26767 .44309 L F
.26378 .43351 m .32123 .49438 L .27091 .43923 L .544 .068 .076 r
F
.24139 .41558 m .25837 .43234 L .26378 .43351 L F
.24788 .42414 m .26767 .44309 L .24053 .41473 L .381 .012 .208 r
F
.26767 .44309 m .25837 .43234 L .24053 .41473 L F
.26265 .43828 m .26405 .44405 L .26767 .44309 L F
.2717 .44202 m .267 .44327 L .25558 .43173 L .578 .465 .688 r
F
.2717 .44202 m .25558 .43173 L .26147 .43301 L F
.25837 .43234 m .32123 .49438 L .26378 .43351 L .544 .068 .076 r
F
.26147 .43301 m .25558 .43173 L .22551 .40135 L .578 .465 .688 r
F
.26378 .43351 m .26147 .43301 L .22551 .40135 L F
.24933 .43594 m .25946 .44527 L .25599 .4462 L F
.24933 .43594 m .25599 .4462 L .25513 .44643 L F
.24655 .43338 m .24933 .43594 L .25513 .44643 L F
.25339 .44689 m .25546 .45196 L .25889 .44543 L .381 .012 .208 r
F
.24647 .42253 m .26234 .43857 L .24655 .43338 L .578 .465 .688 r
F
.22551 .40135 m .24647 .42253 L .24655 .43338 L F
.20568 .37117 m .24434 .41265 L .22551 .40135 L F
.24655 .43338 m .25513 .44643 L .24284 .42592 L F
.25513 .44643 m .25862 .45024 L .24284 .42592 L F
.20568 .37117 m .24655 .43338 L .20416 .3663 L F
.24655 .43338 m .24284 .42592 L .20416 .3663 L F
.20499 .36769 m .25862 .45024 L .25546 .45196 L .682 .512 .649 r
F
.20416 .3663 m .20524 .36796 L .20499 .36769 L F
.20524 .36796 m .25862 .45024 L .20499 .36769 L F
.21656 .39666 m .25546 .45196 L .24211 .45925 L F
.20416 .3663 m .25546 .45196 L .21656 .39666 L F
.24902 .47616 m .24897 .47743 L .24984 .47817 L .119 0 .191 r
F
.24897 .47743 m .24888 .47947 L .24964 .47845 L F
.24897 .47743 m .24964 .47845 L .24984 .47817 L F
.20416 .3663 m .23973 .45342 L .24069 .45639 L .682 .512 .649 r
F
.23973 .45342 m .25408 .48856 L .24069 .45639 L F
.24069 .45639 m .25408 .48856 L .2529 .4865 L F
.24211 .45925 m .26417 .4588 L .24984 .47817 L F
.24069 .45639 m .24964 .47845 L .23739 .44615 L F
.24964 .47845 m .2529 .4865 L .25004 .47905 L F
.22096 .40774 m .24236 .4639 L .20533 .36918 L .774 .568 .62 r
F
.23885 .54546 m .23773 .53907 L .23765 .53896 L F
.23883 .545 m .23875 .54352 L .23799 .53945 L F
.24097 .5566 m .23875 .54352 L .23883 .545 L F
.22958 .58851 m .22305 .61064 L .23778 .55044 L .894 .819 .346 r
F
.23885 .54546 m .24097 .5566 L .23883 .545 L .774 .568 .62 r
F
.23936 .5554 m .22193 .63579 L .22305 .61064 L .894 .819 .346 r
F
.23966 .56145 m .22193 .63579 L .23936 .5554 L F
.23892 .54692 m .23549 .55746 L .23707 .53813 L F
.23549 .55746 m .23303 .55491 L .23707 .53813 L F
.24097 .5566 m .25019 .60508 L .24274 .56499 L .774 .568 .62 r
F
.23798 .5395 m .24274 .56499 L .23303 .55491 L .866 .64 .594 r
F
.24236 .4639 m .24239 .46438 L .20533 .36918 L .774 .568 .62 r
F
.25392 .48984 m .25321 .49227 L .25349 .4931 L 0 0 .007 r
F
.24882 .4809 m .24881 .48107 L .20533 .36918 L .774 .568 .62 r
F
.20416 .3663 m .24069 .45639 L .20416 .36305 L .682 .512 .649 r
F
.20439 .36423 m .22096 .40774 L .20533 .36918 L .774 .568 .62 r
F
.23707 .53813 m .23761 .5389 L .25079 .48697 L 0 0 .007 r
F
.23799 .53945 m .24274 .56499 L .23798 .5395 L .866 .64 .594 r
F
.2319 .57279 m .22467 .6037 L .2175 .60331 L F
.24274 .56499 m .25019 .60508 L .22896 .5676 L F
.23303 .55491 m .22896 .5676 L .20571 .52653 L F
.24274 .56499 m .22896 .5676 L .23303 .55491 L F
.2376 .53889 m .23543 .54743 L .23761 .5389 L 0 0 .007 r
F
.23549 .55746 m .22382 .59325 L .23303 .55491 L .894 .819 .346 r
F
.23543 .54743 m .22382 .59325 L .2355 .54721 L 0 0 .007 r
F
.23543 .54743 m .2355 .54721 L .23761 .5389 L F
.2355 .54721 m .22382 .59325 L .25392 .48984 L F
.25349 .4931 m .24863 .48551 L .24888 .47947 L F
.24882 .4809 m .24863 .48551 L .2498 .48342 L .119 0 .191 r
F
.25402 .48906 m .25349 .4931 L .24888 .47947 L 0 0 .007 r
F
.26417 .4588 m .26498 .46004 L .24984 .47817 L .682 .512 .649 r
F
.25125 .48086 m .26197 .46262 L .26217 .46151 L .119 0 .191 r
F
.2529 .4865 m .25402 .48906 L .25027 .4794 L .682 .512 .649 r
F
.2529 .4865 m .25027 .4794 L .25004 .47905 L F
.25129 .48093 m .26197 .46262 L .25125 .48086 L .119 0 .191 r
F
.26289 .46253 m .26362 .46358 L .25408 .48856 L .682 .512 .649 r
F
.25408 .48856 m .25402 .48906 L .25398 .48838 L 0 0 .007 r
F
.25402 .48906 m .25473 .48952 L .25129 .48093 L .682 .512 .649 r
F
.25007 .47909 m .25125 .48086 L .26217 .46151 L .119 0 .191 r
F
.24888 .47947 m .24882 .4809 L .26217 .46151 L F
.25027 .4794 m .25129 .48093 L .23739 .44615 L .682 .512 .649 r
F
.25402 .48906 m .25129 .48093 L .25027 .4794 L F
.24882 .4809 m .2498 .48342 L .25125 .48086 L .119 0 .191 r
F
.24882 .4809 m .25125 .48086 L .25007 .47909 L F
.24863 .48551 m .25129 .48093 L .25125 .48086 L F
.25004 .47905 m .25027 .4794 L .23739 .44615 L .682 .512 .649 r
F
.20533 .36918 m .25349 .4931 L .2185 .43847 L .774 .568 .62 r
F
.20479 .36469 m .25349 .4931 L .20439 .36423 L F
.24069 .45639 m .23739 .44615 L .20425 .36327 L .682 .512 .649 r
F
.20425 .36327 m .20425 .36327 L .20416 .36305 L F
.24069 .45639 m .20425 .36327 L .20425 .36327 L F
.24964 .47845 m .25004 .47905 L .23739 .44615 L F
.20613 .36797 m .25473 .48952 L .20622 .36848 L .774 .568 .62 r
F
.20622 .36848 m .25473 .48952 L .25349 .4931 L F
.25313 .49254 m .22382 .59325 L .25349 .4931 L 0 0 .007 r
F
.2185 .43847 m .25349 .4931 L .2376 .53889 L .774 .568 .62 r
F
.23765 .53896 m .23773 .53907 L .20479 .36073 L F
.23773 .53907 m .23799 .53945 L .20479 .36073 L F
.20416 .36305 m .20613 .36797 L .20622 .36848 L F
.20416 .36305 m .20479 .36469 L .20439 .36423 L F
.20416 .36305 m .2376 .53889 L .20479 .36073 L F
.2376 .53889 m .23765 .53896 L .20479 .36073 L F
.20479 .36073 m .2048 .3613 L .20535 .35815 L .866 .64 .594 r
F
.20506 .36218 m .23799 .53945 L .2048 .36185 L F
.23761 .5389 m .2355 .54721 L .23798 .53943 L 0 0 .007 r
F
.23798 .53943 m .2355 .54721 L .23799 .53945 L F
.23799 .53945 m .23798 .5395 L .2048 .36185 L .866 .64 .594 r
F
.23707 .53813 m .23527 .54559 L .2376 .53889 L 0 0 .007 r
F
.23527 .54559 m .22382 .59325 L .2376 .53889 L F
.2048 .36185 m .23798 .5395 L .20571 .52653 L .866 .64 .594 r
F
.23798 .5395 m .23303 .55491 L .20571 .52653 L F
.20479 .36073 m .20506 .36218 L .2048 .36185 L F
.2048 .3613 m .20613 .60269 L .20535 .35931 L F
.2048 .3613 m .20535 .35931 L .20535 .35815 L F
.24982 .48346 m .24881 .48107 L .24882 .4809 L .774 .568 .62 r
F
.24982 .48346 m .24977 .48354 L .24881 .48107 L F
.24236 .4639 m .24982 .48346 L .24239 .46438 L F
.2319 .57279 m .25019 .60508 L .22467 .6037 L .866 .64 .594 r
F
.23549 .55746 m .22305 .61064 L .22382 .59325 L .894 .819 .346 r
F
.25349 .4931 m .22382 .59325 L .24588 .55072 L 0 0 .007 r
F
.24982 .48346 m .25349 .4931 L .24977 .48354 L .774 .568 .62 r
F
.25349 .4931 m .24588 .55072 L .24863 .48551 L 0 0 .007 r
F
.24863 .48551 m .24588 .55072 L .26197 .46262 L .119 0 .191 r
F
.27382 .43424 m .32123 .49438 L .35543 .48851 L .544 .068 .076 r
F
.26256 .43008 m .32123 .49438 L .27382 .43424 L F
.26767 .44309 m .27354 .44988 L .267 .44327 L .578 .465 .688 r
F
.26767 .44309 m .32123 .49438 L .25837 .43234 L .381 .012 .208 r
F
.26767 .44309 m .26806 .46053 L .32123 .49438 L F
.26405 .44405 m .26806 .46053 L .26767 .44309 L F
.26234 .43857 m .267 .44327 L .26134 .44477 L .578 .465 .688 r
F
.26289 .46253 m .26498 .46004 L .26362 .46358 L .682 .512 .649 r
F
.26217 .46151 m .24588 .55072 L .28153 .5159 L .119 0 .191 r
F
.25837 .4561 m .28153 .5159 L .25725 .45636 L F
.26217 .46151 m .28153 .5159 L .25837 .4561 L F
.25546 .45196 m .28153 .5159 L .26475 .44689 L .381 .012 .208 r
F
.22896 .5676 m .2175 .60331 L .20613 .60269 L .866 .64 .594 r
F
.26806 .46053 m .28153 .5159 L .30646 .50239 L .381 .012 .208 r
F
.26806 .46053 m .30646 .50239 L .32123 .49438 L F
.25 g
.5 Mabswid
.34421 .56553 m
.38361 .68825 L
s
.36987 .54866 m
.43467 .66497 L
s
.36739 .5442 m
.36987 .54866 L
s
.36476 .47485 m
.38388 .49155 L
s
.33651 .45017 m
.36476 .47485 L
s
.38096 .51796 m
.3813 .51836 L
s
.3813 .51836 m
.42885 .57542 L
s
.5892 .3897 m
.59785 .39476 L
s
.57111 .3791 m
.58056 .38463 L
s
.58056 .38463 m
.5892 .3897 L
s
.56703 .3767 m
.57111 .3791 L
s
0 g
.006 w
.56703 .3767 m
.5727 .36283 L
s
.25 g
.5 Mabswid
.59014 .3718 m
.5998 .37677 L
s
.57689 .36498 m
.58583 .36958 L
s
.58583 .36958 m
.59014 .3718 L
s
.5727 .36283 m
.57689 .36498 L
s
0 g
.006 w
.5727 .36283 m
.57872 .34912 L
s
.25 g
.5 Mabswid
.58192 .35098 m
.59103 .35627 L
s
.59103 .35627 m
.59121 .35637 L
s
.57872 .34912 m
.58192 .35098 L
s
0 g
.006 w
.57872 .34912 m
.58543 .33591 L
s
.25 g
.5 Mabswid
.58698 .33741 m
.59285 .34311 L
s
.58697 .3374 m
.58698 .33741 L
s
.58543 .33591 m
.58697 .3374 L
s
0 g
.006 w
.58543 .33591 m
.59271 .32359 L
s
.25 g
.5 Mabswid
.31576 .58322 m
.32955 .69819 L
s
.5957 .33169 m
.59912 .34096 L
s
.59285 .32399 m
.5957 .33169 L
s
.59284 .32396 m
.59285 .32399 L
s
.59271 .32359 m
.59284 .32396 L
s
.27974 .6924 m
.28428 .60058 L
s
.28428 .60058 m
.28448 .59651 L
s
.60772 .30398 m .60174 .4477 L .60022 .31276 L 0 0 .188 r
F
.25 g
.60022 .31276 m
.60031 .32142 L
s
.60031 .32142 m
.60046 .33471 L
s
.60046 .33471 m
.60058 .3447 L
s
.60077 .36231 m
.60094 .37737 L
s
.60094 .37737 m
.60101 .38335 L
s
.60101 .38335 m
.60174 .4477 L
s
.60058 .3447 m
.60073 .35825 L
s
.60073 .35825 m
.60077 .36231 L
s
0 g
.006 w
.59271 .32359 m
.60022 .31276 L
s
.25 g
.5 Mabswid
.59912 .34096 m
.60058 .34491 L
s
.59285 .34311 m
.60049 .35052 L
s
.60049 .35052 m
.60064 .35067 L
s
.59121 .35637 m
.60077 .36192 L
s
0 g
.006 w
.60022 .31276 m
.60772 .30398 L
s
.25 g
.5 Mabswid
.2417 .67071 m
.24956 .62768 L
s
.24956 .62768 m
.25386 .60416 L
s
1 0 0 r
.003 w
.50961 .65443 m
.56215 .6559 L
s
.56215 .6559 m
.61984 .64191 L
s
.25 g
.5 Mabswid
.22193 .63579 m
.23022 .604 L
s
1 0 0 r
.003 w
.61984 .64191 m
.67453 .61378 L
s
.25 g
.5 Mabswid
.58919 .4744 m
.59607 .41108 L
s
.59607 .41108 m
.60083 .3673 L
s
0 g
.006 w
.60772 .30398 m
.6152 .29754 L
s
.25 g
.5 Mabswid
.22382 .59325 m
.23303 .55491 L
s
1 0 0 r
.003 w
.46956 .63857 m
.47931 .64243 L
s
.47931 .64243 m
.50961 .65443 L
s
.25 g
.5 Mabswid
.24588 .55072 m
.24825 .49445 L
s
.24825 .49445 m
.24863 .48551 L
s
.25725 .45636 m
.26577 .47724 L
s
.25546 .45196 m
.25725 .45636 L
s
.26577 .47724 m
.28153 .5159 L
s
1 0 0 r
.003 w
.38361 .68825 m
.43467 .66497 L
s
.43467 .66497 m
.46916 .63809 L
s
.25 g
.5 Mabswid
.5961 .5002 m
.60087 .44955 L
s
.61024 .35013 m
.61028 .34971 L
s
.61028 .34971 m
.61212 .33029 L
s
.61212 .33029 m
.6152 .29754 L
s
0 g
.006 w
.6152 .29754 m
.62286 .29309 L
s
1 0 0 r
.003 w
.32955 .69819 m
.38361 .68825 L
s
.25 g
.5 Mabswid
.26088 .43481 m
.27374 .4475 L
s
.25837 .43234 m
.26088 .43481 L
s
.27374 .4475 m
.2893 .46286 L
s
.2893 .46286 m
.32123 .49438 L
s
1 0 0 r
.003 w
.67453 .61378 m
.71861 .57482 L
s
.25 g
.5 Mabswid
.26576 .42562 m
.30752 .45491 L
s
.30752 .45491 m
.35543 .48851 L
s
.26468 .42486 m
.26576 .42562 L
s
.26458 .42479 m
.26468 .42486 L
s
.25833 .42041 m
.26458 .42479 L
s
1 0 0 r
.003 w
.48432 .62191 m
.50366 .59618 L
s
.47708 .63155 m
.48432 .62191 L
s
.25 g
.5 Mabswid
.62219 .49343 m
.62239 .43283 L
s
.6221 .51914 m
.62219 .49343 L
s
.62267 .35045 m
.62273 .33151 L
s
.62263 .36016 m
.62267 .35045 L
s
.62273 .33151 m
.62286 .29309 L
s
0 g
.006 w
.62286 .29309 m
.6308 .28968 L
s
.25 g
.5 Mabswid
.27293 .42582 m
.29584 .44163 L
s
.29584 .44163 m
.3078 .44987 L
s
.3078 .44987 m
.37679 .49744 L
s
.27051 .42416 m
.27293 .42582 L
s
.27049 .42414 m
.27051 .42416 L
s
.2651 .42043 m
.27049 .42414 L
s
.25023 .41017 m
.2651 .42043 L
s
.24253 .40486 m
.25023 .41017 L
s
1 0 0 r
.003 w
.27974 .6924 m
.32955 .69819 L
s
.44708 .61182 m
.46956 .63857 L
s
.25 g
.5 Mabswid
.26604 .42403 m
.2726 .42938 L
s
.24877 .40995 m
.26604 .42403 L
s
.34691 .48997 m
.38104 .5178 L
s
.21984 .38637 m
.22392 .38969 L
s
.22392 .38969 m
.24877 .40995 L
s
.63723 .3355 m
.63902 .34822 L
s
.63902 .34822 m
.63927 .35005 L
s
.63927 .35005 m
.6426 .37372 L
s
.6426 .37372 m
.6431 .37734 L
s
.6308 .28968 m
.63723 .3355 L
s
0 g
.006 w
.6308 .28968 m
.63877 .28599 L
s
1 0 0 r
.003 w
.50366 .59618 m
.51334 .56243 L
s
.71861 .57482 m
.74604 .53007 L
s
.25 g
.5 Mabswid
.24642 .41489 m
.26378 .43351 L
s
.32074 .49465 m
.36722 .54453 L
s
.21108 .37696 m
.24434 .41265 L
s
.24434 .41265 m
.24642 .41489 L
s
0 g
.006 w
.20416 .3663 m
.20484 .36846 L
s
.25 g
.5 Mabswid
.70915 .49797 m
.71633 .5196 L
s
.6587 .34602 m
.66035 .35099 L
s
.63877 .28599 m
.6587 .34602 L
s
1 0 0 r
.003 w
.44387 .57972 m
.44708 .61182 L
s
.2417 .67071 m
.27974 .6924 L
s
.25 g
.5 Mabswid
.24881 .43512 m
.25862 .45024 L
s
.2961 .50801 m
.31065 .53043 L
s
.31065 .53043 m
.33743 .57171 L
s
.20755 .37153 m
.22913 .40478 L
s
.22913 .40478 m
.24813 .43407 L
s
.24813 .43407 m
.24881 .43512 L
s
0 g
.006 w
.20416 .3663 m
.20416 .36305 L
s
.6518 .27347 m .7712 .49767 L .6461 .28083 L .54 .474 .731 r
F
.25 g
.5 Mabswid
.6469 .28223 m
.65112 .28954 L
s
.6461 .28083 m
.6469 .28223 L
s
0 g
.006 w
.63877 .28599 m
.6461 .28083 L
s
.25 g
.5 Mabswid
.67197 .38598 m
.67724 .40187 L
s
.67164 .385 m
.67197 .38598 L
s
.66035 .35099 m
.67164 .385 L
s
.64945 .4225 m
.65432 .45718 L
s
1 0 0 r
.003 w
.50524 .53741 m
.51334 .56243 L
s
.25 g
.5 Mabswid
.24202 .45774 m
.25129 .48093 L
s
.26984 .52732 m
.29632 .59355 L
s
.20615 .36801 m
.21913 .40047 L
s
.21913 .40047 m
.24202 .45774 L
s
0 g
.006 w
.20416 .36305 m
.20479 .36073 L
s
.6518 .27347 m .81973 .46267 L .7712 .49767 L .54 .474 .731 r
F
.25 g
.5 Mabswid
.72995 .47216 m
.7532 .48578 L
s
.655 .26373 m .81973 .46267 L .6518 .27347 L .463 .459 .769 r
F
.25 g
.68804 .35352 m
.69454 .3648 L
s
.65112 .28954 m
.68804 .35352 L
s
.65432 .45718 m
.66406 .52655 L
s
0 g
.006 w
.6461 .28083 m
.6518 .27347 L
s
.25 g
.5 Mabswid
.6518 .27347 m
.65363 .27553 L
s
.65363 .27553 m
.66127 .28414 L
s
1 0 0 r
.003 w
.75131 .49746 m
.7532 .48578 L
s
.74604 .53007 m
.7499 .50618 L
s
.44387 .57972 m
.45808 .54887 L
s
.25 g
.5 Mabswid
.22818 .4866 m
.23799 .53945 L
s
.24162 .55894 m
.24274 .56499 L
s
.20536 .36379 m
.21172 .39803 L
s
.21172 .39803 m
.22818 .4866 L
s
.24274 .56499 m
.25019 .60508 L
s
1 0 0 r
.003 w
.6221 .51914 m
.66406 .52655 L
s
.66406 .52655 m
.71633 .5196 L
s
.655 .26373 m .85322 .41879 L .81973 .46267 L .463 .459 .769 r
F
.25 g
.5 Mabswid
.80723 .44858 m
.81973 .46267 L
s
.68493 .42056 m
.72401 .44066 L
s
.72401 .44066 m
.73977 .44877 L
s
.68722 .43192 m
.70915 .49797 L
s
.74422 .45091 m
.7712 .49767 L
s
.6553 .25188 m .85322 .41879 L .655 .26373 L .363 .448 .814 r
F
.25 g
.69454 .3648 m
.71641 .40271 L
s
0 g
.006 w
.6518 .27347 m
.655 .26373 L
s
.25 g
.5 Mabswid
.655 .26373 m
.65771 .26585 L
s
.65771 .26585 m
.67319 .27796 L
s
1 0 0 r
.003 w
.48385 .52648 m
.50524 .53741 L
s
.22193 .63579 m
.2417 .67071 L
s
.71633 .5196 m
.75646 .50356 L
s
.75646 .50356 m
.7712 .49767 L
s
.5961 .5002 m
.6221 .51914 L
s
.63451 .17901 m .63675 .18228 L .63933 .19379 L .411 .044 .227 r
F
.65924 .25414 m .86493 .37195 L .65969 .25559 L .363 .448 .814 r
F
.653 .23845 m .86493 .37195 L .6553 .25188 L .206 .431 .858 r
F
.65458 .23945 m .85175 .329 L .86493 .37195 L F
.653 .23845 m .65452 .23915 L .65458 .23945 L F
.65452 .23915 m .85175 .329 L .65458 .23945 L F
.64418 .20897 m .8154 .29655 L .64896 .224 L .436 0 0 r
F
.81787 .31145 m .79472 .28755 L .85175 .329 L 0 .366 .817 r
F
.71532 .25836 m .77284 .2795 L .81787 .31145 L F
.77284 .2795 m .79472 .28755 L .81787 .31145 L F
.7024 .24733 m .79472 .28755 L .71532 .25836 L F
.79472 .28755 m .8154 .29655 L .82566 .30571 L F
.79472 .28755 m .82566 .30571 L .85175 .329 L F
.6497 .22432 m .8154 .29655 L .64967 .22436 L F
.75908 .26774 m .7611 .27461 L .8154 .29655 L .436 0 0 r
F
.7611 .27461 m .79352 .28954 L .8154 .29655 L F
.61242 .14008 m .6065 .37262 L .61817 .14536 L .879 .649 .587 r
F
.60941 .25832 m .61086 .26638 L .6065 .37262 L F
.60975 .24512 m .61068 .25092 L .60941 .25832 L F
.61734 .15446 m .61446 .2176 L .61392 .19178 L .969 .771 .338 r
F
.61766 .15251 m .61446 .2176 L .61734 .15446 L F
.61799 .14887 m .61446 .2176 L .61783 .14912 L F
.61446 .2176 m .6065 .37262 L .61313 .21101 L F
.61446 .2176 m .61313 .21101 L .61392 .19178 L F
.61783 .14912 m .61766 .15251 L .61734 .15446 L F
.61817 .14536 m .61799 .14887 L .61783 .14912 L F
.61817 .14536 m .61392 .19178 L .624 .15392 L F
.61392 .19178 m .61502 .22559 L .624 .15392 L F
.624 .15392 m .62194 .17035 L .62241 .18243 L 0 0 .201 r
F
.62194 .17035 m .61502 .22559 L .61797 .20833 L F
.62194 .17035 m .61797 .20833 L .62241 .18243 L F
.61242 .14008 m .61896 .22046 L .60975 .24512 L .879 .649 .587 r
F
.61068 .25092 m .61133 .25496 L .60941 .25832 L F
.61133 .25496 m .63246 .38636 L .61086 .26638 L F
.61133 .25496 m .61086 .26638 L .60941 .25832 L F
.61896 .22046 m .63246 .38636 L .60975 .24512 L F
.61392 .19178 m .61165 .24709 L .61193 .2135 L .969 .771 .338 r
F
.61193 .2135 m .6065 .37262 L .59951 .34928 L F
.61165 .24709 m .6065 .37262 L .61193 .2135 L F
.61392 .19178 m .59951 .34928 L .61502 .22559 L F
.61618 .22549 m .63246 .38636 L .61797 .20833 L .725 .544 .646 r
F
.61502 .22559 m .61361 .23683 L .62241 .18243 L 0 0 .201 r
F
.60729 .13768 m .61217 .18582 L .61242 .14008 L .725 .544 .646 r
F
.61217 .18582 m .61483 .16967 L .61242 .14008 L F
.60729 .13768 m .6124 .15741 L .61217 .18582 L F
.60971 .16153 m .61078 .16541 L .61194 .15812 L .62 .493 .686 r
F
.6283 .16294 m .62125 .20314 L .62948 .16541 L 0 0 .201 r
F
.62346 .16362 m .62125 .20314 L .6283 .16294 L F
.61686 .23221 m .63647 .28742 L .63246 .38636 L .725 .544 .646 r
F
.6179 .23049 m .67193 .38728 L .61686 .23221 L F
.61954 .21067 m .62295 .22217 L .61618 .22549 L F
.62295 .22217 m .67193 .38728 L .6179 .23049 L F
.62295 .22217 m .6179 .23049 L .61618 .22549 L F
.6282 .19574 m .62731 .21497 L .63258 .18401 L .224 0 .3 r
F
.62125 .20314 m .62429 .21996 L .62948 .16541 L 0 0 .201 r
F
.61361 .23683 m .61699 .22193 L .62241 .18243 L F
.61217 .18582 m .61549 .19703 L .61483 .16967 L .725 .544 .646 r
F
.61217 .18582 m .61618 .22549 L .61549 .19703 L F
.61618 .22549 m .61797 .20833 L .61483 .16967 L F
.62948 .16541 m .62433 .21946 L .62462 .21941 L .224 0 .3 r
F
.62948 .16541 m .62462 .21941 L .62722 .21513 L F
.62731 .21497 m .67193 .38728 L .62295 .22217 L .725 .544 .646 r
F
.62948 .16541 m .62704 .219 L .62958 .16602 L .224 0 .3 r
F
.6269 .22389 m .67193 .38728 L .62731 .21497 L .62 .493 .686 r
F
.62821 .22864 m .65587 .27343 L .67193 .38728 L F
.65587 .27343 m .71798 .374 L .689 .38236 L F
.65587 .27343 m .689 .38236 L .67193 .38728 L F
.62948 .16541 m .63733 .21246 L .63451 .17901 L .224 0 .3 r
F
.62953 .22823 m .71798 .374 L .62821 .22864 L .62 .493 .686 r
F
.63733 .21246 m .64105 .22471 L .63451 .17901 L .224 0 .3 r
F
.64967 .22436 m .7024 .24733 L .71532 .25836 L 0 .366 .817 r
F
.64456 .20916 m .68544 .23359 L .69191 .23338 L .436 0 0 r
F
.64418 .20897 m .64467 .20925 L .64456 .20916 L F
.64467 .20925 m .68544 .23359 L .64456 .20916 L F
.69191 .23338 m .73323 .26142 L .75908 .26774 L F
.65969 .25559 m .86493 .37195 L .85322 .41879 L .363 .448 .814 r
F
.64896 .224 m .85175 .329 L .653 .23845 L 0 .366 .817 r
F
.67087 .23597 m .7623 .3471 L .67464 .2457 L .532 .465 .727 r
F
.6753 .23694 m .7623 .3471 L .67087 .23597 L F
.66443 .22736 m .67087 .23597 L .67691 .2373 L .505 .009 .012 r
F
.66443 .22736 m .67691 .2373 L .67666 .23388 L F
.67431 .23395 m .7623 .3471 L .67605 .23789 L .532 .465 .727 r
F
.68544 .23359 m .7286 .25935 L .69191 .23338 L .436 0 0 r
F
.7286 .25935 m .73323 .26142 L .69191 .23338 L F
.63933 .19379 m .72683 .25473 L .64467 .20925 L .505 .009 .012 r
F
.72683 .25473 m .72742 .25627 L .64467 .20925 L F
.7463 .26729 m .73326 .27148 L .7286 .25935 L .442 .452 .774 r
F
.7286 .25935 m .74162 .26712 L .73323 .26142 L .436 0 0 r
F
.73323 .26142 m .7463 .26729 L .75908 .26774 L F
.72683 .25473 m .7463 .26729 L .7286 .25935 L .442 .452 .774 r
F
.72442 .24847 m .73418 .25686 L .72683 .25473 L F
.73418 .25686 m .7463 .26729 L .72683 .25473 L F
.73323 .26142 m .74162 .26712 L .7463 .26729 L .436 0 0 r
F
.73624 .26128 m .74162 .26712 L .7286 .25935 L .505 .009 .012 r
F
.72742 .25627 m .7286 .25935 L .64467 .20925 L F
.73624 .26128 m .7286 .25935 L .72742 .25627 L F
.7463 .26729 m .79558 .30966 L .73326 .27148 L .442 .452 .774 r
F
.63933 .19379 m .66443 .22736 L .71323 .24526 L .505 .009 .012 r
F
.66443 .22736 m .68741 .2396 L .71323 .24526 L F
.67431 .23395 m .67567 .23702 L .66734 .22686 L .532 .465 .727 r
F
.67567 .23702 m .67605 .23789 L .6753 .23694 L F
.67567 .23702 m .6753 .23694 L .66734 .22686 L F
.7286 .25935 m .73326 .27148 L .6871 .24321 L .442 .452 .774 r
F
.67713 .24031 m .7623 .3471 L .67691 .2373 L F
.67087 .23597 m .67328 .2392 L .71323 .24526 L .505 .009 .012 r
F
.67328 .2392 m .71186 .25039 L .71323 .24526 L F
.66734 .22686 m .6753 .23694 L .67087 .23597 L .532 .465 .727 r
F
.67211 .23402 m .67713 .24031 L .67517 .2359 L .442 .452 .774 r
F
.67211 .23402 m .67489 .23527 L .67431 .23395 L F
.67713 .24031 m .67691 .2373 L .67431 .23395 L F
.67666 .23388 m .67691 .2373 L .68741 .2396 L .505 .009 .012 r
F
.70266 .24772 m .6871 .24321 L .67211 .23402 L .442 .452 .774 r
F
.7286 .25935 m .6871 .24321 L .70266 .24772 L F
.71323 .24526 m .71186 .25039 L .72683 .25473 L .505 .009 .012 r
F
.72442 .24847 m .7286 .25935 L .67211 .23402 L .442 .452 .774 r
F
.67211 .23402 m .79558 .30966 L .7623 .3471 L F
.65757 .21262 m .65932 .21913 L .6556 .21555 L .411 .044 .227 r
F
.65757 .21262 m .66734 .22686 L .65932 .21913 L F
.66734 .22686 m .66867 .23028 L .6556 .21555 L F
.67319 .23539 m .66443 .22736 L .6556 .21555 L F
.63933 .19379 m .64467 .20925 L .64418 .20897 L .505 .009 .012 r
F
.64636 .19628 m .65757 .21262 L .64812 .20555 L .411 .044 .227 r
F
.65757 .21262 m .6556 .21555 L .64812 .20555 L F
.63675 .18228 m .64636 .19628 L .64109 .19615 L F
.64636 .19628 m .64812 .20555 L .64109 .19615 L F
.63675 .18228 m .64109 .19615 L .63933 .19379 L F
.63451 .17901 m .64105 .22471 L .64492 .22353 L F
.6553 .25188 m .65924 .25414 L .65969 .25559 L .363 .448 .814 r
F
.63878 .21087 m .71798 .374 L .6269 .22389 L .62 .493 .686 r
F
.63733 .21246 m .63842 .21899 L .64105 .22471 L .224 0 .3 r
F
.63842 .21899 m .65126 .29597 L .64174 .22953 L F
.63842 .21899 m .64174 .22953 L .64105 .22471 L F
.64525 .22916 m .71798 .374 L .64492 .22353 L .532 .465 .727 r
F
.64525 .22916 m .67464 .2457 L .71798 .374 L F
.6591 .22772 m .67464 .2457 L .64525 .22916 L F
.64896 .224 m .6497 .22432 L .64967 .22436 L 0 .366 .817 r
F
.64105 .22471 m .64174 .22953 L .66157 .21845 L .411 .044 .227 r
F
.64174 .22953 m .64328 .22937 L .66157 .21845 L F
.66924 .23177 m .67087 .23597 L .66443 .22736 L F
.66734 .22686 m .67464 .2457 L .6591 .22772 L .532 .465 .727 r
F
.64184 .23023 m .65989 .23106 L .66157 .21845 L .411 .044 .227 r
F
.62704 .219 m .62681 .22398 L .62712 .21899 L .224 0 .3 r
F
.62681 .22398 m .6269 .22389 L .62712 .21899 L F
.62704 .219 m .62712 .21899 L .62958 .16602 L F
.62265 .19697 m .62731 .21497 L .61954 .21067 L .725 .544 .646 r
F
.61086 .26638 m .61754 .3035 L .6065 .37262 L .879 .649 .587 r
F
.62433 .21946 m .61462 .32145 L .62704 .219 L .224 0 .3 r
F
.62731 .21497 m .62295 .22217 L .61954 .21067 L .725 .544 .646 r
F
.62722 .21513 m .62462 .21941 L .62704 .219 L .224 0 .3 r
F
.6269 .22389 m .62953 .22823 L .62821 .22864 L .62 .493 .686 r
F
.62731 .21497 m .62263 .31589 L .63066 .20944 L .224 0 .3 r
F
.62731 .21497 m .63066 .20944 L .63258 .18401 L F
.62125 .20314 m .6187 .22026 L .62067 .21347 L 0 0 .201 r
F
.62241 .18243 m .61699 .22193 L .62125 .20314 L F
.61618 .22549 m .6179 .23049 L .61686 .23221 L .725 .544 .646 r
F
.61699 .22193 m .59951 .34928 L .62125 .20314 L 0 0 .201 r
F
.6124 .15741 m .62265 .19697 L .61217 .18582 L .725 .544 .646 r
F
.62265 .19697 m .61954 .21067 L .61217 .18582 L F
.62125 .20314 m .62124 .20335 L .62138 .20388 L 0 0 .201 r
F
.62124 .20335 m .61462 .32145 L .62138 .20388 L F
.62138 .20388 m .61462 .32145 L .62429 .21996 L F
.61754 .3035 m .63246 .38636 L .62002 .37977 L .879 .649 .587 r
F
.61754 .3035 m .62002 .37977 L .6065 .37262 L F
.62704 .219 m .61462 .32145 L .62263 .31589 L .224 0 .3 r
F
.61078 .16541 m .6269 .22389 L .61351 .16502 L .62 .493 .686 r
F
.63647 .28742 m .67193 .38728 L .65443 .38687 L .725 .544 .646 r
F
.63647 .28742 m .65443 .38687 L .63246 .38636 L F
.63812 .21921 m .62263 .31589 L .64962 .2971 L .224 0 .3 r
F
.63549 .20147 m .63309 .22282 L .63812 .21921 L F
.63309 .22282 m .62263 .31589 L .63812 .21921 L F
.63969 .21808 m .64525 .22916 L .63951 .21666 L .532 .465 .727 r
F
.63842 .21899 m .64962 .2971 L .64404 .25268 L .224 0 .3 r
F
.63549 .20147 m .63812 .21921 L .63842 .21899 L F
.63812 .21921 m .64962 .2971 L .63842 .21899 L F
.63258 .18401 m .63066 .20944 L .63549 .20147 L F
.63066 .20944 m .62263 .31589 L .63549 .20147 L F
.6269 .22389 m .62731 .21497 L .60729 .13768 L .62 .493 .686 r
F
.62239 .20753 m .63878 .21087 L .6269 .22389 L F
.61078 .16541 m .61351 .16502 L .61194 .15812 L F
.60299 .13716 m .60971 .16153 L .60729 .13768 L F
.60971 .16153 m .61194 .15812 L .60729 .13768 L F
.60299 .13716 m .62791 .18849 L .62239 .20753 L F
.62958 .16602 m .6282 .19574 L .63258 .18401 L .224 0 .3 r
F
.62791 .18849 m .63878 .21087 L .62239 .20753 L .62 .493 .686 r
F
.64525 .22916 m .64492 .22353 L .60299 .13716 L .532 .465 .727 r
F
.63087 .19506 m .63141 .19569 L .63367 .20395 L F
.64306 .19148 m .64492 .22353 L .66157 .21845 L .411 .044 .227 r
F
.63451 .17901 m .64492 .22353 L .64306 .19148 L F
.63141 .19569 m .64652 .21317 L .63367 .20395 L .532 .465 .727 r
F
.63512 .20855 m .63367 .20395 L .60299 .13716 L F
.63703 .21279 m .63367 .20395 L .63512 .20855 L F
.63703 .21279 m .6375 .21228 L .63367 .20395 L F
.59908 .13722 m .63703 .21279 L .60299 .13716 L F
.63367 .20395 m .64652 .21317 L .6355 .20973 L F
.64652 .21317 m .6591 .22772 L .64316 .21558 L F
.64652 .21317 m .64316 .21558 L .6355 .20973 L F
.63969 .21808 m .6591 .22772 L .64525 .22916 L F
.63703 .21279 m .63969 .21808 L .6375 .21228 L F
.63969 .21808 m .63951 .21666 L .6375 .21228 L F
.6355 .20973 m .64316 .21558 L .63969 .21808 L F
.64316 .21558 m .6591 .22772 L .63969 .21808 L F
.64404 .25268 m .64962 .2971 L .65126 .29597 L .224 0 .3 r
F
.62067 .21347 m .59951 .34928 L .61462 .32145 L 0 0 .201 r
F
.6187 .22026 m .59951 .34928 L .62067 .21347 L F
.66157 .21845 m .66035 .22759 L .66734 .22686 L .411 .044 .227 r
F
.6659 .22313 m .66734 .22686 L .62434 .18751 L .532 .465 .727 r
F
.66734 .22686 m .6591 .22772 L .62434 .18751 L F
.64174 .22953 m .64184 .23023 L .64328 .22937 L .411 .044 .227 r
F
.64184 .23023 m .65126 .29597 L .65989 .23106 L F
.66868 .22672 m .67431 .23395 L .66734 .22686 L .532 .465 .727 r
F
.66734 .22686 m .6698 .23044 L .66867 .23028 L .411 .044 .227 r
F
.6698 .23044 m .6703 .23138 L .66867 .23028 L F
.6703 .23138 m .67108 .23301 L .66867 .23028 L F
.6659 .22313 m .66868 .22672 L .66734 .22686 L .532 .465 .727 r
F
.67211 .23402 m .6695 .22946 L .67048 .23171 L .442 .452 .774 r
F
.6695 .22946 m .6659 .22313 L .6698 .23044 L F
.6695 .22946 m .6698 .23044 L .67048 .23171 L F
.66734 .22686 m .65126 .29597 L .68627 .28544 L .411 .044 .227 r
F
.67056 .23156 m .6709 .23251 L .6703 .23138 L F
.6709 .23251 m .67108 .23301 L .6703 .23138 L F
.67211 .23402 m .67431 .23395 L .6659 .22313 L .442 .452 .774 r
F
.67464 .2457 m .7623 .3471 L .72314 .37087 L .532 .465 .727 r
F
.67328 .2392 m .7039 .28014 L .71186 .25039 L .505 .009 .012 r
F
.67319 .23539 m .7039 .28014 L .67087 .23597 L .411 .044 .227 r
F
.67319 .23539 m .67087 .23597 L .66924 .23177 L F
.66734 .22686 m .68627 .28544 L .6698 .23044 L F
.66035 .22759 m .65126 .29597 L .66734 .22686 L F
.64984 .20248 m .6659 .22313 L .62434 .18751 L .532 .465 .727 r
F
.67048 .23171 m .6659 .22313 L .64984 .20248 L .442 .452 .774 r
F
.60241 .14384 m .64984 .20248 L .62434 .18751 L .532 .465 .727 r
F
.64081 .19478 m .6709 .23251 L .64984 .20248 L .442 .452 .774 r
F
.6709 .23251 m .67211 .23402 L .67048 .23171 L F
.6709 .23251 m .67048 .23171 L .64984 .20248 L F
.6698 .23044 m .67056 .23156 L .6703 .23138 L .411 .044 .227 r
F
.6709 .23251 m .72442 .24847 L .67211 .23402 L .442 .452 .774 r
F
.67061 .23169 m .72442 .24847 L .6709 .23251 L F
.7067 .23323 m .72442 .24847 L .67013 .23154 L F
.67056 .23156 m .67319 .23539 L .67108 .23301 L .411 .044 .227 r
F
.67013 .23154 m .67061 .23169 L .6709 .23251 L .442 .452 .774 r
F
.67464 .2457 m .72314 .37087 L .71798 .374 L .532 .465 .727 r
F
.6698 .23044 m .68627 .28544 L .7039 .28014 L .411 .044 .227 r
F
.624 .15392 m .62346 .16362 L .6283 .16294 L 0 0 .201 r
F
.59908 .13722 m .60582 .14588 L .60241 .14384 L .532 .465 .727 r
F
.60582 .14588 m .64984 .20248 L .60241 .14384 L F
.59456 .13679 m .60576 .14643 L .59908 .13722 L .442 .452 .774 r
F
.64081 .19478 m .64984 .20248 L .59908 .13722 L F
.59456 .13679 m .7067 .23323 L .67013 .23154 L F
.62434 .18751 m .63087 .19506 L .6355 .20973 L .532 .465 .727 r
F
.72683 .25473 m .73624 .26128 L .72742 .25627 L .505 .009 .012 r
F
.74512 .26724 m .79558 .30966 L .7463 .26729 L .328 .447 .83 r
F
.74512 .26724 m .80083 .29291 L .79558 .30966 L F
.74162 .26712 m .76259 .27963 L .75908 .26774 L .436 0 0 r
F
.73624 .26128 m .76259 .27963 L .74162 .26712 L .505 .009 .012 r
F
.72683 .25473 m .7039 .28014 L .76259 .27963 L F
.71186 .25039 m .7039 .28014 L .72683 .25473 L F
.62681 .22398 m .62263 .31589 L .6269 .22389 L .224 0 .3 r
F
.73004 .25456 m .74512 .26724 L .72442 .24847 L .328 .447 .83 r
F
.74512 .26724 m .7463 .26729 L .72442 .24847 L F
.68868 .21979 m .73004 .25456 L .70235 .22949 L F
.73004 .25456 m .72442 .24847 L .70235 .22949 L F
.58823 .13534 m .60872 .15256 L .59456 .13679 L F
.60872 .15256 m .61763 .15793 L .59456 .13679 L F
.53792 .11883 m .5578 .12785 L .55332 .12449 L .413 0 0 r
F
.64575 .1837 m .66283 .19699 L .59733 .13924 L .328 .447 .83 r
F
.64575 .1837 m .59733 .13924 L .59723 .13921 L F
.64575 .1837 m .59554 .13766 L .59549 .13765 L F
.60872 .15256 m .64575 .1837 L .61763 .15793 L F
.64575 .1837 m .68868 .21979 L .66283 .19699 L F
.68868 .21979 m .70235 .22949 L .59456 .13679 L F
.58823 .13534 m .68734 .2088 L .67757 .21045 L F
.59958 .14375 m .70566 .2057 L .68734 .2088 L F
.58823 .13534 m .59921 .14192 L .59958 .14375 L F
.59921 .14192 m .70566 .2057 L .59958 .14375 L F
.70566 .2057 m .80881 .2675 L .68734 .2088 L F
.57924 .13275 m .80881 .2675 L .58823 .13534 L .154 .442 .875 r
F
.58359 .1353 m .79557 .22839 L .80881 .2675 L F
.5578 .12785 m .69165 .18862 L .56513 .12996 L .413 0 0 r
F
.5578 .12785 m .56513 .12996 L .55332 .12449 L F
.59723 .13921 m .59733 .13924 L .59554 .13766 L .328 .447 .83 r
F
.59549 .13765 m .59554 .13766 L .59456 .13679 L F
.55332 .12449 m .56695 .12961 L .56742 .12912 L .366 0 0 r
F
.58172 .13385 m .79557 .22839 L .58359 .1353 L .154 .442 .875 r
F
.57924 .13275 m .58172 .13385 L .58359 .1353 L F
.56742 .12912 m .79557 .22839 L .57924 .13275 L 0 .39 .798 r
F
.57594 .13283 m .75472 .20021 L .79557 .22839 L F
.56742 .12912 m .57382 .13155 L .57594 .13283 L F
.57382 .13155 m .75472 .20021 L .57594 .13283 L F
.56695 .12961 m .75472 .20021 L .57382 .13155 L .366 0 0 r
F
.56695 .12961 m .57382 .13155 L .56742 .12912 L F
.67757 .21045 m .80083 .29291 L .74512 .26724 L .328 .447 .83 r
F
.68734 .2088 m .80083 .29291 L .67757 .21045 L F
.61361 .23683 m .59951 .34928 L .61699 .22193 L 0 0 .201 r
F
.61217 .18582 m .61954 .21067 L .61618 .22549 L .725 .544 .646 r
F
.68734 .2088 m .80881 .2675 L .80083 .29291 L .328 .447 .83 r
F
.7611 .27461 m .76259 .27963 L .79352 .28954 L .436 0 0 r
F
.25 g
.5 Mabswid
.78229 .32461 m
.86493 .37195 L
s
.77504 .35763 m
.85322 .41879 L
s
.76189 .34734 m
.77504 .35763 L
s
.73296 .36491 m
.80723 .44858 L
s
.71641 .40271 m
.74422 .45091 L
s
1 0 0 r
.003 w
.48363 .52668 m
.48471 .52574 L
s
.45808 .54887 m
.48363 .52668 L
s
.20535 .35815 m .17141 .58449 L .20561 .35395 L .954 .729 .559 r
F
.20535 .35815 m .20613 .60269 L .17141 .58449 L F
.25 g
.5 Mabswid
.82279 .3158 m
.85175 .329 L
s
.7973 .30419 m
.82279 .3158 L
s
1 0 0 r
.003 w
.48471 .52574 m
.51648 .5155 L
s
.7712 .49767 m
.81973 .46267 L
s
.73977 .44877 m
.7532 .48578 L
s
.29632 .59355 m
.33743 .57171 L
s
.33743 .57171 m
.36722 .54453 L
s
.20586 .34707 m .15614 .50528 L .20658 .33712 L .854 .802 .312 r
F
.20413 .35946 m .15293 .55086 L .2051 .35002 L .999 .818 .485 r
F
.20561 .35395 m .17141 .58449 L .15293 .55086 L F
.20586 .34707 m .15293 .55086 L .15614 .50528 L .854 .802 .312 r
F
.20658 .33712 m .15614 .50528 L .18294 .4546 L 0 0 0 r
F
.20658 .33712 m .20624 .33881 L .20804 .32441 L F
.20624 .33881 m .18294 .4546 L .20733 .32807 L F
.20624 .33881 m .20733 .32807 L .20804 .32441 L F
.20561 .35395 m .20413 .35946 L .20586 .34707 L .999 .818 .485 r
F
.20413 .35946 m .2051 .35002 L .20586 .34707 L F
.25 g
.5 Mabswid
.20514 .35711 m
.20561 .35395 L
s
0 g
.006 w
.20535 .35815 m
.20561 .35395 L
s
.25 g
.5 Mabswid
.20536 .36326 m
.20551 .40955 L
s
.20535 .36082 m
.20536 .36326 L
s
.20535 .35815 m
.20535 .36082 L
s
0 g
.006 w
.20561 .35395 m
.20586 .34707 L
s
1 0 0 r
.003 w
.25019 .60508 m
.29632 .59355 L
s
.58919 .4744 m
.5961 .5002 L
s
.25 g
.5 Mabswid
.64174 .22953 m
.64177 .22971 L
s
.64105 .22471 m
.64174 .22953 L
s
.64769 .27103 m
.65126 .29597 L
s
.64184 .23023 m
.64769 .27103 L
s
.64177 .22971 m
.64184 .23023 L
s
1 0 0 r
.003 w
.36722 .54453 m
.38104 .5178 L
s
.25 g
.5 Mabswid
.15293 .55086 m
.1731 .47321 L
s
.2051 .35002 m
.20586 .34707 L
s
.20016 .36904 m
.2051 .35002 L
s
0 g
.006 w
.20586 .34707 m
.20658 .33712 L
s
.25 g
.5 Mabswid
.61462 .32145 m
.62356 .22753 L
s
.62356 .22753 m
.62357 .22746 L
s
.62357 .22746 m
.62429 .21996 L
s
1 0 0 r
.003 w
.22305 .61064 m
.22382 .59325 L
s
.22193 .63579 m
.22305 .61064 L
s
.22467 .6037 m
.25019 .60508 L
s
.20613 .60269 m
.22336 .60363 L
s
.58919 .4744 m
.60174 .4477 L
s
.25 g
.5 Mabswid
.61335 .23887 m
.61457 .22915 L
s
.61457 .22915 m
.61502 .22559 L
s
.59951 .34928 m
.61335 .23887 L
s
0 g
.006 w
.61817 .14536 m
.62095 .14943 L
s
1 0 0 r
.003 w
.81973 .46267 m
.85322 .41879 L
s
.70945 .425 m
.73977 .44877 L
s
.20804 .32441 m .22959 .40799 L .21013 .3097 L 0 0 .076 r
F
.20804 .32441 m .18294 .4546 L .22959 .40799 L F
.25 g
.5 Mabswid
.20756 .32689 m
.20804 .32441 L
s
.20733 .32807 m
.20756 .32689 L
s
.18294 .4546 m
.20733 .32807 L
s
.15614 .50528 m
.20381 .34636 L
s
.20558 .43198 m
.20613 .60269 L
s
.17141 .58449 m
.19202 .44553 L
s
1 0 0 r
.003 w
.37679 .49744 m
.38104 .5178 L
s
0 g
.006 w
.61242 .14008 m
.6149 .14235 L
s
.6149 .14235 m
.61581 .14319 L
s
.61581 .14319 m
.61668 .14399 L
s
.61668 .14399 m
.61817 .14536 L
s
.22371 .22909 m .3865 .41933 L .23013 .21553 L .42 .423 .757 r
F
.22371 .22909 m .26289 .26525 L .29215 .30171 L F
.29291 .30335 m .29215 .30171 L .29684 .30757 L F
.22371 .22909 m .29215 .30171 L .29291 .30335 L F
.28911 .30552 m .29684 .30757 L .3139 .33449 L F
.22371 .22909 m .28658 .29656 L .28911 .30552 L F
.28658 .29656 m .29684 .30757 L .28911 .30552 L F
.28841 .35938 m .35535 .43912 L .31742 .45035 L .72 .533 .637 r
F
.21954 .24443 m .28236 .29588 L .22371 .22909 L .134 .366 .824 r
F
.23688 .22433 m .29437 .29926 L .26289 .26525 L .587 .472 .689 r
F
.30151 .30856 m .3071 .31585 L .29635 .30695 L F
.3071 .31585 m .31403 .32488 L .29996 .31145 L F
.3071 .31585 m .29996 .31145 L .29635 .30695 L F
.29437 .29926 m .30151 .30856 L .29028 .29939 L F
.30151 .30856 m .29635 .30695 L .29028 .29939 L F
.29437 .29926 m .29028 .29939 L .26289 .26525 L F
.31403 .32488 m .3865 .41933 L .30159 .31348 L F
.31403 .32488 m .30159 .31348 L .29996 .31145 L F
.29723 .30806 m .40422 .39567 L .3865 .41933 L .42 .423 .757 r
F
.3139 .33449 m .29684 .30757 L .3865 .41933 L F
.21954 .24443 m .24797 .26438 L .26751 .28228 L .134 .366 .824 r
F
.22076 .24543 m .26751 .28228 L .28236 .29588 L F
.21954 .24443 m .26751 .28228 L .22076 .24543 L F
.28236 .29588 m .26289 .26525 L .22371 .22909 L F
.2466 .24494 m .3865 .41933 L .26751 .28228 L .587 .472 .689 r
F
.26751 .28228 m .3865 .41933 L .35535 .43912 L F
.23013 .21553 m .23688 .22433 L .2466 .24494 L F
.23688 .22433 m .26289 .26525 L .2466 .24494 L F
.23013 .21553 m .26751 .28228 L .23904 .20455 L F
.28236 .29588 m .40422 .39567 L .26289 .26525 L .134 .366 .824 r
F
.2919 .30369 m .4036 .37359 L .40422 .39567 L F
.28236 .29588 m .28791 .29944 L .2919 .30369 L F
.28791 .29944 m .4036 .37359 L .2919 .30369 L F
.26751 .28228 m .28404 .2953 L .23904 .20455 L .587 .472 .689 r
F
.26593 .25878 m .28404 .2953 L .25487 .24309 L .72 .533 .637 r
F
.28404 .2953 m .27767 .28851 L .24661 .22829 L F
.24797 .26438 m .26866 .2789 L .28236 .29588 L .134 .366 .824 r
F
.24661 .22829 m .27767 .28851 L .2597 .26934 L .72 .533 .637 r
F
.26751 .28228 m .28564 .31465 L .27253 .28623 L .587 .472 .689 r
F
.28564 .31465 m .35535 .43912 L .27253 .28623 L F
.26866 .2789 m .28791 .29944 L .28236 .29588 L .134 .366 .824 r
F
.27253 .28623 m .35535 .43912 L .28404 .2953 L .587 .472 .689 r
F
.21684 .26072 m .27525 .29602 L .21954 .24443 L 0 .219 .644 r
F
.27525 .29602 m .26866 .2789 L .21954 .24443 L F
.2597 .26934 m .28422 .30163 L .26645 .29052 L .72 .533 .637 r
F
.27735 .285 m .4036 .37359 L .28887 .30005 L .134 .366 .824 r
F
.27767 .28851 m .28454 .30183 L .2597 .26934 L .72 .533 .637 r
F
.28454 .30183 m .28489 .30251 L .28422 .30163 L F
.28454 .30183 m .28422 .30163 L .2597 .26934 L F
.23669 .27253 m .25704 .28463 L .25406 .28321 L 0 .219 .644 r
F
.25315 .23862 m .25487 .24309 L .24661 .22829 L .72 .533 .637 r
F
.26593 .25878 m .25487 .24309 L .25315 .23862 L F
.23904 .20455 m .26593 .25878 L .24661 .22829 L F
.23904 .20455 m .26645 .29052 L .25006 .19662 L F
.26866 .2789 m .27735 .285 L .28791 .29944 L .134 .366 .824 r
F
.27735 .285 m .28887 .30005 L .28791 .29944 L F
.28404 .2953 m .2891 .30551 L .27767 .28851 L .72 .533 .637 r
F
.2891 .30551 m .35535 .43912 L .28613 .30491 L F
.2891 .30551 m .28613 .30491 L .27767 .28851 L F
.27525 .29602 m .30693 .31517 L .26866 .2789 L 0 .219 .644 r
F
.30693 .31517 m .4036 .37359 L .33938 .32852 L F
.30693 .31517 m .33938 .32852 L .26866 .2789 L F
.26645 .29052 m .2675 .29115 L .26743 .29113 L F
.25704 .28463 m .26743 .29113 L .25406 .28321 L F
.28197 .30008 m .38212 .35903 L .4036 .37359 L F
.27525 .29602 m .28003 .29884 L .28197 .30008 L F
.28003 .29884 m .38212 .35903 L .28197 .30008 L F
.26645 .29052 m .27662 .29665 L .25508 .22536 L .72 .533 .637 r
F
.25424 .22054 m .25928 .23134 L .25006 .19662 L F
.25928 .23134 m .27662 .29665 L .2525 .21682 L .849 .618 .589 r
F
.25406 .28321 m .26743 .29113 L .27525 .29602 L 0 .219 .644 r
F
.27662 .29665 m .27428 .29515 L .2525 .21682 L .849 .618 .589 r
F
.26743 .29113 m .27491 .29556 L .27525 .29602 L 0 .219 .644 r
F
.27491 .29556 m .38212 .35903 L .28003 .29884 L F
.27491 .29556 m .28003 .29884 L .27525 .29602 L F
.26809 .27289 m .27428 .29515 L .26466 .27441 L .849 .618 .589 r
F
.27428 .29515 m .2675 .29082 L .25761 .2592 L F
.26843 .29141 m .27364 .2945 L .27491 .29556 L 0 .219 .644 r
F
.27364 .2945 m .38212 .35903 L .27746 .29707 L F
.27364 .2945 m .27746 .29707 L .27491 .29556 L F
.26809 .27289 m .26466 .27441 L .26279 .26597 L .849 .618 .589 r
F
.2525 .21682 m .26809 .27289 L .25761 .2592 L F
.25006 .19662 m .25928 .23134 L .2525 .21682 L F
.25321 .22267 m .26299 .23385 L .26244 .19158 L F
.36559 .35097 m .36236 .34728 L .26843 .29141 L .501 0 0 r
F
.26645 .29052 m .28489 .30251 L .28502 .30469 L .72 .533 .637 r
F
.27101 .30481 m .28502 .30469 L .28841 .35938 L F
.27 .30165 m .27756 .30318 L .27101 .30481 L F
.26645 .29052 m .28502 .30469 L .27 .30165 L F
.28422 .30163 m .28489 .30251 L .26645 .29052 L F
.26645 .29052 m .27101 .30481 L .27431 .29526 L F
.28489 .30251 m .35535 .43912 L .28841 .35938 L F
.27101 .30481 m .31742 .45035 L .27721 .30572 L F
.27756 .30318 m .28502 .30469 L .27101 .30481 L F
.27101 .30481 m .27721 .30572 L .27431 .29526 L F
.26422 .31401 m .31742 .45035 L .28055 .44942 L .849 .618 .589 r
F
.26309 .30463 m .26619 .31295 L .26422 .31401 L F
.26619 .31295 m .31742 .45035 L .26422 .31401 L F
.2672 .30482 m .31742 .45035 L .26309 .30463 L F
.25704 .28463 m .26843 .29141 L .2675 .29115 L 0 .219 .644 r
F
.25704 .28463 m .2675 .29115 L .26645 .29052 L F
.26843 .29141 m .27491 .29556 L .26743 .29113 L F
.21684 .26072 m .23669 .27253 L .25406 .28321 L F
.26858 .29211 m .26843 .29141 L .21684 .26072 L .501 0 0 r
F
.27144 .30502 m .31742 .45035 L .27891 .33874 L .849 .618 .589 r
F
.27021 .29947 m .27196 .30504 L .27144 .30502 L F
.27196 .30504 m .31742 .45035 L .27144 .30502 L F
.21468 .27732 m .27144 .30502 L .21684 .26072 L .501 0 0 r
F
.27428 .29515 m .27709 .30528 L .27021 .29947 L .849 .618 .589 r
F
.27709 .30528 m .31742 .45035 L .27196 .30504 L F
.27709 .30528 m .27196 .30504 L .27021 .29947 L F
.25199 .29801 m .26174 .30457 L .26068 .29977 L .501 0 0 r
F
.26161 .30396 m .2677 .30484 L .26068 .29977 L F
.26174 .30457 m .26309 .30463 L .26161 .30396 L F
.26309 .30463 m .2677 .30484 L .26161 .30396 L F
.27144 .30502 m .26858 .29211 L .21684 .26072 L F
.26068 .29977 m .2677 .30484 L .27144 .30502 L F
.27021 .29947 m .27891 .33874 L .26092 .2866 L .849 .618 .589 r
F
.2675 .29082 m .27021 .29947 L .26092 .2866 L F
.26092 .2866 m .2672 .30482 L .26309 .30463 L F
.26279 .26597 m .26466 .27441 L .25761 .2592 L F
.25761 .2592 m .2675 .29082 L .26092 .2866 L F
.25321 .22267 m .26309 .30463 L .26299 .23385 L F
.26309 .30463 m .26402 .31231 L .26392 .305 L F
.27029 .30825 m .27081 .31066 L .27062 .30803 L F
.26402 .31231 m .27018 .31081 L .27029 .30825 L F
.27018 .31081 m .27081 .31066 L .27029 .30825 L F
.26402 .31231 m .27062 .30803 L .26392 .305 L F
.26402 .31231 m .26422 .31401 L .27081 .31066 L F
.26422 .31401 m .28055 .44942 L .27113 .31527 L F
.26422 .31401 m .27113 .31527 L .27081 .31066 L F
.25885 .3169 m .25792 .32868 L .26601 .32047 L .413 0 .028 r
F
.24671 .31085 m .25262 .32026 L .25885 .3169 L F
.25262 .32026 m .25792 .32868 L .25885 .3169 L F
.23728 .31319 m .25345 .33321 L .24671 .31085 L F
.21013 .3097 m .25144 .34454 L .21246 .29379 L .241 0 .103 r
F
.25688 .33502 m .28055 .44942 L .25543 .43568 L .97 .728 .514 r
F
.25688 .33502 m .25543 .43568 L .25413 .40592 L F
.25784 .33334 m .28055 .44942 L .25688 .33502 L F
.26031 .32625 m .28055 .44942 L .25709 .32952 L F
.25821 .31658 m .26601 .32047 L .25876 .31438 L .413 0 .028 r
F
.26601 .32047 m .26494 .30935 L .2375 .29186 L F
.23523 .29459 m .2375 .29186 L .21468 .27732 L F
.26601 .32047 m .2375 .29186 L .23523 .29459 L F
.26954 .30828 m .27017 .31625 L .26541 .31423 L .97 .728 .514 r
F
.26954 .30828 m .26541 .31423 L .26494 .30935 L F
.27017 .31625 m .28055 .44942 L .26031 .32625 L F
.25821 .31658 m .25876 .31438 L .21468 .27732 L .413 0 .028 r
F
.27017 .31625 m .26031 .32625 L .25781 .31101 L .97 .728 .514 r
F
.27062 .30803 m .27113 .31527 L .27027 .30812 L F
.27113 .31527 m .28055 .44942 L .27017 .31625 L F
.27113 .31527 m .27017 .31625 L .26954 .30828 L F
.27001 .30818 m .27175 .30777 L .27099 .30722 L .501 0 0 r
F
.27113 .31527 m .26954 .30828 L .27027 .30812 L .97 .728 .514 r
F
.26883 .30933 m .27099 .30722 L .2677 .30484 L .501 0 0 r
F
.26843 .29141 m .27021 .29947 L .2675 .29082 L .849 .618 .589 r
F
.27662 .29665 m .31742 .45035 L .27428 .29515 L F
.2677 .30484 m .34099 .35783 L .27144 .30502 L .501 0 0 r
F
.26174 .30457 m .26786 .30868 L .2677 .30484 L F
.26786 .30868 m .26862 .3085 L .2677 .30484 L F
.27428 .29515 m .27021 .29947 L .26843 .29141 L .849 .618 .589 r
F
.27144 .30502 m .36559 .35097 L .26858 .29211 L .501 0 0 r
F
.36559 .35097 m .26843 .29141 L .26858 .29211 L F
.26392 .305 m .27062 .30803 L .26246 .19184 L .849 .618 .589 r
F
.26244 .19184 m .26246 .19184 L .26244 .19158 L F
.26392 .305 m .26246 .19184 L .26244 .19184 L F
.28859 .18629 m .28842 .18717 L .30196 .18329 L 0 0 0 r
F
.27027 .30812 m .26954 .30828 L .26818 .29085 L .97 .728 .514 r
F
.26601 .32047 m .34099 .35783 L .26494 .30935 L .413 0 .028 r
F
.28842 .18717 m .28122 .22444 L .30156 .1848 L 0 0 0 r
F
.26494 .30935 m .26541 .31423 L .25781 .31101 L .97 .728 .514 r
F
.25105 .33565 m .25492 .33985 L .25345 .33321 L .413 0 .028 r
F
.21246 .29379 m .25821 .31658 L .21468 .27732 L F
.252 .32839 m .25792 .32868 L .24671 .31085 L F
.25345 .33321 m .25709 .32952 L .252 .32839 L F
.25709 .32952 m .25792 .32868 L .252 .32839 L F
.25875 .31675 m .26031 .32625 L .25709 .32952 L .97 .728 .514 r
F
.26309 .30463 m .26392 .305 L .26299 .23385 L .849 .618 .589 r
F
.25709 .30435 m .26494 .30935 L .25935 .30445 L .501 0 0 r
F
.25709 .30435 m .25935 .30445 L .25577 .30132 L F
.26494 .30935 m .26786 .30868 L .25199 .29801 L F
.23849 .28894 m .25199 .29801 L .26068 .29977 L F
.26178 .20872 m .26954 .30828 L .25781 .31101 L .97 .728 .514 r
F
.26426 .21753 m .26948 .29172 L .26178 .20872 L F
.26948 .29172 m .26818 .29085 L .26178 .20872 L F
.26244 .19158 m .26426 .21753 L .26178 .20872 L F
.26244 .19158 m .25709 .32952 L .27542 .18859 L F
.25413 .40592 m .25543 .43568 L .25302 .43436 L F
.25709 .32952 m .25784 .33334 L .25688 .33502 L F
.25709 .32952 m .25302 .43436 L .26247 .33071 L F
.25144 .34454 m .2533 .3461 L .25105 .33565 L .241 0 .103 r
F
.2533 .3461 m .25679 .34905 L .25414 .34286 L F
.2533 .3461 m .25414 .34286 L .25105 .33565 L F
.25679 .34905 m .25699 .34209 L .25492 .33985 L F
.25414 .34286 m .25492 .33985 L .25105 .33565 L F
.25679 .34905 m .25492 .33985 L .25414 .34286 L F
.26244 .33076 m .26218 .33367 L .25699 .34209 L .959 .791 .348 r
F
.26218 .33367 m .25505 .4121 L .25679 .34905 L F
.26218 .33367 m .25679 .34905 L .25699 .34209 L F
.25144 .34454 m .22959 .40799 L .2379 .40304 L .241 0 .103 r
F
.25144 .34454 m .24331 .37963 L .24937 .37026 L F
.24331 .37963 m .24642 .37868 L .24937 .37026 L F
.2533 .3461 m .24937 .37026 L .25679 .34905 L F
.25144 .34454 m .24937 .37026 L .2533 .3461 L F
.25709 .32952 m .25867 .32987 L .25792 .32868 L .413 0 .028 r
F
.26247 .33071 m .25302 .43436 L .26244 .33076 L .959 .791 .348 r
F
.25792 .32868 m .28192 .36684 L .26601 .32047 L .413 0 .028 r
F
.28192 .36684 m .28648 .37409 L .28394 .36745 L F
.28192 .36684 m .28394 .36745 L .26601 .32047 L F
.25667 .3494 m .25302 .43436 L .25436 .35601 L .959 .791 .348 r
F
.25505 .4121 m .25302 .43436 L .25699 .34209 L F
.25345 .33321 m .2555 .33574 L .2561 .33152 L .413 0 .028 r
F
.25345 .33321 m .25867 .32987 L .25709 .32952 L F
.25492 .33985 m .2555 .33574 L .25345 .33321 L F
.25105 .33565 m .25345 .33321 L .22775 .30141 L F
.25493 .32294 m .25302 .43436 L .24237 .40525 L .959 .791 .348 r
F
.25679 .34905 m .24937 .37026 L .28648 .37409 L .241 0 .103 r
F
.24642 .37868 m .24237 .40525 L .24809 .37817 L .959 .791 .348 r
F
.24777 .38013 m .24237 .40525 L .24537 .39489 L 0 0 0 r
F
.24809 .37817 m .24237 .40525 L .24777 .38013 L F
.24937 .37026 m .2379 .40304 L .24471 .39898 L .241 0 .103 r
F
.24937 .37026 m .24471 .39898 L .28648 .37409 L F
.24642 .37868 m .24809 .37817 L .25234 .35803 L .959 .791 .348 r
F
.25709 .32952 m .26247 .33071 L .27542 .18859 L .97 .728 .514 r
F
.27527 .19026 m .26247 .33071 L .27531 .18933 L .959 .791 .348 r
F
.26247 .33071 m .26244 .33076 L .27531 .18933 L F
.2561 .33152 m .25967 .33652 L .25867 .32987 L .413 0 .028 r
F
.25699 .34209 m .25667 .3494 L .25451 .34724 L .959 .791 .348 r
F
.25667 .3494 m .25436 .35601 L .25451 .34724 L F
.2555 .33574 m .28648 .37409 L .2561 .33152 L .413 0 .028 r
F
.26396 .3141 m .26244 .33076 L .25493 .32294 L .959 .791 .348 r
F
.25967 .33652 m .26102 .33372 L .25867 .32987 L .413 0 .028 r
F
.28114 .36661 m .28192 .36684 L .25867 .32987 L F
.25492 .33985 m .25699 .34209 L .2555 .33574 L F
.25699 .34209 m .25835 .33927 L .2555 .33574 L F
.26244 .33076 m .25451 .34724 L .25493 .32294 L .959 .791 .348 r
F
.27531 .18933 m .26396 .3141 L .25493 .32294 L F
.25103 .35764 m .25234 .35803 L .28846 .18689 L F
.28846 .18689 m .28846 .18689 L .28859 .18629 L F
.25103 .35764 m .28846 .18689 L .28846 .18689 L F
.24642 .37868 m .25234 .35803 L .25103 .35764 L F
.25967 .33652 m .28114 .36661 L .26102 .33372 L .413 0 .028 r
F
.28114 .36661 m .28648 .37409 L .28192 .36684 L F
.27542 .18859 m .27527 .19026 L .27531 .18933 L .959 .791 .348 r
F
.27542 .18859 m .24969 .35724 L .28859 .18629 L F
.24969 .35724 m .24642 .37868 L .25103 .35764 L F
.24969 .35724 m .25103 .35764 L .28859 .18629 L F
.24331 .37963 m .2379 .40304 L .24642 .37868 L .241 0 .103 r
F
.25199 .36047 m .24777 .38013 L .24878 .3831 L 0 0 0 r
F
.24777 .38013 m .24537 .39489 L .24878 .3831 L F
.25234 .35803 m .24809 .37817 L .25199 .36047 L F
.24809 .37817 m .24777 .38013 L .25199 .36047 L F
.26176 .31337 m .25234 .35803 L .26381 .30545 L F
.25234 .35803 m .25199 .36047 L .26381 .30545 L F
.2768 .24214 m .26176 .31337 L .28122 .22444 L F
.26176 .31337 m .26381 .30545 L .28122 .22444 L F
.25679 .34905 m .28648 .37409 L .25699 .34209 L .241 0 .103 r
F
.25699 .34209 m .28648 .37409 L .25835 .33927 L .413 0 .028 r
F
.26948 .29172 m .27062 .30803 L .26818 .29085 L .97 .728 .514 r
F
.27062 .30803 m .27027 .30812 L .26818 .29085 L F
.27075 .27864 m .25199 .36047 L .25415 .36456 L 0 0 0 r
F
.28122 .22444 m .26381 .30545 L .27075 .27864 L F
.26381 .30545 m .25199 .36047 L .27075 .27864 L F
.25199 .36047 m .24878 .3831 L .25415 .36456 L F
.26786 .30868 m .26883 .30933 L .26862 .3085 L .501 0 0 r
F
.26494 .30935 m .34099 .35783 L .26786 .30868 L F
.28122 .22444 m .25415 .36456 L .29 .22863 L 0 0 0 r
F
.28122 .22444 m .29 .22863 L .30156 .1848 L F
.28842 .18717 m .30156 .1848 L .30196 .18329 L F
.26883 .30933 m .34099 .35783 L .27175 .30777 L .501 0 0 r
F
.26883 .30933 m .27175 .30777 L .27001 .30818 L F
.27144 .30502 m .34099 .35783 L .38212 .35903 L F
.26601 .32047 m .28648 .37409 L .34099 .35783 L .413 0 .028 r
F
.29903 .21777 m .25415 .36456 L .29054 .31749 L 0 0 .068 r
F
.30196 .18329 m .29 .22863 L .29903 .21777 L F
.29 .22863 m .25415 .36456 L .29903 .21777 L F
.28859 .18629 m .2768 .24214 L .28122 .22444 L 0 0 0 r
F
.21973 .30167 m .25105 .33565 L .22775 .30141 L .413 0 .028 r
F
.25144 .34454 m .25105 .33565 L .21246 .29379 L .241 0 .103 r
F
.2246 .3219 m .22826 .38507 L .25144 .34454 L F
.22826 .38507 m .22959 .40799 L .25144 .34454 L F
.2449 .29658 m .25709 .30435 L .25577 .30132 L .501 0 0 r
F
.24559 .29672 m .25577 .30132 L .25199 .29801 L F
.2449 .29658 m .25577 .30132 L .24559 .29672 L F
.22775 .30141 m .23728 .31319 L .24671 .31085 L .413 0 .028 r
F
.22759 .28554 m .2449 .29658 L .23849 .28894 L .501 0 0 r
F
.2449 .29658 m .25199 .29801 L .23849 .28894 L F
.21468 .27732 m .22759 .28554 L .23849 .28894 L F
.21246 .29379 m .21973 .30167 L .22775 .30141 L .413 0 .028 r
F
.36559 .35097 m .38212 .35903 L .36236 .34728 L .501 0 0 r
F
.25006 .19662 m .25321 .22267 L .26244 .19158 L .849 .618 .589 r
F
.21013 .3097 m .2131 .32469 L .2246 .3219 L .241 0 .103 r
F
.2131 .32469 m .22959 .40799 L .2246 .3219 L F
.25 g
.5 Mabswid
.21025 .31027 m
.21435 .331 L
s
.21013 .3097 m
.21025 .31027 L
s
.21435 .331 m
.22959 .40799 L
s
0 g
.006 w
.20804 .32441 m
.21013 .3097 L
s
.21013 .3097 m
.21246 .29379 L
s
1 0 0 r
.003 w
.60174 .4477 m
.63081 .42677 L
s
.25 g
.5 Mabswid
.21973 .30167 m
.24641 .33062 L
s
.21253 .29386 m
.21973 .30167 L
s
.21246 .29379 m
.21253 .29386 L
s
.27899 .36597 m
.28648 .37409 L
s
.26489 .35067 m
.27899 .36597 L
s
.25105 .33565 m
.25271 .33746 L
s
.24641 .33062 m
.25105 .33565 L
s
0 g
.006 w
.21246 .29379 m
.21468 .27732 L
s
.25 g
.5 Mabswid
.61242 .14008 m
.6125 .14103 L
s
.6125 .14103 m
.61256 .14173 L
s
.61256 .14173 m
.61261 .14235 L
s
.61261 .14235 m
.61265 .14283 L
s
.61265 .14283 m
.61293 .14639 L
s
0 g
.006 w
.60729 .13768 m
.61242 .14008 L
s
.25 g
.5 Mabswid
.24396 .29598 m
.25532 .30322 L
s
.22759 .28554 m
.24396 .29598 L
s
.21468 .27732 m
.22759 .28554 L
s
.30176 .33282 m
.34099 .35783 L
s
.2863 .32297 m
.30176 .33282 L
s
.25709 .30435 m
.2577 .30474 L
s
.25532 .30322 m
.25709 .30435 L
s
0 g
.006 w
.21468 .27732 m
.21684 .26072 L
s
1 0 0 r
.003 w
.17141 .58449 m
.20613 .60269 L
s
.66984 .41783 m
.70945 .425 L
s
.25 g
.5 Mabswid
.25704 .28463 m
.25879 .28567 L
s
.23669 .27253 m
.24364 .27666 L
s
.24364 .27666 m
.25704 .28463 L
s
.21684 .26072 m
.23669 .27253 L
s
.36236 .34728 m
.38212 .35903 L
s
.31991 .32203 m
.36236 .34728 L
s
0 g
.006 w
.21684 .26072 m
.21954 .24443 L
s
1 0 0 r
.003 w
.22382 .59325 m
.24588 .55072 L
s
.25 g
.5 Mabswid
.21954 .24443 m
.22054 .24513 L
s
.24797 .26438 m
.2488 .26497 L
s
.2488 .26497 m
.25919 .27225 L
s
.22054 .24513 m
.24797 .26438 L
s
.29241 .29556 m
.30976 .30774 L
s
0 g
.006 w
.21954 .24443 m
.22371 .22909 L
s
.25 g
.5 Mabswid
.60729 .13768 m
.60751 .1385 L
s
.60751 .1385 m
.60805 .14061 L
s
.60805 .14061 m
.60824 .14133 L
s
.60824 .14133 m
.60918 .14497 L
s
0 g
.006 w
.60299 .13716 m
.60729 .13768 L
s
1 0 0 r
.003 w
.63081 .42677 m
.66984 .41783 L
s
.35543 .48851 m
.37679 .49744 L
s
.25 g
.5 Mabswid
.22371 .22909 m
.2263 .23148 L
s
.2263 .23148 m
.25272 .25586 L
s
.29265 .29271 m
.30634 .30534 L
s
0 g
.006 w
.22371 .22909 m
.23013 .21553 L
s
.23013 .21553 m
.23904 .20455 L
s
.25 g
.5 Mabswid
.60299 .13716 m
.60425 .13974 L
s
.60425 .13974 m
.60468 .14063 L
s
.60468 .14063 m
.60624 .14385 L
s
0 g
.006 w
.59908 .13722 m
.60299 .13716 L
s
1 0 0 r
.003 w
.85322 .41879 m
.86493 .37195 L
s
.25 g
.5 Mabswid
.31839 .36457 m
.35535 .43912 L
s
0 g
.006 w
.23904 .20455 m
.25006 .19662 L
s
1 0 0 r
.003 w
.32123 .49438 m
.35543 .48851 L
s
.24588 .55072 m
.28153 .5159 L
s
.25 g
.5 Mabswid
.59908 .13722 m
.60036 .13886 L
s
.60036 .13886 m
.60126 .14002 L
s
.60126 .14002 m
.60341 .14278 L
s
0 g
.006 w
.59456 .13679 m
.59908 .13722 L
s
.25 g
.5 Mabswid
.29639 .37113 m
.31742 .45035 L
s
0 g
.006 w
.25006 .19662 m
.26244 .19158 L
s
1 0 0 r
.003 w
.15293 .55086 m
.17141 .58449 L
s
.28153 .5159 m
.32123 .49438 L
s
.25 g
.5 Mabswid
.59456 .13679 m
.59558 .13767 L
s
.59558 .13767 m
.59743 .13927 L
s
.59743 .13927 m
.60002 .14149 L
s
0 g
.006 w
.58823 .13534 m
.59456 .13679 L
s
.25 g
.5 Mabswid
.27571 .3805 m
.28055 .44942 L
s
0 g
.006 w
.26244 .19158 m
.27542 .18859 L
s
1 0 0 r
.003 w
.63246 .38636 m
.67193 .38728 L
s
.67193 .38728 m
.71798 .374 L
s
.25 g
.5 Mabswid
.58994 .13637 m
.59353 .13852 L
s
.59353 .13852 m
.59586 .13991 L
s
.58823 .13534 m
.58919 .13592 L
s
.58919 .13592 m
.58994 .13637 L
s
0 g
.006 w
.57924 .13275 m
.58823 .13534 L
s
.25 g
.5 Mabswid
.25302 .43436 m
.25504 .41216 L
s
.25504 .41216 m
.25691 .39171 L
s
0 g
.006 w
.27542 .18859 m
.28859 .18629 L
s
1 0 0 r
.003 w
.6065 .37262 m
.63246 .38636 L
s
.25 g
.5 Mabswid
.58172 .13385 m
.59287 .13878 L
s
.57924 .13275 m
.58081 .13345 L
s
.58081 .13345 m
.58172 .13385 L
s
0 g
.006 w
.56742 .12912 m
.57924 .13275 L
s
1 0 0 r
.003 w
.71798 .374 m
.7623 .3471 L
s
.25 g
.5 Mabswid
.25234 .35803 m
.26176 .31337 L
s
.24809 .37817 m
.25234 .35803 L
s
.24237 .40525 m
.24355 .39967 L
s
.26176 .31337 m
.26704 .2884 L
s
.27508 .25027 m
.27552 .2482 L
s
.26704 .2884 m
.27508 .25027 L
s
.27552 .2482 m
.28859 .18629 L
s
1 0 0 r
.003 w
.85175 .329 m
.86493 .37195 L
s
.59951 .34928 m
.6065 .37262 L
s
.31742 .45035 m
.35535 .43912 L
s
.35535 .43912 m
.3865 .41933 L
s
.42737 .09369 m .43806 .14163 L .44239 .08939 L .721 .539 .643 r
F
.43806 .14163 m .48438 .34948 L .45036 .13878 L F
.43806 .14163 m .45036 .13878 L .44239 .08939 L F
.42737 .09369 m .52082 .34548 L .48438 .34948 L F
.414 .10127 m .46172 .21036 L .42737 .09369 L .585 .475 .695 r
F
.46172 .21036 m .45518 .16861 L .42737 .09369 L F
.414 .10127 m .44636 .15274 L .45797 .19629 L F
.414 .10127 m .45797 .19629 L .45724 .20014 L F
.45036 .13878 m .4581 .18671 L .446 .14471 L .886 .65 .575 r
F
.4581 .18671 m .45665 .18595 L .446 .14471 L F
.46019 .19963 m .45928 .19865 L .45154 .1672 L F
.45181 .1672 m .45154 .1672 L .446 .14471 L F
.46019 .19963 m .45154 .1672 L .45181 .1672 L F
.46146 .20749 m .46092 .20658 L .446 .14471 L F
.46209 .21144 m .46193 .21102 L .446 .14471 L F
.40238 .11104 m .44734 .17435 L .414 .10127 L .454 .438 .751 r
F
.44734 .17435 m .44636 .15274 L .414 .10127 L F
.40238 .11104 m .40458 .11335 L .44734 .17435 L F
.40458 .11335 m .4363 .1466 L .44699 .17346 L F
.40458 .11335 m .44699 .17346 L .44734 .17435 L F
.4581 .18671 m .46019 .19963 L .45665 .18595 L .886 .65 .575 r
F
.45724 .20014 m .45797 .19629 L .46006 .20415 L .585 .475 .695 r
F
.46026 .20704 m .46006 .20415 L .46172 .21036 L F
.45724 .20014 m .46006 .20415 L .46026 .20704 L F
.46223 .21228 m .48438 .34948 L .44972 .16532 L .886 .65 .575 r
F
.46223 .21228 m .44972 .16532 L .44524 .14156 L F
.46019 .19963 m .46146 .20749 L .45928 .19865 L F
.46146 .20749 m .46209 .21144 L .46092 .20658 L F
.46172 .21036 m .52082 .34548 L .45518 .16861 L .585 .475 .695 r
F
.44524 .14156 m .47918 .32189 L .4561 .34009 L .886 .65 .575 r
F
.47441 .09362 m .4668 .14932 L .47456 .0926 L 0 0 .035 r
F
.45797 .19629 m .50107 .23973 L .46172 .21036 L .585 .475 .695 r
F
.4616 .17697 m .50107 .23973 L .45797 .19629 L F
.44636 .15274 m .4616 .17697 L .45797 .19629 L F
.44722 .17174 m .44875 .16042 L .44636 .15274 L .454 .438 .751 r
F
.44734 .17435 m .44875 .16042 L .44722 .17174 L F
.44734 .17435 m .45754 .1887 L .44875 .16042 L F
.45754 .1887 m .45774 .17083 L .44636 .15274 L F
.44572 .15034 m .44699 .17346 L .44932 .15615 L .886 .65 .575 r
F
.44699 .17346 m .45395 .18333 L .4584 .0889 L F
.50107 .23973 m .5573 .32916 L .55353 .32448 L .585 .475 .695 r
F
.50107 .23973 m .55353 .32448 L .46172 .21036 L F
.45754 .1887 m .5573 .32916 L .45774 .17083 L .454 .438 .751 r
F
.4363 .1466 m .45425 .16541 L .44734 .17435 L F
.45395 .18333 m .45749 .18834 L .4584 .0889 L .886 .65 .575 r
F
.45425 .16541 m .45554 .17457 L .44762 .17435 L .454 .438 .751 r
F
.44748 .17416 m .44762 .17435 L .44734 .17435 L F
.45425 .16541 m .44762 .17435 L .44748 .17416 L F
.45941 .19134 m .54068 .26331 L .5573 .32916 L F
.54068 .26331 m .58572 .30319 L .57962 .30877 L F
.54068 .26331 m .57962 .30877 L .5573 .32916 L F
.45766 .16961 m .45749 .18834 L .45552 .14064 L .989 .77 .381 r
F
.45557 .13968 m .45552 .14064 L .45535 .13653 L F
.45766 .16961 m .45552 .14064 L .45557 .13968 L F
.45749 .18834 m .45549 .17421 L .45535 .13653 L F
.46318 .17477 m .46049 .18659 L .44734 .17435 L .454 .438 .751 r
F
.39193 .12184 m .45353 .17948 L .40238 .11104 L .298 .418 .816 r
F
.44734 .17435 m .45675 .18311 L .45754 .1887 L .454 .438 .751 r
F
.45098 .24644 m .45733 .20498 L .45749 .18834 L .886 .65 .575 r
F
.45098 .24644 m .45749 .18834 L .45395 .18333 L F
.45749 .18834 m .45743 .19482 L .45549 .17421 L .989 .77 .381 r
F
.45098 .24644 m .4561 .34009 L .45733 .20498 L .886 .65 .575 r
F
.45743 .19482 m .4561 .34009 L .45554 .18739 L .989 .77 .381 r
F
.45743 .19482 m .45554 .18739 L .45549 .17421 L F
.45353 .17948 m .45425 .16541 L .40238 .11104 L .298 .418 .816 r
F
.43455 .16172 m .44506 .16881 L .45353 .17948 L F
.44506 .16881 m .452 .17349 L .45279 .1766 L F
.44506 .16881 m .45279 .1766 L .45353 .17948 L F
.44699 .17346 m .45098 .24644 L .45395 .18333 L .886 .65 .575 r
F
.45279 .1766 m .45411 .1873 L .45234 .18371 L .989 .77 .381 r
F
.45374 .1618 m .45402 .18143 L .45279 .1766 L F
.45402 .18143 m .45411 .1873 L .45279 .1766 L F
.42546 .14626 m .44954 .1638 L .43455 .16172 L .298 .418 .816 r
F
.45535 .13653 m .45549 .17421 L .45374 .1618 L .989 .77 .381 r
F
.45549 .17421 m .45553 .18476 L .45374 .1618 L F
.45553 .18476 m .45406 .18381 L .45374 .1618 L F
.4584 .0889 m .45766 .16961 L .45535 .13653 L F
.45425 .16541 m .46318 .17477 L .45554 .17457 L .454 .438 .751 r
F
.46162 .18163 m .58572 .30319 L .46049 .18659 L F
.46318 .17477 m .46553 .17724 L .46162 .18163 L F
.46553 .17724 m .58572 .30319 L .46162 .18163 L F
.45353 .17948 m .46206 .18747 L .45425 .16541 L .298 .418 .816 r
F
.46206 .18747 m .48357 .2076 L .46453 .1802 L F
.46206 .18747 m .46453 .1802 L .45425 .16541 L F
.48357 .2076 m .4795 .19187 L .45425 .16541 L F
.45374 .1618 m .45279 .1766 L .46354 .17323 L .989 .77 .381 r
F
.45279 .1766 m .46183 .1857 L .46354 .17323 L F
.46502 .17508 m .47283 .18076 L .46422 .17776 L .298 .418 .816 r
F
.47283 .18076 m .4676 .18401 L .46323 .18106 L F
.46567 .16389 m .46322 .18107 L .46719 .1582 L 0 0 .035 r
F
.46748 .15591 m .46719 .1582 L .46791 .15402 L F
.46567 .16389 m .46719 .1582 L .46748 .15591 L F
.47283 .18076 m .46323 .18106 L .46422 .17776 L .298 .418 .816 r
F
.46323 .18106 m .4676 .18401 L .46147 .18691 L F
.48357 .2076 m .58572 .30319 L .4795 .19187 L F
.47463 .09199 m .46598 .1719 L .49063 .09774 L 0 0 .035 r
F
.4676 .18401 m .51261 .21436 L .4622 .18737 L .298 .418 .816 r
F
.51261 .21436 m .52793 .22831 L .4622 .18737 L F
.4676 .18401 m .4622 .18737 L .46147 .18691 L F
.51261 .21436 m .59817 .27206 L .52793 .22831 L F
.47283 .18076 m .59817 .27206 L .4676 .18401 L F
.46368 .18556 m .46566 .18684 L .46502 .17508 L .07 .398 .855 r
F
.46566 .18684 m .59817 .27206 L .47094 .17938 L F
.46566 .18684 m .47094 .17938 L .46502 .17508 L F
.46598 .1719 m .46472 .18349 L .47454 .1797 L 0 0 .035 r
F
.47016 .18973 m .47483 .191 L .49218 .20389 L .07 .398 .855 r
F
.46566 .18684 m .47158 .18952 L .47016 .18973 L F
.47158 .18952 m .47483 .191 L .47016 .18973 L F
.47454 .1797 m .47264 .18937 L .4834 .17418 L 0 0 .214 r
F
.47483 .191 m .53085 .21645 L .49218 .20389 L .07 .398 .855 r
F
.53085 .21645 m .58797 .24239 L .54057 .22334 L F
.53085 .21645 m .54057 .22334 L .49218 .20389 L F
.49063 .09774 m .48927 .18695 L .50639 .10486 L 0 0 .214 r
F
.49218 .20389 m .58797 .24239 L .59817 .27206 L .07 .398 .855 r
F
.47264 .18937 m .47963 .18835 L .4834 .17418 L 0 0 .214 r
F
.46472 .18349 m .47264 .18937 L .47454 .1797 L 0 0 .035 r
F
.47451 .1882 m .47594 .18889 L .46566 .18684 L .07 .398 .855 r
F
.47594 .18889 m .58797 .24239 L .47158 .18952 L F
.47594 .18889 m .47158 .18952 L .46566 .18684 L F
.46322 .18107 m .46235 .1872 L .46461 .17646 L 0 0 .035 r
F
.46235 .1872 m .46286 .18719 L .46461 .17646 L F
.46286 .18719 m .46303 .18718 L .4631 .18671 L F
.46286 .18719 m .4631 .18671 L .46461 .17646 L F
.46461 .17646 m .4631 .18671 L .46598 .1719 L F
.4631 .18671 m .464 .18493 L .46598 .1719 L F
.44954 .1638 m .452 .17349 L .43455 .16172 L .298 .418 .816 r
F
.45553 .18476 m .45602 .32017 L .45406 .18381 L .989 .77 .381 r
F
.45234 .18371 m .45602 .32017 L .44376 .31806 L F
.45411 .1873 m .45602 .32017 L .45234 .18371 L F
.46322 .18107 m .46461 .17646 L .46791 .15402 L 0 0 .035 r
F
.46354 .17323 m .46183 .1857 L .46355 .17318 L F
.46183 .1857 m .46185 .18564 L .46685 .14907 L F
.45675 .18311 m .46049 .18659 L .45754 .1887 L .454 .438 .751 r
F
.46049 .18659 m .58572 .30319 L .45959 .19054 L F
.46049 .18659 m .45959 .19054 L .45754 .1887 L F
.46685 .14907 m .46356 .17311 L .47062 .129 L 0 0 .035 r
F
.46147 .18691 m .59817 .27206 L .58572 .30319 L .298 .418 .816 r
F
.46356 .17311 m .46119 .19051 L .46446 .16919 L 0 0 .035 r
F
.46356 .17311 m .46446 .16919 L .47062 .129 L F
.45959 .19054 m .58572 .30319 L .45941 .19134 L .454 .438 .751 r
F
.46119 .19051 m .44376 .31806 L .46216 .18858 L 0 0 .035 r
F
.46169 .18722 m .46235 .1872 L .47062 .129 L F
.45766 .18015 m .46323 .18106 L .46277 .1826 L .298 .418 .816 r
F
.45766 .18015 m .46277 .1826 L .46147 .18691 L F
.45353 .17948 m .45766 .18015 L .46147 .18691 L F
.452 .17349 m .46323 .18106 L .45353 .17948 L F
.45279 .1766 m .45234 .18371 L .46183 .1857 L .989 .77 .381 r
F
.45754 .1887 m .45959 .19054 L .45941 .19134 L .454 .438 .751 r
F
.45234 .18371 m .44376 .31806 L .46117 .19053 L .989 .77 .381 r
F
.45234 .18371 m .46117 .19053 L .46183 .1857 L F
.39193 .12184 m .42546 .14626 L .43455 .16172 L .298 .418 .816 r
F
.4484 .17574 m .46368 .18556 L .39193 .12184 L .07 .398 .855 r
F
.46422 .17776 m .46323 .18106 L .452 .17349 L .298 .418 .816 r
F
.46791 .15402 m .46461 .17646 L .46598 .1719 L 0 0 .035 r
F
.44954 .1638 m .46502 .17508 L .452 .17349 L .298 .418 .816 r
F
.46502 .17508 m .46422 .17776 L .452 .17349 L F
.46368 .18556 m .46502 .17508 L .39193 .12184 L .07 .398 .855 r
F
.46368 .18556 m .47451 .1882 L .46566 .18684 L F
.46471 .18352 m .47451 .1882 L .46368 .18556 L F
.4795 .18837 m .47451 .1882 L .46471 .18352 L F
.483 .18952 m .47749 .18866 L .4795 .18837 L F
.47749 .18866 m .47451 .1882 L .4795 .18837 L F
.4834 .17418 m .47963 .18835 L .48857 .17209 L 0 0 .214 r
F
.47963 .18835 m .48078 .18818 L .48952 .17036 L F
.483 .18952 m .46471 .18352 L .46525 .18244 L .07 .398 .855 r
F
.466 .18095 m .483 .18952 L .46525 .18244 L F
.483 .18952 m .58797 .24239 L .47451 .1882 L F
.46472 .18349 m .46415 .18715 L .46433 .18714 L 0 0 .035 r
F
.46598 .1719 m .464 .18493 L .46472 .18349 L F
.464 .18493 m .44376 .31806 L .46472 .18349 L F
.38161 .13278 m .4484 .17574 L .39193 .12184 L .07 .398 .855 r
F
.41383 .14989 m .46733 .17831 L .42222 .1589 L F
.46733 .17831 m .466 .18095 L .42222 .1589 L F
.4785 .19261 m .47837 .19309 L .47859 .19265 L 0 0 .214 r
F
.48952 .17036 m .48078 .18818 L .48927 .18695 L F
.46733 .17831 m .58797 .24239 L .466 .18095 L .07 .398 .855 r
F
.4785 .19261 m .47859 .19265 L .48078 .18818 L 0 0 .214 r
F
.47963 .18835 m .4785 .19261 L .48078 .18818 L F
.4484 .17574 m .46471 .18352 L .46368 .18556 L .07 .398 .855 r
F
.4631 .18671 m .44376 .31806 L .464 .18493 L 0 0 .035 r
F
.46525 .18244 m .46471 .18352 L .4484 .17574 L .07 .398 .855 r
F
.44601 .17088 m .466 .18095 L .4484 .17574 L F
.466 .18095 m .46525 .18244 L .4484 .17574 L F
.48309 .19469 m .58797 .24239 L .48481 .1876 L 0 .324 .708 r
F
.48927 .18695 m .47837 .19309 L .48912 .19675 L 0 0 .214 r
F
.48078 .18818 m .47837 .19309 L .48927 .18695 L F
.47264 .18937 m .47231 .19103 L .47963 .18835 L F
.46172 .21036 m .5573 .32916 L .52082 .34548 L .585 .475 .695 r
F
.47231 .19103 m .45357 .28646 L .47837 .19309 L 0 0 .214 r
F
.47231 .19103 m .47837 .19309 L .47963 .18835 L F
.46472 .18349 m .46433 .18714 L .47264 .18937 L 0 0 .035 r
F
.46209 .21144 m .46223 .21228 L .46193 .21102 L .886 .65 .575 r
F
.46433 .18714 m .45357 .28646 L .47231 .19103 L 0 0 .035 r
F
.46433 .18714 m .47231 .19103 L .47264 .18937 L F
.42222 .1589 m .44601 .17088 L .4484 .17574 L .07 .398 .855 r
F
.38161 .13278 m .41383 .14989 L .42222 .1589 L F
.37044 .14347 m .48309 .19469 L .38161 .13278 L 0 .324 .708 r
F
.40095 .15673 m .40887 .16017 L .4097 .16132 L F
.48309 .19469 m .48481 .1876 L .38161 .13278 L F
.40887 .16017 m .47047 .18695 L .42123 .16618 L F
.40887 .16017 m .42123 .16618 L .4097 .16132 L F
.49565 .19147 m .49466 .19944 L .49908 .192 L .216 0 .208 r
F
.51065 .20723 m .55192 .22236 L .58797 .24239 L 0 .324 .708 r
F
.48677 .19637 m .49547 .19984 L .51065 .20723 L F
.49547 .19984 m .55192 .22236 L .51065 .20723 L F
.48927 .18695 m .48912 .19675 L .49565 .19147 L 0 0 .214 r
F
.48912 .19675 m .49466 .19944 L .49565 .19147 L F
.49466 .19944 m .49751 .20056 L .49908 .192 L .216 0 .208 r
F
.53869 .19812 m .49751 .20056 L .53934 .21571 L F
.54283 .21008 m .53934 .21571 L .54556 .21796 L F
.53869 .19812 m .53934 .21571 L .54283 .21008 L F
.49908 .192 m .49751 .20056 L .53869 .19812 L F
.49751 .20056 m .54418 .21875 L .54556 .21796 L F
.48309 .19469 m .50291 .20266 L .48677 .19637 L 0 .324 .708 r
F
.50291 .20266 m .55192 .22236 L .48677 .19637 L F
.49985 .2004 m .55192 .22236 L .48309 .19469 L F
.48912 .19675 m .4883 .25074 L .49466 .19944 L 0 0 .214 r
F
.49466 .19944 m .4883 .25074 L .49751 .20056 L .216 0 .208 r
F
.46949 .18698 m .50425 .2019 L .46813 .18702 L 0 .324 .708 r
F
.50425 .2019 m .49985 .2004 L .46813 .18702 L F
.43814 .17353 m .46949 .18698 L .44194 .17598 L F
.46949 .18698 m .46813 .18702 L .44194 .17598 L F
.46433 .18714 m .44376 .31806 L .45357 .28646 L 0 0 .035 r
F
.46415 .18715 m .44376 .31806 L .46433 .18714 L F
.47047 .18695 m .46949 .18698 L .4097 .16132 L 0 .324 .708 r
F
.46119 .19051 m .46216 .18858 L .46235 .1872 L 0 0 .035 r
F
.46119 .19051 m .46235 .1872 L .46169 .18722 L F
.53876 .21664 m .55192 .22236 L .5369 .21592 L 0 .324 .708 r
F
.50425 .2019 m .55192 .22236 L .49985 .2004 L F
.53821 .21751 m .55192 .22236 L .53876 .21664 L .39 0 0 r
F
.49751 .20056 m .4883 .25074 L .5422 .21989 L .216 0 .208 r
F
.53821 .21751 m .54583 .22205 L .55192 .22236 L .39 0 0 r
F
.53294 .21437 m .5422 .21989 L .54418 .21875 L .216 0 .208 r
F
.49751 .20056 m .5422 .21989 L .53294 .21437 L F
.46235 .1872 m .44376 .31806 L .46303 .18718 L 0 0 .035 r
F
.48912 .19675 m .45357 .28646 L .4883 .25074 L 0 0 .214 r
F
.47837 .19309 m .45357 .28646 L .48912 .19675 L F
.46183 .1857 m .44376 .31806 L .46185 .18564 L 0 0 .035 r
F
.39614 .16725 m .49292 .21934 L .54583 .22205 L .39 0 0 r
F
.39614 .16725 m .54583 .22205 L .53821 .21751 L F
.46634 .18708 m .49985 .2004 L .48309 .19469 L 0 .324 .708 r
F
.44194 .17598 m .46813 .18702 L .46634 .18708 L F
.46813 .18702 m .49985 .2004 L .46634 .18708 L F
.4097 .16132 m .43814 .17353 L .44194 .17598 L F
.37044 .14347 m .40095 .15673 L .4097 .16132 L F
.35792 .15373 m .53821 .21751 L .37044 .14347 L .39 0 0 r
F
.47047 .18695 m .53876 .21664 L .46949 .18698 L 0 .324 .708 r
F
.53876 .21664 m .5369 .21592 L .46949 .18698 L F
.53821 .21751 m .53876 .21664 L .37044 .14347 L .39 0 0 r
F
.4889 .17075 m .48857 .17209 L .48952 .17036 L 0 0 .214 r
F
.4834 .17418 m .48857 .17209 L .4889 .17075 L F
.50271 .13449 m .49565 .19147 L .51207 .12127 L .216 0 .208 r
F
.49565 .19147 m .49908 .192 L .51207 .12127 L F
.48927 .18695 m .49565 .19147 L .50639 .10486 L 0 0 .214 r
F
.51207 .12127 m .49908 .192 L .53869 .19812 L .216 0 .208 r
F
.50639 .10486 m .50271 .13449 L .51207 .12127 L F
.46598 .1719 m .47454 .1797 L .49063 .09774 L 0 0 .035 r
F
.4777 .16357 m .47454 .1797 L .48983 .14994 L 0 0 .214 r
F
.47454 .1797 m .4834 .17418 L .48983 .14994 L F
.48983 .14994 m .4834 .17418 L .48952 .17036 L F
.49063 .09774 m .4777 .16357 L .48983 .14994 L F
.4584 .0889 m .45374 .1618 L .47463 .09199 L .989 .77 .381 r
F
.45374 .1618 m .46354 .17323 L .47463 .09199 L F
.47062 .129 m .46567 .16389 L .46791 .15402 L 0 0 .035 r
F
.4668 .14932 m .46354 .17323 L .46685 .14907 L F
.46354 .17323 m .46355 .17318 L .46685 .14907 L F
.4668 .14932 m .46685 .14907 L .47456 .0926 L F
.44584 .14123 m .446 .14471 L .44524 .14156 L .886 .65 .575 r
F
.45036 .13878 m .446 .14471 L .44584 .14123 L F
.44239 .08939 m .45036 .13878 L .44524 .14156 L F
.44239 .08939 m .44572 .15034 L .4584 .0889 L F
.44572 .15034 m .44932 .15615 L .4584 .0889 L F
.35792 .15373 m .38575 .16726 L .39614 .16725 L .39 0 0 r
F
.38575 .16726 m .49292 .21934 L .39614 .16725 L F
.45602 .32017 m .4561 .34009 L .4558 .33956 L .989 .77 .381 r
F
.45602 .32017 m .4558 .33956 L .44376 .31806 L F
.47456 .0926 m .46685 .14907 L .47062 .129 L 0 0 .035 r
F
.47918 .32189 m .48438 .34948 L .48346 .34918 L .886 .65 .575 r
F
.47918 .32189 m .48346 .34918 L .4561 .34009 L F
.38025 .17691 m .42064 .23668 L .49292 .21934 L .354 0 0 r
F
.34429 .16337 m .36629 .1845 L .38025 .17691 L F
.36629 .1845 m .42064 .23668 L .38025 .17691 L F
.34422 .16334 m .34425 .16337 L .34429 .16337 L F
.34425 .16337 m .42064 .23668 L .34429 .16337 L F
.47463 .09199 m .47441 .09362 L .47456 .0926 L 0 0 .035 r
F
.25 g
.5 Mabswid
.44376 .31806 m
.45603 .22819 L
s
.4668 .14932 m
.47441 .09362 L
s
.47441 .09362 m
.47463 .09199 L
s
0 g
.006 w
.47463 .09199 m
.49063 .09774 L
s
.4584 .0889 m
.47463 .09199 L
s
.25 g
.5 Mabswid
.4561 .34009 m
.45662 .28333 L
s
0 g
.006 w
.44239 .08939 m
.4584 .0889 L
s
.25 g
.5 Mabswid
.45357 .28646 m
.46546 .22593 L
s
.48248 .13922 m
.4904 .0989 L
s
.4904 .0989 m
.49063 .09774 L
s
.25858 .34778 m
.27359 .29087 L
s
.25415 .36456 m
.25858 .34778 L
s
.27359 .29087 m
.28654 .24177 L
s
.30196 .18329 m .29054 .31749 L .31573 .17856 L 0 0 .068 r
F
0 g
.006 w
.28859 .18629 m
.30196 .18329 L
s
.25 g
.5 Mabswid
.47127 .26826 m
.48438 .34948 L
s
0 g
.006 w
.42737 .09369 m
.44239 .08939 L
s
.25 g
.5 Mabswid
.4883 .25074 m
.49217 .21952 L
s
.49557 .1921 m
.49565 .19147 L
s
.49489 .19757 m
.49557 .1921 L
s
.49565 .19147 m
.49687 .18162 L
s
.49687 .18162 m
.49746 .17683 L
s
.49746 .17683 m
.49978 .15812 L
s
.49978 .15812 m
.50264 .13506 L
s
.50639 .10486 m .54556 .21796 L .52213 .11217 L .216 0 .208 r
F
.25 g
.50264 .13506 m
.50639 .10486 L
s
0 g
.006 w
.49063 .09774 m
.50639 .10486 L
s
.55332 .12449 m .69165 .18862 L .75472 .20021 L .366 0 0 r
F
0 g
.55332 .12449 m
.56742 .12912 L
s
.25 g
.5 Mabswid
.56742 .12912 m
.57196 .13084 L
s
.52213 .11217 m .61742 .19536 L .53792 .11883 L .348 0 .11 r
F
.52213 .11217 m .54556 .21796 L .61742 .19536 L F
0 g
.006 w
.50639 .10486 m
.52213 .11217 L
s
.25 g
.5 Mabswid
.52213 .11217 m
.52233 .1131 L
s
.53196 .15655 m
.53676 .17822 L
s
.52714 .13478 m
.53196 .15655 L
s
.52233 .1131 m
.52714 .13478 L
s
.54159 .20001 m
.54421 .21187 L
s
.54421 .21187 m
.54556 .21796 L
s
.42737 .09369 m
.42918 .09854 L
s
.42918 .09854 m
.44526 .14188 L
s
0 g
.006 w
.414 .10127 m
.42737 .09369 L
s
.53792 .11883 m .61742 .19536 L .69165 .18862 L .413 0 0 r
F
.25 g
.5 Mabswid
.53792 .11883 m
.55184 .13223 L
s
.55184 .13223 m
.58404 .16322 L
s
.58404 .16322 m
.61742 .19536 L
s
0 g
.006 w
.52213 .11217 m
.53792 .11883 L
s
.25 g
.5 Mabswid
.53676 .17822 m
.54159 .20001 L
s
0 g
.006 w
.53792 .11883 m
.55332 .12449 L
s
.25 g
.5 Mabswid
.57382 .13155 m
.59095 .13805 L
s
.59095 .13805 m
.63553 .15497 L
s
.57196 .13084 m
.57382 .13155 L
s
.56513 .12996 m
.66628 .17685 L
s
.55332 .12449 m
.56513 .12996 L
s
.63553 .15497 m
.75472 .20021 L
s
.66628 .17685 m
.69165 .18862 L
s
1 0 0 r
.003 w
.28055 .44942 m
.31742 .45035 L
s
.25 g
.5 Mabswid
.414 .10127 m
.41518 .10315 L
s
.41518 .10315 m
.44581 .15185 L
s
.33938 .32852 m
.4036 .37359 L
s
0 g
.006 w
.40238 .11104 m
.414 .10127 L
s
.25 g
.5 Mabswid
.40238 .11104 m
.40256 .11124 L
s
.40256 .11124 m
.4363 .1466 L
s
0 g
.006 w
.39193 .12184 m
.40238 .11104 L
s
1 0 0 r
.003 w
.3865 .41933 m
.40422 .39567 L
s
.31573 .17856 m .34885 .27185 L .32994 .17181 L .062 0 .106 r
F
.31573 .17856 m .29054 .31749 L .34885 .27185 L F
0 g
.006 w
.30196 .18329 m
.31573 .17856 L
s
.25 g
.5 Mabswid
.3135 .19089 m
.31573 .17856 L
s
.30527 .23625 m
.3135 .19089 L
s
.29362 .3005 m
.30527 .23625 L
s
.29054 .31749 m
.29362 .3005 L
s
.29993 .31014 m
.31991 .32203 L
s
.30976 .30774 m
.33938 .32852 L
s
.29491 .21002 m
.29841 .19676 L
s
.28654 .24177 m
.29491 .21002 L
s
.29841 .19676 m
.30196 .18329 L
s
1 0 0 r
.003 w
.15293 .55086 m
.15614 .50528 L
s
.25 g
.5 Mabswid
.39193 .12184 m
.42546 .14626 L
s
0 g
.006 w
.38161 .13278 m
.39193 .12184 L
s
.32994 .17181 m .42064 .23668 L .34422 .16334 L .238 0 .061 r
F
.32994 .17181 m .34885 .27185 L .42064 .23668 L F
0 g
.31573 .17856 m
.32994 .17181 L
s
.25 g
.5 Mabswid
.32994 .17181 m
.33006 .17243 L
s
.38161 .13278 m
.41383 .14989 L
s
0 g
.006 w
.37044 .14347 m
.38161 .13278 L
s
1 0 0 r
.003 w
.7623 .3471 m
.79558 .30966 L
s
.59951 .34928 m
.61462 .32145 L
s
.25 g
.5 Mabswid
.50705 .20286 m
.53222 .21379 L
s
.53222 .21379 m
.53876 .21664 L
s
.54394 .21889 m
.55192 .22236 L
s
.371 .14371 m
.37122 .1438 L
s
.37044 .14347 m
.371 .14371 L
s
.34422 .16334 m .49292 .21934 L .35792 .15373 L .354 0 0 r
F
.25 g
.34422 .16334 m
.34484 .16394 L
s
.34484 .16394 m
.34618 .16523 L
s
.34618 .16523 m
.34708 .16608 L
s
.34708 .16608 m
.42064 .23668 L
s
0 g
.006 w
.35792 .15373 m
.37044 .14347 L
s
.25 g
.5 Mabswid
.37122 .1438 m
.40095 .15673 L
s
.40095 .15673 m
.43515 .1716 L
s
.43646 .17217 m
.45666 .18095 L
s
.43515 .1716 m
.43646 .17217 L
s
.47047 .18695 m
.50705 .20286 L
s
.45666 .18095 m
.47047 .18695 L
s
.43146 .15926 m
.4434 .1656 L
s
.41383 .14989 m
.43146 .15926 L
s
.46733 .17831 m
.48481 .1876 L
s
.4434 .1656 m
.46733 .17831 L
s
0 g
.006 w
.32994 .17181 m
.34422 .16334 L
s
.25 g
.5 Mabswid
.3302 .17317 m
.34885 .27185 L
s
.33006 .17243 m
.3302 .17317 L
s
.42546 .14626 m
.44954 .1638 L
s
.44954 .1638 m
.46502 .17508 L
s
.4363 .1466 m
.45356 .16468 L
s
.4777 .16357 m
.48248 .13922 L
s
.47726 .16583 m
.4777 .16357 L
s
.47454 .1797 m
.47462 .17926 L
s
.47462 .17926 m
.47726 .16583 L
s
.4741 .18191 m
.47454 .1797 L
s
.46354 .17323 m
.46363 .17253 L
s
.46363 .17253 m
.4668 .14932 L
s
.46344 .17392 m
.46354 .17323 L
s
0 g
.006 w
.34422 .16334 m
.35792 .15373 L
s
.25 g
.5 Mabswid
.42577 .18671 m
.47512 .21069 L
s
.47512 .21069 m
.49292 .21934 L
s
.42307 .1854 m
.42577 .18671 L
s
.38575 .16726 m
.42307 .1854 L
s
.35997 .15473 m
.38575 .16726 L
s
.35792 .15373 m
.35997 .15473 L
s
1 0 0 r
.003 w
.25302 .43436 m
.28055 .44942 L
s
.4036 .37359 m
.40422 .39567 L
s
.8154 .29655 m
.85175 .329 L
s
.61462 .32145 m
.65126 .29597 L
s
.48438 .34948 m
.52082 .34548 L
s
.52082 .34548 m
.5573 .32916 L
s
.4561 .34009 m
.48438 .34948 L
s
.80083 .29291 m
.8039 .28315 L
s
.79558 .30966 m
.80083 .29291 L
s
.8039 .28315 m
.80881 .2675 L
s
.15614 .50528 m
.18294 .4546 L
s
.24237 .40525 m
.25302 .43436 L
s
.5573 .32916 m
.58572 .30319 L
s
.38212 .35903 m
.4036 .37359 L
s
.76259 .27963 m
.79352 .28954 L
s
.80113 .29198 m
.8154 .29655 L
s
.44376 .31806 m
.4561 .34009 L
s
.65126 .29597 m
.7039 .28014 L
s
.7039 .28014 m
.76259 .27963 L
s
.58572 .30319 m
.59817 .27206 L
s
.34099 .35783 m
.38212 .35903 L
s
.18294 .4546 m
.22959 .40799 L
s
.44376 .31806 m
.45357 .28646 L
s
.24537 .39489 m
.25415 .36456 L
s
.24237 .40525 m
.24408 .39936 L
s
.79557 .22839 m
.80881 .2675 L
s
.28648 .37409 m
.34099 .35783 L
s
.22959 .40799 m
.24471 .39898 L
s
.24471 .39898 m
.28648 .37409 L
s
.58797 .24239 m
.59817 .27206 L
s
.45357 .28646 m
.4883 .25074 L
s
.75472 .20021 m
.79557 .22839 L
s
.25415 .36456 m
.29054 .31749 L
s
.55192 .22236 m
.58797 .24239 L
s
.5422 .21989 m
.54418 .21875 L
s
.53372 .22474 m
.53903 .2217 L
s
.4883 .25074 m
.53372 .22474 L
s
.54418 .21875 m
.54556 .21796 L
s
.69165 .18862 m
.75472 .20021 L
s
.29054 .31749 m
.34885 .27185 L
s
.54556 .21796 m
.58655 .20507 L
s
.58655 .20507 m
.61742 .19536 L
s
.49292 .21934 m
.55192 .22236 L
s
.61742 .19536 m
.69165 .18862 L
s
.34885 .27185 m
.42064 .23668 L
s
.42064 .23668 m
.49292 .21934 L
s
0 g
.25 Mabswid
0 .04482 m
.2463 .18451 L
s
.2463 .18451 m
.2702 .99535 L
s
.2702 .99535 m
.03924 .68322 L
s
.03924 .68322 m
0 .04482 L
s
1 .10791 m
.2463 .18451 L
s
.2463 .18451 m
.2702 .99535 L
s
.2702 .99535 m
.94883 .82632 L
s
.94883 .82632 m
1 .10791 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 286.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00017Q000`40O003h00OZGoo2000Kgoo002K
Ool>0006Ool00`00Ool00003001[Ool008ioo`d001Aoo`03001oogoo00=oo`<006Qoo`00P7oo3P00
8Goo00<007ooOol01Woo1000I7oo001cOol=000_Ool00`00Oomoo`0:Ool4001POol006Eoo`h003ao
o`03001oogoo00ioo`<005eoo`00F7oo3@00BWoo00<007ooOol04Goo1000FGoo001;Ool=001GOol0
0`00Oomoo`0EOol3001FOol003eoo`h006Aoo`03001oogoo01Qoo`@0059oo`00<7oo3@00LWoo00<0
07ooOol077oo1000CWoo000ROol>001oOol00`00Oomoo`0POol3001;Ool001Eoo`d008eoo`03001o
ogoo02=oo`@004Moo`001goo3P00VWoo00<007ooOol09goo0`00A7oo0007002XOol00`00Oomoo`0Z
Ool40010Ool000<00:aoo`03001oogoo02ioo`<003eoo`0000<007ooOol00P00ZWoo00<007ooOol0
<Goo1000>Goo00000`00Oomoo`02Ool2002XOol00`00Oomoo`0eOol4000eOol00003001oogoo00Ao
o`03001oogoo0:Eoo`03001oogoo03Uoo`<0039oo`0000<007ooOol01Goo0P00YGoo00<007ooOol0
?7oo1000;Woo00000`00Oomoo`07Ool2002SOol00`00Oomoo`10Ool3000[Ool00003001oogoo00Uo
o`800:5oo`03001oogoo04=oo`@002Moo`0000<007ooOol02goo00<007ooOol0WWoo00<007ooOol0
Agoo0`0097oo00000goo001oo`0<Ool2002NOol00`00Oomoo`1:Ool4000POol00003Ool007oo00io
o`8009aoo`03001oogoo04ioo`@001aoo`0000=oo`00Ool047oo0P00VWoo00<007ooOol0DWoo0`00
6Goo00000goo001oo`0BOol00`00Oomoo`1YOol5000YOol00`00Oomoo`1EOol4000EOol00003Ool0
07oo01=oo`8006Eoo`@0009^T@03O`]k2gl;00<002Ioo`03001oogoo05Uoo`<0019oo`0000=oo`00
Ool05Goo0P00H7oo0`0000aJ4g:BKY5bTVjALY9k2gl;N`]o37/;7>L2000TOol00`00Oomoo`1LOol4
000>Ool00003Ool007oo01Moo`8005aoo`800004FQ<LieXCFQ@3KY400fjBKY5o2`02O`/00g/;O`/L
i`05000POol00`00Oomoo`1QOol4000:Ool00003Ool007oo01Uoo`03001oogoo05Moo`0C000LidWf
AME9mAcWFSAJ4g:BKY5bTVjAOomk2gl<N`]o2`007>L00`0000@Li`05000001ioo`03001oogoo06Eo
o`<000Moo`0000=oo`00Ool06Woo0P00EWoo00@003FgBMDLi`99e@05FQ@LieXDKY5^TP03KY401Gl;
N`]o2gl;7>L0100000@Li`0600H01P8001aoo`03001oogoo06Qoo`@000=oo`0000=oo`00Ool077oo
0P00Dgoo01@003Fg>KM5eAcWAME9mTGE7>MJ4g:BKY5bTVjALY9k2gl;N`]o31cW0`0000LLi`0600D0
1P0500HLi`02000JOol00`00Oomoo`1YOol50001Ool00003Ool007oo01ioo`80051oo`0;000e]cVg
=KLi]dWE7>M5eDWE7>MJ5003KY400fjBKY5o2`02O`/00g/;7>L0000200000acW00H01P0300H00acW
60DH1P03000GOol00`00Oomoo`1OOol:0004Ool10001Ool00003Ool007oo021oo`03001oogoo04ao
o`0F000QVAcW=KLi]cFg>KLLidWeAMEJ=1cWLY9^TG:BKY5o2g/;O`ak2gl;7>L3000031cW00H01@06
00D01QcW60HD1AP67>LX0`8001Eoo`03001oogoo05Eoo`X000ioo`40005oo`0000=oo`00Ool08Goo
0P00Bgoo00l0026i9KTQ^AcW=KLi]cFgBMDLidWEAMDLifjAKY800VjA0Wl;00Ak2gl;O`/Li`<00003
7>L01P0600<01P087>LH1QP660DX0acW:0<X0P8001=oo`03001oogoo04]oo`X001Qoo`40005oo`00
00=oo`00Ool08goo0P00B7oo01L0026I9KTQVBFi8ITLicFg>KLe]acWAME9mAcWFSA^TG:BKY5o37/;
O`]k2acW00@0000@7>L01P0500H01AcW50EooaP560HD1AcW:08X0bP2;0<2000AOol00`00Oomoo`11
Ool:000ROol10001Ool00003Ool007oo02Eoo`8004Eoo`0@0005VQcW7>LU^B6i9KTQ^AcW=KLi]cFg
7>M9eAcWFQ<2KY400gooN`]o2`02O`/00acW0000000200000acW00H01P0200H00acW60Ioo`0360H0
21cW:0<X0RP3:08X0acW00027>L>Ool00`00Oomoo`0hOol9000/Ool10001Ool00003Ool007oo02Mo
o`03001oogoo045oo`0I0005VPVK1IX5VacW9KTQVBFi8ITLicFg>KM5eAcWAMDLifjALY9oogl;N`]o
37/;7>L00`0001@Li`0500H01@0600DLiaP560HD1AP660DLibP2;0<X0RP3:08/0acW0S001AcW2Goo
00<007ooOol0;Woo2P00=Goo0@000Goo0002Ool00`00Oomoo`0VOol20010Ool00`001IX5VP041IX0
31cW9KTQ^BFi8KTLicFg>KLLidWE7>M^TP9^T@9o2`03N`]o2acW00<000037>L01P0600<01P0?7>LH
1QP6OolH1AP6:08LibP2:0<X0RP3:08X0acW00<`0003;00`01cW008Li`Moo`03001oogoo02Aoo`X0
03moo`40005oo`000Woo00<007ooOol0:7oo0P00?Goo00T0004e7>LLi`FK1IX9V`FJ1I/00QcW00HQ
VBFi8ITLicFg>KL27>L026jALY9^TGl<N`]o2g/;7>L300005QcW00D01P0500H01AcW50DH1Woo60HD
1AP67>LX0bP2;0<X0RP3:08/0acW0S0000@d0300;00`00DLi`@001aoo`X004Qoo`40005oo`5oo`00
0Woo00<007ooOol0:Woo0P00>Woo00D0004f0EH1=@5F008Li`D5VP0<7>LQ^BFi8KTLicFg7>M5eAcW
KY5^TW/;0gl;00DLi`00000001cW00D01P037>LH1QP500<H1P0;60DLibP2:0<X0RP3:08X0bP2:0<L
i`06<0000b`07>LLi`057>L00`00Oomoo`0?Ool:001BOol10001Ool1Ool0009oo`03001oogoo02ao
o`03001oogoo03Ioo`8Li`060EH1=@5F0CD1EP4e0QcW00@9V`FJ1I/5VP8Li`049KTQVAcW=KL27>L0
1W:BKY5o2g/;O``Li`@0000H7>L01@0600D01P057>LH1AP650EooaP560HLib`3:08X0bP2;0<X0RP3
:08/0acW0S0000Hd0300<00`03@0:0027>L01CWH7>LLiacW00001Woo2P00G7oo0@000Goo0Goo0002
Ool00`00Oomoo`0]Ool2000eOol00`00;00`00027>L01P4f0EH1=@5F0CH1EP8Li`@5VP037>LU^B6i
008Li`03KY9^TFjA009o2`03N`/Li`0000<000037>L01P0600801P037>LH1AP6008H1P0?60DH1QP6
:0<LibP3:08X0bP2:0<X0RP3:08X0acW00P`0003;00LiacW00T006Ioo`40005oo`5oo`000Woo00<0
07ooOol0;goo0P00<Goo0P0000D/0300;00`02`0008Li`0;0EH1=@5F0CD1EP4e7>L5VPFK1IX9V`02
7>L02B6I7>LLieXdKY5o37/;O`/Li`0300006goo7>L01@0600D01QcW60HD1AP660DH1Q@560HH1AcW
:08/0bP2:0<X0R`3:08X0bP2;0<Li`0:00027>L00`6I0GP000027>MXOol10001Ool1Ool0009oo`03
001oogoo035oo`8002ioo`8Li`03;00`02`0008/0003<00/02`0008Li`050CD1EP4f0EH1=@027>L3
1IX01b6i7>LQ^AcWFQ=^TW/;009o2`057>L00000000Li`0500H011cW60HH1QP50QP600EooaP560HL
ibP300X000037>L`030000P`0006;00LiacW:001VGoo0acWIGoo0@000Goo0Goo0002Ool00`00Oomo
o`0cOol00`00Oomoo`0ZOol00`00;00X00027>L02300;00`02`0<00/0300;0037>L0104e0EH1=@5F
0QcW00/5VPVK1IXLib6I7>M^TGl;N`]o31cW00<000077>L01P0500H01@067>L02P0000`X0bP2;0<X
0RP3:08/0bP2:0<X0R`37>L2<0001C@0<00`0300=0000c0000Pd03007>LLib`0:00/07oo0QcWHgoo
0@000Goo0Goo0002Ool00`00Oomoo`0dOol2000XOol20005:0027>L3;0001S00;00/02`0<00/008L
i`040EH1=@5F0CH27>L21IX37>L2O`/00g/;7>L0000900005aP560HH1QP660DH1Woo60HLibP3:08X
0bP2:0<X0RP3:08X0bP2:0<X0RP37>L03C000QcW0R`000<X006I7>L00QcWH7oo0@000Goo0Goo0002
Ool00`00Oomoo`0fOol2000UOol02P007>L/02P0;00X02`0:00/02P00QcW00T`02`0<00/0300;00`
02`0<0000QcW00@1=@5F0CD1EP/0008Li`0N00H01@0600D01QcW60HD1AP660DH1Q@5OolH1AP67>L/
0bP2:0<X0R`3:08X0bP2;0<X0RP3:08/0acW0S0000Dd0300<00`03@000<`0004=00`0300<0027>L0
1B`0:00/02P0Ool00acWGGoo0@000Goo0Goo0002Ool00`00Oomoo`0hOol2000QOol200000aP17>LX
0009:0027>L00b`0<00/000:00000`5F0CD5VP037>L2O`/011cW000001cW1@0600DLiaP660HH1QP5
00<H1P0C60DH1QP67>LX0RP3:08X0bP2:0<X0RP3:08X0bP2:0<X0RP37>L03c000QcW00HX02`0;00/
006HOol27>MKOol10001Ool1Ool0009oo`03001oogoo03Yoo`03001oogoo01aoo`0;7>L001`1604L
0AP17>LX02`0:00/000:000027oo<00/0300;00`02`0<0037>L0105F0CD1EPFJ11cW0P00028Li`05
00H01@0600DLia@560HH1AP650DH1QP560IooaP67>LX0bP2;0<X0RP3:08/0bP2:0<X0R`3:08X0bP2
;0<Li`8`0005=00`0300<00d0003<0001S@0<00`0300=00`008Li`06;00X02`0:00/02P00acWF7oo
0@000Goo0Goo0002Ool00`00Oomoo`0kOol2000JOol200000acW000000080009:0027>L3;0001C00
;00/02`0<0000R`00QcW00@1=@5F0CH5VP8Li`8000037>L01P0600<01P037>LH1QP500<H1P0G60DH
1QP6OolH1BP37>LX0bP2:0<X0RP3:08X0bP2:0<X0RP3:08X0bP2:0<Li`0A<0027>L2;0001BP0;00/
02`0Ool00QcWEWoo0@000Goo0Goo0002Ool00`00Oomoo`0mOol2000AOol:00005AP1704H0A`1604L
0AP17>LX02`0:00/02P0;00X02`0:00/02P0;00X00027>L02S00;00`02`0<00/0300;00`02`00QcW
02X1EP4e0EH5VQcW000Li`0500H01@0600DLiaP560HD1AP660DH1Q@560HH1AP6:08LibP2:0<X0R`3
:08X0bP2;0<X0RP3:08/0bP2:0<X0R`37>L2<0001C@0<00`0300=0000c0000Dd0300<00`03@000<`
00<Li`06:00/02P0;00X02`00acWDgoo0@000Goo0Goo0002Ool00`00Oomoo`0oOol20005Ool;0000
1AcW000000017>L00P@200/40acW704H0A`1604L0AP1704H0AcW00hX008Li`03;00`02`0008/0005
<00/02`0;00`00027>L00`4f0EH1=@027>L500H01AcW60HH1QP660D00aP601HH1AP6OolH1QcW:0<X
0RP3:08X0bP2:0<X0RP3:08X0bP2:0<X0RP3:08X0`8Lia<`008Li`</0004:00/02`0;0037>M@Ool1
0001Ool1Ool0009oo`03001oogoo045oo`D000Ioo`D0000R7>L00@027>L40`@210<40P@37>LL0AP1
704H0A`1604L0AP17>LX02`0:00/02P0;00X02`0:00/02P0;00X02`0:0037>L02B`0<00/0300;00`
02`0<00/00027>L00`5F0CD1EP027>L09P0500H01AcW50DH1QP560HD1AP660DH1Q@560HH1AcW:08/
0bP2:0<X0R`3:08X0bP2;0<X0RP3:08/0bP2:0<X0R`3:08Lic00=003<0001C@0<00`0300=0000c00
00Dd0300<00`03@0008`008Li`08:00/02P0;00X02`0:01oo`8Lidioo`40005oo`5oo`000Woo00<0
07ooOol0@Goo00<007ooOol01Goo0`0000Ek:QcW000001cW00<00@037>L40P@300<40P0;7>LH0A`1
604L0AP1704H0A`1604Li`0@:0000b`07>LLi`02;0001C00;00/02`0<0000R`00acW00<1EP4f7>L0
0P0600<LiaP660D00aP601`H1AP660HH1QP560HX0QcW:08X0bP2:0<X0RP3:08X0bP2:0<X0RP3:08X
0bP2:0<X0RP3:08Lia4`00Ql00</0003:00/02`000<LidYoo`03001oogoo005oo`000goo00<007oo
Ool0@7oo00@007ooOomoo`@00005N_1g2W/ZM`XLi`020000:1cW00800@017>L40`@210<40P@37>LL
0AP1704H0A`1604L0AP1704H0AcW:00/02P0;00X02`0:00/02P0;00X02`0:00/02P0;00X03000QcW
00X/0300;00`02`0<00/0300;001EP8Li`0X00D01P057>LH1AP650DH1QP560HD1AP660DH1Woo;0<L
ibP3:08/0bP2:0<X0R`3:08X0bP2;0<X0RP3:08/0bP2:0<X0R`3:08Lic00=003<0000c@0O01l0008
O00022Fi4M/A^a7K3KXAfa6k4M/6O0000bP0;00X00037>M7Ool00`00Oomoo`01Ool000=oo`03001o
ogoo041oo`@00008JW9jkg[?N_1jcg/ZN`XLi`<000057>L00@01004Li`0310803`@3108LiaP1704H
0A`1604L0AP1704H0A`1604Li`0B:00012`07>LLic000b`000H`02`000H/03000CD47>L360H01AP5
60HH1QP660D00aP601HH1AcW:08X0bP2:0<X0RP3:08X0bP2:0<X0RP3:08X0bP2:0<X0RP3:08X0`Ml
00Hef007:MXU^Goo9KTYfRFi9MX02Q6k00<1V7`0O00017`00QcWAGoo00<007ooOol00Goo0003Ool0
0`00Oomoo`10Ool03000JW5^LVYaJW9jcg[`N/mjl7L:Nb/Li`<0000/7>L00@01008Li`@310840`@2
10<40QcW604L0AP1704H0A`1604L0AP1704H0AcW:00/02P0;00X02`0:00/02P0;00X02`0:00/02P0
;00X02`0:00`008Li`0;;00`02`0<00/0300;0001R`0<00/00027>L07AP660DH1Q@560HH1AP650DH
1QP560HLib`3:08X0bP2;0<X0RP3:08/0bP2:0<X0R`3:08X0bP2;0<00g`002EN=4WeCOE9m4ge@MI1
ed7F>MPe]cGH=KLif3Fg:MXU^BWJ9KTYfRFi:MXA^a7K3KXAfa6k4M/=^Q7K4K/Af`fj0IT1N06I0GP1
V@04O013Ool00`00Oomoo`01Ool000=oo`03001oogoo03moo`8000AZLP07N_1jcg[_N`Yk:WL:7>L0
0P0000<Ligoo00400P0100<Li`@210<00`@200h40acW704H0A`1604L0AP1704H0A`1604L0AP10QcW
4bP000</01cW7>L00R`000T`02`0;00/0300;00H1R`00EH00acW00<H1QP560H00QP6018H1AP6OolL
ibP2:0<X0RP3:08X0bP2:0<X0RP3:08X0bP2:0<3O0001GooKY9J=5XcFS@00dge147F1SGH00PYfRFi
9MXU^BWJ9KTUfRFi316k00H1V@6H0IT1V06I0IP2O011Ool00`00Oomoo`01Ool000=oo`03001oogoo
03ioo`0>001J4`00JW5ZLVYaKW9jcg[`N/mk:gL:NbXLi`80000a7>L00@02004Li`@210<40P@31084
0`@27>LH0A`1604L0AP1704H0A`1604L0AP1704H0A`17>L/02P0;00X02`0:00/02P0;00X02`0:00/
02P0;00X02`0:00/02P0<0000QcW00`/0300;00`02`0<00/0300;00`02`0<0027>L04Q@560HH1AP6
50DH1RP27>LX0R`3:08X0bP2;0<X0RP3:08/0`=l00Aoo`0^LY9k2EXd00E=mDWeCOE1eT7G<0I1ecFg
>MPe]cGH=KLif3Fg:MXU^BWJOolYfRFi:MXU^BWJ3KXAfa6k4M/=^Q7K4K/Af`fj4M/A^a7K0GP1V@5h
0IT1N06IO010Ool00`00Oomoo`01Ool000=oo`03001oogoo03eoo`05001J4eXD001J4`03JW801g[_
N/mjl7L:NbYk2QcW008000067>L00@01004Li`@30`@201@40`@2108Lia`1604L0AP1704H0A`1604L
0AP1704H0A`1604L0AcW5BP000@/01cW7>L`00</0005<00/02`0;00`0002;0000`4f7>LLi`0360H0
2AP560HLibP3:08X0bP2:0<X0P04O007Ool016jBN`YJ=00614ge147F1cGH00XYfRFi9MXU^BWJ9KTU
fRFi:MXU^@dA^`040IP1V@6H0IT2O00nOol00`00Oomoo`01Ool000=oo`03001oogoo03eoo`0?0019
eEXC001J4fibJW5ZLW[?N_1jcg/ZM`YooacW0080000e7>L00@01004Li`@210<40P@310840`@27>LH
0A`1604L0AP1704H0A`1604L0AP1704H0A`1604L0AcW;00X02`0:00/02P0;00X02`0:00/02P0;00X
02`0:00/02P0;00X02`0:00`00027>L032`0<00/0300;00`02`0<00/0300;00`008Li`0660DH1Q@5
7>LX0RP317`02goo035^TW/9GS@01DgeBOA=mDWe60U1eT7G@MI1ecFg>MPe]cGH=KLif3Fg=MPU^BWJ
9KTYfRFi:MXU^BWJ9KTAfa6k4M/=^Q7K4K/Af`fj4M/A^a7K3KXAfa6k0IT1N06I0GQl000mOol00`00
Oomoo`01Ool000=oo`03001oogoo03aoo`060019eDWEFQ<005XD0fYb00Ijl7[?N^mk2W/Z7>L30000
1AcW00400@017>L00P@201P40`@210840P@3108LiaP1704H0A`1604L0AP1704H0A`1604L0AP1704H
0A`17>LG:0000b`07>LLi`02;0001C00;00/02`0<0000b`000D`02`07>LLiaP600=l00moo`03KY9k
2UXc00801@9=m@0360TH247F00A1ePPef00:9KTUfRFi:MXU^BGJ9KTYfRFi9MX>4K/00`6H0IT1V002
O00kOol00`00Oomoo`01Ool000=oo`03001oogoo03]oo`0@000e^4GEBMEJ4`00FQ=ZLVYaKW9jcg[`
N/mk:gL:7>L20000>1cW00400@02004Li`@210<40P@310840`@210<Lia`1604L0AP1704H0A`1604L
0AP1704H0A`1604L0AP1704Lib`0:00/02P0;00X02`0:00/02P0;00X02`0:00/02P0;00X02`0:00/
02P0;00;O0001300;00`02`00g`04Goo03AbTW/9FS@01@067>LH2AP870U9mD7G@MI1ed7F@MLe]cWH
=KLef3Fg>MPe]cGH9KTYfRFi:MXU^BWJ9KTYfRFi:MXU^A7K3KXAfa6k4M/=^Q7K4K/Af`fj4M/A^a7K
3KXAf`5h0IUl03Yoo`03001oogoo005oo`000goo00<007ooOol0>goo00<0036gBMD00TWE00<005XC
JW800VYb00Ijkg[?NbYg2W/Z7>L200000acW00400@0200400acW10<40P02108060@310840P@27>LH
0A`1604L0AP1704H0A`1604L0AP1704H0A`1604L0AP1704Lia8X00Al00801P037>LH1AP6008H1P04
60DH1QP660H9O00?Ool02VjBN`YJ=0067>M=mAP860TH21cW1T7F23GH00/U^BGJ9KTYfRFi9MXU^BWJ
9KTUfRFi010A^`030IUl07`003Qoo`03001oogoo005oo`000goo00<007ooOol0>Woo0140036g=KLa
]dWEAMD005XCKW9ZLG[`N/mjl7L:NbYg2QcW0080000`7>L00P01004Li`@310840`@210<40P@31084
0acW704H0A`1604L0AP1704H0A`1604L0AP1704H0A`1604L0AP1704Lib`0:00/02P0;00X02`0:00/
02P0;00X01cW17`001001@0600D01P0560HLiaP650DH1QP560HD1AP660DH1P9l00061IX5V`FJ2I/5
VP5F0W`03Goo00A^TW/97>L01@8Li`0a70TH21P960PLid7F@MM1eT7G@MHef3Fg>MPe]cGH=KLif3Fg
=MPU^BWJ9KTYfRFi:MXU^BWJ9KTYfRFi:MX=^Q7K4K/Af`fj4M/A^a7K3KXAfa6k4M/=^Q7K4K/Af`fj
O000=goo00<007ooOol00Goo0003Ool00`00Oomoo`0jOol01000<KLa]cFg0TWE00/005XDJW9ZLW[?
N_1jcg/ZN`YooacW008000057>L00@01004Li`03108070@310840P@210<40QcW604L0AP1704H0A`1
604L0AP1704H0A`1604L0AP1704H0A`1604L0AcW22P017`00P0000<Li`0600H0100600DH1AcW60HH
1QP500<H1P0560El07`0OolQ^@071IX00`4eO01l000;Ool02fjBN`XLi`057>MJ=1P860TH21P97>L0
1S0V2SGH00`UfRFi:MXU^BGJ9KTYfRFi9MXU^BWJ9KT?4K/00g`0Oomoo`0eOol00`00Oomoo`01Ool0
00=oo`03001oogoo03Yoo`0C000LicFh<KLe]dGE001J4fYbJW5jl7[?N_1g2W/[000Li`007>L00`01
02D00QcW10<40P@310840`@210<40P@3108LiaP1704H0A`1604L0AP1704H0A`1604L0AP1704H0A`1
604L0AP1704Lib`0:00/0004O00017ooO`]k2acW0P0001hLi`0600D01P0500H01AP67>LH1QP560HD
1AP660El026I9KTQVBFiOol9V`FJ1I/5VPVK1IX5V`FJ2I/2O009Ool0>7:BN`TLi`057>MJ4aP960PL
2AP87>L`1S@W<0H`9c06=2L`1S0W=KLif3Fg=MPe]cWH=KLef3Fg:MXU^BWJ9KTYfRFi:MXU^BWJ9KTY
fRFi:MXA^a7K3KXAfa6k4M/=^Q7K4K/Af`fj4M/A^a7KO00fOol00`00Oomoo`01Ool000=oo`03001o
ogoo03Uoo`04000=N@ei7>L2<KL02dWE001J4eXCJW9jcg[_N/mk:WL:7>L00P0000<Li`0100400P01
00<Li`@210<00`@201/40`@210840P@37>LL0AP1704H0A`1604L0AP1704H0A`1604L0AP1704H0A`1
604L0AP170400g`01Goo0Wl;00<Li`007>L01`0600<LiaP660D00aP60W`000PQ^BFi8KTU^B6i9KUo
obFi2@FJ0W`01goo0W/:00TLi`067>LH2AP860TH21P97>L02C0V2CGH00dUfRFi:MXU^BGJ9KTYfRFi
9MXU^BWJ9KTUfP0=4K/00g`0Oomoo`0cOol00`00Oomoo`02Ool000=oo`03001oogoo03Uoo`0A000A
NPei4GXLicFh<KL005XCFQAZLG[`N/mjl7L:NbXLi`0200000acW00400P0200407acW10<40P@31084
0`@210<40P@3108LiaP1704H0A`1604L0AP1704H0A`1604L0AP1704H0A`1604L0AP1009l00Qoo`0W
O`ak2acW000Li`0500H01@0600D01P057>LH1AP650DH1W`0>KLe]bFi8ITU^B6I9KTQVBFi8IUoo`FJ
1I/5VPVK1IX5V`FJ2I/5VPFK009l00Eoo`0hN`Yk2AcW00DLiaP870TH21P960PLic06<2L`1S@W<0H`
9c06=2L`1SGH=KLif3Fg=MPe]cWH=KLef3Fg:MXU^BWJ9KTYfRFi:MXU^BWJ9KTYfRFi:MXU^A7K3KXA
fa6k4M/=^Q7K4K/Af`fj4M]l03Eoo`03001oogoo009oo`000goo00<007ooOol0>Goo00<000ei3GT0
0Pei0QcW00Y9e@00FQ=ZLW[?N_1g2W/ZN`XLi`8000037>L00Goo00800@057>L40P@210840`031080
5@@310840QcW704H0A`1604L0AP1704H0A`1604L0AP1704H0A`1604L0@02O00:Ool01G/;7>L00000
7>L01`0600<LiaP660H00W`000hi]cFg>KLe]bFi8KTU^B6i9KTQ^BFi8KTU^B6i2@FJ00=l07ooOol0
0goo00]k2VjB7>L01AcW60TH21P960PH2AcW00X`9P<ef003?00ef3GH00@ef00?9MXU^BWJ9KTUfRFi
:MXU^BGJ9KTYfRFi9MXU^BWJ00XA^`03O01oogoo039oo`03001oogoo009oo`000goo00<007ooOol0
>Goo03<001cW3GTANPei4GXa]acW001J56YaN_1jcg/ZM`YooacW000Li`02005oo`017>L40P@31084
0`@210<40P@310840`@210<Lia`1604L0AP1704H0A`1604L0AP1704H0A`160400W`037oo00eo2acW
000001cW00D01P0500H01@0600DLi`02O0006cFg>KLe]cVg=KLi]cFg>KLQVBFi8ITU^B6I9KTQVBFi
Ool5V`FJ2I/5VPFK1IX9V`FJ1I]l0004Ool0>G/:KY4Li`057>LH21P960PL2AP87>L`1S@W<0H`9c06
=2L`1S0W<0Hd9c06?04l0401=KLef3Fg>MPe]cGH=KLYfRFi:MXU^BWJ9KTYfRFi:MXU^BWJ9KTYfRFi
:MX=^Q7K4K/Af`fj4M/A^a7K3KYl000dOol00`00Oomoo`02Ool000Aoo`03001oogoo03Qoo`040000
dacW7>L43GT02000FQ=ZLW[?N^mk2W/Z7>L200000acW00400@02004011cW10840P@30`@201<40`@2
10840P@3108LiaP1704H0A`1604L0AP1704H0A`1604L0@02O00>Ool01Gl;7>L000007>L01`0601Il
04WEAMDi]cFg>KLe]cVg=KLi]cFg>KLQ^BFi8KTU^B6i9KTQ^BFi8KUoo`L5VP03O01oogoo009oo`0<
N`XLi`057>LH21P960PH2AP860TH21cW2S0V00<l03`1?0000S`000<l0C`0?0000cGH010UfRFi:MXU
^BGJ9KTYfRFi9MXU^BWJ9KTUfRFi:MXU^@LA^`03O01oogoo039oo`03001oogoo009oo`0017oo00<0
07ooOol0=goo0140003C0=@0d`3D7>LANPei4GX001cWJW5jl7[?Nb]g2QcW0080000M7>L00@010080
0AcW10840`@210<40P@310840`@210<40P@37>LL0AP1704H0A`1604L0AP1704H0@02O00@Ool0:Wl<
7>L000007>L01@0600D01P0500Il04WfAME9mDGE>KLe]cVg=KLi]cFg>KLe]cVg8ITU^B6I9KTQVBFi
8ITU^B6I9KT5VPVK1IX5V`FJ2I]l00Aoo`0jN`XLi`067>LH2AP870TH21P960PL2AcW<2L`1S@W<0H`
9c06=2L`1S0W<0Hd9c`0?04l0401?00l0C`0@04l03`1?00YfRFi:MXU^BWJ9KTYfRFi:MXU^BWJ9KTY
fRFi:MXU^BWJ4K/Af`fj4M/A^a7KO00cOol00`00Oomoo`02Ool000Aoo`03001oogoo03Moo`070000
e03C0=@0d`3D7>L00Pei00/004WEJW9jcg[`M`Yk:QcW00000AcW00@00@037>L40`@200840P0510<4
0P@210840`0310802AcW604L0AP1704H0A`1604L0@02O00BOol017/;7>L001cW1P0600=l04WEAMD0
0dWE01E5eCVg=KLi]cFg>KLe]cVg=KLi]b6i9KTQ^BFi8KTU^B6i9KTQ^BFiOol01@FJ011l07ooOomo
og/:7>L01AcW60PH2AP860TH21P960PLi```9P03?00l0C`0008l000H?04l03`0?00l0C`0=MPU^BWJ
9KTUfRFi:MXU^BGJ9KTYfRFi9MXU^BWJ9KTUfRFi116k00=l07ooOol0<Goo00<007ooOol00Woo0004
Ool00`00Oomoo`0gOol01`000=<0e03C0=@0d`3D008Li`07000ANVYaN_1jcg/Z7>L00P0000<Li`01
00800`0101@Li`@210<40P@310840`@210<40P@310840acW704H0A`1604L0AP10W`057oo02]o2acW
000Li`0600D01P0500Il05XdAME9mDGEBOI5eDWe=KLi]cFg>KLe]cVg=KLi]cFg>KLQVBFi8ITU^B6I
9KTQVBFi8ITU^B6I2I/5VPFK1IYl0003Ool0>W/:7>L01QcW70TH21P960PL2AP860TLic@W<0H`9c06
=2L`1S0W<0Hd9c06<2L`1S@W?00l0C`0@04l03`1?0100C`0?04l04019KTYfRFi:MXU^BWJ9KTYfRFi
:MXU^BWJ9KTYfRFi:MXU^A7K3KXAfg`0<goo00<007ooOol00Woo0004Ool00`00Oomoo`0gOol04000
7>LLi`3D0=<0e03C0=@0d`003GUZLW[?NbYk2QcW0P0000<Li`0100400`0100@Li`@210840`<40P05
10<40P@210840`02108011cW704H0A`10W`05Woo00Ao2acW000Li`@01P03O01J55XC00=9e@0JAME9
eDWEBMDe]cVg=KLi]cFg>KLe]cVg=KLi]b6i9KTQ^BFi8KTU^B6i9KTQ^BFi8KUoo`85VP0@O01oogoo
Oomk2QcW00DLiaP860TH21P960PH2AP87>L=<2H2?0001C`1?00l03`0?0400c`001Dl0C`0?00U^BWJ
9KTUfRFi:MXU^BGJ9KTYfRFi9MXU^BWJ9KTUfRFi:MX00Q6k00=l07ooOol0<7oo00<007ooOol00Woo
0004Ool00`00Oomoo`0fOol01000?00l03`00QcW00D0d`3D0=<0e000008Li`04N_1g2W/[7>L20000
5QcW00400@01008Li`@310840`@210<40P@310840`@210<40P@3108LiaP10W`067oo02ao31cW000L
i`0600D01W`0FSAJ4eXdAME9mTGEBOE5eDWfAME9mCFg>KLe]cVg=KLi]cFg>KLe]cVg8ITU^B6I9KTQ
VBFi8ITU^B6I9KTQVBFi1IX5Vg`00Woo03]k2QcW00HLiaP960PL2AP860TH21`97>L`9c06=2L`1S0W
<0Hd9c06<2L`1S@W<0H`9c06@04l03`1?0100C`0?04l0401?00l0C`0@04U^BWJ9KTYfRFi:MXU^BWJ
9KTYfRFi:MXU^BWJ9KTYfRFi:MXU^G`0039oo`03001oogoo009oo`0017oo00<007ooOol0=Woo00<0
03`0?0000c`000dLi`3C0=@0d`000=<0e1cWNbYg2QcW000Li`0500400acW10840`0310801@@31084
0P@210<00`@200<40g`0O0006Woo00@Li`00000Li`801P07O00LieXCFQAJ4eXDAMD00dWE01a5eDWE
BME9eCFg>KLe]cVg=KLi]cFg>KLe]cVg8KTU^B6i9KTQ^BFi8KTU^B6i9KTQ^BFi8KUl009oo`0<N`XL
i`057>MJ=1P960PH2AP860TH21cW3c0V0S`000Dl0C`0?00l03`100<l000E?04l03`0?00YfRFi9MXU
^BWJ9KTUfRFi:MXU^BGJ9KTYfRFi9MXU^G`003=oo`03001oogoo009oo`0017oo00<007ooOol0=Woo
00<003`0?00013`00QcW00X0e0000=@0dg[`M`Yk:QcW000Li`800@0B00800@017>L40`@210<40P@3
10840`@210<40P@310840g`077oo02`Li`00000Li`06O01bTQcWFSAJ4eXdFQ=9mDGEBOI5eDWeAME9
mTGE>KLe]cVg=KLi]cFg>KLe]cVg=KLi]b6I9KTQVBFi8ITU^B6I9KTQVBFi8ITU^G`00Woo03Yk2QcW
00HLiehd60PH2AP870TH21P97>Ld9c06<2L`1S@W<0H`9c06=2L`1S0W<0Hd9c06<2Ll0401?00l0C`0
@04l03`1?0100C`0?04l0401?00d02Fi:MXU^BWJ9KTYfRFi:MXU^BWJ9KTYfRFi:MYl03=oo`03001o
ogoo009oo`0017oo00<007ooOol0=Woo00<001cW?0001S`000XLi`000=<0e7[?NbYk2QcW000Li`D0
0@057>L40P@210840`03108010@310840P@20W`07Goo00lLi`007>L01W`0KY9^TEXD7>MJ55XCFQAJ
4dWEAMD00dWE01U5eDWEBMDi]cFg>KLe]cVg=KLi]cFg>KLe]cVg8KTU^B6i9KTQ^BFi8KTU^B6i9KUl
0003Ool031cW00D01AcWFS<H2AP860TH21P960PLi`l`9Q=l000;9KTYfRFi9MXU^BWJ9KTUfRFi:MYl
000dOol00`00Oomoo`02Ool000Aoo`03001oogoo03Ioo`04000`0AcW7>L6?0002P007>L0dg[`M`XL
i`00004Li`020`0100d00QcW10<40P@310840`@210<40P@3109l000OOol0:acW000Lig`0LY9^TG:B
KY4LieXCFSAJ4eXdAME9mDGEBOI5eDWeAME9mTGE>KLe]cVg=KLi]cFg>KLe]cVg=KLi]b6I9KTQVBFi
8ITU^B6I9KTQVG`0009oo`0IN`TLi`0500HLieXd60PL2AP860TH21`97>L`9c06=2L`1S0W<0Hd9c06
<2L`1S@W<0H00g`001=1eT7G=KLif3Fg=MPe]cWH=KLef3Fg>MPe]cGH=KLif3Fg:MXU^@03O00022Fi
:MXU^BWJ9KTYfRFiO00dOol00`00Oomoo`02Ool000Aoo`03001oogoo03Eoo`07000`0C01<05ooacW
Ool013`000P003`07>LLig/Z7>L001cW1P0100<Li`@210<00`@200D40`@210840W`001moo`05O`/L
i`00O00Li`03KY401eXD7>MJ55XCFQAJ4eXD0099e@0KAME9eDWEBME5eDWE=KLi]cFg>KLe]cVg=KLi
]cFg>KLe]cVg=KLU^B6i9KTQ^BFi8KTU^G`0009oo`0>N`XLi`0600DLieXd60TH21P960PH2AP860TL
i`P`9P=l00I1ePlef004:MXU^BGJ9KT3O0001BFi:MXU^BGJO000=7oo00<007ooOol00Woo0004Ool0
0`00Oomoo`0eOol00`00<00d0@02<04013007>LLigoo0S`000P003`0?01k:gL:7>L001cW0`0100/0
0P017>L40P@310840`@210<40P@3009l021oo`0[N`/Li`00O00Lig:BKY5bTUXC7>MJ4eXdFQ=J=5XC
BOI5eDWeAME9mTGEBOE5eDWf=KLi]cFg>KLe]cVg=KLi]cFg>KLe]cVg=KLU^B6I9KTQVBFiO0000goo
019k2AcW00D01QcWGS@H21P960PL2AP860TH21cW<0H`9c06=2L4O0007d7F@MM1eT7G@MI1ed7F@MM1
eT7G=KLif3Fg=MPe]cWH=KLef3Fg>MPe]cGH=KLif3Fg:MXU^BWJ9KTYfRFi009l0003:MYl07oo03=o
o`03001oogoo00=oo`0017oo00<007ooOol0=Goo00<001cW<0401C010QcW00Uoo`00?00l07L:NbXL
i`007>L0100100<=NAcW10<00`@200@40`@2109l029oo`0@O`/Lig`0KY4LifjAKY9^TEXD7>MJ55XC
FQAJ4eXDAMD3BMD064GEBME9eDWEAME9eCFg>KLe]cVg=KLi]cFg>KLe]cVg=KLi]cFg9KTQ^BFi8KUl
00=oo`0?N`XLi`0500DLiaP860TH21P960PH2AP860TLic0V00=l00==m@a1eQ0ef0079KTUfRFi:MXU
^BGJ9KT00g`0<Woo00<007ooOol00goo0004Ool00`00Oomoo`0eOol01@00<04Lic00=0400S0100h`
03@1OolLi`00Oomjcg/ZM`XLi`017>L00@020`0100PLi`@210<40P@310840g`08goo02]k2acWO01b
TQcWLY9^TG:BKY4LieXCFSAJ4eXdFQ=J=4GEBOI5eDWeAME9mTGEBOE5eDWf=KLi]cFg>KLe]cVg=KLi
]cFg>KLe]cVg=KLU^B6I9KUl0003Ool03G/97>L01@067>LH2AP870TH21P960PL2AP8009l000ZCOE9
mDgeBOA=mDWeCOE1eT7G@MI1ed7F@MM1eT7G@MI1ed7F@MLe]cWH=KLef3Fg>MPe]cGH=KLif3Fg=MPe
]cWH=KLef2Fi:MXU^BWJ9KTYfW`00P5i0g`0;goo00<007ooOol00goo0004Ool00`00Oomoo`0eOol0
1000709ooacW1c0100D001cWN^mk2P00008Li`H00@057>L40P@210<40P02O00TOol01Gl;7>Ml06jA
7>L00fjA00Y^TUXC7>MJ4eXDFQ=J55XCBME5e@=9e@0EAME9eDWEBME5eCVg=KLi]cFg>KLe]cVg=KLi
]cFg>KLe]cVg=KLU^G`000Aoo`0;N`XLi`067>LH2AP860TH21P960PH2@02O009COD<@MHA=MP01RFi
9MXU^BWJ9KUl00D1N@03O01oogoo02aoo`03001oogoo00=oo`0017oo00<007ooOol0=Goo00L001P2
70=ooacW<00d0@02<0402S00=04003017>Mk:acW000Li`020`0100L00P017>L40P@3109l000VOol0
:QcWO01k2g:B7>MbTVjALY9^TEXd7>MJ=5XCFSAJ4eXdFQ=9mDGEBOI5eDWeAME9mTGEBOE5eCVg=KLi
]cFg>KLe]cVg=KLi]cFg>KLe]cVg=KMl00Aoo`0jN`TLi`057>LH21`960PH2AP870Ul05XdBOA=mDWe
COE9m4geBOE=mDWdCOE9mD7G@MI1ed7F@MM1eT7G@MI1ed7F@MM1eSGH=KLif3Fg=MPe]cWH=KLef3Fg
>MPe]cGH=KLif3Fg=MPU^BWJ9KUl01cW0GX30GT00`5jOoml000]Ool00`00Oomoo`03Ool000Eoo`03
001oogoo03Aoo`06000L0QP2709ooacW1C0100L00301NbYg2QcW000Li`0600401AcW10<40W`07>L0
9Woo00LLig`0O`]^TAcWKY5^TP02KY4025XC7>MJ4eXDFQ=J55XCFQ@2BMD01DGEBME9eDWEAMD00dWE
00i5eCVg=KLi]cFg>KLe]cVg=KLi]cFg>KMoog`01Goo00XLi`0500DLiaP960PH2AP860Ul00=J=0Y=
m@e1eQ8ef0039MYl01Vk008Li`@1N@03Ooml07oo02]oo`03001oogoo00=oo`001Goo00<007ooOol0
=7oo00T001P270<H0Q`37>L`0C00=0400S0100L003@1M`Yk:QcW008Li`0200401@0200400AcW10<0
0W`000@0d`3D7>LLibAoo`0V7>Ml07/;7>M^TG:BKY5bTVjAFS@LieXdFQ=J=5XCFSAJ4eXdAME9mDGE
BOI5eDWeAME9mTGEBODe]cVg=KLi]cFg>KLe]cVg=KLi]`9l00Ioo`077>L01P057>LH21P960P00W`0
039J=5XCEQEJ4dgeBOA=mDWeCOE9m4geBOE=mDWdCOE1eT7G@MI1ed7F@MM1eT7G@MI1ed7F@MM1eSGH
=KLif3Fg=MPe]cWH=KLef3Fg>MPe]cGH=KLif3Fg=MPe]g`05KXI^aFj0acW00@1N@5jOoml02]oo`03
001oogoo00=oo`001Goo00<007ooOol0=7oo00L001`2708L0QP2708Li`04<0401000<05k:W/:0QcW
1P0100@Lig`0?00l008Li`030=@0dacW02=oo`05O01k2gl;7>M^TP03KY402VjBKY4LieXCFQAJ4eXD
FQ=J55XC0dWE00E5eDWEBME9eDGE00=9e@09=KLi]cFg>KLe]cVg=KLi]g`000Moo`09000Li`0500HL
iaP960Ql05Xc00=J=003FS=J=4ge00Y=m@i1eQ0ef008O00E^QVj5KXI^aFj6KYoo`8Li`81N@9l02Uo
o`03001oogoo00=oo`001Goo00<007ooOol0<goo010001cW608L0aP270<H0Q`37>L`0C00=0400301
M`X0008Li`0300400P0100800@03009l03`000@l008Li`030=<LiacW025oo`0UO01o2g/;7>M^TG:B
KY5bTVjALY8LieXdFQ=J=5XCFSAJ4eXdFQ=9mTGEBOE5eDWfAME9mDGEBOI5eDWe=KLi]cFg>KLe]cVg
O0001goo00H001cW7>L01P057>L2O000>UXCFSAJ4ehdFQ=J=5XCCOE9mDgeBOA=mDWeCOE9m4geBOE=
mDWd@MM1eT7G@MI1ed7F@MM1eT7G@MI1ed7F@MM1eSGH=KLif3Fg=MPe]cWH=KLef3Fg>MPe]cGH=KMl
01Fj6K/E^QVk5KXI^aFj6K/E^QVk0QcW00<1NGooO000:7oo00<007ooOol00goo0005Ool00`00Oomo
o`0cOol01000004LiaP20a`200<H0Q`27>L00S0100@00301NbX0008Li`D00@03O00l03`000Hl0004
7>L0d`3D7>LQOol00g`0O`/Li`02KY403VjBKY5^TFjAKY8LieXDFQ=J55XCFQAJ4eXDAMD3BMD01DGE
BME9eDWEAMD00dWE00<e]cVg=KL00W`027oo00<001cW7>L00P0500=l06jBKY800eXd00EJ<eXdFSAF
5EXc00]=m@i1ePdef00>O00E^QVj5KXI^aFj6KXE^QVk5KXI^QFj6K/E^P8Li`03Ooml07oo02Ioo`03
001oogoo00=oo`001Goo00<007ooOol0<goo00X000027>LL0aP270<H0Q`3608Li`8`0@06000d0GL:
7>L00AcW0`0100<00W`07>L02C`00QcW00<0e1cW7>L07goo025l07/;7>M^TG:BKY5bTVjALY9J4acW
FQ=J=5XCFSAJ4eXdFQ=9mDGEBOI5eDWeAME9mTGEBOE5eDWfAMDi]cFgO0002Goo04L002097>LLi`06
O01bTVjAKY9J4ehdFQ=J=5XCGSAJ4eXdBOA=mDWeCOE9m4geBOE=mDWdCOE9mDge@MI1ed7F@MM1eT7G
@MI1ed7F@MM1eT7G@MI1ecFg=MPe]cWH=KLef3Fg>MPe]cGH=KMl01Fj6K/E^QVk5KXI^aFj6K/E^QVk
5KXI^aFj6K/E^QVk008Li`03O01oogoo02Aoo`03001oogoo00=oo`001Goo00<007ooOol0<goo00<L
i`017>L00Q`200XH0Q`2708L0QP27>L`0@00M`Yk:P8Li`@00@03O00`0C01008Li`Tl008Li`030=<L
igoo01ioo`03O00LifjB00=^T@0>KY9^TFjA7>MJ55XCFQAJ4eXDFQ=J55XCBME5e@=9e@05AME9eDWE
BME5e@02BMD00g`0Oomoo`07Ool01`007>LP2G/:7>L01G`000=^TP03FSAJ<eXd009J=003FS=J=5Xd
00a=m@m1ePTef00FO00Y^AcW7>LI^aFj6KXE^QVk5KXI^QFj6K/E^QVj5KXI^aFj6KXE^QcWO00UOol0
0`00Oomoo`03Ool000Eoo`03001oogoo03=oo`0?7>L00QcW70<H0Q`3608L0aP270<H0QcW001k:WL:
008Li`800@0500800G`0<00d0@02<0427>L9?00011cW0=<LiacW7Goo01al01cWKY5bTVjALY9^TG:B
KY4LieXCFSAJ4eXdFQ=J=5XCFSA5eDWeAME9mTGEBOE5eDWfAME9m@9l00Yoo`0j000Lib09N`XLig`0
KY5^TVjALY9J4eXdFQ=N=5XCFSAJ4eHEFQ==mDWdCOE9mDgeBOA=mDWeCOE9m4geBOE1ed7F@MM1eT7G
@MI1ed7F@MM1eT7G@MI1ed7F@MLe]cGH=KLif3Fg=MPe]g`0:KT]fBVi;MT27>L041Fj6K/E^QVk5KXI
^aFj6K/E^QVk5KXI^aFj6K/E^W`09Goo00<007ooOol00goo0005Ool00`00Oomoo`0bOol01@017>L0
0AcW60800a`200PH0Q`2708L0QP2000Li`000QcW0`0100=l0301<040130100<l01cW7>L023`00QcW
00<0e1cWOol077oo00Al06jAKY5^TP=^T@0;KY8LieXDFQ=J55XCFQAJ4eXDFQ=J5002BMD01DGEBME9
eDWEAMD00W`02goo00L003aV7>LP2AcW00Il0004KY83FS@01UXcFSAJ=5XdFS=J=0a=mA11ePDef00I
O00Y^BgI:KT]fBVi;MTY^AcW5KXI^QFj6K/E^QVj5KXI^aFj6KXE^QVk5KXI^QFjO00097oo00<007oo
Ool00goo0005Ool00`00Oomoo`0bOol03QcW00400QcW70<H0Q`3608L0aP270<H0Q`300027>L01`01
7>L00P01O00`03@1008`0@07<00d0C01<04`03`07>L02C`000<Li`3D7>L077oo0W`001EbTVjALY9^
TG:BKY4LieXCFSAJ4eXdFQ=J=5XCFSAJ4dWfAME9mDGEBOH00W`037oo00@001cW>4HlI`8Li`0iO01^
TVjALY9^TFjBFQ=N=5XCFSAJ4ehdFQ=J=5XCCOE9mDgeBOA=mDWeCOE9m4geBOE=mDWdCOE1eT7G@MI1
ed7F@MM1eT7G@MI1ed7F@MM1eT7G@MHif3Fg=MPe]g`0:KT]fBVi;MTY^BgI:KT]fBVi008Li`0>6K/E
^QVk5KXI^aFj6K/E^QVk5KXI^aFj6K]l02Aoo`03001oogoo00=oo`001Goo00<007ooOol0<Woo00LL
i`0200400AcW708H0P0370801AP2708L0P00M`X00QcW0P0100=l0301<0402C0100<l01cW?00023`0
11cW77oo0g`000i^TVjAKY5^TAcWFQ=J55XCFQAJ4eXDFQ=J55XC0TWE0W`03Woo00<004@07>L00acW
00=l06jBKY8016jB00EJ<eXdFSAJ=5Xc00=J=0e=mA11eP8ef00=O00Y^BgI:KT]fBVi;MTY^BgI:KT]
fBVi;MT00QcW00`E^QVk5KXI^QFj6K/E^QVj5KXI^aFjO00SOol00`00Oomoo`04Ool000Eoo`03001o
ogoo039oo`0?7>L00@02004LiaP270<H0Q`3608L0aP270<007/Z008Li`04005l0300=042<0401S00
=04`0C01<00d0@8`0@04<00d0AcW7>L9?0037>LNOol3O0001g:B7>MJ=5XCFSAJ4eXd00Il00moo`14
001404P0A01801cWO01k2G:BKY5^TVjALY9^TEXdFQ=N=5XCFSAJ4ehdFQ=J=4WdCOE9mDgeBOA=mDWe
COE9m4geBOE=mDWd@MM1eT7G@MI1ed7F@MM1eT7G@MI1ed7F@MM1eT7G@MIl02Vi;MTY^BgI:KT]fBVi
;MTY^BgI:KT]fBVi;MTY^@8Li`0;6K/E^QVk5KXI^aFj6K/E^QVk5KYl000ROol00`00Oomoo`04Ool0
00Eoo`03001oogoo039oo`057>L00@01008Li`0370801aP2708L0Q`2608007/:008Li`03O00`0C01
00h`0@03?00Lic`000Tl008Lib1oo`Ml01Eoo`04001404@0B002A0000g`0N`Y^TP05KY82FS@01EXc
FSAJ=5XdFS<00UXd3Dge3T7F0W`001dLibgI:KT]fBVi;MTY^BgI:KT]fBVi;MTY^BgI:KT]fBViOolL
iaVk5KXI^QFj6K/E^QVj5KXI^g`0029oo`03001oogoo00Aoo`001Goo00<007ooOol0<Goo0QcW00d0
0@02004LiaP2OolH0Q`3608L0aP270<000027>L00`01O00Li`02<0401VYa=04`0C01<00d0@8`0@08
<00d0C01<04`03@1<04Li`Xl00<LicUoo`0f0000mQcWB01404P0A01l07/9KY9^TG:BKY5^TVjAGSAJ
4eXdFQ=N=5XCFSAJ4ehdBOE=mDWdCOE9mDgeBOA=mDWeCOE9m4geBOE=mD7F@MM1eT7G@MI1ed7F@MM1
eT7G@MI1eg`0>MPeecWH0QcW010Y^BgI:KT]fBVi;MTY^BgI:KT]fBVi;MTY^BgI:KT]f@8Li`085KXI
^aFj6K/E^QVk5KYl029oo`03001oogoo00Aoo`001Goo00<007ooOol0<Goo00<Li`0100800P0100<L
ia`2Ool00a`200@H0Q`27080008Li`04O00L0QP27>LA<0427>L:?0027>LhOol00`000?D0mP027>L0
14@0B00Lig`01VjB00EJ<eXdFSAJ=5Xc00=J=003FS=J=4ge00a=m@Y1eP9l0006>MPiecWH>MLif3WG
0QcW010]fBVi;MTY^BgI:KT]fBVi;MTY^BgI:KT]fBVi;MTY^@8Li`066KXE^QVk5KXI^W`08Woo00<0
07ooOol017oo0005Ool00`00Oomoo`0aOol05QcW00800@02004LiaP2OolH0Q`3608L0aP270=g2P00
O00L0aP270<H0QcW0S0100H`03@1<04`0C00=042<0401c00=04`0C01<00d0C0100il00037>Moogoo
03=oo`060000m@3f0?D0mP3e0acW04]l07:BKY5^TVjALY9^TEXdFQ=N=5XCFSAJ4ehdFQ=J=5XCCOE9
mDgeBOA=mDWeCOE9m4geBOE=mDWdCOE9mD7G@MI1ed7F@MM1eT7G@MIl03GG>MPeecWH=MLif3GG>MPe
ebgI7>L]fBVi;MTY^BgI:KT]fBVi;MTY^BgI:KT]fBVi;MTY^BgI7>LI^aFj6K/E^QVkO0008Goo00<0
07ooOol017oo0005Ool00`00Oomoo`0`Ool27>L300401P02004Ligoo708H0P<L0P05609k:P00708H
0P0370800aP27>L`0@0:<0400acWO01l0002O0000dWE=KLa]`02<KL00cFg<KLa]`063GT2O00dOol0
2P000?H0m@3f0?D0mP3e0?HLig`01VjB0UXd00EJ<eXdFSAJ=5Xc00=J=0i=m@I1eP9l000<>MLif3WG
>MPiecWH>MLif3WG>MPiebgI0QcW010Y^BgI:KT]fBVi;MTY^BgI:KT]fBVi;MTY^BgI:KT]f@8Li`04
5KXI^aFjO00QOol00`00Oomoo`04Ool000Ioo`03001oogoo02moo`8Li`0G00800@0200400QcW70<H
0Q`3608L0aP270=g2P00608L0aP270<H0Q`3608Li`02<0401C00=04`0C01<00017`001E9eDGEBME5
eDWEAMDe]c6g=KPa]cFg<KLe^36g4GX=NA5j3GTANP3CO000<Woo054001FJ7>LLi`3e0?H0m@3f0?DL
ig`0KY9^TG:BKY5^TVjAGSAJ4eXdFQ=N=5XCFSAJ4ehdFQ==mDWdCOE9mDgeBOA=mDWeCOE9m4geBOE=
mDWdCOE1eT7G@MI1eg`07>LeecWH=MLif3GG>MPeecWH=MLif3GG>MPeebgI:KTLibVi;MTY^BgI:KT]
fBVi;MTY^BgI:KT]fBVi;MTY^BgI:KT00QcW00<I^g`0Ool087oo00<007ooOol017oo0006Ool00`00
Oomoo`0_Ool27>L00`0100800@0200400acW608L0P0270801AP2709k2QcW00000a`200HH0Q`2708L
0QP27>L2<044O003FQ<00dWE7>M9e@05BMD01CFg<KLa]c6g=KL00c6g1Pei0W`0<7oo00@001FI5IXE
VP8Li`060?H0m@3f7>LP2G`01FjB00EJ<eXdFSAJ=5Xc00=J=003FS=J=5Xd00i=m@91eP9l0091eP0S
7>LiecWH>MLif3WG>MPiecWH>MLif3WG>MPiecWH:KTLibVi;MTY^BgI:KT]fBVi;MTY^BgI:KT]fBVi
;MTY^BgI:KT]f@027>L00g`0Oomoo`0NOol00`00Oomoo`04Ool000Ioo`03001oogoo02moo`0J7>L0
0@0200400P01008Lia`3608L0aP270<H0W/[O00001P270<H0Q`3608L0aP270<H0P9l000PJW8LieXD
FQ=J55XCFQA5eAcWAME9eDGEBME5eDWEAMDe]c6g=KPa]cFg<KLe^36g4GX=NA5j3GTANPei4GYl02io
o`07000AVAFJ4ITEVQ6I5IX00QcW02801AcW80Ul06jAKY9^TG:BKY5^TUXCGSAJ4eXdFQ=N=5XCFSAJ
4ehdBOE=mDWdCOE9mDgeBOA=mDWeCOE9m4geBOE=m@9l000Z@MI5md7FAOM1eQcW=MLif3GG>MPeecWH
=MLif3GG>MPeecWH=MLif2Vi7>LY^BgI:KT]fBVi;MTY^BgI:KT]fBVi;MTY^BgI:KT]fBVi;MTY^G`0
87oo00<007ooOol017oo0006Ool00`00Oomoo`0^Ool27>L01`0200400@0100800AcW008L0P09608L
0Q`2709g2W`0000L0QP200<L0P04608L0W`0O003JW801EXD7>MJ4eXCFQ@00UXC00=9eAcWBMD01DWE
00<a]cFg<KL00S6g00De]c6g<KLa]cFg00D=N@03O01oogoo02aoo`05000EVQFJ5IXEV@035IX00aFI
7>LLi`0280T2O004KY800eXdFS=J=002FS@01EXcFSAJ=5XdFS<02Tge17`000E1ed7F@MI1eT7G00=1
eP0T7>LiecWH>MLif3WG>MPiecWH>MLif3WG>MPiecWH:KTLibVi;MTY^BgI:KT]fBVi;MTY^BgI:KT]
fBVi;MTY^BgI:KT]fG`087oo00<007ooOol017oo0006Ool00`00Oomoo`0^Ool27>L05@0100800@02
00400P017>LH0Q`3608L0aP270=l0000608L0aP270<H0P02O00096ibJW5ZLVYaKW9ZLAcWFQ=J55XC
FQAJ4dWE7>M9eDGEBME5eDWEAME9eC6g=KLa]cFh<KLe]c6g=KPa]cFg3GTANPei4GYl02eoo`0<000]
^1cW7>LAVAFJ4ITEVQ6I5IX01AcW0b0901HP2W`0O01^TG:BFQ=J=5XCGSAJ4eXdFQ=N=5XCFSA9m4ge
BOE=mDWdCOE9m@=l000M7>M5md7FAOM1eTGg@MI5md7FAOM1eTGg@MHLicGG>MPeecWH=MLif3GG>MPe
ecWH=MLif3GG>MPee`027>L042gI:KT]fBVi;MTY^BgI:KT]fBVi;MTY^BgI:KT]fG`08Goo00<007oo
Ool017oo0006Ool00`00Oomoo`0^Ool27>L200401P0200400@01008Li`<L0P05608L0Q`2O0000003
708011P2O01jcacW1VYb00<LieXDFQ<00UXC00AJ55XCBMDLi`M9e@03<KLe]c6g008a]`05=KLa]c6g
<KLe]`043GT00g`0Oomoo`0ZOol01000;KP]^7oo0QcW00HEVQFI5IXEVP057>L480T013aV?4Il07`0
0eXd00EJ<eXdFSAJ=5Xc00=J=09=m@Al0006BOEoodWeBODLid7G0d7F00E1ed7F@MI1eT7G0091eP0R
7>Lif3WG>MPiecWH>MLif3WG>MPiecWH>MLif3WG>MPiebgI7>L]fBVi;MTY^BgI:KT]fBVi;MTY^BgI
:KT]fBViO00QOol00`00Oomoo`04Ool000Ioo`03001oogoo02eoo`0E7>L001cW00400P0100800@02
004LiaP270<H0Q`3Ooml01P2000H0Q`3009l000XN/mjl1cWJW9ZLFibJW5ZLVYa7>MJ4eXDFQ=J55XC
FQA5eAcWAME9eDGEBME5eDWEAME9eC6g=KLa]cFh<KLe]c6g=KPa]cFg3GTANPeiO00[Ool00`00;KP]
^@02;KP02Woo;KTLiacW4ITEVP057>LP2B0:0b0900<lIcQ6?6L03G`003I=mTWeCOI9mDgfBOE=mTWe
COHLidGg@MI5md7FAOM1eTGg@MI5md7FAOLLicWH=MLif3GG>MPeecWH=MLif3GG>MPeecWH=MLif3GG
;MTLibgI:KT]fBVi;MTY^BgI:KT]fBVi;MTY^BgIO00QOol00`00Oomoo`04Ool000Ioo`03001oogoo
02eoo`8Li`0300400P0100800@0600800@017>LL0QP20a`200=l01`200000W`000Ejkg[?N_1jcacW
00AZLP06OomZLUXC7>MJ4eXD0eXC00=J54WE7>L024WE00<a]cFg<KL00S6g00Pe]c6g<KLa]cFg<KL=
NG`0:goo00<002fh;KP01Bfh00=ooacW5IT00QcW1B0900PhASaV?4HlISQ6?6HlATP00d@000EF5EHD
EQAF51cW00=9m@09COE9mDWeOom=mDWe7>M1eT7G00=1eP05@MM1eT7F@MI1e`02@MH07acW>MPiecWH
>MLif3WG>MPiecWH>MLif3WG>MPiecWH>ML]fAcW;MTY^BgI:KT]fBVi;MTY^BgI:KT]fG`0025oo`03
001oogoo00Eoo`001Woo00<007ooOol0;Goo0QcW00h00P0100800@0200400P017>LH0Q`3608L0aP2
0W`002d001cWN_1jcg[`N/mjl1cWKW9ZLFYbJW5^LUXCJW8LieXDFQ=J55XCFQAJ4dWE7>M9eDGEBME5
eDWEAME9eDGE=KPa]cFg<KLe^36g=KLa]cFh<KLe]c6gO000:Woo00<003gG7>L00Rfh00H]^Bfh;KP]
^2fi;KP37>L380T0>b0:80TlIcQ6?6LhASaW>4HlIcQ6B01404P0A01F5E8DEQDLidgfBOE=mTWeCOI9
mDgfBOE=mTWe7>M1eTGg@MI5md7FAOM1eTGg@MI5md7FAOLLicWH=MLif3GG>MPeecWH=MLif3GG>MPe
ecWH=MLif3GG>MP00QcW00XY^BgI:KT]fBVi;MTY^BgI:KUl025oo`03001oogoo00Eoo`001Woo00<0
07ooOol0;7oo00<Li`007>L00`0100H00P0100400@027>L3708031P2709l07/Z000Lig[?N_1jcg[_
N/lLi`MZLP057>MJ4eXCFQ=J5003FQ<00dWE7>M9e@07BMD2<KL01CFg<KLa]c6g=KL00c6g00=l07oo
Ool0:Goo00<003WG>ML00QcW1Bfh00Aoobfh7>LLi`HP2@09?6HhASaV?4HlISQ6?6HlATP000=40005
EQEF57oo7>M=m@03BOD01TgeBOEoodWeCODLi`91eP05@MM1eT7F@MI1e`03@MH0847G@MI1eQcW>MPi
ecWH>MLif3WG>MPiecWH>MLif3WG>MPiecWH>MLif2Vi7>LY^BgI:KT]fBVi;MTY^BgIO00QOol00`00
Oomoo`05Ool000Ioo`03001oogoo02aoo`0?7>L001cW00800@0200400P0100800@027>LL0aP2009l
000]Nb]g2P007>Mjl7[?N_1jcg[`7>MZLVYaKW9ZLFYbJW5^LQcWFQAJ4eXDFQ=J55XCFQA5eAcWAME9
eDGEBME5eDWEAME9eDGE=KPa]cFg<KLe^36g=KLa]g`002]oo`09000i]cgG>KHmecVg7>L]^2fi00<]
^005OolLiacW80TP2P0380T0AB0:>4HlIcQ6?6LhASaW>4HlIcQ6B01404P0A018058D7>M9mDgfBOE=
mTWeCOI9mDgfBOE=mQcWAOM1eTGg@MI5md7FAOM1eTGg@MI5md7FAOLLicWH=MLif3GG>MPeecWH=MLi
f3GG>MPeecWH=MLif3GG>MPY^AcW:KT]fBVi;MTY^BgI:KUl000QOol00`00Oomoo`05Ool000Ioo`03
001oogoo02aoo`057>L001cW00400P0300401@0200400@017>L00W`000`Lig`0M`Yk:P007>Mjcg[_
N/mjl7[?7>L6JW8017ooFQ<LieXD0eXC00AJ55XCFQ<Li`Y9e@8a]`05=KLa]c6g<KMl000/Ool01`00
7>LiecgG>MMoocWG008Li`@]^08Li`HP2@0;?6HlASaV>4HlISa6?6HhASaV?4I80003A0001DP0BOE9
mDWeCOD00dWe00I=mGooBOE9mGoo7>L2@MH01D7G@MI1eT7F@ML00d7F01e1ed7F@MHLicWH>MLif3WG
>MPiecWH>MLif3WG>MPiecWH>MLif3WG>MPieacW:KT]fBVi;MTY^G`0029oo`03001oogoo00Eoo`00
1Woo00<007ooOol0;7oo03dLi`027>L00P0100800@0200400P01009l01cWAME9eG`0NbYg2P007>Mj
l7[?N_1jcg[`7>M^LVYaJW9ZLFibJW5ZLVYa7>MJ4eXDFQ=J55XCFQAJ4dWE7>M9eDGEBME5eDWEAME9
eDGEBME5eCFh<KLe]c6g=KQl000[Ool02P00AOHi]QcW>KLmecVfOoli]goo0QcW0Rfh0QcW0b0904HP
2R0980ThASaW>4HlIcQ6?6LhASaW>4HlIcQ6B01404P0A01804@0COI9mDgfBOE=mTWeCOI9mDgfBODL
id7FAOM1eTGg@MI5md7FAOM1eTGg@MI5md7FAOLLicWH=MLif3GG>MPeecWH=MLif3GG>MPeecWH=MLi
f3GG>MPeeacW:KT]fBVi;MUl029oo`03001oogoo00Eoo`001Woo00<007ooOol0:goo00@Li`007>L0
0P<00@0600800@0100400W`00UHD00dLidGEAMEl07/Z000Lig[?N_1jcg[_N/lLi`08JW8011cWFQ=J
4eXD0eXC00=J55XC7>L02TWE0c6g00<e]g`0Ool0:goo00h004GFAMHieacW>MLmecWGOoliecgG;KPL
ibfh0QcW1b0900`hASaV?4HlISQ6?6HlASaV>4HlIT@0B003A0001DP0A019mDWeCOD00dWe00EoodWe
BOE9mAcW00=1eP05@MM1eT7F@MI1e`03@MH05T7G@MHLicWG>MPiecWH>MLif3WG>MPiecWH>MLif3WG
>MPiecWH>MLif3WG0QcW00<]fBViO0008Woo00<007ooOol01Goo0006Ool00`00Oomoo`0[Ool0?1cW
000Li`0100800@0200400P01009l01cWDO=F51cWBME5eG`0M`X001cWN_1jcg[`N/mjl6Ya7>MZLFib
JW5ZLVYaKW9ooacWFQ=J55XCFQAJ4eXDFQ=J54GE7>M5eDWEAME9eDGEBME5eDWEAME9eC6g=KQl02ao
o`0>7>M1eDGf@MI5mT7E7>Li]cgG>KIoocVg?ML]^0<Li`0380TP2R09008P2@1380XP2CaW>4HlIcQ6
?6LhASaW>4HlIcQ6?6M404P0A01804@0B01404P0BOE=mTWeCOI9mDgfBOE=mQcWAOM1eTGg@MI5md7F
AOM1eTGg@MI5md7FAOM1eQcW=MLif3GG>MPeecWH=MLif3GG>MPeecWH=MLif3GG>MPeecWH=MLif1cW
O0008goo00<007ooOol01Goo0006Ool00`00Oomoo`0[Ool00acW000Li`020040200200400@01009l
068c7>L3EQ@03AcWBMEl07/Z000Lig[?N^mjcg[`N/mZLQcW00QZLP057>MJ4eXCFQ=J5003FQ<00eXD
7>M9e@0:BMD00g`0Oomoo`0YOol200001Dge7>M5eTGFOol00TGF00PLicWG?MLiegoo>MLme`050QcW
1b0900XlASaV>4HlISa6?6HhASaV?4HlIPEl00940005B01404@0BOE=m@02BOD01WooCOE9mDWe7>M1
e`=1eP05@MM1eT7F@MI1e`03@MH0647G@MHLicWG>MPiecWH>MLif3WG>MPiecWH>MLif3WG>MPiecWH
>MLif3WG>MQl02=oo`03001oogoo00Eoo`001Woo00<007ooOol0:Woo03TLi`00000Li`0100800@02
00400W`0HU=N<V9C7>MF557cEQ@LidWEO00001cWN_1jcg[`N/mjl6Ya7>MZLFYbJW5^LVYaJW9ZLFib
7>MJ55XCFQAJ4eXDFQ=J55XCBMDLidWEAME9eDGEBME5eDWEAMD00W`0:Goo0`00015=mDWeCOHLidGf
@ME5mT7FAOHi]QcW>KLmecVf?MLi]`05008Li`<P2@0880XP2B0980TP2SQ6?6LhAPIl0005EQEB55HE
DQ@EVP06O000:dWeCOI9mDgfBOE=mTWe7>M1eTGg@MI5md7FAOM1eTGg@MI5md7FAOM1eTGg@MHLicGG
>MPeecWH=MLif3GG>MPeecWH=MLif3GG>MPeecWH=MLif7`002Aoo`03001oogoo00Eoo`001goo00<0
07ooOol0:Goo00DLi`00000Li`0200<00@07009l06jB7>MR<goo7>L00eHD00a5eAcWO00007[_N/mj
l7[?N^mjcfYb7>L8JW800acWFQ=J5003FQ<01EXDFQ=J4eXC7>L01dWE00=l07ooOol04Woo2`002Goo
00H001cW001F5Dge7>L4COD00acWAMI5eP03AMH013WG7>LiecgG0SWG00<01AcW7>L022090g`000AN
Df9C7>MF5@=F5007EQEF55HDEQ@EVQFI5IX00QcW00`0mG`0O01l04WeOom9mDgeBODLid7F@ML3@MH0
1D7G@MI1eT7F@ML00d7F01E1ed7F7>LiecWH>MLif3WG>MPiecWH>MLif3WG>MPiecWH>MLif3WGO000
97oo00<007ooOol01Goo0007Ool00`00Oomoo`0YOol0=QcW000Li`0200400P01009l06jBJW8Liehb
HU=N<QcWDO=F557c7>Ml0000N/mjl7[?N_1jcg[`N/lLifYaKW9ZLFYbJW5^LVYaJW8LieXDFQ=J55XC
FQAJ4eXDFQ=J54GE7>M5eDWEAME9e@9l00ioo`037>L0000000@0000;70T00`0400<017LZNb]g:W/[
7>MjlP0900006eiD7>MF5EHDEQDLidgfBOE=mDWeCOHLidGf@MEood7FAOHi]QcW>KLmecVf7>L01AcW
80TP2P0380T05R0:O01l05hcHU@]^69DGS<Lie8DEQEB55HEDQAF5E8DEQEB51FJ4ITEVQ6I0QcW02T0
mP3eO019mDgfBOE=mTWe7>M1eTGg@MI5md7FAOM1eTGg@MI5md7FAOM1eTGg@MHLicGG>MPeecWH=MLi
f3GG>MPeecWH=MLif3GG>MPeeg`002Eoo`03001oogoo00Eoo`001goo00<007ooOol0:7oo00@Li`00
000Li`<00@03009l01cW009^TP057>MR<f8cHS<Li`04EQ@02QcW001jl7[?N^mjcg[`N/mjkacW2FYb
00@LieXCFQ=J50=J4`04FQAJ4eXC7>L3BMD00g`0Oomoo`0?Ool01AcW?6LlIQcW70P00a`90`0317LZ
00dLigKaM_5flAcWJW=ZTfYc7>MN=5iDGS@Li`03EQ@00acWCOE=m@03COD00dGF7>M5eP04AMH01cWG
7>LiecgG7>L01AcW00DP2@09O01RDf9CHUANDbfhHU=RE1cW009F5005EQEF55HDEQAF5@03EQ@00acW
5ITEVP025IX27>L00`3eO01l0002BOD01Dge7>M1eT7F@ML00d7F00E1ed7F@MI1eT7G00=1eP0A@MM1
eQcW>MLif3WG>MPiecWH>MLif3WG>MPiecWH>MMl000VOol00`00Oomoo`05Ool000Moo`03001oogoo
02Qoo`0d7>L000007>L00P01009l06jB7>M^TVYb7>MN<V9CGS8Lie7cEQAAleHD7>L007[?N_1jcg[`
N/mjl7[?7>MZLFYbJW5^LVYaJW9ZLFibJW4LieXCFQAJ4eXDFQ=J55XCFQAJ4dWE7>L2O00COol0<QcW
?6LhAQcW70PP2A`800@00`04MbYk:gLZ7>MfdG[aM]5jlQcWJY=VLVZC7>MNE5hcHU@LieHEDQAF5EHD
7>M9mDgfBOE=mDWe7>M1eTGfOom5mT7FAOHi]QcW>KLLi`057>L380T2O0006QcWGS=RE5hcHUAN<f9D
GS<Lie8DEQEB55HEDQAF5E8DEQEB55HE7>M=mQ6I5IXAVAFJ4IT27>L0903fO01=mTWeCOHLidGg@MI5
md7FAOM1eTGg@MI5md7FAOM1eTGg@MI5md7F7>LeecWH=MLif3GG>MPeecWH=MLif3GG>MQl02Ioo`03
001oogoo00Eoo`001goo00<007ooOol0:7oo00dLi`00000Li`01009l07[aKY8LifZBKY8Li`04HS<0
0acWEQAF5002EQ@02@00O01l07[`N/mjkg[?N_0Li`09JW800acWFQAJ4`02FQ<01EXDFQ=J4eXCFQ@0
0W`00Woo00<001cWOol04Goo00TLicaW7>LlIa`870T00`0400<00gLZ010LigKaM_5jlGKa7>MZLfZC
JW<LiehdGUAN=1cWEQAF5@9F50037>M=mDge00A=m@037>M5eTGF00A5eP05>MLLiacW00DLi`0280T0
1W`0K[8ieacWHUAND`9RD`05HUANDf9CEQ@Li`03EQ@01EHEEQAF55HDEQD00UHD00<Lidge5IT00aFJ
00DEVAFJ7>LLig`00099m@057>M1eT7F@MI1e`03@MH01D7G@MI1eT7F@ML00d7F00i1eacW>MPiecWH
>MLif3WG>MPiecWH>MLif7`09goo00<007ooOol01Goo0007Ool00`00Oomoo`0WOol06QcW00000000
7>L00W`0N_5fd6jB7>M^TVYbKY8Lif9CGS9ooacWEQAAleHDDO<001cWBMD2O00057[?N_1jcacWJW5^
LVYaJW9ZLFibJW5ZLVYa7>MJ4eXDFQ=J55XCFQ@3O00010007>L000000S`000<LigooOol047oo030L
icaW7>LlIa`880T00`04MbYk:gLZ7>MfdG[bM]4LifIbJY=ZLgoo7>MRE5hcGUAN<acWEQAF5E8DCOHL
idgeBOE=mTWeCOE1eAcW@MIood7EAOI1eTGf>KHLi`057>L2O0008VjAL[8i]QcWGS=RE5hcHUAN<f9D
GS=RE1cWEQEB55HEDQAF5E8DEQEB55HEDQ@LidWeCOHAVAFJ4ITEVQ6I5IXAVAcW0W`001e9mAcW@MI5
md7FAOM1eTGg@MI5md7FAOM1eTGg@MI5md7FAOLLicWH=MLif3GG>MPeecWH=MLif7`002Moo`03001o
ogoo00Ioo`001goo00<007ooOol09goo00/Li`00000Li`02O00LigKAN_5ooacW009^TP03JY8Lif8c
00=R<`077>MF55HDEQ@001cW;0D00R`60W`000=jkacWJW802FYb00<LieXCO0000g`000=oo`007>L0
0PeI0QcW0c`000<LigooOol047oo0QcW00<lISaW70P00P030gLZ00lLig[aM_5flAcWJY=ZLfZCJW<L
iehdGUAN=5iD7>L00UHD00=F5EHD7>L01Tge00<LidGFAMH01DGF00DLi`05O01b/Vjb00=b/P0<7>MR
Df9CHUANDf9C;KQRE5iC7>MF55HE0eHD00IF5EHDEQAF55HE7>L2BOD00dge5ITEVP025IX021FI5IXE
VQFJ7>Ml01cW@ML3@MH01D7G@MI1eT7F@ML00d7F00i1ed7F@MI1eT7G7>Lif3WG>MPiecWH>MLif7`0
:7oo00<007ooOol01Woo0007Ool00`00Oomoo`0WOol07QcW000001cWO01oCacWN_5fdGoo7>M^TVYb
KY8Lif9CGS9RDehb7>MAleHDDO<0057c7>L/1C06;0D/1Pil009oo`05000Li`00<KP9F@027>L010ei
2ETLiacW0S`00QcW4Goo0QcW06hhASaW00<017LZNb]g:QcWM]5jlGKA7>MZLfZCIW9ZTacWGUAN<f9D
GS<Lie8DEQEF55HEBODLidWeCOE9mDgfBOE5mQcWAOI1eTGf@ME5mT7F7>L01G`0KY5b/VjAL[9^TAcW
GS=RE5hcHUAN<f9DGS=RE1cWEQEB55HEDQAF5E8DEQEB55HEDQAF5AcWCOI9mDgf4ITEVQ6I5IXAVAFJ
4ITEVQ6IO00LidGg@MI5md7FAOM1eTGg@MI5md7FAOM1eTGg@MI5md7FAOLLicWH=MLif3GG>MPeeg`0
:7oo00<007ooOol01Woo0007Ool00`00Oomoo`0WOol031cW000007`0Obmo;QcWM]5jlGoo7>MZTP9^
TP037>MR<f8c00=R<`057>MF55HD000Li`02;0H01B`5;0H/1R`67>L00T0Q00E48T0Q@2508C`000<L
i`9oo`0:000Lid7F@MDLic6G<KLaU`eI7>L23ET00c`07>Ll0002?0000acWOomoo`0?Ool01AcW?6Ll
IQ`900<00WLZ015ooacWM_5flG[a7>MZTfYcJY=ZLacWGSANE5hdGU@LieHE00=F5003EQDLidge00E=
m@04AMHLidGFOol3AMH00acWO00Li`03L[801FjbL[8Lif9DGU<00V9C00ERE5iCHU=RDacW00=F5005
EQEF55HDEQAF5@03EQ@01QcWBOE9mDWeCODEV@<EVP085ITEVQFJ5IYl04We7>M1e`=1eP05@MM1eT7F
@MI1e`03@MH02d7G@MI1eT7F@MLLicWH>MLif3WGO000:Goo00<007ooOol01Woo0007Ool00`00Oomo
o`0VOol0:AcW000007`0Odmo;Wm?7>MjlGK@OolLifjBJW9^TQcWHU=N<V9CGS9RDacWEQAAl`007>L`
1R`5;0H/1C06;0D/1QcWA4908DA2@254@T0QA4800acW00l004Wd@MHLid7F@KDLic6G<KP]U`ei7>L=
N@UI3GT00QcW00<l04007>L04Goo06`LicaW>4H017LZNb/Lig[aM]5jlWKA7>MVLVZCJW=ZTacWHUAN
<eiDGS<LieHDEQEB55HEEQ@LidWeCOI9mDgeBOE=mTWe7>M1eDGf@MI5mP057>Ml01cWKY5b/VjAL[9^
TAcWGS=RE5hcHUAN<f9DGS=RE1cWEQEB55HEDQAF5E8DEQEB55HEDQAF5AcWCOI9mDgfBOE=mQ6I5IXA
VAFJ4ITEVQ6I5IYl01cW@MI5md7FAOM1eTGg@MI5md7FAOM1eTGg@MI5md7FAOM1eTGg7>Lif3GGO00Z
Ool00`00Oomoo`06Ool000Moo`03001oogoo02Ioo`0<7>L00000O01o;Wl_7>MjlGKAN_5ooacW0VjB
00=ZTQcWHS<00f8c00MooacWEQAF500030DLi`03;0H01B`5;0H/1R`67>L00T0Q00I48T0Q@2508D@R
?0027>L02dgeCOA1eQcW@MI1eAcW<ILa]goo<KL00QcW0`eI0QcW00<l01cWOol03goo0acW00HlIWLZ
MbXLigKaN_42M_402acWJY=ZLfZCJW<LiehdGUAN=5iD7>L00UHD00EF5EHDEQA=mAcW00I=m@0;AMHL
idGFOom5eQcWO01o2acWL[9^/P03L[801AcWHU=RDf9DGU<00V9C00DmeeiC7>MF55HE00=F5009EQEF
55HDEQAF5EHDBODLidge00=9m@03CODEVAFJ008EVP085ITEVQFJO019mAcW@MI1e`=1eP05@MM1eT7F
@MI1e`03@MH0247G@MI1eT7F@MLLicWHO00ZOol00`00Oomoo`06Ool000Moo`03001oogoo02Ioo`0/
7>L007`0ObioCgl^7>Mfd7[aM]5ooacWKY9ZLVjBJW8LiehbHU=N<V9CGS8Lie7c001AlacW;0D`1R`5
;0H/1C06;0D/1QcWA4908DA2@254@T0QA489F@<Li`05BO@Lid6e@MI1]@027>L02c6h;ILa^0eI7>L9
F@ei3ETl01cW@0000QcW3Woo0QcW06ThAQcW>4Ik:acWN_9fdG[aM]4LifYcJY=VLVZC7>MNE5hcHUAN
<acWDQAF5EHDEQEB55HE7>M=mDWeCOI9mDgeBOE=mT7F7>M1eDGf7>Ml07/;7>M^TG:bKY5b/VjA7>MN
<f9DGS=RE5hcHUAN<f9D7>MF5E8DEQEB55HEDQAF5E8DEQEB55HEDQ@LidWeCOI9mDgfBOE=mQ6I5IXA
VAFJ4ITEVQ6IO00LidGg@MI5md7FAOM1eTGg@MI5md7FAOM1eTGg@MI5md7FAOM1eTGgO000:goo00<0
07ooOol01Woo0007Ool00`00Oomoo`0UOol03QcW000007`0Obmo;Wl_7>MjlGKAN_5ooacWJY83KY80
0acWHS=R<`03HS<00acWEQ@0000230D00acW;0D/1P02;0H01B`5;0H/1R`67>L00T0Q00I48T0Q@250
8D@R@2437>L0347E7>M1eT7F@ME1eQcW<KLaUc6g<ILLi`@=F@8Li`03?00LiacW00eoo`067>LlIcaV
7>LlIQcW0gKa00ejlAcWJY=ZLfZCJW<LiehdGUAN=5iDGS@Li`03EQ@015HEEQA=mAcW1dge00LLidGF
AMHLig`0O`/Li`03L[801FjbL[8Lif9DGU<00V9C00ERE5iCHU=RDacW00=F5005EQEF55HDEQAF5@03
EQ@01EHE7>M9mDWeCOD00dWe00==mAFI5IX00QFJ00DEVAFJO01=mAcW0091eP05@MM1eT7F@MI1e`03
@MH01T7G@MI1eT7F@MM1eP9l02aoo`03001oogoo00Ioo`001goo00<007ooOol09Goo030Li`00O01o
Cgl^Odmo;QcWM]5jlGK@OolLifjBJW9^TVYb7>MN<V9CGS9RDehbHU<Li`0020D<1AcW;0H/1C06;0D/
1R`5<0H/1B`67>M4@T0QA4908DA2@254@T0Q3ET47>L02D6e@MI1]D7F7>La^2fG<KPaU`027>L01@ei
3ET=NC`07>L00S`000<LigooOol02Woo0QcW06DlIacW?6LhAW[aM]5jlQcWJY=VLVZCOomZTacWHUAN
<eiDGS=RE1cWEQEB55HEEQAF5E8D7>M9mDgeBOE=mTWeCOE9mDGf7>M5mW`0Obak2acWKY5b/VjAL[9^
TAcWGS=RE5hcHUAN<f9DGS=RE5hc7>MB55HEDQAF5E8DEQEB55HEDQAF5E8D7>M9mDgfBOE=mTWeCOI9
mDgf7>LEVQ6I5IXAVG`0BODLid7FAOM1eTGg@MI5md7FAOM1eTGg@MI5md7FAOM1eW`002ioo`03001o
ogoo00Ioo`001goo00<007ooOol09Goo00dLi`00O01o;Wl_Obio;acWN_5fdG[aOolLi`02KY800fZB
KY8Li`06HS<021cW30D000`5;0HLib`6;0D3;0H01B`5;0H/1R`67>L00T0Q00E48T0Q@2508D@R0090
8@@Li`0;@MIood7E@MHLic6g<ILa]c6G<KLLi`043ET27>L00c`07>Moo`0:Ool27>L05SaV?6LLicaW
?6IjlGKa7>MZLfZCJW=ZTfYc7>MN=5iDGSANE5hd7>MF55HE0eHD00=F5AcWCOD01dge00DLidGFO01k
2acW009b/P05K[9b/W:bL[8Li`02HU<02F9DGU=RDf9CHU@ief9C7>MF5@03EQ@01EHEEQAF55HDEQD0
0eHD00DLidWeBOE9mDge00=9m@03CODLiacW008EVP045IUl04We7>L3@MH01D7G@MI1eT7F@ML00d7F
00=1ed7FO000;goo00<007ooOol01Woo0007Ool00`00Oomoo`0TOol0=1cW001l01cWOdmo;Wm?ObhL
igK@N_5fdGoo7>M^TVYbKY9ZLQcWGS9RDehbHU=N<WooGS8Li`0030D81AcW;0D/1R`5<0H/1B`6;0D`
1R`5;0HLidA2@254@T0QA4908DA2@254@PUI0acW00Y1]Goo@KE1eQcW<KP]Uc6h<ILa^08Li`063ET=
N@UI@00Lic`00QcW2Goo00DLia`87>LhASaW008Li`19>4IjlAcWJY=ZLfZCIW9ZTacWGUAN<f9DGS=N
E1cWEQEF55HEDQAF5EHDCODLidgfBOE=mDWeCOI9mDgeBODLig`0Ob`Lig:bKY5b/VjAL[9^TAcWGS=R
E5hcHUAN<f9DGS=RE5hc7>MB55HEDQAF5E8DEQEB55HEDQAF5E8DEQDLidgfBOE=mTWeCOI9mDgfBOD0
0Rfh0QcW00lEVW`0COI9mAcW@MI5md7FAOM1eTGg@MI5md7FAOL00W`0<7oo00<007ooOol01Woo0008
Ool00`00Oomoo`0SOol03acW001l07l_Obio;gl^7>MfdG[aM]5jlGKA7>MZTP03KY800fZB7>MR<`05
HS<01AcW000<1@`57>L00b`600D/1B`6;0H/1R`500</1P047>M08D0QA283@24014@R@2508D0Q0acW
0T7F00U1eD7F7>La]c6GOolaUc6g<IL00QcW0`eI0QcW00<l01cWOol01goo01HLia`970PLicaV?6Ll
IQcW?6HLifYcJY=ZLfZCJW<LiehdGUAN=5iDGS@Li`=F5005EQEF55HDEQ@Li`08COD01DGF7>Ml01cW
K[800g:b00E^/W:b7>MRE5iC009RD`06HUANDf9CHU=RE1cW0UHD00EF5EHDEQAF55HE00=F5005EQEF
51cWBOE=m@03BOD014geBOE9mDWe0bfh0QcW00Al04We7>M1e`=1eP06@MM1eT7F@MI1eg`0<Woo00<0
07ooOol01Woo0008Ool00`00Oomoo`0SOol0=QcWO00Ligl^Odmo;Wm?7>MjlGKAN_5fd7[a7>M^TVYb
KY9ZLVjB7>MRDehbHU=N<V9C7>L<1@0030D81@`57>L`1R`5;0H/1C06;0D/1R`5<0H/1B`67>M4@T0Q
A4908DA2@254@T0QA4908@<Li`04@KE1eT6e@MH27>L02bfGOolaUc6h;IL=NAcW3GT9F@ei3ET00acW
1goo060Lia`870TLicaW>4HlIcQ67>LhAVZCIW9ZTfYcJY<Lif9DGS=NE5hcHUAN<acWDQAF5EHDEQEB
55HEBODLidWeCOI9mDgeBOE=mTWeCODLig`07>Mb/VjAL[9^TG:bKY4LiehcHUAN<f9DGS=RE5hcHUAN
<acWDQAF5E8DEQEB55HEDQAF5E8DEQEB55HEDQ@LidWeCOI9mDgfBOE=mTWeCOI9mDgf;KP]^BfhO019
mDgf7>M5md7FAOM1eTGg@MH2O00cOol00`00Oomoo`06Ool000Qoo`03001oogoo02=oo`0>7>Ml01cW
Obmo;Wl_ObhLigKAN_5fdG[aM]4Li`9^TP04JY9^TVjB7>L5HS<00acW30D0000330D00acW;0D/1P02
;0H01B`5;0H/1R`6;0D00b`600@Lid0Q@2548P=08@03A2908AcW00=l008Li`0<@MI1eD7F@MHLic6G
<KLaUc6g<IL=FAcW10eI00@l01cW7>LLi`Eoo`0H7>LL2A`97>LlISaW?6HlIcaV7>LlIVZCJW=ZTfYc
7>MN=5iDGSANE5hdGU@LieHE0eHD00AF5EHDEQ@Li`U=m@05O00Lig:bL[9^/P03L[801AcWHU=RDf9D
GU<00V9C00ERE5iCHU<LieHE00=F5005EQEF55HDEQAF5@03EQ@01EHE7>M9mDWeCOD00dWe00E=mDWe
BOE9mDge008]^006O01=mDWe7>M1eT7G0d7F00=l07ooOol0<goo00<007ooOol01Woo0008Ool00`00
Oomoo`0ROol0<QcWO01[:1cWObioCgl^OdlLig[aM]1jlGKAN_4LifjBJW9^TVYbKY8Lif9CGS9RDehb
HU<Li``5000<1@P530DLib`6;0D`1R`5;0H/1C06;0D/1R`5<0H/1B`67>M4@T0QA485O0000acW2ET=
F@02O00031cW@MI1]D7F@KDLibfG<KPaUc6h;ILa^08Li`042ET=N@eI3GT37>L4Ool0GacW70PP2A`8
7>LhASaW>4HlIcQ67>LhAVZCIW9ZTacWGUAN<f9DGS=NE5hc7>MF55HEDQAF5EHDEQEB51cWBOE=mDWe
COI9mDgeBOE=mTWeO00Lig:bKY5b/VjAL[9^TAcWGS=RE5hcHUAN<f9DGS=RE5hcHU@LieHEDQAF5E8D
EQEB55HEDQAF5E8DEQEB51cWBOE=mTWeCOI9mDgfBOE=mTWeCOI9mBfhO01=mTWeCOI9mAcW@MI5md7F
O000=Woo00<007ooOol01Woo0008Ool00`00Oomoo`0ROol041cWO00Ligl^Obmo;Wl_ObhLigKAN_5f
dG[aM]4LifZB0fjB00=ZTQcWHS<0168c00<Li``5000010`500<Lib`6;0D00b`600D/1B`6;0H/1R`5
00</1P=l0003=KLa]cFg008e]`03<KLLiacW0089F@9l000=7>M1eD7F@MHLic6G<KLaUc6g<ILa]`eI
7>L010eI00<l01cW7>L00goo01LLia`970PL2AcW?6LlISaW?6HlIcaV7>MZLfZCJW<LiehdGUAN=5iD
GSANE1cW009F5007EQEF55HDEQAF5Dge7>L02Dge00=l06jbL[800W:b00E^/W:b7>MRE5iC009RD`09
HUANDf9CHU=RE5iC7>MF55HE00=F5005EQEF55HDEQAF5@02EQ@00dWe7>M9m@02BOD01DgeBOE9mDWe
COD00dWe00Ml04WeBOE9mDge7>M1eP02O00fOol00`00Oomoo`07Ool000Qoo`03001oogoo029oo`0]
O01_:AcWOdmo;Wm?ObioCacWN_5fdG[aM]1jlAcWKY9ZLVjBJW9^TVYb7>MN<V9CGS9RDacW30D000`5
20D<1@P57>L/1B`6;0D`1R`5;0H/1C06;0D/1R`5009l000?=KLLicFg<ILe]c6F=KLaUcFg<IHe]acW
3ET9F@eI009l000A@KE1eT6e7>L]Uc6h<ILa^2fG<KPaUacW2ET=N@eI3GT9F@037>L03Goo7>LL21`9
70PP2AcW?6LhASaW>4HlIcQ6008Li`1<JY<Lif9DGS=NE5hcHUAN<acWDQAF5EHDEQEB55HEEQAF5AcW
COI9mDgeBOE=mTWeCOE9mDgfO01b/VjAL[9^TG:bKY4LiehcHUAN<f9DGS=RE5hcHUAN<f9D7>MF5E8D
EQEB55HEDQAF5E8DEQEB55HEDQAF5AcWCOI9mDgfBOE=mTWeCOI9mDgfBOE=mW`0COI9mDgfBOD2O00h
Ool00`00Oomoo`07Ool000Qoo`03001oogoo025oo`0@7>Ml06/Y7>Mo;Wl_Obio;gl^7>MfdG[aM]5j
lGKA7>L2KY801FZBKY9^TVjB7>L0168c00<Li``5000010`500D/1AcW;0H/1R`500</1P05;0E5eG`0
O01N<`02AMD00cFg7>Le]`02=KL01c6g=KLe]cFg<KM=mAcW00<9F@03O011eT7E0091eP8Li`06<KMo
oc6g<ILa]c6G0QcW10eI11cW0a`900XL21cW?6HlIcaV?6LlISaW?6HlI`8Li`08GSANE5hdGUAN=5iD
GS@Li`=F5005EQEF55HDEQ@Li`0:COD00g`0L[9^/P03L[801AcWHU=RDf9DGU<00V9C00ERE5iCHU=R
DacW00=F5005EQEF55HDEQAF5@03EQ@01EHEEQ@LidWeCOD00dWe00E=mDWeBOE9mDge0099m@Al03Yo
o`03001oogoo00Moo`0027oo00<007ooOol08Goo02Yl06/YKbTLigm?ObioCgl^7>MfdG[aM]1jlGKA
N_4LifjBJW9^TVYbKY9ZLQcWGS9RDehbHU<Li``5000<1@P530D81@`57>L`1R`5;0H/1C06;0D2O000
8dWEAME9eEhcBME5eCFg7>Le]c6G=KLaUSFg<ILe]c6F=KLLi`eI2EUl046e@MI1]D7F@KDa^1cW<KQo
oc6h;ILa^36G<KP00QcW00@=FGoo2ET=N@8Li`1C70PP2A`870TL21cW>4HlIcQ6?6LhASaW>4HlIacW
GUAN<f9DGS=NE5hcHU@LieHEDQAF5EHDEQEB55HEEQ@LidWeCOI9mDgeBOE=mTWeCOE9mDgfO01b/VjA
L[9^TAcWGS=RE5hcHUAN<f9DGS=RE5hcHU@LieHEDQAF5E8DEQEB55HEDQAF5E8DEQEB55HEBODLidWe
COI9mDgfBOE=mTWeCOI9m@02O00nOol00`00Oomoo`07Ool000Qoo`03001oogoo025oo`0AO01[:AcW
Obmo;Wl_Obio;acWN_5fdG[aM]5jlGKA7>MZTP03KY800fZBKY8Li`04HS<00acW30D0000530D00acW
;0D/1P02;0H2O0000dGEBME5e@02AMD01TWEAME5eDGE=KLLi`<e]`06<KLe]cFg=KLa]cFg0QcW00D9
FG`0@MI1eT7E0091eP0;OolLic6gOola]c6G<KLaUc6g3ETLi`043ET37>L370T051cW?6LlISaW?6Hl
IcaV?6LlISaW7>MNE5hdGUAN=5iDGS@LieHDEQD3EQ@015HEEQAF51cW2dge0W`000E^/W:b7>MRE5iC
009RD`09HUANDf9CHU=RE5iC7>MF55HE00=F5005EQEF55HDEQAF5@03EQ@01EHE7>M9mDWeCOD00dWe
00E=mG`0O00]^7`003ioo`03001oogoo00Moo`0027oo00<007ooOol08Goo02Il06/X7>Mo;Wm?Obio
Cgl^7>Mfd7[aM]5jlGK@N_4LifjBJW9^TVYbKY9ZLQcWGS9RDehb000Li``5000<1@P530D81@`520DL
ib`50W`002eF51cWBME5eDWEAME9eDGEBME5eDWEAMDe]acW=KLaUcFg<IHe]c6G=KLaUSFg@KDLig`0
@MI1]D7F@KE1eT6e@MHLic6hOola^2fG<KPaUc6h;ILLi`eI3GT00QcW04hL21`97>LP2A`870TLicaW
>4HlIcQ6?6LhASaW>4HlIacWGUAN<f9DGS=NE1cWEQEF55HEDQAF5EHDEQEB54gf7>M=mDWeCOI9mDge
BOE=mTWeCOE9mAcW@MIl06jA7>MN<f9DGS=RE5hcHUAN<f9DGS=RE1cWEQEB55HEDQAF5E8DEQEB55HE
DQAF5E8DEQEB51cWBOE=mTWeCOH3O002;KP00bfiO01oo`0mOol00`00Oomoo`07Ool000Qoo`03001o
ogoo025oo`0@O01[:AcWObmo;Wl_Obio;acWN_5fdG[aM]5jlGKA7>L2KY801VZBKY9^TVjBJY8Li`9R
<`04000Li``5000630D2O004EQ@011cWAME5eDWE0dGE00I9eDGEAME5eCFg7>L3=KL01C6g=KLe]cFg
<KL00SFg00=l047E@MH00T7F00e1eD7F@MI1eQcW<KLaUc6g<ILa]c6G<KLaU`047>L370T03AcW70TL
2AcW?6HlIcaV?6LlISaW?6HlIcaV009l0005GUAN=5iDGS@Li`03EQ@01eHEEQAF55HDEQEF51cW00]=
m@047>M5eW`07>L2HU<01V9DGU=RDf9CHUAND`9RD`05HU@LieHDEQAF5@03EQ@01EHEEQAF55HDEQD0
0eHD00@LidWeO01l00H]^003O01oogoo03aoo`03001oogoo00Moo`0027oo00<007ooOol08Goo05El
01cWOdmo;Wm?ObioCgl^7>MfdG[aM]1jlGKAN_4LifjBJW9^TVYbKY9ZLVjB7>MRDehb30DLi``5000<
1@P530D81@`5O01F57:bEQAAleHDDO=F51cWBME5eDWEAME9eDGEBME5eEXDAMDe]acW=KLaUcFg<IHe
]c6G=KLaUW`07>M1eT6e@MI1]D7F@KE1eT6e@MHLic6h<IMoobfG<KPaUc6h;ILa^0027>L03A`880TL
21`97>LP2A`87>LhASaW>4HlIcQ600=l000OGS=RE5hcGUAN<f9D7>MF5E8DEQEF55HEDQAF5EHDEQDL
idgfBOE=mDWeCOI9mDgeBOE=mTWeCOE1eAcWOol00g`001EN<f9DGS=RE5hcHUAN<f9DGS<Lie8DEQEB
55HEDQAF5E8DEQEB55HEDQ@01G`000Pi]SgG7>LLibfh;KT]^7`0?goo00<007ooOol01goo0008Ool0
0`00Oomoo`0QOol04G`07>Mo;Wl_Obio;gl^OblLig[aM]5jlGKAN_5fdAcWJY800fjB00MZTVjBKY8L
if8cLbXLi`0230D00`0030D<1@0230D01G`0EQAF55HDJW<015HD00DLidGEAME5eDWE00=5e@06BME5
eEHDAMDLic6g0cFg00Ta]cFg=KLe]g`0CODLid7FOol00d7F00e1eD7F@MI1eQcW<KLaUgoo<ILa]c6G
<KLaU`027>L00a`970PL2@0270T37>L00caW?6Il0002O00036Yc7>MN=5iDGSANE5hdGUAN=5iD7>MF
5@=F5006EQEF55HDEQAF5AcW2dge00<LidGFAMH00TGF1W`000ERE5iCHU<LieHE009F50Ql0003>MLm
ecWG008ie`05?MLiecWGOolLi`02;KP00g`0Oomoo`0mOol00`00Oomoo`07Ool000Qoo`03001oogoo
025oo`1=O00Ligm?ObioCgl^Odmo;QcWM]1jlGKAN_5fd7[a7>M^TVYbKY9ZLVjBJW9^TQcWHU<001cW
20D<1@0030D81@`5O01F557cEQAAleHDIW9F557cEQAAlacWAME9eDGEBME5eDWEAME9eDGEBME5eAcW
<IHe]c6G=KLaUSFgO01=mDWdCODLid7F@KE1eT6e@MI1]D7F@KE1eP027>L01S6GOol]Uc6h<ILa^08L
i`0770PL2A`880TL21`970P00g`002ioofZCJW=ZTacWHUAN<eiDGS=RE5hcGUAN<acWEQAF5E8DEQEF
55HEDQAF5EHD7>M9mDgfBOE=mDWeCOI9mDgeBOE=mTWeCODLigoo@MI5mT7EAOI1eTGf@ME5mPMl000B
?MLi]cgG>KHmecVg?MLi]SgG>KLmecVf?MLi]cgG>KHmecVg0QcW00=l07ooOol0?Goo00<007ooOol0
1goo0008Ool00`00Oomoo`0POol04G`0JbTLigl^Obmo;Wl_ObhLigKAN_5fdG[aM]5jlGKA7>L00VjB
00UZTVjBKY9^TVZB7>MR<`007>L00P`500D000`530El01cW00IF5003JW=F55HD009F50057>M5eDGE
AME9e@03AMD01TWEAME5eDGE7>La]`<e]`09<KMl04geCOE=m4ge7>M1eT7E00=1eP0>@ME1eT7F@MHa
UacW<IMooc6G<KLaUacW00<Li`8L2@0470PL2A`9O0023ET2O0003FYcJY=ZLacWGSANE5hdGUAN=5iD
GSANE1cW009F5005EQEF55HDEQAF5@02EQ@00dge7>M=m@0:COD00dGF7>M5eP0=AMH01CgG7>LiecWG
?ML00cWG00DmecWG>MLiecgG00<ie`06?MLiecWG>MLmeg`0?goo00<007ooOol01goo0008Ool00`00
Oomoo`0POol0Hg`07>Mo;Wm?ObioCgl^OdlLig[aM]5jlGK@N_5fdG[a7>M^TVYbKY9ZLVjBJW9^TVYb
7>L001cW20D<1@0030El069CGS8Lie7cEQAAleHDDO=F557cEQAAleHDAMDLidGEBME5eDWEAME9eDGE
BME5eDWEAMDLic6F=KLaUg`0BOA=mDWdCOE9m4ge7>M1eT6e@MI1]D7F@KE1eT6e@MIooacW<IMoobfG
00@Li`047>LP2A`870TL27`03ET=N@UI3GT=F@02O000AVZC7>MNE5hcHUAN<eiDGS=RE5hc7>MB55HE
EQAF5E8DEQEF55HEDQAF5AcWCOE9mDgfBOE=mDWeCOI9mDgeBOE=mTWe7>M1eDGf@MI5mT7EAOI1eTGf
@ME5mT7FAOI1eDGf@MHmeacW?MLi]cgG>KHmecVg?MLi]SgG>KLmecVf?MLi]cgG>KHmeg`0@7oo00<0
07ooOol01goo0008Ool00`00Oomoo`0POol04W`07>Mo;gl^Obmo;Wl_ObhLigKAN_5fdG[aM]5jlGKA
7>MZTP=^TP07JY9^TVjBKY8Li`007>L00P`500<007`0HS<00V8c00<LieHDEQ@02EHD00<LidWEAMD0
0TGE00E9eDGEAME5eDWE0095e@07EQ@Lic6g=KMl04geCO@00dge00E=m1cW@MI1eT7E00=1eP0>@ME1
eT7F@MI1eAcW<IMoo`037>L00acW70PL2@9l0003<ILLiacW00D=F@9l000:GSANE5hdGUAN=5iDGSAN
E1cWEQD3EQ@01eHEEQAF55HDEQEF51cW00e=m@037>M5eTGF00e5eP05?MLLicWG>MLme`03>ML01CgG
>MLiecWG?ML00cWG00<mecWGO000@7oo00<007ooOol01goo0009Ool00`00Oomoo`0OOol0ZW`07>Mo
;Wm?ObioCgl^OdlLig[aM]1jlGKAN_5fd7[a7>M^TVYbKY9ZLVjBJW9^TVYb7>L001cW20D<1@00HU=N
<V9CGS9RDacWEQAAleHDDO=F557cEQAAleHDDO=9eAcWBME5eDWEAME9eDGEBME5eDWEAME9eDGE7>Ml
04geBOA=mDWdCOE9m4geBO@Lid6eOom1]D7F@KE1eT6e@MI1]D7F@KDLic6G00@Li`047>LL2G`0<KPa
Uc6h;IL=NAcW3GT9F@ei3ET=NG`0HUAN<eiDGS=RE5hcGUAN<f9D7>MF5E8DEQEF55HEDQAF5EHDEQE9
mAcWBOE=mDWeCOI9mDgeBOE=mTWeCOE9mDgf7>M5mT7EAOI1eTGf@ME5mT7FAOI1eDGf@MI5mT7EAOI1
eSgG7>LmecVg?MLi]SgG>KLmecVf?MLi]cgG>KHmecVgO011Ool00`00Oomoo`07Ool000Uoo`03001o
ogoo01moo`0AO00Ligl_Obio;gl^Obmo;QcWM]5jlGKAN_5fdG[aM]4Li`02KY801VZBKY9^TVjBJY9^
TP8000047>L<1G`00005HS<00acWEQAF5009EQ@00acWAME9e@03AMD01DWEAME5eDGEBMD00dGE00=l
07ooCOD00Tge00I=m4geCOE=mDgd7>L2@MH01D7E@MI1eT7F@MD00d7F00m1eAcW7>L010037>Ml036g
<ILa]c6G<KLaUc6g7>L010eI00dLig`0GUAN=5iDGSANE5hdGUAN=1cWEQAF5@03EQ@01UHEEQAF55HD
EQDLi`e=m@037>MoodGF00i5eP05?MLLicWG>MLme`03>ML01CgG>MLiecWG?ML00SWG00=l07ooOol0
?goo00<007ooOol01goo0009Ool00`00Oomoo`0OOol06G`0Odmo;Wm?ObioCgl^OdlLig[aM]5jlGK@
N_5fdG[a7>M^TVYbKY9ZLVjBJW9^TVYb008000177>Ml069C001RDehbHU=N<V9CGS8Lie7cEQAAleHD
DO=F557cEQAAleHDDO<LidGEBME5eDWEAME9eDGEBME5eDWEAMEl04Wd7>M9m4geBOA=mDWdCOE9m4ge
BO@Lid6e@MI1]D7F@KE1eT6e@MI1]D7F@KDLi`0300Al036h<ILa^2fG<KPaUc6h;ILa^0027>L0A@UI
3GT=FG`0GS=RE5hcGUAN<f9DGS=NE1cWEQEF55HEDQAF5EHDEQEB55HEEQA=mAcWCOI9mDgeBOE=mTWe
COE9mDgfBOE=mDWeCOHLidGf@ME5mT7FAOI1eDGf@MI5mT7EAOI1eTGf@ME5mT7F?MLLicgG>KLmecVf
?MLi]cgG>KHmecVg?MMl0011Ool00`00Oomoo`08Ool000Uoo`03001oogoo01moo`0BO01o;Wl_Obio
;gl^OblLig[aM]5jlGKAN_5fdG[aM]4LifZB0fjB00=ZTVjBKY800`0000Al068cHS<000IR<`037>MF
55HD00UF5004AMDLidGEBMD3AMD01DWEAME5eDGEO0000UHD00==mAcWCO@00dge00I=m4geCOE=mDgd
7>L2@MH01Goo@MI1eT7F@MD00d7F010Li`0300=l036G<KLaUc6g<ILa]c6G<KLaUc6g3ETLi`8=F@0:
O01NE5hdGUAN=5iDGSANE5hd7>L3EQ@01EHEEQAF55HDEQD00eHD00<LidgeCOD02dge00<LidGFAMH0
3dGF00DmeacW>MLiecgG00<ie`04?MLiecWGO012Ool00`00Oomoo`08Ool000Uoo`03001oogoo021o
o`0GO01o;Wm?ObioCgl^7>MfdG[aM]1jlGKAN_5fd7[a7>M^TVYbKY9ZLVjBJW8Li`0200008W`0HU=N
<V9C001RDehbHU=N<V9CGS8Lie7cEQAAleHDDO=F557cEQAAleHDDO=F51cWBME5eDWEAME9eDGEBME5
eG`00UHD06YF4dge7>M=mDWdCOE9m4geBOA=mDWdCOE9m1cWOom1eWoo@MI1]D7F@KE1eT6e7>L00g`0
7>MjlBfG<KPaUc6h;ILa^36G<KP]Uc6h<ILLi`UIO01N<eiDGS=RE5hcGUAN<f9D7>MF5E8DEQEF55HE
DQAF5EHDEQEB55HE7>M=mDWeCOI9mDgeBOE=mTWeCOE9mDgfBOE=mDWe7>M1eTGf@ME5mT7FAOI1eDGf
@MI5mT7EAOI1eTGf@ME5mT7F7>Li]SgG>KLmecVf?MLi]cgG>KIl049oo`03001oogoo00Qoo`002Goo
00<007ooOol087oo011l07l_Obio;gl^OblLig[aM]5jlGKAN_5fdG[aM]4Li`9^TP05JY9^TVjBKY8L
i`0200001G`0HS=R<f8c00001f8c00<LieHDEQ@02UHD00@LidGEAME9e@95e@9l00EF5004CODLidge
CO@3COD01TgdCOE=mDge@MDLi`91eP0GOom1eT7F@MI1eD7F7>L017`0@MIflC6g<ILa]c6G<KLaUc6g
<ILa]c6G<KLaU`027>L02g`0GSANE5hdGUAN=5iDGSANE1cWEQD00eHD00QF5EHDEQAF55HEEQA=mAcW
3Tge00<LidGFAMH03dGF00DLicWG>MLiecgG00<ie`03O01oogoo045oo`03001oogoo00Qoo`002Goo
00<007ooOol08Goo03Ql07m?ObioCgl^7>Mfd7[aM]5jlGK@N_5fdG[a7>M^TVYbKY9ZLVjBJW8Li`00
O00Lif9CGS9RD`00HU=N<V9CGS9RDehbHU<LieHDDO=F557cEQAAleHDDO=F557cEQAAlacWAME9eDGE
BMEl05XD0UHD06YF4eXDEQAF55HC7>M9m4geBOA=mDWdCOE9m4geBOA=mD6e7>M1]D7FOom1eT6e@MI1
]AcWO00LigKAN_8Lic6h;ILa^36G<KP]Uc6h<ILa^2fG<KPaUc6hO01RE5hcGUAN<f9DGS=NE5hc7>MF
55HEDQAF5EHDEQEB55HEEQAF5E8D7>M9mDgeBOE=mTWeCOE9mDgfBOE=mDWeCOI9mDge7>M5mT7FAOI1
eDGf@MI5mT7EAOI1eTGf@ME5mT7FAOI1eDGf@MHLicVf?MLi]cgG>KIl04Aoo`03001oogoo00Qoo`00
2Goo00<007ooOol08Goo011l07l^Obmo;Wl_7>MjlGKAN_5fdG[aM]5jlGKA7>MZTP=^TP06JY8Li`00
001l01cW0f8c00<0068cHS<01V8c00<LieHDEQ@02UHD00@LidGEAMEl00UF5005CO@LidgeCOE=m003
COD01DgdCOE=mDge7>L00d7F025ood7F@MH011cWO00Lig[aM_51eQcW<KLaUc6g<ILa]c6G<KLaUc6g
<ILa]c6GO01N=5iDGSANE5hdGUAN=5iD7>L00UHD00EF5EHDEQAF55HE00=F5003EQDLidge00i=m@03
7>M5eTGF0115eP067>LiecWG>MLmeg`0A7oo00<007ooOol027oo0009Ool00`00Oomoo`0ROol0=G`0
ObioCgl^7>MfdG[aM]1jlGKAN_5fd7[a7>M^TVYbKY9ZLVjB7>L007`0KY8Lif9CGS9RD`00HU=N<V9C
GS9RDehbHU=N<QcWDO=F557cEQAAleHDDO=F557cEQAAleHD7>M9eG`07>L00UHD00IF4eXDEQAF55HC
FQ@2EQ@0HacWCOE9m4geBOA=mDWdCOE9m4geBOA=mAcW@MI1]D7FOom1eQcWO01g:QcWM]5jlD6e@MHL
ic6h;ILa^36G<KP]Uc6h<ILa^2fGO01N<eiDGS=RE5hcGUAN<f9DGS<Lie8DEQEF55HEDQAF5EHDEQEB
55HEEQAF5AcWCOI9mDgeBOE=mTWeCOE9mDgfBOE=mDWeCOI9mDge7>M5mT7FAOI1eDGf@MI5mT7EAOI1
eTGf@ME5mT7FAOI1eDGf@MHLicVf?MMl0015Ool00`00Oomoo`08Ool000Uoo`03001oogoo02=oo`0=
O01o;Wl_7>MjlGKAN_5fdG[aM]5jlGKA7>L00VjB00QZTVjBKY8Li`00O01^TQcW0f8c00<0068cHS<0
1V8c00<LieHDEQ@02eHD00Al05hdGS<Li`UF5003CODLidge009=m@05COA=mDgeCOE=m003COD02AcW
Oom1eT7F@MDLig`0MbXLi`02M_406D7F@ME1eQcW<KLaUc6g<ILa]c6G<KLaUc6gO01NE5hdGUAN=5iD
GSANE5hdGU@LieHE00=F5005EQEF55HDEQAF5@03EQ@00acWCOE=m@0=COD00acWAMI5eP0AAMH00acW
>MMl0015Ool00`00Oomoo`08Ool000Uoo`03001oogoo02=oo`0_O01oCacWN_5fd7[aM]5jlGK@N_5f
dG[a7>M^TVYbKY9ZLVjB7>Ml06YbKY9ZLQcWGS9RD`00HU=N<V9CGS9RDehbHU=N<V9C7>MF557cEQAA
leHDDO=F557cEQAAl`02O0001F9DGS=RE1cWFQ@00UHD06QF4eXDEQAF55HCFQAF51cWBOA=mDWdCOE9
m4geBOA=mDWdCOE9m4ge7>M1eT6eOoml07/[MbXLigKAN_91]D7F@KE1eQcW<KP]Uc6h<ILa^2fG<KPa
Ug`0GS=RE5hcGUAN<f9DGS=NE5hcHU@LieHEDQAF5EHDEQEB55HEEQAF5E8DEQE9mAcWBOE=mTWeCOE9
mDgfBOE=mDWeCOI9mDgeBOE=mTWe7>M1eDGf@MI5mT7EAOI1eTGf@ME5mT7FAOI1eDGf@MI5mT7EAOI1
eW`0AWoo00<007ooOol027oo0009Ool00`00Oomoo`0TOol03G`07>MfdG[aM]5jlGKAN_5fdG[aM]4L
ifZB00=^TP07JY8Lig`0KY9ZTVjB7>L00V8c00<0068cHS<01f8c00<LieHDEQ@01UHD0W`000=N<ehd
GS<00Uhc00<LieHDEQ@025HD00==mAcWCO@00dge00E=m4geCOE=mDgd00==m@097>M1eT7FO01g:QcW
M_5jlGKa00=1eP0H@ME1eQcW7>LaUc6g<ILa]c6GO01N=5iDGSANE5hdGUAN=5iDGSANE5hd7>MF55HE
0eHD00EF5EHDEQAF55HE009F50037>M=mDge00i=m@037>M5eTGF00m5eP03O01oogoo04Eoo`03001o
ogoo00Qoo`002Goo00<007ooOol097oo02Yl01cWN_5fdG[aM]1jlGKAN_5fd7[a7>M^TVYbKY9ZLVjB
O01^TVYbKY9ZLQcWGS9RD`00HU=N<V9CGS9RDehbHU=N<V9CGS8Lie7cEQAAleHDDO<2O0002f9DGS=R
E5hcHUAN<f9DGS<LieHCFQ@00UHD06AF4eXDEQAF55HCFQ@LidgeBOA=mDWdCOE9m4geBOA=mDWdCOE9
m1cW@KE1eW`0Nb/Lig[bM]5jlD6e@MI1]D7F@KE1eT6e7>L]Uc6h<ILa^7`0HUAN<eiDGS=RE5hcGUAN
<f9DGS=NE1cWEQEF55HEDQAF5EHDEQEB55HEEQAF5E8D7>M9mDgeBOE=mTWeCOE9mDgfBOE=mDWeCOI9
mDgeBOE=mQcWAOI1eDGf@MI5mT7EAOI1eTGf@ME5mT7FAOI1eDGf@MIl04Qoo`03001oogoo00Qoo`00
2Goo00<007ooOol09Goo00]l07KAN_5fdG[aM]5jlGKAN_5fdAcW009^TP05JY9^TQcWO01ZTP03KY80
11cWHS=R<`002V8c00@LieHDEQAF509l00047>MN<ehcGS@3GS<015hdGS=N<acW2UHD00A=mAcWCOE=
m0==m@05COA=mDgeCOE=m002COD01AcW@MEl07LZ7>L00gKa00=jlD7E@MH00T7F01A1eD7F@MHLic6G
<KLaUg`0GSANE5hdGUAN=5iDGSANE5hdGUAN=1cW0eHD00EF5EHDEQAF55HE00=F5003EQEF51cW011=
m@037>M5eTGF00]5eP9l04Uoo`03001oogoo00Qoo`002Goo00<007ooOol09Woo0W`0029jlGKAN_5f
d7[aM]5jlAcWKY9ZLVjBJW9l06YbKY9ZLVjBJW8LiehbHU=N<P00GS9RDehbHU=N<V9CGS9RDehbHU<L
i`9l000=JW=VLQcWGS=RE5hcHUAN<f9DGS=RE5hc7>L00UHD00IF4eXDEQAF55HCFQ@2EQ@0FeHC7>M9
m4geBOA=mDWdCOE9m4geBOA=mDWdCOE9m1cWO01k:acWN_5fdG[bM]51eT6e@MI1]D7F@KE1eT6e7>L]
Uc6hO01NE5hcHUAN<eiDGS=RE5hcGUAN<f9D7>MF5E8DEQEF55HEDQAF5EHDEQEB55HEEQAF5AcWCOI9
mDgeBOE=mTWeCOE9mDgfBOE=mDWeCOI9mDgeBODLid7FAOI1eDGf@MI5mT7EAOI1eTGf@ME5mW`004]o
o`03001oogoo00Qoo`002Goo00<007ooOol0:7oo0W`000MfdG[aM]5jlGKA7>MZTP03KY801g`0KY9^
TVjBJY9^TQcW00=R<`03001R<f8c00MR<`9l009ZL`04IW=ZLacWGS@3GS<01ehdGS=N<ehcGSAN<acW
00YF5005CO@LidgeCOE=m003COD034gdCOE=mDgeCOA=mAcWO01g:QcWM_5jl@9fl@91eP05@ME1eT7F
@MI1e@02@MH04AcWO00LiehdGUAN=5iDGSANE5hdGUAN=5iDGSANE1cWEQD00eHD00EF5EHDEQAF55HE
00=F5003CODLidge00m=m@037>M5eTGF00Q5eP03O01oogoo04Yoo`03001oogoo00Qoo`002Goo00<0
07ooOol0:Woo0W`001QjlGK@N_4LifjBJW9^TVYbO01ZLVjBJW9^TVYbKY8Lif9CGS8005hbHU=N<V9C
GS84O0004fYcIW9ZLfIbJW=VLQcWGS=RE5hcHUAN<f9DGS=RE5hcHU@LieXD009F5006EQ=J55HDEQAF
4eXD0UHD05LLidgeBOA=mDWdCOE9m4geBOA=mDWdCOE9m4ge7>Ml01cWN_9fdG[aM]51eT6e@MI1]D7F
@KE1eT6e@MI1]G`07>MRE5hcGUAN<f9DGS=NE5hcHUAN<eiDGS<LieHDEQEB55HEEQAF5E8DEQEF55HE
DQAF5EHD7>M9mDgfBOE=mDWeCOI9mDgeBOE=mTWeCOE9mDgfBOE=mDWe7>M1eTGf@ME5mT7FAOI1eDGf
O000C7oo00<007ooOol02Goo000:Ool00`00Oomoo`0[Ool2O0002GKA7>M^TVjBJY9^TW`0KY9ZTP03
KY801FZB7>MR<f8c00000V8c0g`000=bdQcWIW<00fYc00QVLfYcJW=ZLfIc7>MN<ehd0ehc00EN=5hc
GS=N<acW00aF50057>M=mDgeCOE=m003COD024gdCOE=mDgeCOAg:W`0N_43M_400g[a@ME1eP02@MH0
5D7E@MI1eT7F@MEl06Yc7>MN=5iDGSANE5hdGUAN=5iDGSANE5hdGU@Li`02EQ@01EHEEQAF55HDEQD0
0eHD00AF5EHDEQ@Lia5=m@037>M5eTGF00E5eP03O01oogoo04]oo`03001oogoo00Uoo`002Woo00<0
07ooOol0;Goo2W`000=^TVYbKY800QcW021l0000O01l07:bM]9b/WKC7>MZLfIbJW=VLVYcIW9ZLfIb
JW<Lif9DGS=RE5hcHUAN<f9DGS=RE5hc7>MF4eXD0UHD05UF4eXDEQAF55HCFQAF51cWBOA=mDWdCOE9
m4geBOA=mDWdCOE9m4geMbYl07KAN_5fdG[bM]51eT6e@MI1]D7F@KE1eT6e@MIl06ZC7>MNE5hcHUAN
<eiDGS=RE5hcGUAN<f9DGS<Lie8DEQEF55HEDQAF5EHDEQEB55HEEQAF5E8DEQDLidgeBOE=mTWeCOE9
mDgfBOE=mDWeCOI9mDgeBOE=mTWeCODLidGf@MI5mT7E009l04ioo`03001oogoo00Uoo`002Woo00<0
07ooOol0<goo00Al07l`7>Mo<0El0003L]8007;B00EbdP047>MZLfYcIW<3JW<016IcJW=ZLacW0ehc
00EN=5hcGS=N<ehd009N<`037>MF55HD00YF50037>M=m4ge009=m@05COA=mDgeCOE=m003COD017`0
M_5flG[a0WKa0T7F01Q1eD7F@MI1eT7E@MIl06ZCJW<LiehdGUAN=5iDGSANE5hdGUAN=5iDGSANE1cW
EQD3EQ@01EHEEQAF55HDEQD00eHD00=F5EHD7>L04Tge00@LidGFAMIl051oo`03001oogoo00Uoo`00
2Woo00<007ooOol0<goo02Ml01cWOc5k<7laNc1o<G/`7>Mb/P00L[9fdW:bM]=b/WKB7>MZLfIbJW=V
LVYcIW9ZLfIbJW<Lif9DGS=RE5hcHUAN<f9DGS=RE5hc7>L00UHD00IF4eXDEQAF55HCFQ@2EQ@0DUHC
FQA9m1cWBOA=mDWdCOE9m4geBOA=mDWdCOE9m7`0M]5jlWKAN_5fdD7F@KE1eT6e@MI1]D7FO01ZTfYc
JY<Lif9DGS=NE5hcHUAN<eiDGS=RE5hcGUAN<acWEQAF5E8DEQEF55HEDQAF5EHDEQEB55HEEQAF5DWe
7>M9mDgeBOE=mTWeCOE9mDgfBOE=mDWeCOI9mDgeBOE=mTWe7>M1eG`0DGoo00<007ooOol02Goo000:
Ool00`00Oomoo`0cOol00g`07>Mo<004Oc0017oo7>MbdP001W;B00<LifIcJW<00VYc00QVLfYcJW=Z
LfIc7>MN<ehd0ehc00MN=5hcGS=N<ehdGS<Li`0<EQ@00acWCOE=m003COD01DgdCOE=mDgeCO@00Tge
00Il07KaM_5flG[aM_43@MH0647E@MIl06ZCJW=ZTfYc7>MN=5iDGSANE5hdGUAN=5iDGSANE5hdGUAN
=1cWEQAF5@=F5005EQEF55HDEQAF5@03EQ@00eHE7>M=m@0ACOD00g`0Oomoo`1@Ool00`00Oomoo`09
Ool000Yoo`03001oogoo03=oo`0YO00LiglaNc1o<G/`Oc4LigKCL[8007:bM]=b/WKBL[9fdacWJW=V
LVYcIW9ZLfIbJW=VLVYc7>MRE5hcHUAN<f9DGS=RE5hcHUAN<f9D7>MJ5002EQ@01UHCFQAF55HDEQ=J
509F501<EQ==mAcWCOE9m4geBOA=mDWdCOE9m4geBOA=mDWdO01fdG[bM]5jlAcW@MI1]D7F@KEl06Yc
JY=VLVZC7>MNE5hcHUAN<eiDGS=RE5hcGUAN<f9DGS=NE1cWEQEF55HEDQAF5EHDEQEB55HEEQAF5E8D
EQEF51cWBOE=mTWeCOE9mDgfBOE=mDWeCOI9mDgeBOE=mTWeCOD2O01COol00`00Oomoo`09Ool000Yo
o`03001oogoo03=oo`03O01o<7l`00Ao<0047>MbdW;B0006L]8011cWJW=ZLfIc0fYc00AVLfYcJW<L
i`=N<`05GSAN<ehcGS=N=003GS<00acWEQAF500;EQ@011cWCOE=mDgd0dge00Q=m4geCOE=mDgdCOEl
07[a0gKa01TLid7E@MI1eW`0JW=ZTfYcJY=ZLacWGSANE5hdGUAN=5iDGSANE5hdGUAN=5iDGS@Li`03
EQ@01EHEEQAF55HDEQD00eHD00EF5EHDEQAF51cW00e=m@9l05Eoo`03001oogoo00Uoo`002Woo00<0
07ooOol0<Woo02al01cWNc1o<G/`Oc5k<7la7>MfdW:b001b/WKBL[9fdg:bM]8LifYcIW9ZLfIbJW=V
LVYcIW9ZLacWHUAN<f9DGS=RE5hcHUAN<f9DGS=RE5hc7>MF4eXD0UHD00IF4eXDEQAF55HCFQ@2EQ@0
ATWd7>M9m4geBOA=mDWdCOE9m4geBOA=mDWdCOEl07[aBOAjlQcW@MIVLW`0JW=ZTfIbJY=ZLfZC7>MR
E5hcGUAN<f9DGS=NE5hcHUAN<eiDGS=RE1cWEQEB55HEEQAF5E8DEQEF55HEDQAF5EHDEQEB55HE7>M=
mDWeCOI9mDgeBOE=mTWeCOE9mDgf0W`000=oo`000000E7oo00<007ooOol02Goo000:Ool00`00Oomo
o`0bOol00g`07>Mo<005Oc0011cWL]9bdP001W;B00<LifIcJW<00VYc00QVLfYcJW=ZLfIcJW<Liehd
0ehc00EN=5hcGS=N<ehd009N<`037>MF55HD00]F50057>M=mDgeCOE=m003COD094gdCOE=mDgeCOA=
mG`0N_4LifZC@MIl06YcJY=ZLfZCJW=ZTfYcJY<LieiDGSANE5hdGUAN=5iDGSANE5hdGUAN=1cWEQAF
5@=F5005EQEF55HDEQAF5@03EQ@00eHEEQ@Li`09COD2O005Ool00`00Oomoo`1AOol00`00Oomoo`09
Ool000Yoo`03001oogoo039oo`0^O01o<G/`Oc5k<7laNc1o<AcWM]=b/P00L[9fdg:bM]9b/WKC7>MZ
LfIbJW=VLVYcIW9ZLfIbJW=VLQcWGS=RE5hcHUAN<f9DGS=RE5hcHUAN<f9D7>MF55HCFQ@2EQ@01UHC
FQAF55HDEQ=J509F50107>M=mDWdCOE9m4geBOA=mDWdCOE9m4geBOA=mG`07>MVLW`0JW=ZTfIbJY=Z
LfZCIW9ZTfYc7>MN<f9DGS=NE5hcHUAN<eiDGS=RE5hcGUAN<acWEQAF5E8DEQEF55HEDQAF5EHDEQEB
55HEEQAF5E8D7>M9mDgeBOE=mTWeCOD2O008Ool00`00Oomoo`1@Ool00`00Oomoo`09Ool000Yoo`03
001oogoo039oo`03O01o<7l`00Eo<0047>MbdW;B0006L]8011cWJW=ZLfIc0fYc00EVLfYcJW=ZLacW
009N<`05GSAN<ehcGS=N=003GS<00ehdGS<Li`0=EQ@00acWCOA=m@02COD01DgdCOE=mDgeCO@00dge
01e=m7`07>MZTfYcJY=ZLfZCJW=ZTfYcJY=ZLfZC7>MNE5hdGUAN=5iDGSANE5hdGUAN=5iDGSANE1cW
009F5005EQEF55HDEQAF5@03EQ@01UHEEQAF55HDEQDLi`A=m@9l00]oo`80051oo`03001oogoo00Uo
o`002Woo00<007ooOol0<goo02]l07/`Oc5k<7laNc0Lig:bM]9b/P00L[9fdW:bM]=b/WKB7>MZLfIb
JW=VLVYcIW9ZLfIbJW=VLQcWGS=RE5hcHUAN<f9DGS=RE5hcHUAN<f9D7>MJ5002EQ@01UHCFQAF55HD
EQ=J509F500AEQ=J55HD7>M9m4geBOA=mDWdCOE9m4geBOA=mDWdCOE9m002O000:fZCIW9ZTfYcJY=V
LVZCJW=ZTfIb7>MN<eiDGS=RE5hcGUAN<f9DGS=NE5hcHUAN<acWDQAF5EHDEQEB55HEEQAF5E8DEQEF
55HEDQAF5EHDEQDLidgf009l00moo`03001oogoo04eoo`03001oogoo00Uoo`002Woo00<007ooOol0
<goo00=l07l`Oc000gl`00DLig;BL]9bdP0000IbdP037>MVLfYc009ZL`08IW=ZLfYcJW=VLfYc7>MN
=0=N<`05GSAN<ehcGS=N=003GS<00ehd7>MF500<EQ@00acWCOE=m003COD01DgdCOE=mDgeCO@00Tge
00=l07ooOol00g`001MZTfYcJY=ZLfZCJW=ZTacWGUAN=5iDGSANE5hdGUAN=5iDGSANE5hdGU@LieHE
00=F5005EQEF55HDEQAF5@03EQ@00eHEEQAF5003O00BOol2001=Ool00`00Oomoo`09Ool000Yoo`03
001oogoo03Aoo`0/O01o<G/`Oc5k<1cWL[9fdg:b001b/WKCL[9fdW:bM]<LifYcIW9ZLfIbJW=VLVYc
IW9ZLfIb7>MN<f9DGS=RE5hcHUAN<f9DGS=RE5hcHUAN<acWEQ=J509F5006EQ=J55HDEQAF4eXD0UHD
00aF4eXD7>M=mDWdCOE9m4geBOA=mDWdCOD2O006Ool2O0007fYcJY=VLVZCJW<LiehcHUAN<eiDGS=R
E5hcGUAN<f9DGS=NE5hc7>MF55HEDQAF5EHDEQEB55HEEQAF5E8D00Al01Moo`03001oogoo04Yoo`03
001oogoo00Uoo`002Woo00<007ooOol0<Goo0`0000=l07l`Oc000Wl`00DLig;BL]9bdP0000EbdP05
7>MZLfYcJW=VL`03JW<01FIcJW=ZLfYc7>L00Uhc00EN=5hcGS=N<ehd00=N<`04GSAN<ehc7>L>EQ@0
11cWCOE=mDgd0dge00==m4geO0002Woo0W`001EZTfYcJY<LieiDGSANE5hdGUAN=5iDGSANE5hdGUAN
=5iDGS@LieHDEQD00eHD00=F5G`0O0000W`077oo00<007ooOol0B7oo00<007ooOol02Woo000:Ool0
0`00Oomoo`0/Ool50004Ool0;G`0Nc1o<G/`7>Mb/WKBL[8007:bM]9b/WKCL[8LifIbJW=VLVYcIW9Z
LfIbJW=VLVYcIW8LiehcHUAN<f9DGS=RE5hcHUAN<f9DGS=RE5hcHU@LieHDEQ=J5002EQ@01UHCFQAF
55HDEQ=J509F5009EQ<LidWdCOE9m4geBOA=mG`000eoo`9l000CIW8LiehcGUAN<f9DGS=NE5hcHUAN
<eiDGS=RE5hcGU@LieHEEQ@017`08Goo0P00B7oo00<007ooOol02Woo000;Ool00`00Oomoo`0VOol5
000:Ool017`0Oc1o<1cW0g;B00<007;BL]800g;B00<LifYcIW<00fYc00EVLfYcJW=ZLfIc009ZL`05
7>MN<ehcGS=N=003GS<01ehdGS=N<ehcGSAN<acW00iF50077>M=mDgeCOE=m4geO00047oo4g`09goo
00<007ooOol0AGoo00<007ooOol02Woo000;Ool00`00Oomoo`0POol6000?Ool0:W`0Oc4LigKBL[9f
dg:b001b/WKCL[9fdW:b7>MVLVYcIW9ZLfIbJW=VLVYcIW9ZLfIbJW<Lif9DGS=RE5hcHUAN<f9DGS=R
E5hcHUAN<f9D7>MJ509F5006EQ=J55HDEQAF4eXD0UHD00MF4eXDEQAF51cWCOE9m002O01<Ool20015
Ool00`00Oomoo`0:Ool000]oo`03001oogoo01]oo`D001Ioo`03O00Lig;B00=bdP03001bdW;B00=b
dP057>MZLfYcJW=VL`03JW<026IcJW=ZLfYcIW<LiehcGS@3GS<01EhdGS=N<ehcGS@00ehc00=N=1cW
EQ@03EHD00<LidgdO000D7oo00<007ooOol0@Woo00<007ooOol02Woo000;Ool00`00Oomoo`0FOol5
000KOol0:g`07>Mfdg:bM]9b/P00L[9fdW:bM]=b/QcWIW9ZLfIbJW=VLVYcIW9ZLfIbJW=VLVYc7>MR
E5hcHUAN<f9DGS=RE5hcHUAN<f9DGS=RE5hc7>MF4eXD009F5006EQ=J55HDEQAF4eXD0UHD00AF4eXD
O01l059oo`03001oogoo045oo`03001oogoo00Yoo`002goo00<007ooOol047oo1P008Goo00=l07;B
L]800W;B00<007;BL]800g;B00<LifYcIW<00fYc00EVLfYcJW=ZLfIc009ZL`057>MN<ehcGS=N=003
GS<01EhdGS=N<ehcGS@00Uhc00<LieHDEQ@02UHD0W`0EGoo0P00@Goo00<007ooOol02Woo000;Ool0
0`00Oomoo`0;Ool5000XOol2O000:GKCL[8007:bM]=b/WKBL[8LifIbJW=VLVYcIW9ZLfIbJW=VLVYc
IW9ZLacWHUAN<f9DGS=RE5hcHUAN<f9DGS=RE5hcHUAN<f9D7>MF55HCFQ@00UHD00AF4eXDEQAF509l
05Uoo`03001oogoo03ioo`03001oogoo00Yoo`002goo00<007ooOol01Woo1@00;goo00=l07;B0000
1G;B00DLifYcJW=ZLfIc00=ZL`08IW=ZLfYcJW=VLacWGS=N=0=N<`05GSAN<ehcGS=N=003GS<00ehd
GS<Li`06EQ@3O01LOol2000nOol00`00Oomoo`0:Ool000]oo`03001oogoo00H003Eoo`0VO00007:b
M]9b/WKCL[8LifIbJW=VLVYcIW9ZLfIbJW=VLVYcIW9ZLacWHUAN<f9DGS=RE5hcHUAN<f9DGS=RE5hc
HUAN<f9D7>MJ509F5003EQ=l07`0065oo`03001oogoo03]oo`03001oogoo00Yoo`002goo0`00?7oo
00<007`0O0000g;B00<LifYcIW<00fYc00EVLfYcJW=ZLfIc00=ZL`047>MN<ehcGS@3GS<01EhdGS=N
<ehcGS@00ehc00=N=1cWEQ@00W`0I7oo00<007ooOol0>Woo00<007ooOol02Woo000<Ool00`00Oomo
o`0kOol08P00Oomoog`0M]9b/QcWIW9ZLfIbJW=VLVYcIW9ZLfIbJW=VLVYcIW8LiehcHUAN<f9DGS=R
E5hcHUAN<f9DGS=RE5hc17`0Igoo0P00>Woo00<007ooOol02Woo000<Ool00`00Oomoo`0kOol01000
Oomoogoo0W`000DLifYcJW=ZLfIc00=ZL`08IW=ZLfYcJW=VLfYc7>MN=0=N<`04GSAN<ehcGS<5O01]
Ool00`00Oomoo`0gOol00`00Oomoo`0:Ool000eoo`03001oogoo03Yoo`03001oogoo00=oo`Ml000:
IW9ZLfIbJW=VLVYcIW8LiehcHU@6O01cOol2000gOol00`00Oomoo`0:Ool000ioo`03001oogoo03Uo
o`03001oogoo00Yoo`Yl07]oo`03001oogoo03Aoo`03001oogoo00Yoo`003goo00<007ooOol0>7oo
00<007ooOol0T7oo00<007ooOol0<Woo00<007ooOol02goo000?Ool00`00Oomoo`0hOol00`00Oomo
o`2AOol2000bOol00`00Oomoo`0;Ool0011oo`03001oogoo03Qoo`03001oogoo099oo`03001oogoo
02moo`03001oogoo00]oo`004Goo00<007ooOol0=goo00<007ooOol0Tgoo0P00;goo00<007ooOol0
2goo000BOol00`00Oomoo`0fOol00`00Oomoo`2EOol00`00Oomoo`0/Ool00`00Oomoo`0;Ool0019o
o`03001oogoo03Ioo`03001oogoo09Ioo`8002aoo`03001oogoo00]oo`004goo00<007ooOol0=Goo
00<007ooOol0V7oo00<007ooOol0:Goo00<007ooOol02goo000DOol00`00Oomoo`0dOol00`00Oomo
o`2IOol00`00Oomoo`0XOol00`00Oomoo`0;Ool001Eoo`03001oogoo03=oo`03001oogoo09Yoo`80
02Qoo`03001oogoo00]oo`005Goo00<007ooOol0<goo00<007ooOol0W7oo00<007ooOol09Goo00<0
07ooOol02goo000FOol00`00Oomoo`0bOol00`00Oomoo`2MOol2000UOol00`00Oomoo`0;Ool001Mo
o`03001oogoo035oo`03001oogoo09moo`03001oogoo029oo`03001oogoo00]oo`0067oo00<007oo
Ool0<7oo00<007ooOol0X7oo00<007ooOol08Goo00<007ooOol02goo000HOol00`00Oomoo`0`Ool0
0`00Oomoo`2QOol2000QOol00`00Oomoo`0;Ool001Uoo`03001oogoo02moo`03001oogoo0:=oo`03
001oogoo01eoo`03001oogoo00aoo`006Woo00<007ooOol0;Woo00<007ooOol0Y7oo0P007Goo00<0
07ooOol037oo000KOol00`00Oomoo`0]Ool00`00Oomoo`2VOol00`00Oomoo`0JOol00`00Oomoo`0<
Ool001]oo`03001oogoo02eoo`03001oogoo0:Moo`03001oogoo01Uoo`03001oogoo00aoo`0077oo
00<007ooOol0;7oo00<007ooOol0Z7oo0P006Goo00<007ooOol037oo000MOol00`00Oomoo`0[Ool0
0`00Oomoo`2ZOol00`00Oomoo`0FOol00`00Oomoo`0<Ool001ioo`03001oogoo02Yoo`03001oogoo
0:]oo`8001Ioo`03001oogoo00aoo`007Woo00<007ooOol0:Woo00<007ooOol0[Goo00<007ooOol0
4goo00<007ooOol037oo000OOol00`00Oomoo`0YOol00`00Oomoo`2^Ool00`00Oomoo`0BOol00`00
Oomoo`0<Ool0021oo`03001oogoo02Qoo`03001oogoo0:moo`80019oo`03001oogoo00aoo`008Goo
00<007ooOol09goo00<007ooOol0/Goo00<007ooOol03goo00<007ooOol037oo000QOol00`00Oomo
o`0WOol00`00Oomoo`2bOol2000?Ool00`00Oomoo`0<Ool0029oo`03001oogoo02Ioo`03001oogoo
0;Aoo`03001oogoo00aoo`03001oogoo00aoo`008goo00<007ooOol09Goo00<007ooOol0]Goo0P00
37oo00<007ooOol037oo000SOol00`00Oomoo`0UOol00`00Oomoo`2gOol00`00Oomoo`09Ool00`00
Oomoo`0<Ool002Aoo`03001oogoo02Aoo`03001oogoo0;Qoo`03001oogoo00Moo`03001oogoo00eo
o`009Goo00<007ooOol08goo00<007ooOol0^Goo0P001goo00<007ooOol03Goo000VOol00`00Oomo
o`0ROol00`00Oomoo`2kOol00`00Oomoo`04Ool00`00Oomoo`0=Ool002Ioo`03001oogoo029oo`03
001oogoo0;aoo`8000Aoo`03001oogoo00eoo`009goo00<007ooOol08Goo00<007ooOol0_Woo00D0
07ooOomoo`0000moo`00:7oo00<007ooOol087oo00<007ooOol0_goo00@007ooOol000moo`00:Goo
00<007ooOol087oo00<007ooOol0_goo0`003goo000YOol00`00Oomoo`0POol00`00Oomoo`2oOol3
000?Ool002Yoo`03001oogoo01moo`03001oogoo0;]oo`@0019oo`00:goo00<007ooOol07Woo00<0
07ooOol0]goo10005Woo000/Ool00`00Oomoo`0MOol00`00Oomoo`2cOol4000JOol002aoo`03001o
ogoo01eoo`03001oogoo0:moo`@001ioo`00;Goo00<007ooOol077oo00<007ooOol0Zgoo10008Woo
000^Ool00`00Oomoo`0KOol00`00Oomoo`2WOol4000VOol002moo`03001oogoo01Yoo`03001oogoo
0:=oo`@002Yoo`00;goo00<007ooOol06Woo00<007ooOol0Wgoo1000;Woo000`Ool00`00Oomoo`0I
Ool00`00Oomoo`2KOol4000bOol0035oo`03001oogoo01Qoo`03001oogoo09Moo`@003Ioo`00<Woo
00<007ooOol05goo00<007ooOol0Tgoo1000>Woo000bOol00`00Oomoo`0GOol00`00Oomoo`2?Ool4
000nOol003=oo`03001oogoo01Ioo`03001oogoo08]oo`@0049oo`00=7oo00<007ooOol05Goo00<0
07ooOol0Qgoo1000AWoo000eOol00`00Oomoo`0DOol00`00Oomoo`23Ool4001:Ool003Eoo`03001o
ogoo01Aoo`03001oogoo07ioo`D004ioo`00=Woo00<007ooOol04goo00<007ooOol0NWoo1000Dgoo
000gOol00`00Oomoo`0BOol00`00Oomoo`1fOol4001GOol003Moo`03001oogoo019oo`03001oogoo
079oo`@005]oo`00>7oo00<007ooOol04Goo00<007ooOol0KWoo1000Ggoo000iOol00`00Oomoo`0@
Ool00`00Oomoo`1ZOol4001SOol003Yoo`03001oogoo00moo`03001oogoo06Ioo`@006Moo`00>Woo
00<007ooOol03goo00<007ooOol0HWoo1000Jgoo000kOol00`00Oomoo`0>Ool00`00Oomoo`1NOol4
001_Ool003aoo`03001oogoo00eoo`03001oogoo05Yoo`@007=oo`00?Goo00<007ooOol037oo00<0
07ooOol0EWoo1000Mgoo000mOol00`00Oomoo`0<Ool00`00Oomoo`1BOol4001kOol003ioo`03001o
ogoo00]oo`03001oogoo04ioo`@007moo`00?goo00<007ooOol02Woo00<007ooOol0BWoo1000Pgoo
0010Ool00`00Oomoo`09Ool00`00Oomoo`16Ool40027Ool0041oo`03001oogoo00Uoo`03001oogoo
049oo`@008]oo`00@Goo00<007ooOol02Goo00<007ooOol0?7oo1@00Sgoo0012Ool00`00Oomoo`08
Ool00`00Oomoo`0hOol4002DOol004=oo`03001oogoo00Moo`03001oogoo03Aoo`@009Qoo`00@goo
00<007ooOol01goo00<007ooOol0<7oo1000W7oo0014Ool00`00Oomoo`06Ool00`00Oomoo`0/Ool4
002POol004Eoo`03001oogoo00Eoo`03001oogoo02Qoo`@00:Aoo`00AWoo00<007ooOol017oo00<0
07ooOol097oo1000Z7oo0016Ool00`00Oomoo`04Ool00`00Oomoo`0POol4002/Ool004Moo`03001o
ogoo00=oo`03001oogoo01aoo`@00;1oo`00B7oo00<007ooOol00Woo00<007ooOol067oo1000]7oo
0019Ool01@00Oomoogoo00005Woo1000^7oo0019Ool01@00Oomoogoo00004Woo1000_7oo001:Ool0
1000Oomoo`003Woo1000`7oo001;Ool00`00Ool0000:Ool40034Ool004aoo`8000Ioo`@00<Qoo`00
C7oo0P000Woo1000c7oo001=Ool3003@Ool00001
\>"],
  ImageRangeCache->{{{0, 287}, {285.625, 0}} -> {0.0897907, 0.12268, 
  0.0030716, 0.0030716}}]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[CellGroupData[{

54804 L
s
.53638 .59135 m
.54785 .57065 L
s
.50236 .62168 m .59719 .68827 L .52121 .60879 L .739 .561 .653 r
F
0 g,

121 .60879 m
.53638 .59135 L
s
.45703 .63158 m .48515 .73903 L .52325 .73041 L .644 .544 .727,

Cell["", "Input"],

Cell[CellGroupData[{

Cell["Show[%,ViewPoint->{3.266,0.218,-0.859}]", "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03102 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.046999 1.14918 -0.118162 1.14918 [
[ 0 0 0 0 ]
[ 1 1.03102 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18412 0 m
.20578 .69733 L
s
.20578 .69733 m
.90142 .71313 L
s
.90142 .71313 m
.92701 .00476 L
s
.92701 .00476 m
.18412 0 L
s
0 .09414 m
1 .10279 L
s
1 .10279 m
.95998 1.03102 L
s
.95998 1.03102 m
.04376 1.00356 L
s
.04376 1.00356 m
0 .09414 L
s
.18412 0 m
.20578 .69733 L
s
.20578 .69733 m
.04376 1.00356 L
s
.04376 1.00356 m
0 .09414 L
s
0 .09414 m
.18412 0 L
s
.92701 .00476 m
1 .10279 L
s
1 .10279 m
.95998 1.03102 L
s
.95998 1.03102 m
.90142 .71313 L
s
.90142 .71313 m
.92701 .00476 L
s
0 0 m
1 0 L
1 1.03102 L
0 1.03102 L
closepath
clip
newpath
.32521 .46127 m .56215 .58125 L .52008 .64289 L .78 .65 .719 r
F
.32881 .44444 m .56215 .58125 L .32521 .46127 L .752 .662 .761 r
F
.39574 .48369 m .57769 .51232 L .56215 .58125 L F
.32881 .44444 m .4031 .4647 L .39574 .48369 L F
.4031 .4647 m .57769 .51232 L .39574 .48369 L F
.43792 .29235 m .45656 .32683 L .41912 .30086 L .87 .633 .577 r
F
.32987 .42724 m .60015 .51844 L .32881 .44444 L .724 .68 .807 r
F
.33001 .41004 m .49386 .43862 L .32987 .42724 L .686 .711 .867 r
F
.49386 .43862 m .56771 .45151 L .50466 .44508 L F
.49386 .43862 m .50466 .44508 L .32987 .42724 L F
.56771 .45151 m .56844 .45339 L .32987 .42724 L F
.59554 .45636 m .5951 .45826 L .32987 .42724 L F
.47841 .47736 m .59827 .46049 L .60015 .51844 L .724 .68 .807 r
F
.39369 .44878 m .50277 .45502 L .47841 .47736 L F
.50277 .45502 m .57358 .45907 L .47841 .47736 L F
.57358 .45907 m .57844 .46328 L .47841 .47736 L F
.4114 .43678 m .51008 .44832 L .39369 .44878 L F
.59785 .44659 m .63903 .47062 L .63301 .47656 L .813 .648 .678 r
F
.61578 .46727 m .63301 .47656 L .62806 .48144 L F
.59785 .44659 m .63301 .47656 L .61578 .46727 L F
.6013 .43192 m .63903 .47062 L .59785 .44659 L F
.53938 .43149 m .53923 .43152 L .5349 .42556 L F
.52762 .41434 m .52671 .41431 L .50794 .38853 L F
.53564 .42487 m .50794 .38853 L .50907 .38884 L F
.56771 .45151 m .54715 .43028 L .59554 .45636 L .686 .711 .867 r
F
.49386 .43862 m .53923 .43152 L .56771 .45151 L F
.53923 .43152 m .54715 .43028 L .56771 .45151 L F
.48796 .3849 m .49606 .39988 L .47754 .39196 L .87 .633 .577 r
F
.48382 .40092 m .4946 .39989 L .50009 .40178 L .593 .767 .962 r
F
.46791 .40008 m .48268 .39998 L .48382 .40092 L F
.48268 .39998 m .4946 .39989 L .48382 .40092 L F
.44826 .38337 m .47083 .38487 L .45016 .38606 L 0 .559 .732 r
F
.47083 .38487 m .47626 .39466 L .38779 .39357 L F
.38305 .3899 m .38779 .39357 L .33106 .39287 L F
.47083 .38487 m .38779 .39357 L .38305 .3899 L F
.47223 .38739 m .47981 .3976 L .47626 .39466 L .922 .531 .215 r
F
.45828 .36452 m .47157 .38495 L .45861 .36906 L F
.4398 .33657 m .46758 .38455 L .42577 .33773 L F
.44826 .38337 m .45583 .38378 L .47083 .38487 L 0 .559 .732 r
F
.45583 .38378 m .46758 .38455 L .47083 .38487 L F
.46758 .38455 m .47083 .39015 L .46584 .38443 L .922 .531 .215 r
F
.46758 .38455 m .46584 .38443 L .40022 .30912 L F
.46584 .38443 m .45194 .38352 L .40022 .30912 L F
.45419 .38357 m .46463 .38425 L .45583 .38378 L 0 .559 .732 r
F
.45108 .38346 m .45583 .38378 L .44826 .38337 L F
.45194 .38352 m .45108 .38346 L .40022 .30912 L .922 .531 .215 r
F
.45419 .38357 m .45583 .38378 L .45108 .38346 L 0 .559 .732 r
F
.47157 .38495 m .47981 .3976 L .47032 .38482 L .922 .531 .215 r
F
.49606 .39988 m .48268 .39998 L .47754 .39196 L .87 .633 .577 r
F
.44873 .34703 m .48268 .39998 L .43927 .33526 L .922 .531 .215 r
F
.48268 .39998 m .47981 .3976 L .43935 .33546 L F
.43927 .33526 m .43935 .33546 L .43759 .33276 L F
.48268 .39998 m .43935 .33546 L .43927 .33526 L F
.45619 .39075 m .45607 .39076 L .45108 .38346 L F
.45605 .39824 m .47681 .39511 L .48192 .39935 L .593 .767 .962 r
F
.45606 .39464 m .47951 .3947 L .45605 .39824 L F
.38779 .39357 m .42274 .394 L .36714 .39442 L F
.42274 .394 m .47951 .3947 L .42169 .39456 L F
.42274 .394 m .42169 .39456 L .36714 .39442 L F
.35787 .39429 m .4946 .39989 L .46791 .40008 L F
.33106 .39287 m .35907 .39408 L .35787 .39429 L F
.35907 .39408 m .4946 .39989 L .35787 .39429 L F
.33252 .39299 m .50009 .40178 L .51159 .40719 L F
.33106 .39287 m .33282 .39297 L .33252 .39299 L F
.33282 .39297 m .50009 .40178 L .33252 .39299 L F
.47157 .38495 m .47032 .38482 L .45861 .36906 L .922 .531 .215 r
F
.45861 .36906 m .47223 .38739 L .47083 .39015 L F
.48796 .3849 m .50506 .40412 L .49606 .39988 L .87 .633 .577 r
F
.33106 .39287 m .41944 .40044 L .33001 .41004 L .593 .767 .962 r
F
.41944 .40044 m .49057 .40652 L .43123 .40782 L F
.41944 .40044 m .43123 .40782 L .33001 .41004 L F
.49057 .40652 m .51451 .40857 L .49219 .40931 L F
.47568 .36219 m .50727 .38761 L .48796 .3849 L .87 .633 .577 r
F
.43792 .29235 m .4669 .33216 L .47568 .36219 L F
.4669 .33216 m .50727 .38761 L .47568 .36219 L F
.48796 .3849 m .47754 .39196 L .44873 .34703 L F
.47083 .38487 m .48254 .38565 L .47626 .39466 L 0 .559 .732 r
F
.50727 .38761 m .50794 .38853 L .49946 .38699 L .87 .633 .577 r
F
.50727 .38761 m .49946 .38699 L .48796 .3849 L F
.50794 .38853 m .52671 .41431 L .51421 .40764 L F
.52671 .41431 m .5349 .42556 L .5162 .40937 L F
.52671 .41431 m .5162 .40937 L .51421 .40764 L F
.52403 .39294 m .58404 .43066 L .53747 .41464 L .813 .648 .678 r
F
.52437 .39061 m .58404 .43066 L .52403 .39294 L F
.54935 .39064 m .58404 .43066 L .52437 .39061 L F
.52465 .3888 m .52437 .39061 L .52131 .38855 L F
.54935 .39064 m .52437 .39061 L .52465 .3888 L F
.56771 .45151 m .59554 .45636 L .56844 .45339 L .686 .711 .867 r
F
.53747 .41464 m .62806 .48144 L .54085 .4201 L .813 .648 .678 r
F
.58404 .43066 m .62806 .48144 L .53747 .41464 L F
.53564 .42487 m .5349 .42556 L .52671 .41431 L F
.53564 .42487 m .52671 .41431 L .52762 .41434 L F
.5349 .42556 m .53923 .43152 L .52457 .42123 L .87 .633 .577 r
F
.41692 .41814 m .5169 .41584 L .53598 .42924 L .686 .711 .867 r
F
.33001 .41004 m .44023 .41346 L .41692 .41814 L F
.44023 .41346 m .5169 .41584 L .41692 .41814 L F
.51421 .40764 m .51451 .40857 L .48796 .3849 L .87 .633 .577 r
F
.51451 .40857 m .50506 .40412 L .48796 .3849 L F
.50794 .38853 m .51421 .40764 L .48796 .3849 L F
.45561 .28249 m .54085 .4201 L .43792 .29235 L .813 .648 .678 r
F
.54085 .4201 m .53564 .42487 L .43792 .29235 L F
.45561 .28249 m .56196 .39157 L .55797 .39128 L F
.45561 .28249 m .60028 .43625 L .58404 .43066 L F
.45561 .28249 m .54935 .39064 L .52131 .38855 L F
.50907 .38884 m .50794 .38853 L .43792 .29235 L F
.47105 .27076 m .6877 .41626 L .63903 .47062 L .776 .66 .735 r
F
.47105 .27076 m .63903 .47062 L .45561 .28249 L F
.46463 .38425 m .639 .3956 L .47777 .38532 L 0 .559 .732 r
F
.46803 .38459 m .47777 .38532 L .47083 .38487 L F
.46463 .38425 m .47777 .38532 L .46803 .38459 L F
.55797 .39128 m .6013 .43192 L .60028 .43625 L .813 .648 .678 r
F
.56196 .39157 m .6013 .43192 L .55797 .39128 L F
.58404 .43066 m .60028 .43625 L .59785 .44659 L F
.5216 .40918 m .64665 .41791 L .61123 .41685 L .593 .767 .962 r
F
.5349 .42556 m .51772 .41835 L .51451 .40857 L .87 .633 .577 r
F
.5162 .40937 m .51451 .40857 L .51421 .40764 L F
.5349 .42556 m .51451 .40857 L .5162 .40937 L F
.51451 .40857 m .52121 .40904 L .5216 .40918 L .593 .767 .962 r
F
.52121 .40904 m .64665 .41791 L .5216 .40918 L F
.50009 .40178 m .64943 .39679 L .5171 .40763 L F
.47951 .3947 m .48521 .39477 L .50009 .40178 L F
.48521 .39477 m .64943 .39679 L .50009 .40178 L F
.51648 .41455 m .5169 .41584 L .49559 .41518 L F
.49493 .41403 m .49559 .41518 L .33001 .41004 L F
.51648 .41455 m .49559 .41518 L .49493 .41403 L F
.33106 .39287 m .51159 .40719 L .51451 .40857 L F
.51472 .40921 m .51648 .41455 L .49493 .41403 L F
.49219 .40931 m .49493 .41403 L .33001 .41004 L F
.51472 .40921 m .49493 .41403 L .49219 .40931 L F
.49057 .40652 m .49219 .40931 L .33001 .41004 L F
.51008 .44832 m .62937 .46227 L .50277 .45502 L .724 .68 .807 r
F
.58667 .49407 m .5349 .42556 L .53564 .42487 L .813 .648 .678 r
F
.54085 .4201 m .54715 .43028 L .53564 .42487 L F
.54715 .43028 m .58667 .49407 L .54041 .43133 L F
.54715 .43028 m .54041 .43133 L .53564 .42487 L F
.57358 .45907 m .59827 .46049 L .57844 .46328 L .724 .68 .807 r
F
.59827 .46049 m .62171 .47698 L .60015 .51844 L F
.54085 .4201 m .62806 .48144 L .59751 .51156 L .813 .648 .678 r
F
.54715 .43028 m .64639 .41985 L .59554 .45636 L .686 .711 .867 r
F
.52058 .41595 m .61912 .41901 L .54715 .43028 L F
.61912 .41901 m .64639 .41985 L .54715 .43028 L F
.39809 .42192 m .54715 .43028 L .49386 .43862 L F
.33001 .41004 m .41692 .41814 L .39809 .42192 L F
.41692 .41814 m .54715 .43028 L .39809 .42192 L F
.53574 .47327 m .52561 .46693 L .4855 .40437 L .87 .633 .577 r
F
.48582 .40431 m .4855 .40437 L .48268 .39998 L F
.53574 .47327 m .4855 .40437 L .48582 .40431 L F
.47981 .3976 m .53098 .47619 L .47083 .39015 L .922 .531 .215 r
F
.53098 .47619 m .56835 .53358 L .54059 .49275 L F
.53098 .47619 m .54059 .49275 L .47083 .39015 L F
.51008 .44832 m .50277 .45502 L .39369 .44878 L .724 .68 .807 r
F
.47083 .39015 m .54059 .49275 L .55442 .53451 L .922 .531 .215 r
F
.54059 .49275 m .56835 .53358 L .56442 .53384 L F
.54059 .49275 m .56442 .53384 L .55442 .53451 L F
.51451 .40857 m .51472 .40921 L .49219 .40931 L .593 .767 .962 r
F
.51451 .40857 m .51772 .41835 L .50506 .40412 L .87 .633 .577 r
F
.49606 .39988 m .49722 .40202 L .48268 .39998 L F
.49722 .40202 m .53574 .47327 L .48582 .40431 L F
.49722 .40202 m .48582 .40431 L .48268 .39998 L F
.53598 .42924 m .52058 .41595 L .54715 .43028 L .686 .711 .867 r
F
.5169 .41584 m .52058 .41595 L .53598 .42924 L F
.52457 .42123 m .58331 .49206 L .51772 .41835 L .87 .633 .577 r
F
.53923 .43152 m .58331 .49206 L .52457 .42123 L F
.52078 .41466 m .52058 .41595 L .5169 .41584 L .593 .767 .962 r
F
.52078 .41466 m .5169 .41584 L .51648 .41455 L F
.61123 .41685 m .61912 .41901 L .52058 .41595 L F
.61123 .41685 m .52058 .41595 L .52078 .41466 L F
.51159 .40719 m .64665 .41791 L .51451 .40857 L F
.52131 .38855 m .52437 .39061 L .52403 .39294 L .813 .648 .678 r
F
.48254 .38565 m .64943 .39679 L .48521 .39477 L 0 .559 .732 r
F
.48254 .38565 m .48521 .39477 L .47626 .39466 L F
.48254 .38565 m .639 .3956 L .64943 .39679 L F
.48042 .38551 m .48211 .38562 L .48254 .38565 L F
.48211 .38562 m .639 .3956 L .48254 .38565 L F
.5216 .40918 m .52078 .41466 L .51648 .41455 L .593 .767 .962 r
F
.5216 .40918 m .51648 .41455 L .51472 .40921 L F
.51451 .40857 m .5216 .40918 L .51472 .40921 L F
.53574 .47327 m .58331 .49206 L .56835 .53358 L .87 .633 .577 r
F
.49722 .40202 m .52028 .42614 L .53574 .47327 L F
.52028 .42614 m .58331 .49206 L .53574 .47327 L F
.53574 .47327 m .56835 .53358 L .52561 .46693 L F
.48468 .40309 m .52561 .46693 L .48131 .3999 L .922 .531 .215 r
F
.52561 .46693 m .56835 .53358 L .53098 .47619 L F
.52561 .46693 m .53098 .47619 L .48131 .3999 L F
.5216 .40918 m .61123 .41685 L .52078 .41466 L .593 .767 .962 r
F
.47083 .38487 m .47777 .38532 L .48042 .38551 L 0 .559 .732 r
F
.47777 .38532 m .639 .3956 L .48042 .38551 L F
.45656 .32683 m .48796 .3849 L .44873 .34703 L .87 .633 .577 r
F
.44548 .37186 m .639 .3956 L .45419 .38357 L .624 .256 .324 r
F
.44299 .3698 m .45108 .38346 L .45054 .37607 L .055 .267 .761 r
F
.42011 .3382 m .45108 .38346 L .43246 .35202 L F
.34147 .35911 m .44548 .37186 L .33458 .37578 L .624 .256 .324 r
F
.45075 .37896 m .45108 .38346 L .4541 .38346 L .055 .267 .761 r
F
.45108 .38346 m .45609 .38364 L .45609 .38345 L F
.44548 .37186 m .45419 .38357 L .33458 .37578 L .624 .256 .324 r
F
.45054 .37607 m .45075 .37896 L .45609 .38345 L .055 .267 .761 r
F
.45075 .37896 m .4541 .38346 L .45609 .38345 L F
.44548 .37186 m .45106 .37615 L .45895 .37352 L .624 .256 .324 r
F
.45054 .37607 m .45609 .38345 L .4471 .37555 L .055 .267 .761 r
F
.37018 .36263 m .37452 .36377 L .42058 .36903 L .624 .256 .324 r
F
.41985 .36872 m .42058 .36903 L .44548 .37186 L F
.37018 .36263 m .42058 .36903 L .41985 .36872 L F
.54204 .51314 m .45133 .38382 L .45211 .38376 L .922 .531 .215 r
F
.45133 .38382 m .45108 .38346 L .45211 .38376 L F
.45211 .38376 m .45108 .38346 L .45194 .38352 L F
.47083 .39015 m .45694 .39072 L .45194 .38352 L F
.47083 .39015 m .45194 .38352 L .46584 .38443 L F
.42141 .38151 m .45419 .38357 L .45108 .38346 L 0 .559 .732 r
F
.43105 .38206 m .45419 .38357 L .42141 .38151 L F
.36768 .37799 m .45108 .38346 L .44826 .38337 L F
.33458 .37578 m .45108 .38346 L .36768 .37799 L F
.45583 .38378 m .45609 .38379 L .45609 .38379 L F
.45609 .38379 m .46463 .38425 L .45609 .38379 L F
.45609 .38379 m .46463 .38425 L .46758 .38455 L F
.45108 .38346 m .45607 .39076 L .45609 .38364 L .055 .267 .761 r
F
.33458 .37578 m .44826 .38337 L .33106 .39287 L 0 .559 .732 r
F
.44826 .38337 m .45016 .38606 L .33106 .39287 L F
.45609 .38345 m .44031 .38467 L .43004 .37298 L .055 .267 .761 r
F
.45609 .38345 m .43004 .37298 L .4471 .37555 L F
.44171 .37474 m .45822 .38244 L .45054 .37607 L .624 .256 .324 r
F
.43004 .37298 m .43839 .38249 L .44789 .38058 L .494 .47 .759 r
F
.43004 .37298 m .44789 .38058 L .44762 .38032 L F
.43839 .38249 m .44031 .38467 L .44384 .3828 L F
.43839 .38249 m .44384 .3828 L .44811 .38053 L F
.54204 .51314 m .53726 .50943 L .45607 .39076 L .922 .531 .215 r
F
.54204 .51314 m .45607 .39076 L .45619 .39075 L F
.47083 .39015 m .54204 .51314 L .45694 .39072 L F
.45609 .38345 m .53726 .50943 L .55587 .51619 L .055 .267 .761 r
F
.45607 .39076 m .53726 .50943 L .45609 .38345 L F
.36714 .39442 m .45606 .39464 L .45605 .39824 L .593 .767 .962 r
F
.45609 .38345 m .55587 .51619 L .44031 .38467 L .055 .267 .761 r
F
.45665 .3841 m .55587 .51619 L .57033 .48425 L .494 .47 .759 r
F
.43004 .37298 m .45822 .38244 L .44171 .37474 L .624 .256 .324 r
F
.44659 .3799 m .45822 .38244 L .43004 .37298 L F
.40475 .37176 m .44762 .38032 L .38187 .36571 L F
.44762 .38032 m .45822 .38244 L .44659 .3799 L F
.44762 .38032 m .44659 .3799 L .38187 .36571 L F
.44031 .38467 m .55587 .51619 L .4539 .38295 L .494 .47 .759 r
F
.35194 .3612 m .45054 .37607 L .44548 .37186 L .624 .256 .324 r
F
.4471 .37555 m .43004 .37298 L .38214 .31846 L .055 .267 .761 r
F
.45822 .38244 m .45964 .38273 L .44548 .37186 L .624 .256 .324 r
F
.43246 .35202 m .44299 .3698 L .45054 .37607 L .055 .267 .761 r
F
.43246 .35202 m .45054 .37607 L .41907 .35092 L F
.45054 .37607 m .4471 .37555 L .41907 .35092 L F
.45106 .37615 m .45964 .38273 L .45924 .37738 L .624 .256 .324 r
F
.45106 .37615 m .45924 .37738 L .45895 .37352 L F
.5171 .40763 m .64943 .39679 L .64665 .41791 L .593 .767 .962 r
F
.45895 .37352 m .61837 .41446 L .639 .3956 L .624 .256 .324 r
F
.45964 .38273 m .61837 .41446 L .45895 .37352 L F
.43095 .36456 m .61837 .41446 L .44762 .38032 L .644 .43 .578 r
F
.44811 .38053 m .4539 .38295 L .45091 .37905 L .494 .47 .759 r
F
.44031 .38467 m .4539 .38295 L .44811 .38053 L F
.45091 .37905 m .4539 .38295 L .45665 .3841 L F
.4539 .38295 m .55587 .51619 L .45665 .3841 L F
.38187 .36571 m .44659 .3799 L .43004 .37298 L .624 .256 .324 r
F
.44689 .3755 m .43004 .37298 L .45091 .37905 L .494 .47 .759 r
F
.41 .35018 m .43004 .37298 L .44689 .3755 L F
.35194 .3612 m .40475 .37176 L .38187 .36571 L .624 .256 .324 r
F
.43004 .37298 m .44811 .38053 L .45091 .37905 L .494 .47 .759 r
F
.34147 .35911 m .35194 .3612 L .37452 .36377 L .624 .256 .324 r
F
.34147 .35911 m .37452 .36377 L .37018 .36263 L F
.43095 .36456 m .44762 .38032 L .34147 .35911 L .644 .43 .578 r
F
.44762 .38032 m .44789 .38058 L .44811 .38053 L .494 .47 .759 r
F
.44689 .3755 m .57033 .48425 L .41062 .36369 L F
.35198 .34353 m .43095 .36456 L .34147 .35911 L .644 .43 .578 r
F
.40692 .362 m .45982 .38616 L .45883 .3837 L F
.44863 .3767 m .45883 .3837 L .45722 .37972 L F
.40692 .362 m .45883 .3837 L .44863 .3767 L F
.38672 .35278 m .45722 .37972 L .44764 .369 L F
.36223 .34626 m .40692 .362 L .38672 .35278 L F
.40692 .362 m .45722 .37972 L .38672 .35278 L F
.44764 .369 m .45722 .37972 L .45353 .37057 L F
.43719 .38032 m .46055 .38649 L .4443 .37907 L .602 .478 .684 r
F
.43351 .38097 m .57033 .48425 L .47329 .39231 L F
.48192 .39935 m .47951 .3947 L .4946 .39989 L .593 .767 .962 r
F
.47681 .39511 m .47951 .3947 L .48192 .39935 L F
.47223 .38739 m .47626 .39466 L .47083 .39015 L .922 .531 .215 r
F
.51159 .40719 m .50009 .40178 L .5171 .40763 L .593 .767 .962 r
F
.49606 .39988 m .51314 .4132 L .49722 .40202 L .87 .633 .577 r
F
.50506 .40412 m .51314 .4132 L .49606 .39988 L F
.51314 .4132 m .58331 .49206 L .49722 .40202 L F
.45982 .38616 m .59324 .44707 L .45353 .37057 L .644 .43 .578 r
F
.43351 .38097 m .47329 .39231 L .46228 .38728 L .602 .478 .684 r
F
.43351 .38097 m .4697 .38891 L .43719 .38032 L F
.48468 .40309 m .48131 .3999 L .47981 .3976 L .922 .531 .215 r
F
.48268 .39998 m .48468 .40309 L .47981 .3976 L F
.58667 .49407 m .58331 .49206 L .53923 .43152 L .813 .648 .678 r
F
.58667 .49407 m .53923 .43152 L .53938 .43149 L F
.45697 .37684 m .57033 .48425 L .59324 .44707 L .602 .478 .684 r
F
.46157 .39049 m .59324 .44707 L .45982 .38616 L .644 .43 .578 r
F
.4443 .37907 m .4697 .38891 L .45697 .37684 L .602 .478 .684 r
F
.46055 .38649 m .4697 .38891 L .4443 .37907 L F
.38214 .31846 m .41 .35018 L .44689 .3755 L .494 .47 .759 r
F
.38214 .31846 m .44689 .3755 L .36577 .32984 L F
.44689 .3755 m .41062 .36369 L .36577 .32984 L F
.36577 .32984 m .43021 .37848 L .45697 .37684 L .602 .478 .684 r
F
.43021 .37848 m .43719 .38032 L .45697 .37684 L F
.38239 .3545 m .46157 .39049 L .45982 .38616 L .644 .43 .578 r
F
.36223 .34626 m .37625 .3525 L .38239 .3545 L F
.37625 .3525 m .46157 .39049 L .38239 .3545 L F
.36223 .34626 m .45982 .38616 L .40692 .362 L F
.46228 .38728 m .47329 .39231 L .4697 .38891 L .602 .478 .684 r
F
.33458 .37578 m .43105 .38206 L .42141 .38151 L 0 .559 .732 r
F
.43021 .37848 m .43351 .38097 L .43719 .38032 L .602 .478 .684 r
F
.40022 .30912 m .42011 .3382 L .43246 .35202 L .055 .267 .761 r
F
.35277 .34374 m .35778 .3459 L .36223 .34626 L .644 .43 .578 r
F
.35778 .3459 m .46157 .39049 L .36223 .34626 L F
.40022 .30912 m .43246 .35202 L .38214 .31846 L .055 .267 .761 r
F
.43246 .35202 m .41907 .35092 L .38214 .31846 L F
.35252 .34376 m .46161 .39058 L .35277 .34374 L .644 .43 .578 r
F
.46161 .39058 m .59324 .44707 L .46157 .39049 L F
.46161 .39058 m .46157 .39049 L .35277 .34374 L F
.61123 .41685 m .64665 .41791 L .64639 .41985 L .593 .767 .962 r
F
.61123 .41685 m .64639 .41985 L .61912 .41901 L F
.45353 .37057 m .59324 .44707 L .61837 .41446 L .644 .43 .578 r
F
.43898 .33453 m .43927 .33526 L .43759 .33276 L .922 .531 .215 r
F
.44873 .34703 m .43927 .33526 L .43898 .33453 L F
.35198 .34353 m .35252 .34376 L .35277 .34374 L .644 .43 .578 r
F
.41912 .30086 m .4398 .33657 L .40022 .30912 L .922 .531 .215 r
F
.4398 .33657 m .42577 .33773 L .40022 .30912 L F
.33106 .39287 m .38779 .39357 L .36714 .39442 L .593 .767 .962 r
F
.54204 .51314 m .55442 .53451 L .53726 .50943 L .922 .531 .215 r
F
.53726 .50943 m .55442 .53451 L .55447 .53381 L .055 .267 .761 r
F
.53726 .50943 m .55447 .53381 L .55587 .51619 L F
.43759 .33276 m .45828 .36452 L .45861 .36906 L .922 .531 .215 r
F
.59554 .45636 m .64639 .41985 L .62937 .46227 L .686 .711 .867 r
F
.58667 .49407 m .59751 .51156 L .58331 .49206 L .813 .648 .678 r
F
.58331 .49206 m .59751 .51156 L .59232 .51548 L .87 .633 .577 r
F
.57769 .51232 m .60015 .51844 L .59242 .5312 L .752 .662 .761 r
F
.57769 .51232 m .59242 .5312 L .56215 .58125 L F
.58331 .49206 m .59232 .51548 L .56835 .53358 L .87 .633 .577 r
F
.59554 .45636 m .62937 .46227 L .5951 .45826 L .686 .711 .867 r
F
.59827 .46049 m .62937 .46227 L .62171 .47698 L .724 .68 .807 r
F
.32987 .42724 m .4114 .43678 L .39369 .44878 L F
.45656 .32683 m .44873 .34703 L .41912 .30086 L .87 .633 .577 r
F
.41912 .30086 m .44873 .34703 L .43759 .33276 L .922 .531 .215 r
F
.25 g
.5 Mabswid
.53672 .56837 m
.56215 .58125 L
s
1 0 0 r
.003 w
.59242 .5312 m
.60015 .51844 L
s
.56215 .58125 m
.59242 .5312 L
s
.25 g
.5 Mabswid
.59152 .51609 m
.60015 .51844 L
s
1 0 0 r
.003 w
.62171 .47698 m
.62937 .46227 L
s
.60015 .51844 m
.61027 .49898 L
s
.4831 .25724 m .6877 .41626 L .47105 .27076 L .748 .675 .781 r
F
.25 g
.5 Mabswid
.4736 .27247 m
.47591 .27402 L
s
.47105 .27076 m
.4736 .27247 L
s
.4831 .25724 m .7368 .35599 L .6877 .41626 L .748 .675 .781 r
F
.25 g
.66158 .39872 m
.67268 .40617 L
s
.67268 .40617 m
.6877 .41626 L
s
1 0 0 r
.003 w
.63903 .47062 m
.65631 .45132 L
s
.65631 .45132 m
.6877 .41626 L
s
.31819 .47694 m .52008 .64289 L .47966 .6954 L .813 .641 .668 r
F
.32521 .46127 m .52008 .64289 L .31819 .47694 L .78 .65 .719 r
F
1 0 0 r
.52008 .64289 m
.56215 .58125 L
s
.25 g
.5 Mabswid
.49017 .48845 m
.49775 .49052 L
s
.49775 .49052 m
.53042 .49943 L
s
.4031 .4647 m
.42376 .47034 L
s
.37317 .45654 m
.4031 .4647 L
s
.62981 .46116 m
.63903 .47062 L
s
.45561 .28249 m
.45686 .28378 L
s
.45686 .28378 m
.45712 .28405 L
s
1 0 0 r
.003 w
.59751 .51156 m
.62806 .48144 L
s
.62806 .48144 m
.63903 .47062 L
s
.49094 .24241 m .7368 .35599 L .4831 .25724 L .72 .695 .826 r
F
.25 g
.5 Mabswid
.45712 .28405 m
.4874 .3151 L
s
.49094 .24241 m .77934 .29782 L .7368 .35599 L .72 .695 .826 r
F
.25 g
.57306 .33927 m
.66158 .39872 L
s
1 0 0 r
.003 w
.6877 .41626 m
.7368 .35599 L
s
.25 g
.5 Mabswid
.51633 .34477 m
.51956 .34808 L
s
.51956 .34808 m
.55596 .38542 L
s
.5951 .45826 m
.62937 .46227 L
s
.42295 .43813 m
.47613 .44435 L
s
.47613 .44435 m
.49418 .44646 L
s
1 0 0 r
.003 w
.62937 .46227 m
.64639 .41985 L
s
.30767 .49047 m .47966 .6954 L .44693 .73132 L .861 .63 .587 r
F
.31819 .47694 m .47966 .6954 L .30767 .49047 L .813 .641 .668 r
F
.25 g
.5 Mabswid
.32521 .46127 m
.32891 .46314 L
s
.40256 .50044 m
.43218 .51543 L
s
.43218 .51543 m
.53672 .56837 L
s
.35349 .50596 m
.45107 .58616 L
s
.45107 .58616 m
.52008 .64289 L
s
1 0 0 r
.003 w
.47966 .6954 m
.52008 .64289 L
s
.25 g
.5 Mabswid
.42376 .47034 m
.49017 .48845 L
s
.57367 .47882 m
.58331 .49206 L
s
.58331 .49206 m
.59751 .51156 L
s
.43792 .29235 m
.43808 .29257 L
s
.43808 .29257 m
.45568 .31675 L
s
1 0 0 r
.003 w
.56835 .53358 m
.59751 .51156 L
s
.4944 .22683 m .77934 .29782 L .49094 .24241 L .684 .723 .879 r
F
.25 g
.5 Mabswid
.4831 .25724 m
.49208 .26073 L
s
.47591 .27402 m
.47808 .27548 L
s
.4944 .22683 m .80915 .24925 L .77934 .29782 L .684 .723 .879 r
F
.25 g
.47808 .27548 m
.51463 .30003 L
s
1 0 0 r
.003 w
.7368 .35599 m
.77934 .29782 L
s
.25 g
.5 Mabswid
.61496 .41888 m
.61912 .41901 L
s
.33001 .41004 m
.33085 .41007 L
s
.46318 .41417 m
.46632 .41427 L
s
.61912 .41901 m
.64639 .41985 L
s
1 0 0 r
.003 w
.64639 .41985 m
.64943 .39679 L
s
.25 g
.5 Mabswid
.34147 .35911 m
.35194 .3612 L
s
0 g
.006 w
.33458 .37578 m
.34147 .35911 L
s
.36577 .32984 m .59324 .44707 L .35198 .34353 L .602 .478 .684 r
F
.25 g
.5 Mabswid
.35198 .34353 m
.35742 .34587 L
s
.35742 .34587 m
.36231 .34797 L
s
.36231 .34797 m
.39274 .36103 L
s
.39274 .36103 m
.44314 .38265 L
s
.44612 .38393 m
.46161 .39058 L
s
.44314 .38265 m
.44612 .38393 L
s
.48093 .39887 m
.59324 .44707 L
s
.47023 .39428 m
.48093 .39887 L
s
.46161 .39058 m
.47023 .39428 L
s
0 g
.006 w
.34147 .35911 m
.35198 .34353 L
s
.25 g
.5 Mabswid
.40475 .37176 m
.42726 .37626 L
s
.35194 .3612 m
.40475 .37176 L
s
.44023 .41346 m
.46318 .41417 L
s
.35725 .41089 m
.44023 .41346 L
s
.33085 .41007 m
.35725 .41089 L
s
.49208 .26073 m
.7368 .35599 L
s
.45568 .31675 m
.48027 .35053 L
s
.48374 .35529 m
.50074 .37864 L
s
.48027 .35053 m
.48374 .35529 L
s
.32987 .42724 m
.36879 .43179 L
s
.36879 .43179 m
.42295 .43813 L
s
.4874 .3151 m
.51633 .34477 L
s
.51463 .30003 m
.57306 .33927 L
s
.32881 .44444 m
.37317 .45654 L
s
0 g
.006 w
.35198 .34353 m
.36577 .32984 L
s
.25 g
.5 Mabswid
.33458 .37578 m
.33642 .3759 L
s
.33642 .3759 m
.37603 .37848 L
s
.37603 .37848 m
.43105 .38206 L
s
.43105 .38206 m
.43533 .38234 L
s
0 g
.006 w
.33106 .39287 m
.33458 .37578 L
s
.25 g
.5 Mabswid
.55642 .51498 m
.56835 .53358 L
s
.44873 .34703 m
.45688 .35974 L
s
.45688 .35974 m
.45806 .36158 L
s
.45806 .36158 m
.46594 .37387 L
s
.41912 .30086 m
.43603 .32722 L
s
.43603 .32722 m
.44873 .34703 L
s
1 0 0 r
.003 w
.55442 .53451 m
.56835 .53358 L
s
.25 g
.5 Mabswid
.47232 .41027 m
.49587 .42804 L
s
.49587 .42804 m
.57033 .48425 L
s
.4351 .38217 m
.47232 .41027 L
s
.42599 .37529 m
.43021 .37848 L
s
.43021 .37848 m
.4351 .38217 L
s
0 g
.006 w
.36577 .32984 m
.38214 .31846 L
s
.25 g
.5 Mabswid
.63786 .39665 m
.64943 .39679 L
s
.33106 .39287 m
.33377 .39291 L
s
.33377 .39291 m
.42274 .394 L
s
.42274 .394 m
.44879 .39432 L
s
0 g
.006 w
.33001 .41004 m
.33106 .39287 L
s
.25 g
.5 Mabswid
.49701 .4492 m
.55587 .51619 L
s
.44405 .38893 m
.49701 .4492 L
s
0 g
.006 w
.38214 .31846 m
.40022 .30912 L
s
.29418 .50116 m .42704 .74503 L .2785 .50889 L .926 .587 .377 r
F
.29713 .50656 m .44693 .73132 L .42704 .74503 L F
.29643 .50528 m .29705 .50622 L .29713 .50656 L F
.29705 .50622 m .44693 .73132 L .29713 .50656 L F
.27919 .50997 m .32695 .58592 L .32922 .58839 L 0 0 .445 r
F
.27901 .5097 m .32695 .58592 L .27919 .50997 L F
.32695 .58592 m .42704 .74503 L .32922 .58839 L F
.32922 .58839 m .34523 .62897 L .26136 .51431 L F
.35908 .63547 m .42704 .74503 L .42591 .74242 L F
.40262 .70413 m .42591 .74242 L .42373 .73741 L F
.35908 .63547 m .42591 .74242 L .40262 .70413 L F
.29571 .50346 m .44693 .73132 L .29643 .50528 L .926 .587 .377 r
F
.30767 .49047 m .44693 .73132 L .29418 .50116 L .861 .63 .587 r
F
.37816 .65094 m .40709 .642 L .44462 .67122 L .741 .671 .782 r
F
.40709 .642 m .46916 .62282 L .45793 .64497 L F
.40709 .642 m .45793 .64497 L .44462 .67122 L F
.32922 .58839 m .35637 .63187 L .35908 .63547 L 0 0 .445 r
F
.35637 .63187 m .42704 .74503 L .35908 .63547 L F
.32922 .58839 m .42373 .73741 L .40809 .71201 L F
.32922 .58839 m .40809 .71201 L .34523 .62897 L F
.40809 .71201 m .42452 .71115 L .41689 .7263 L .776 .645 .717 r
F
.41939 .73036 m .42373 .73741 L .42254 .73468 L 0 0 .445 r
F
.40809 .71201 m .40605 .71212 L .34523 .62897 L F
.34809 .63288 m .38913 .689 L .37816 .65094 L .307 .389 .783 r
F
.37816 .65094 m .44462 .67122 L .38079 .65251 L .741 .671 .782 r
F
.37672 .64592 m .46916 .62282 L .37816 .65094 L F
.36529 .60784 m .38506 .60426 L .46916 .62282 L .693 .719 .869 r
F
.36599 .60693 m .38506 .60426 L .36529 .60784 L F
.3288 .58894 m .34809 .63288 L .36243 .63673 L .307 .389 .783 r
F
.3288 .58894 m .36243 .63673 L .36243 .62616 L F
.26136 .51431 m .30731 .57712 L .3288 .58894 L F
.30731 .57712 m .34809 .63288 L .3288 .58894 L F
.36243 .62616 m .36243 .63673 L .37505 .64013 L F
.31005 .56819 m .37505 .64013 L .31418 .58786 L F
.29957 .55659 m .31005 .56819 L .24344 .51861 L F
.26136 .51431 m .29957 .55659 L .24344 .51861 L F
.31005 .56819 m .31418 .58786 L .24344 .51861 L F
.2785 .50889 m .27901 .5097 L .27919 .50997 L 0 0 .445 r
F
.2785 .50889 m .32922 .58839 L .26136 .51431 L F
.24344 .51861 m .31257 .58629 L .36873 .60339 L .522 .469 .739 r
F
.34809 .63288 m .37816 .65094 L .37505 .64013 L .307 .389 .783 r
F
.37505 .64013 m .36709 .63966 L .31418 .58786 L F
.31257 .58629 m .35206 .62495 L .36529 .60784 L .522 .469 .739 r
F
.31257 .58629 m .36529 .60784 L .36873 .60339 L F
.36529 .60784 m .46916 .62282 L .37086 .61012 L .693 .719 .869 r
F
.3188 .5696 m .36873 .60339 L .32965 .58594 L .522 .469 .739 r
F
.36873 .60339 m .35759 .60279 L .32965 .58594 L F
.24344 .51861 m .3188 .5696 L .22556 .52316 L F
.3188 .5696 m .32965 .58594 L .22556 .52316 L F
.22556 .52316 m .29179 .5631 L .39011 .58362 L .602 .471 .675 r
F
.22556 .52316 m .39011 .58362 L .39139 .58348 L F
.22556 .52316 m .39139 .58348 L .20884 .52889 L F
.38212 .58447 m .39697 .58367 L .48567 .59017 L .499 .8 .999 r
F
.40561 .58196 m .49125 .57856 L .38212 .58447 L F
.38212 .58447 m .48567 .59017 L .39015 .58637 L F
.29179 .5631 m .39015 .58637 L .39399 .58443 L .602 .471 .675 r
F
.39139 .58348 m .37839 .58305 L .38823 .58253 L F
.20884 .52889 m .37839 .58305 L .40495 .58166 L .64 .429 .581 r
F
.3367 .55028 m .40495 .58166 L .49588 .57691 L F
.20884 .52889 m .40495 .58166 L .3367 .55028 L F
.37839 .58305 m .49505 .5784 L .49588 .57691 L F
.44588 .57766 m .49111 .57856 L .40561 .58196 L .499 .8 .999 r
F
.49111 .57856 m .49125 .57856 L .40561 .58196 L F
.29179 .5631 m .35759 .60279 L .39015 .58637 L .602 .471 .675 r
F
.15343 .57188 m .44588 .57766 L .40561 .58196 L .499 .8 .999 r
F
.36554 .58356 m .40561 .58196 L .38212 .58447 L F
.15343 .57188 m .40561 .58196 L .36554 .58356 L F
.39139 .58348 m .39011 .58362 L .39399 .58443 L .602 .471 .675 r
F
.38213 .58605 m .48567 .59017 L .36599 .60693 L .693 .719 .869 r
F
.39139 .58348 m .39399 .58443 L .37839 .58305 L .602 .471 .675 r
F
.38506 .60426 m .48567 .59017 L .47609 .60911 L .693 .719 .869 r
F
.38506 .60426 m .47609 .60911 L .46916 .62282 L F
.35206 .62495 m .36709 .63966 L .36873 .60339 L .522 .469 .739 r
F
.36646 .64465 m .46916 .62282 L .36848 .64798 L .741 .671 .782 r
F
.3696 .61997 m .46916 .62282 L .36646 .64465 L F
.36709 .63966 m .37122 .6073 L .36873 .60339 L .522 .469 .739 r
F
.35939 .60864 m .37086 .61012 L .35113 .61944 L .741 .671 .782 r
F
.37086 .61012 m .46916 .62282 L .3696 .61997 L F
.37086 .61012 m .3696 .61997 L .35113 .61944 L F
.38913 .689 m .40605 .71212 L .37505 .64013 L .307 .389 .783 r
F
.38846 .67063 m .44462 .67122 L .42452 .71115 L .776 .645 .717 r
F
.40605 .71212 m .37819 .64639 L .37505 .64013 L .307 .389 .783 r
F
.37078 .65075 m .38127 .65366 L .38846 .67063 L .776 .645 .717 r
F
.38127 .65366 m .44462 .67122 L .38846 .67063 L F
.36937 .64917 m .37057 .64952 L .37078 .65075 L F
.38079 .65251 m .44462 .67122 L .38127 .65366 L F
.36937 .64917 m .42452 .71115 L .40809 .71201 L F
.37598 .64115 m .42254 .73468 L .43236 .70355 L .307 .389 .783 r
F
.37505 .64013 m .37819 .64639 L .37598 .64115 L F
.37819 .64639 m .42254 .73468 L .37598 .64115 L F
.37057 .64952 m .38079 .65251 L .37078 .65075 L .776 .645 .717 r
F
.38079 .65251 m .38127 .65366 L .37078 .65075 L F
.41162 .72527 m .40404 .70738 L .41616 .72774 L F
.36937 .64917 m .41689 .7263 L .41616 .72774 L F
.40809 .71201 m .42254 .73468 L .40605 .71212 L 0 0 .445 r
F
.40605 .71212 m .42254 .73468 L .37819 .64639 L .307 .389 .783 r
F
.37816 .65094 m .38079 .65251 L .36937 .64917 L .741 .671 .782 r
F
.36848 .64798 m .37672 .64592 L .37816 .65094 L F
.37505 .64013 m .43236 .70355 L .36709 .63966 L .307 .389 .783 r
F
.36788 .63348 m .43236 .70355 L .37122 .6073 L .522 .469 .739 r
F
.36709 .63966 m .36928 .6418 L .36788 .63348 L F
.36928 .6418 m .43236 .70355 L .36788 .63348 L F
.37148 .60525 m .43236 .70355 L .45203 .65975 L F
.36873 .60339 m .37122 .6073 L .37148 .60525 L F
.37122 .6073 m .43236 .70355 L .37148 .60525 L F
.35113 .61944 m .3696 .61997 L .36646 .64465 L .741 .671 .782 r
F
.34329 .60656 m .35939 .60864 L .35113 .61944 L F
.39399 .58443 m .45203 .65975 L .47529 .614 L .602 .471 .675 r
F
.36242 .60036 m .37461 .59421 L .36242 .60743 L .693 .719 .869 r
F
.38213 .58605 m .36599 .60693 L .36242 .60743 L F
.36529 .60784 m .37086 .61012 L .36623 .60952 L F
.36242 .60743 m .36599 .60693 L .36529 .60784 L F
.15013 .57681 m .36241 .58526 L .36242 .60743 L F
.36873 .60339 m .45203 .65975 L .35759 .60279 L .522 .469 .739 r
F
.35759 .60279 m .45203 .65975 L .39399 .58443 L .602 .471 .675 r
F
.39399 .58443 m .41642 .59258 L .38432 .58453 L F
.39399 .58443 m .38432 .58453 L .37839 .58305 L F
.41642 .59258 m .47529 .614 L .40325 .59099 L F
.38212 .58447 m .39015 .58637 L .37719 .58585 L .499 .8 .999 r
F
.37098 .58463 m .37719 .58585 L .35287 .58488 L F
.38212 .58447 m .37719 .58585 L .37098 .58463 L F
.41642 .59258 m .40325 .59099 L .37839 .58305 L .602 .471 .675 r
F
.39697 .58367 m .49125 .57856 L .48735 .58668 L .499 .8 .999 r
F
.39697 .58367 m .48735 .58668 L .48567 .59017 L F
.37839 .58305 m .40325 .59099 L .49505 .5784 L .64 .429 .581 r
F
.40325 .59099 m .47529 .614 L .4797 .60605 L F
.40325 .59099 m .4797 .60605 L .49505 .5784 L F
.33722 .58299 m .35287 .58488 L .15013 .57681 L .499 .8 .999 r
F
.38212 .58447 m .35287 .58488 L .33722 .58299 L F
.15343 .57188 m .38212 .58447 L .15013 .57681 L F
.36241 .58526 m .38213 .58605 L .37461 .59421 L .693 .719 .869 r
F
.36241 .58526 m .37461 .59421 L .36242 .60036 L F
.36242 .60743 m .36529 .60784 L .36623 .60952 L F
.15013 .57681 m .36242 .60743 L .15164 .58179 L F
.36242 .60743 m .36623 .60952 L .15164 .58179 L F
.15698 .58691 m .36937 .64917 L .40404 .70738 L .776 .645 .717 r
F
.15698 .58691 m .40404 .70738 L .41162 .72527 L F
.36848 .64798 m .37816 .65094 L .36937 .64917 L .741 .671 .782 r
F
.15164 .58179 m .34329 .60656 L .36848 .64798 L F
.15164 .58179 m .36848 .64798 L .15698 .58691 L F
.36848 .64798 m .36937 .64917 L .15698 .58691 L F
.29418 .50116 m .29571 .50346 L .29643 .50528 L .926 .587 .377 r
F
.25 g
.5 Mabswid
.29418 .50116 m
.29571 .50346 L
s
.29571 .50346 m
.30279 .51412 L
s
.43112 .70749 m
.44693 .73132 L
s
.30279 .51412 m
.32554 .54841 L
s
1 0 0 r
.003 w
.44693 .73132 m
.47966 .6954 L
s
.25 g
.5 Mabswid
.35874 .55133 m
.36132 .5544 L
s
.45123 .66153 m
.47966 .6954 L
s
.31348 .4974 m
.31506 .49929 L
s
.31506 .49929 m
.31513 .49937 L
s
.31513 .49937 m
.35874 .55133 L
s
.31819 .47694 m
.327 .48418 L
s
.327 .48418 m
.35349 .50596 L
s
.30767 .49047 m
.31348 .4974 L
s
.32891 .46314 m
.34343 .47049 L
s
.34343 .47049 m
.40256 .50044 L
s
1 0 0 r
.003 w
.42704 .74503 m
.44693 .73132 L
s
0 g
.006 w
.32987 .42724 m
.33001 .41004 L
s
.32881 .44444 m
.32987 .42724 L
s
.25 g
.5 Mabswid
.4927 .4443 m
.53726 .50943 L
s
.53726 .50943 m
.55442 .53451 L
s
0 g
.006 w
.40022 .30912 m
.41912 .30086 L
s
.32521 .46127 m
.32881 .44444 L
s
.41912 .30086 m
.43792 .29235 L
s
.31819 .47694 m
.32521 .46127 L
s
.43792 .29235 m
.45561 .28249 L
s
.49425 .21086 m .80915 .24925 L .4944 .22683 L .616 .765 .951 r
F
.49425 .21086 m .78466 .21593 L .80915 .24925 L F
.49202 .19463 m .82191 .21658 L .49425 .21086 L .364 .769 .983 r
F
.48948 .17826 m .59199 .1864 L .49202 .19463 L .427 0 0 r
F
.59199 .1864 m .69245 .19437 L .60558 .19448 L F
.59199 .1864 m .60558 .19448 L .49202 .19463 L F
.69245 .19437 m .69457 .19729 L .49202 .19463 L F
.78466 .21593 m .8183 .22583 L .80915 .24925 L .616 .765 .951 r
F
.75838 .28539 m .80902 .2339 L .7584 .28541 L .748 .682 .787 r
F
.72782 .19844 m .72894 .20161 L .69701 .20067 L .427 0 0 r
F
.69457 .19729 m .69701 .20067 L .49202 .19463 L F
.73759 .19488 m .74323 .19796 L .73369 .19368 L .716 .708 .842 r
F
.74323 .19796 m .75439 .20406 L .74185 .19777 L F
.74323 .19796 m .74185 .19777 L .73369 .19368 L F
.75439 .20406 m .75157 .20454 L .5574 .10532 L F
.6797 .2047 m .69701 .20067 L .73759 .20696 L .364 .769 .983 r
F
.59107 .20122 m .66098 .20086 L .6797 .2047 L F
.66098 .20086 m .69701 .20067 L .6797 .2047 L F
.72087 .20986 m .73759 .20696 L .78282 .21398 L F
.59107 .20122 m .73759 .20696 L .72087 .20986 L F
.69701 .20067 m .72894 .20161 L .78282 .21398 L F
.72737 .19714 m .74067 .20313 L .72894 .20161 L .748 .682 .787 r
F
.72894 .20161 m .79546 .21023 L .78282 .21398 L .364 .769 .983 r
F
.73704 .19712 m .80902 .2339 L .72737 .19714 L .748 .682 .787 r
F
.74585 .17742 m .85888 .18067 L .82901 .21257 L .716 .708 .842 r
F
.74323 .19796 m .82901 .21257 L .75439 .20406 L F
.56809 .10228 m .79653 .19884 L .74323 .19796 L F
.79653 .19884 m .82901 .21257 L .74323 .19796 L F
.72894 .20161 m .81591 .20417 L .79546 .21023 L .364 .769 .983 r
F
.72894 .20161 m .80902 .2339 L .75838 .28539 L .748 .682 .787 r
F
.74067 .20313 m .80902 .2339 L .72894 .20161 L F
.72737 .19714 m .72757 .19773 L .69457 .19729 L .427 0 0 r
F
.73888 .19806 m .74328 .20031 L .73433 .20177 L F
.73618 .19784 m .73888 .19806 L .73433 .20177 L F
.75111 .19903 m .76278 .2026 L .73433 .20177 L F
.75439 .20406 m .80902 .2339 L .75157 .20454 L .716 .708 .842 r
F
.73618 .19784 m .72066 .19896 L .70333 .19741 L .427 0 0 r
F
.72066 .19896 m .69701 .20067 L .70333 .19741 L F
.70333 .19741 m .69701 .20067 L .69457 .19729 L F
.69245 .19437 m .72737 .19714 L .69457 .19729 L F
.638 .19156 m .64999 .19568 L .65158 .19573 L F
.638 .19156 m .65158 .19573 L .67563 .19493 L F
.64999 .19568 m .66005 .19729 L .701 .1972 L F
.61176 .19816 m .69701 .20067 L .59107 .20122 L .364 .769 .983 r
F
.66005 .19729 m .72737 .19714 L .75838 .28539 L .748 .682 .787 r
F
.72737 .19714 m .73618 .19784 L .72757 .19773 L .427 0 0 r
F
.73888 .19806 m .75111 .19903 L .74328 .20031 L F
.75111 .19903 m .81591 .20417 L .76278 .2026 L F
.73618 .19784 m .73433 .20177 L .72894 .20161 L F
.73618 .19784 m .72894 .20161 L .72782 .19844 L F
.7991 .20915 m .81591 .20417 L .81944 .21148 L .364 .769 .983 r
F
.6464 .19072 m .80902 .20687 L .75111 .19903 L .427 0 0 r
F
.75838 .28539 m .75838 .28539 L .65051 .19576 L .748 .682 .787 r
F
.59199 .1864 m .638 .19156 L .6464 .19072 L .427 0 0 r
F
.638 .19156 m .80902 .20687 L .6464 .19072 L F
.65051 .19576 m .65051 .19576 L .63966 .18675 L .748 .682 .787 r
F
.63966 .18675 m .63966 .18675 L .63596 .18368 L F
.65051 .19576 m .63966 .18675 L .63966 .18675 L F
.63966 .18675 m .63596 .18368 L .63597 .18368 L F
.65051 .19576 m .63966 .18675 L .63966 .18675 L F
.63966 .18675 m .63596 .18368 L .63966 .18675 L F
.61449 .16584 m .63596 .18368 L .58211 .15631 L .782 .663 .731 r
F
.63812 .18726 m .65051 .19576 L .63938 .18935 L F
.63966 .18675 m .65051 .19576 L .63812 .18726 L F
.75838 .28539 m .65051 .19576 L .65051 .19576 L .748 .682 .787 r
F
.52556 .18113 m .60678 .18877 L .59199 .1864 L .427 0 0 r
F
.48948 .17826 m .5296 .18185 L .52556 .18113 L F
.5296 .18185 m .60678 .18877 L .52556 .18113 L F
.60678 .18877 m .638 .19156 L .59199 .1864 L F
.65051 .19576 m .7584 .28541 L .649 .2053 L .782 .663 .731 r
F
.6434 .196 m .649 .2053 L .63662 .19623 L F
.65051 .19576 m .649 .2053 L .6434 .196 L F
.59165 .18741 m .6203 .19334 L .638 .19156 L .427 0 0 r
F
.49123 .17842 m .5868 .18947 L .59165 .18741 L F
.5868 .18947 m .6203 .19334 L .59165 .18741 L F
.49202 .19463 m .61176 .19816 L .59107 .20122 L .364 .769 .983 r
F
.49131 .17844 m .49877 .1793 L .49123 .17842 L .427 0 0 r
F
.49877 .1793 m .6203 .19334 L .49869 .17928 L F
.49877 .1793 m .49869 .17928 L .49123 .17842 L F
.48899 .14688 m .49032 .14735 L .48816 .1621 L .645 .439 .589 r
F
.4918 .17853 m .6203 .19334 L .49095 .17839 L .427 0 0 r
F
.58309 .1863 m .60278 .19132 L .54548 .18472 L .641 .316 .405 r
F
.63896 .18866 m .60278 .19132 L .58309 .1863 L F
.66005 .19729 m .75838 .28539 L .65051 .19576 L .748 .682 .787 r
F
.6203 .19334 m .6434 .196 L .638 .19156 L .427 0 0 r
F
.6434 .196 m .65471 .19731 L .65025 .19577 L F
.6434 .196 m .65025 .19577 L .638 .19156 L F
.63896 .18866 m .6434 .196 L .60278 .19132 L .641 .316 .405 r
F
.6388 .18839 m .54548 .18472 L .54238 .18185 L F
.63896 .18866 m .54548 .18472 L .6388 .18839 L F
.48816 .1621 m .63812 .18726 L .60513 .18611 L F
.63812 .18726 m .6388 .18839 L .60513 .18611 L F
.67563 .19493 m .65158 .19573 L .701 .1972 L .427 0 0 r
F
.65258 .1906 m .72737 .19714 L .66005 .19729 L .748 .682 .787 r
F
.78282 .21398 m .7991 .20915 L .82191 .21658 L .364 .769 .983 r
F
.7991 .20915 m .81944 .21148 L .82191 .21658 L F
.78466 .21593 m .82191 .21658 L .8183 .22583 L .616 .765 .951 r
F
.75439 .20406 m .82901 .21257 L .80902 .2339 L .716 .708 .842 r
F
.65471 .19731 m .79284 .21322 L .701 .1972 L .427 0 0 r
F
.65258 .1906 m .79284 .21322 L .67406 .19954 L .641 .316 .405 r
F
.64892 .18907 m .65228 .18964 L .65258 .1906 L F
.65228 .18964 m .72737 .19714 L .65258 .1906 L .748 .682 .787 r
F
.65228 .18964 m .79284 .21322 L .65258 .1906 L .641 .316 .405 r
F
.65228 .18964 m .78134 .22227 L .79284 .21322 L F
.64892 .18907 m .65164 .18976 L .65228 .18964 L F
.5574 .10532 m .63961 .14973 L .65228 .18964 L .748 .682 .787 r
F
.65164 .18976 m .65228 .18964 L .65258 .1906 L F
.5574 .10532 m .65228 .18964 L .65164 .18976 L F
.65403 .1919 m .64709 .19292 L .63966 .18675 L F
.65106 .18961 m .63966 .18675 L .54445 .10765 L F
.65403 .1919 m .63966 .18675 L .65106 .18961 L F
.64892 .18907 m .63896 .18866 L .6388 .18839 L .641 .316 .405 r
F
.64999 .19568 m .65471 .19731 L .66005 .19729 L .427 0 0 r
F
.65051 .19576 m .6434 .196 L .63938 .18935 L .782 .663 .731 r
F
.65403 .1919 m .66005 .19729 L .64709 .19292 L .748 .682 .787 r
F
.66005 .19729 m .65051 .19576 L .64709 .19292 L F
.5574 .10532 m .65403 .1919 L .54445 .10765 L F
.64892 .18907 m .67406 .19954 L .6434 .196 L .641 .316 .405 r
F
.64892 .18907 m .6434 .196 L .63896 .18866 L F
.63812 .18726 m .64892 .18907 L .6388 .18839 L F
.63812 .18726 m .64977 .19011 L .64892 .18907 L F
.64977 .19011 m .78134 .22227 L .65164 .18976 L F
.64977 .19011 m .65164 .18976 L .64892 .18907 L F
.65164 .18976 m .78134 .22227 L .65228 .18964 L F
.63961 .14973 m .69765 .18109 L .65228 .18964 L .748 .682 .787 r
F
.69765 .18109 m .72737 .19714 L .65228 .18964 L F
.61359 .19699 m .60299 .19508 L .6002 .19177 L .782 .663 .731 r
F
.5283 .16883 m .62768 .19073 L .63812 .18726 L .641 .316 .405 r
F
.5415 .17305 m .62768 .19073 L .5283 .16883 L F
.61359 .19699 m .6002 .19177 L .61232 .19564 L .782 .663 .731 r
F
.61262 .19574 m .61359 .19699 L .61232 .19564 L F
.61359 .19699 m .7142 .32698 L .60299 .19508 L F
.60748 .18659 m .61262 .19574 L .62768 .19073 L .641 .316 .405 r
F
.5415 .17305 m .6002 .19177 L .60748 .18659 L F
.6002 .19177 m .61262 .19574 L .60748 .18659 L F
.48889 .16229 m .5973 .19384 L .59958 .19221 L F
.48816 .1621 m .48895 .16233 L .48889 .16229 L F
.48895 .16233 m .5973 .19384 L .48889 .16229 L F
.6002 .19177 m .60299 .19508 L .5984 .19306 L .833 .647 .65 r
F
.53236 .17117 m .61262 .19574 L .5415 .17305 L .641 .316 .405 r
F
.48816 .1621 m .53652 .17517 L .53236 .17117 L F
.53652 .17517 m .61262 .19574 L .53236 .17117 L F
.57141 .20091 m .68215 .35261 L .6662 .35906 L .923 .598 .407 r
F
.48816 .1621 m .5415 .17305 L .5283 .16883 L .641 .316 .405 r
F
.49032 .14735 m .58956 .18191 L .49882 .16482 L .645 .439 .589 r
F
.58956 .18191 m .59426 .18915 L .49882 .16482 L F
.59675 .18769 m .6002 .19177 L .59471 .18985 L .833 .647 .65 r
F
.59426 .18915 m .5973 .19384 L .48816 .1621 L .645 .439 .589 r
F
.60299 .19508 m .59434 .19595 L .5984 .19306 L .833 .647 .65 r
F
.59958 .19221 m .60852 .1971 L .61262 .19574 L .641 .316 .405 r
F
.60299 .19508 m .7142 .32698 L .58926 .19646 L .833 .647 .65 r
F
.5973 .19384 m .60852 .1971 L .59958 .19221 L .641 .316 .405 r
F
.63662 .19623 m .75838 .28539 L .62132 .19673 L .782 .663 .731 r
F
.63938 .18935 m .63662 .19623 L .62867 .19041 L F
.6434 .196 m .63662 .19623 L .63938 .18935 L F
.62808 .18998 m .63662 .19623 L .60545 .18646 L F
.63662 .19623 m .62132 .19673 L .60545 .18646 L F
.75838 .28539 m .75838 .2854 L .60545 .18646 L F
.60545 .18646 m .75838 .2854 L .7142 .32698 L F
.60852 .1971 m .75806 .24059 L .62768 .19073 L .641 .316 .405 r
F
.65433 .20446 m .60894 .19722 L .5973 .19384 L .645 .439 .589 r
F
.59675 .18769 m .59471 .18985 L .59278 .18687 L .833 .647 .65 r
F
.5984 .19306 m .59711 .19354 L .59616 .19207 L F
.59434 .19595 m .58926 .19646 L .5984 .19306 L F
.57185 .19415 m .57449 .19469 L .57268 .19545 L .923 .598 .407 r
F
.48816 .1621 m .56025 .18306 L .48948 .17826 L .641 .316 .405 r
F
.52926 .16091 m .55892 .18275 L .56874 .18248 L .645 .439 .589 r
F
.52926 .16091 m .56874 .18248 L .56644 .17386 L F
.57039 .18867 m .57449 .19469 L .57185 .19415 L .923 .598 .407 r
F
.58522 .19687 m .68215 .35261 L .57449 .19469 L .833 .647 .65 r
F
.56644 .17386 m .56874 .18248 L .58956 .18191 L .645 .439 .589 r
F
.56874 .18248 m .58472 .19606 L .58956 .18191 L F
.55892 .18275 m .57039 .18867 L .56874 .18248 L F
.57039 .18867 m .58472 .19606 L .56874 .18248 L F
.58522 .19687 m .57449 .19469 L .57039 .18867 L .833 .647 .65 r
F
.58449 .19594 m .57039 .18867 L .51812 .11199 L F
.58522 .19687 m .57039 .18867 L .58449 .19594 L F
.57039 .18867 m .58317 .2006 L .58472 .19606 L .645 .439 .589 r
F
.55892 .18275 m .57123 .19181 L .57039 .18867 L F
.57123 .19181 m .58317 .2006 L .57039 .18867 L F
.5441 .17832 m .57185 .19415 L .52926 .16091 L F
.57449 .19469 m .68215 .35261 L .60779 .25028 L .923 .598 .407 r
F
.57455 .19837 m .60779 .25028 L .57466 .20469 L F
.57449 .19469 m .60779 .25028 L .57455 .19837 L F
.57449 .19469 m .57466 .20469 L .57225 .19564 L F
.57185 .19415 m .58317 .2006 L .57123 .19181 L .645 .439 .589 r
F
.58472 .19606 m .58522 .19687 L .58449 .19594 L .833 .647 .65 r
F
.6002 .19177 m .5984 .19306 L .5874 .18822 L F
.58768 .18738 m .5874 .18822 L .57698 .18363 L F
.6002 .19177 m .5874 .18822 L .58768 .18738 L F
.54445 .10765 m .60456 .18532 L .53089 .10956 L .782 .663 .731 r
F
.60456 .18532 m .61262 .19574 L .60174 .18426 L F
.60456 .18532 m .60174 .18426 L .53089 .10956 L F
.61262 .19574 m .61232 .19564 L .53089 .10956 L F
.61232 .19564 m .6002 .19177 L .53089 .10956 L F
.65433 .20446 m .60844 .19591 L .60197 .19111 L .645 .439 .589 r
F
.53089 .10956 m .59675 .18769 L .57698 .18363 L .833 .647 .65 r
F
.58956 .18191 m .65433 .20446 L .59426 .18915 L .645 .439 .589 r
F
.65433 .20446 m .75806 .24059 L .60894 .19722 L F
.58956 .18191 m .71991 .27861 L .75639 .24226 L F
.67225 .2107 m .75639 .24226 L .75806 .24059 L F
.58956 .18191 m .75639 .24226 L .67225 .2107 L F
.60844 .19591 m .5973 .19384 L .60197 .19111 L F
.60197 .19111 m .5973 .19384 L .59426 .18915 L F
.59278 .18687 m .59471 .18985 L .58768 .18738 L .833 .647 .65 r
F
.59278 .18687 m .58768 .18738 L .58818 .18593 L F
.59616 .19207 m .58926 .19646 L .57698 .18363 L F
.59711 .19354 m .58926 .19646 L .59616 .19207 L F
.58522 .19687 m .7142 .32698 L .68215 .35261 L F
.57698 .18363 m .58926 .19646 L .58522 .19687 L F
.58926 .19646 m .7142 .32698 L .58522 .19687 L F
.58317 .2006 m .71991 .27861 L .58956 .18191 L .645 .439 .589 r
F
.59757 .20066 m .57497 .19593 L .57185 .19415 L .607 .482 .684 r
F
.57185 .19415 m .57123 .19181 L .52926 .16091 L .645 .439 .589 r
F
.49032 .14735 m .49882 .16482 L .48816 .1621 L F
.48899 .14688 m .5441 .17832 L .52926 .16091 L F
.56601 .18503 m .57185 .19415 L .48899 .14688 L .607 .482 .684 r
F
.53668 .13923 m .57039 .18867 L .57185 .19415 L .923 .598 .407 r
F
.53089 .10956 m .58472 .19606 L .51812 .11199 L .833 .647 .65 r
F
.58472 .19606 m .58449 .19594 L .51812 .11199 L F
.59757 .20066 m .57185 .19415 L .56601 .18503 L .607 .482 .684 r
F
.49239 .13364 m .56116 .17746 L .48899 .14688 L F
.56116 .17746 m .56601 .18503 L .48899 .14688 L F
.53244 .15916 m .557 .18899 L .56116 .17746 L F
.557 .18899 m .57141 .20091 L .56116 .17746 L F
.51812 .11199 m .57141 .20091 L .50712 .1162 L .923 .598 .407 r
F
.57141 .20091 m .6662 .35906 L .55219 .18501 L F
.56531 .20218 m .5766 .21279 L .53244 .15916 L .607 .482 .684 r
F
.57141 .20091 m .55219 .18501 L .52676 .14618 L .923 .598 .407 r
F
.557 .18899 m .5766 .21279 L .57141 .20091 L .607 .482 .684 r
F
.5653 .20216 m .56013 .19712 L .56665 .20416 L 0 .226 .741 r
F
.53356 .15104 m .52676 .14618 L .50712 .1162 L .923 .598 .407 r
F
.57141 .20091 m .52676 .14618 L .53356 .15104 L F
.50712 .1162 m .55219 .18501 L .5653 .20216 L 0 .226 .741 r
F
.55219 .18501 m .56013 .19712 L .5653 .20216 L F
.56013 .19712 m .56147 .19918 L .56372 .20134 L F
.56013 .19712 m .56372 .20134 L .56665 .20416 L F
.50712 .1162 m .56665 .20416 L .50927 .11927 L F
.49239 .13364 m .56531 .20218 L .53244 .15916 L .607 .482 .684 r
F
.49846 .12328 m .54248 .16839 L .49239 .13364 L .504 .477 .76 r
F
.57225 .19564 m .57466 .20469 L .57066 .19918 L .923 .598 .407 r
F
.5696 .19676 m .57066 .19918 L .56906 .19699 L F
.57225 .19564 m .57066 .19918 L .5696 .19676 L F
.53668 .13923 m .57185 .19415 L .56906 .19699 L F
.57185 .19415 m .57225 .19564 L .56906 .19699 L F
.54747 .16097 m .53668 .13923 L .56906 .19699 L F
.51812 .11199 m .53159 .13175 L .54747 .16097 L F
.53159 .13175 m .53668 .13923 L .54747 .16097 L F
.57185 .19415 m .57268 .19545 L .57225 .19564 L F
.56116 .17746 m .59757 .20066 L .56601 .18503 L .607 .482 .684 r
F
.57066 .19918 m .68215 .35261 L .57141 .20091 L .923 .598 .407 r
F
.59757 .20066 m .71991 .27861 L .57497 .19593 L .607 .482 .684 r
F
.5766 .21279 m .68751 .31703 L .56116 .17746 L F
.56906 .19699 m .57066 .19918 L .57141 .20091 L .923 .598 .407 r
F
.56288 .1893 m .58924 .21632 L .55527 .18732 L .504 .477 .76 r
F
.54248 .16839 m .56288 .1893 L .55527 .18732 L F
.58924 .21632 m .68751 .31703 L .56845 .20513 L F
.58924 .21632 m .56845 .20513 L .49239 .13364 L F
.56288 .1893 m .66824 .34613 L .68751 .31703 L F
.54248 .16839 m .58147 .2235 L .56288 .1893 L F
.58147 .2235 m .66824 .34613 L .56288 .1893 L F
.54248 .16839 m .55527 .18732 L .49239 .13364 L F
.50927 .11927 m .56665 .20416 L .57311 .21038 L 0 .226 .741 r
F
.58026 .22179 m .6662 .35906 L .66824 .34613 L F
.56147 .19918 m .6662 .35906 L .57311 .21038 L F
.50713 .13218 m .66824 .34613 L .54248 .16839 L .504 .477 .76 r
F
.49846 .12328 m .50296 .1292 L .50713 .13218 L F
.49095 .17839 m .49131 .17844 L .49123 .17842 L .427 0 0 r
F
.48948 .17826 m .4918 .17853 L .49095 .17839 L F
.54238 .18185 m .54548 .18472 L .48948 .17826 L .641 .316 .405 r
F
.50296 .1292 m .66824 .34613 L .50713 .13218 L .504 .477 .76 r
F
.58818 .18593 m .58768 .18738 L .57698 .18363 L .833 .647 .65 r
F
.57311 .21038 m .58026 .22179 L .66824 .34613 L 0 .226 .741 r
F
.63938 .18935 m .62867 .19041 L .63663 .18776 L .782 .663 .731 r
F
.63596 .18368 m .63938 .18935 L .58211 .15631 L F
.62768 .19073 m .78134 .22227 L .63812 .18726 L .641 .316 .405 r
F
.63663 .18776 m .62867 .19041 L .58211 .15631 L .782 .663 .731 r
F
.56116 .17746 m .68751 .31703 L .71991 .27861 L .607 .482 .684 r
F
.62768 .19073 m .75806 .24059 L .78134 .22227 L .641 .316 .405 r
F
.63596 .18368 m .63966 .18675 L .63812 .18726 L .782 .663 .731 r
F
.63597 .18368 m .63596 .18368 L .54445 .10765 L .748 .682 .787 r
F
.5574 .10532 m .72524 .19109 L .72737 .19714 L F
.7018 .19727 m .79284 .21322 L .80902 .20687 L .427 0 0 r
F
.701 .1972 m .70137 .19727 L .7018 .19727 L F
.70137 .19727 m .79284 .21322 L .7018 .19727 L F
.72524 .19109 m .73704 .19712 L .72737 .19714 L .748 .682 .787 r
F
.75111 .19903 m .80902 .20687 L .81591 .20417 L .427 0 0 r
F
.56809 .10228 m .73759 .19488 L .5574 .10532 L .716 .708 .842 r
F
.73759 .19488 m .73369 .19368 L .5574 .10532 L F
.75838 .28539 m .7584 .28541 L .75838 .2854 L .782 .663 .731 r
F
.75838 .28539 m .7584 .28541 L .75838 .28539 L .748 .682 .787 r
F
.75838 .2854 m .7584 .28541 L .75839 .28541 L .782 .663 .731 r
F
.75838 .2854 m .75839 .28541 L .7142 .32698 L F
.56809 .10228 m .75728 .15328 L .74585 .17742 L .716 .708 .842 r
F
.75728 .15328 m .85888 .18067 L .74585 .17742 L F
.58211 .15631 m .62808 .18998 L .60545 .18646 L .782 .663 .731 r
F
.54445 .10765 m .61449 .16584 L .58211 .15631 L F
.25 g
.5 Mabswid
.49094 .24241 m
.51503 .24704 L
s
.51503 .24704 m
.55274 .25428 L
s
.55274 .25428 m
.56484 .25661 L
s
.56484 .25661 m
.60402 .26413 L
s
.75099 .29237 m
.77934 .29782 L
s
1 0 0 r
.003 w
.77934 .29782 m
.80915 .24925 L
s
.25 g
.5 Mabswid
.499 .22715 m
.55439 .2311 L
s
.55439 .2311 m
.5821 .23307 L
s
.79494 .24823 m
.80915 .24925 L
s
.4944 .22683 m
.499 .22715 L
s
1 0 0 r
.003 w
.80915 .24925 m
.81952 .22269 L
s
0 g
.006 w
.30767 .49047 m
.31819 .47694 L
s
.45561 .28249 m
.47105 .27076 L
s
.29418 .50116 m
.30767 .49047 L
s
.47105 .27076 m
.4831 .25724 L
s
.2785 .50889 m
.29418 .50116 L
s
.4831 .25724 m
.49094 .24241 L
s
1 0 0 r
.003 w
.639 .3956 m
.64943 .39679 L
s
.25 g
.5 Mabswid
.41616 .72774 m
.42704 .74503 L
s
0 g
.006 w
.26136 .51431 m
.2785 .50889 L
s
.49094 .24241 m
.4944 .22683 L
s
1 0 0 r
.003 w
.55442 .53451 m
.55587 .51619 L
s
0 g
.006 w
.24344 .51861 m
.26136 .51431 L
s
.49425 .21086 m
.4944 .22683 L
s
.22556 .52316 m
.24344 .51861 L
s
.25 g
.5 Mabswid
.49425 .21086 m
.54699 .21178 L
s
.54699 .21178 m
.56613 .21211 L
s
0 g
.006 w
.49202 .19463 m
.49425 .21086 L
s
1 0 0 r
.003 w
.42254 .73468 m
.42704 .74503 L
s
.25 g
.5 Mabswid
.49202 .19463 m
.49346 .19468 L
s
.49346 .19468 m
.50162 .19492 L
s
.50162 .19492 m
.53774 .19598 L
s
.53774 .19598 m
.54147 .19609 L
s
.54147 .19609 m
.55421 .19646 L
s
0 g
.006 w
.48948 .17826 m
.49202 .19463 L
s
.25 g
.5 Mabswid
.73369 .26488 m
.75838 .28539 L
s
.75838 .28539 m
.7584 .28541 L
s
.54445 .10765 m
.55447 .11597 L
s
1 0 0 r
.003 w
.7142 .32698 m
.7584 .28541 L
s
.7584 .28541 m
.80902 .2339 L
s
.25 g
.5 Mabswid
.37839 .58305 m
.38372 .58475 L
s
.20884 .52889 m .49588 .57691 L .19463 .53605 L .64 .429 .581 r
F
0 g
.006 w
.20884 .52889 m
.22556 .52316 L
s
1 0 0 r
.003 w
.81591 .20417 m
.81944 .21148 L
s
.61837 .41446 m
.639 .3956 L
s
.25 g
.5 Mabswid
.48948 .17826 m
.49171 .17852 L
s
.49171 .17852 m
.4918 .17853 L
s
.4918 .17853 m
.49917 .17938 L
s
.49917 .17938 m
.53807 .18386 L
s
.53807 .18386 m
.54524 .18469 L
s
0 g
.006 w
.48816 .1621 m
.48948 .17826 L
s
.25 g
.5 Mabswid
.78328 .22075 m
.80902 .2339 L
s
.5574 .10532 m
.55817 .10571 L
s
.72524 .19109 m
.73704 .19712 L
s
.73704 .19712 m
.73888 .19806 L
s
1 0 0 r
.003 w
.80902 .2339 m
.82901 .21257 L
s
.55587 .51619 m
.57033 .48425 L
s
.25 g
.5 Mabswid
.69666 .30618 m
.7142 .32698 L
s
1 0 0 r
.003 w
.68215 .35261 m
.7142 .32698 L
s
.19463 .53605 m .50871 .55683 L .18423 .54429 L .622 .265 .343 r
F
.19463 .53605 m .49588 .57691 L .50871 .55683 L F
.25 g
.5 Mabswid
.26707 .54749 m
.31521 .56287 L
s
.26582 .54744 m
.29179 .5631 L
s
0 g
.006 w
.19463 .53605 m
.20884 .52889 L
s
.25 g
.5 Mabswid
.20038 .53683 m
.32999 .55441 L
s
.19788 .53649 m
.20038 .53683 L
s
.19463 .53605 m
.19788 .53649 L
s
.32999 .55441 m
.35106 .55727 L
s
.38011 .56121 m
.49588 .57691 L
s
.35106 .55727 m
.38011 .56121 L
s
.28423 .55854 m
.30083 .57479 L
s
.29179 .5631 m
.31152 .575 L
s
.31521 .56287 m
.34478 .57231 L
s
.34478 .57231 m
.35597 .57588 L
s
0 g
.006 w
.18423 .54429 m
.19463 .53605 L
s
.25 g
.5 Mabswid
.48816 .1621 m
.49031 .16272 L
s
.49031 .16272 m
.49904 .16526 L
s
.49904 .16526 m
.538 .17659 L
s
.538 .17659 m
.53812 .17663 L
s
0 g
.006 w
.48816 .1621 m
.48899 .14688 L
s
.25 g
.5 Mabswid
.28367 .54813 m
.32246 .54963 L
s
.19623 .54475 m
.28367 .54813 L
s
.18665 .54438 m
.19623 .54475 L
s
.18423 .54429 m
.18665 .54438 L
s
.32246 .54963 m
.33228 .55001 L
s
.33228 .55001 m
.33721 .5502 L
s
.33721 .5502 m
.33826 .55024 L
s
.33826 .55024 m
.50871 .55683 L
s
.48899 .14688 m
.48986 .14738 L
s
.48986 .14738 m
.53348 .17227 L
s
0 g
.006 w
.48899 .14688 m
.49239 .13364 L
s
.16452 .59235 m .41616 .72774 L .38831 .78362 L .814 .627 .65 r
F
.15698 .58691 m .41616 .72774 L .16452 .59235 L .776 .645 .717 r
F
.25 g
.5 Mabswid
.40605 .71212 m
.41937 .73033 L
s
.41937 .73033 m
.42254 .73468 L
s
.36709 .63966 m
.36928 .6418 L
s
.36937 .64917 m
.37057 .64952 L
s
.37057 .64952 m
.37998 .65228 L
s
1 0 0 r
.003 w
.41616 .72774 m
.41669 .72668 L
s
.25 g
.5 Mabswid
.38275 .70976 m
.39337 .71548 L
s
.39337 .71548 m
.41183 .72541 L
s
.41183 .72541 m
.41616 .72774 L
s
.15698 .58691 m
.15951 .58765 L
s
1 0 0 r
.003 w
.4146 .73087 m
.41616 .72774 L
s
.59324 .44707 m
.61837 .41446 L
s
.57033 .48425 m
.59324 .44707 L
s
.25 g
.5 Mabswid
.49551 .13657 m
.50925 .14949 L
s
.49239 .13364 m
.49551 .13657 L
s
.51812 .11199 m
.51868 .11281 L
s
.67291 .33907 m
.68215 .35261 L
s
1 0 0 r
.003 w
.6662 .35906 m
.68215 .35261 L
s
.25 g
.5 Mabswid
.15164 .58179 m
.15413 .58211 L
s
1 0 0 r
.003 w
.42254 .73468 m
.43236 .70355 L
s
.57491 .09868 m .85888 .18067 L .56809 .10228 L .673 .745 .905 r
F
.25 g
.5 Mabswid
.57059 .10295 m
.57188 .1033 L
s
.56809 .10228 m
.57059 .10295 L
s
.55817 .10571 m
.56869 .11109 L
s
.57491 .09868 m .89997 .13477 L .85888 .18067 L .673 .745 .905 r
F
.25 g
.67156 .16366 m
.70352 .17999 L
s
.70352 .17999 m
.72524 .19109 L
s
1 0 0 r
.003 w
.82901 .21257 m
.85888 .18067 L
s
.50712 .1162 m .66824 .34613 L .49846 .12328 L 0 .226 .741 r
F
.25 g
.5 Mabswid
.49846 .12328 m
.50115 .12681 L
s
.50115 .12681 m
.50296 .1292 L
s
.50296 .1292 m
.5534 .1954 L
s
.56123 .20568 m
.58554 .23758 L
s
.58554 .23758 m
.59805 .25401 L
s
.55865 .20229 m
.56123 .20568 L
s
.55863 .20226 m
.55865 .20229 L
s
.59805 .25401 m
.66824 .34613 L
s
.5534 .1954 m
.55863 .20226 L
s
.59023 .17995 m
.59285 .18305 L
s
.58177 .16992 m
.59023 .17995 L
s
.57243 .15884 m
.57814 .1656 L
s
.57814 .1656 m
.58177 .16992 L
s
.63869 .14686 m
.67156 .16366 L
s
.59271 .14774 m
.61151 .16337 L
s
.61151 .16337 m
.61449 .16584 L
s
.62006 .17047 m
.63596 .18368 L
s
.61449 .16584 m
.62006 .17047 L
s
.54171 .1224 m
.57243 .15884 L
s
.55833 .17098 m
.56396 .17924 L
s
.53668 .13923 m
.55833 .17098 L
s
.53159 .13175 m
.53668 .13923 L
s
.51868 .11281 m
.53159 .13175 L
s
0 g
.006 w
.49239 .13364 m
.49846 .12328 L
s
.25 g
.5 Mabswid
.50925 .14949 m
.54156 .17985 L
s
.53666 .11641 m
.54171 .1224 L
s
.53089 .10956 m
.53666 .11641 L
s
.63966 .18675 m
.64082 .18771 L
s
.63596 .18368 m
.63966 .18675 L
s
0 g
.006 w
.49846 .12328 m
.50712 .1162 L
s
1 0 0 r
.003 w
.79284 .21322 m
.81591 .20417 L
s
.16452 .59235 m .38831 .78362 L .17244 .59793 L .814 .627 .65 r
F
.17244 .59793 m .38831 .78362 L .36554 .82999 L .864 .61 .553 r
F
.25 g
.5 Mabswid
.36623 .60952 m
.36943 .60993 L
s
.35939 .60864 m
.36623 .60952 L
s
.33687 .60573 m
.35939 .60864 L
s
.26752 .59676 m
.30238 .60127 L
s
.30238 .60127 m
.33687 .60573 L
s
1 0 0 r
.003 w
.38831 .78362 m
.4146 .73087 L
s
.25 g
.5 Mabswid
.34019 .68687 m
.38275 .70976 L
s
.28944 .65956 m
.34019 .68687 L
s
.26031 .64388 m
.28944 .65956 L
s
.35044 .64362 m
.36937 .64917 L
s
.28458 .62431 m
.35044 .64362 L
s
.25191 .61474 m
.28458 .62431 L
s
.24571 .61292 m
.25191 .61474 L
s
.38372 .58475 m
.47529 .614 L
s
.37204 .61151 m
.45203 .65975 L
s
.35759 .60279 m
.36188 .60538 L
s
.36188 .60538 m
.37204 .61151 L
s
.38425 .65646 m
.43236 .70355 L
s
.36928 .6418 m
.38425 .65646 L
s
.23411 .59245 m
.26752 .59676 L
s
.15413 .58211 m
.23411 .59245 L
s
.16609 .59319 m
.16669 .59351 L
s
.16452 .59235 m
.16609 .59319 L
s
.61188 .27614 m
.6662 .35906 L
s
.5933 .24777 m
.61188 .27614 L
s
0 g
.006 w
.50712 .1162 m
.51812 .11199 L
s
.25 g
.5 Mabswid
.30949 .58316 m
.35287 .58488 L
s
.15013 .57681 m
.25392 .58094 L
s
.25392 .58094 m
.30949 .58316 L
s
.35287 .58488 m
.37719 .58585 L
s
.37719 .58585 m
.3886 .58631 L
s
1 0 0 r
.003 w
.6662 .35906 m
.66824 .34613 L
s
.49588 .57691 m
.50871 .55683 L
s
0 g
.006 w
.51812 .11199 m
.53089 .10956 L
s
.25 g
.5 Mabswid
.29838 .57474 m
.44846 .57771 L
s
.44846 .57771 m
.49111 .57856 L
s
.15343 .57188 m
.29838 .57474 L
s
0 g
.006 w
.15013 .57681 m
.15343 .57188 L
s
1 0 0 r
.003 w
.43236 .70355 m
.45203 .65975 L
s
0 g
.006 w
.53089 .10956 m
.54445 .10765 L
s
.57675 .09482 m .89997 .13477 L .57491 .09868 L .581 .794 .98 r
F
.57675 .09482 m .92474 .10446 L .89997 .13477 L F
1 0 0 r
.003 w
.85888 .18067 m
.89997 .13477 L
s
.25 g
.5 Mabswid
.66081 .12727 m
.85888 .18067 L
s
.64034 .12175 m
.66081 .12727 L
s
.57188 .1033 m
.64034 .12175 L
s
.59549 .12478 m
.63869 .14686 L
s
.56869 .11109 m
.59549 .12478 L
s
.5699 .12879 m
.59271 .14774 L
s
.55447 .11597 m
.5699 .12879 L
s
.57491 .09868 m
.57908 .09915 L
s
.57908 .09915 m
.58351 .09964 L
s
.58351 .09964 m
.5859 .0999 L
s
.5859 .0999 m
.60147 .10163 L
s
.60147 .10163 m
.89997 .13477 L
s
0 g
.006 w
.15013 .57681 m
.15164 .58179 L
s
1 0 0 r
.003 w
.47529 .614 m
.49588 .57691 L
s
0 g
.006 w
.54445 .10765 m
.5574 .10532 L
s
1 0 0 r
.003 w
.75806 .24059 m
.79284 .21322 L
s
.17244 .59793 m .36554 .82999 L .17917 .60288 L .864 .61 .553 r
F
.17917 .60288 m .36554 .82999 L .35215 .85848 L .917 .558 .339 r
F
.25 g
.5 Mabswid
.22952 .66424 m
.36554 .82999 L
s
1 0 0 r
.003 w
.36554 .82999 m
.38831 .78362 L
s
.25 g
.5 Mabswid
.21147 .60289 m
.24571 .61292 L
s
.15951 .58765 m
.21147 .60289 L
s
.21931 .62183 m
.26031 .64388 L
s
.16669 .59351 m
.21931 .62183 L
s
.1815 .60572 m
.22658 .6445 L
s
.23116 .64844 m
.2727 .68417 L
s
.22658 .6445 m
.23116 .64844 L
s
.2727 .68417 m
.38831 .78362 L
s
1 0 0 r
.003 w
.66824 .34613 m
.68751 .31703 L
s
.45203 .65975 m
.47529 .614 L
s
0 g
.006 w
.15164 .58179 m
.15698 .58691 L
s
.5574 .10532 m
.56809 .10228 L
s
.15698 .58691 m
.16452 .59235 L
s
.56809 .10228 m
.57491 .09868 L
s
1 0 0 r
.003 w
.68751 .31703 m
.71991 .27861 L
s
.71991 .27861 m
.75806 .24059 L
s
0 g
.006 w
.16452 .59235 m
.17244 .59793 L
s
.57331 .09073 m .92474 .10446 L .57675 .09482 L .25 .737 .923 r
F
.57549 .09082 m .92771 .09544 L .92474 .10446 L F
.57537 .09076 m .92771 .09544 L .57549 .09082 L F
.56527 .08621 m .92771 .09544 L .57331 .09073 L .412 0 0 r
F
.56561 .08621 m .90706 .10968 L .92771 .09544 L F
.56527 .08621 m .56565 .08623 L .56561 .08621 L F
.56565 .08623 m .90706 .10968 L .56561 .08621 L F
.55412 .08098 m .55432 .081 L .56527 .08621 L .616 .255 .335 r
F
.55432 .081 m .90706 .10968 L .56565 .08623 L F
.55432 .081 m .56565 .08623 L .56527 .08621 L F
.55412 .08098 m .86575 .14473 L .90706 .10968 L F
.54159 .07514 m .86575 .14473 L .55442 .08104 L .643 .396 .53 r
F
.49536 .07197 m .68469 .32093 L .67164 .33177 L .925 .595 .396 r
F
.5817 .19196 m .68469 .32093 L .55385 .14888 L .823 .655 .675 r
F
.50324 .06481 m .54489 .12966 L .50791 .06345 L .031 .267 .765 r
F
.50257 .06899 m .54489 .12966 L .50324 .06481 L F
.5817 .19196 m .70954 .28939 L .68469 .32093 L .823 .655 .675 r
F
.57792 .18557 m .71455 .29321 L .5817 .19196 L F
.57568 .17955 m .71455 .29321 L .57792 .18557 L F
.57061 .15538 m .71455 .29321 L .57313 .17746 L F
.70954 .28939 m .714 .29372 L .68469 .32093 L F
.54637 .13217 m .57061 .15538 L .57313 .17746 L F
.55385 .14888 m .58286 .19393 L .5817 .19196 L .031 .267 .765 r
F
.49536 .07197 m .67164 .33177 L .50027 .06568 L .925 .595 .396 r
F
.49361 .08164 m .5817 .19196 L .49536 .07197 L .823 .655 .675 r
F
.5817 .19196 m .55385 .14888 L .49536 .07197 L F
.58517 .18741 m .55385 .14888 L .67927 .32232 L .031 .267 .765 r
F
.56211 .15458 m .57695 .16807 L .55722 .14761 L .764 .678 .767 r
F
.57695 .16807 m .61995 .20718 L .56451 .14954 L F
.61995 .20718 m .63165 .21383 L .56451 .14954 L F
.56211 .15458 m .56235 .15432 L .57695 .16807 L F
.56564 .15122 m .56451 .14954 L .56376 .14882 L F
.50679 .0758 m .55385 .14888 L .56655 .1645 L .031 .267 .765 r
F
.50679 .0758 m .56655 .1645 L .56663 .16409 L F
.50679 .0758 m .56872 .16718 L .56211 .15458 L F
.57313 .17746 m .57568 .17955 L .57792 .18557 L .823 .655 .675 r
F
.55385 .14888 m .67188 .33147 L .67927 .32232 L .031 .267 .765 r
F
.49361 .08164 m .54698 .1332 L .5817 .19196 L .823 .655 .675 r
F
.56564 .15122 m .56376 .14882 L .49361 .08164 L .764 .678 .767 r
F
.57695 .16807 m .56564 .15122 L .49361 .08164 L F
.56163 .15366 m .57218 .16334 L .56402 .14822 L .031 .267 .765 r
F
.56235 .15432 m .57689 .16767 L .57695 .16807 L .764 .678 .767 r
F
.57695 .16807 m .58 .16954 L .57965 .17053 L F
.57359 .14195 m .58672 .15005 L .57695 .16807 L F
.50791 .06345 m .57307 .13789 L .51771 .06504 L .492 .48 .771 r
F
.58672 .15005 m .6104 .16464 L .58 .16954 L .764 .678 .767 r
F
.6104 .16464 m .69368 .2243 L .58 .16954 L F
.58672 .15005 m .58 .16954 L .57695 .16807 L F
.61995 .20718 m .71455 .29321 L .63165 .21383 L F
.57965 .17053 m .69536 .22551 L .71455 .29321 L F
.69536 .22551 m .75558 .25412 L .74687 .26241 L F
.69536 .22551 m .74687 .26241 L .71455 .29321 L F
.58 .16954 m .75558 .25412 L .57965 .17053 L F
.6104 .16464 m .75558 .25412 L .69368 .2243 L F
.58538 .15623 m .75558 .25412 L .57359 .14195 L .721 .708 .837 r
F
.51771 .06504 m .61759 .14141 L .52914 .06941 L .591 .488 .706 r
F
.62597 .17958 m .71502 .19548 L .75558 .25412 L .721 .708 .837 r
F
.71502 .19548 m .77954 .23128 L .75558 .25412 L F
.57307 .13789 m .58614 .15283 L .58738 .14814 L .492 .48 .771 r
F
.58614 .15283 m .59796 .16076 L .58738 .14814 L F
.57307 .13789 m .58738 .14814 L .51771 .06504 L F
.56701 .12385 m .58738 .14814 L .56437 .10072 L .591 .488 .706 r
F
.59948 .16178 m .80099 .21082 L .62597 .17958 L .721 .708 .837 r
F
.60038 .16136 m .80099 .21082 L .59948 .16178 L F
.61309 .14585 m .80099 .21082 L .59796 .16076 L F
.71502 .19548 m .80099 .21082 L .77954 .23128 L F
.54159 .07514 m .70498 .14696 L .8123 .13326 L .643 .396 .53 r
F
.61759 .14141 m .6318 .15228 L .6292 .14786 L .591 .488 .706 r
F
.58738 .14814 m .59796 .16076 L .59135 .13664 L F
.59796 .16076 m .60457 .15425 L .59135 .13664 L F
.58738 .14814 m .59135 .13664 L .56437 .10072 L F
.57218 .16334 m .57689 .16767 L .56402 .14822 L .031 .267 .765 r
F
.54489 .12966 m .56163 .15366 L .56402 .14822 L F
.55509 .11954 m .57486 .15182 L .57359 .14195 L .492 .48 .771 r
F
.50791 .06345 m .56402 .14822 L .55064 .11227 L F
.6231 .15619 m .61858 .15885 L .62463 .15778 L .591 .488 .706 r
F
.60245 .13484 m .61825 .15837 L .6231 .15619 L F
.61825 .15837 m .61858 .15885 L .6231 .15619 L F
.6231 .15619 m .80099 .21082 L .61309 .14585 L .669 .753 .914 r
F
.6318 .15228 m .64082 .15697 L .6292 .14786 L .591 .488 .706 r
F
.6073 .10383 m .6975 .14356 L .59611 .09911 L .63 .46 .633 r
F
.6975 .14356 m .70498 .14696 L .59611 .09911 L F
.6292 .14786 m .64082 .15697 L .6659 .13128 L F
.6292 .14786 m .6659 .13128 L .66546 .13087 L F
.66235 .15187 m .69206 .14861 L .65753 .15301 L .669 .753 .914 r
F
.64082 .15697 m .68027 .14764 L .66702 .13014 L .63 .46 .633 r
F
.66702 .13014 m .68027 .14764 L .6975 .14356 L F
.65341 .14259 m .69206 .14861 L .6231 .15619 L .669 .753 .914 r
F
.64108 .15717 m .64239 .15819 L .63716 .15783 L F
.64118 .15716 m .64239 .15819 L .64108 .15717 L F
.64118 .15716 m .64331 .15826 L .64239 .15819 L F
.69206 .14861 m .84299 .17211 L .64331 .15826 L F
.69206 .14861 m .64331 .15826 L .64118 .15716 L F
.69206 .14861 m .63716 .15783 L .65753 .15301 L F
.6259 .15705 m .74553 .16535 L .80099 .21082 L F
.64082 .15697 m .6428 .15852 L .68027 .14764 L .63 .46 .633 r
F
.6428 .15852 m .68536 .15436 L .68027 .14764 L F
.59135 .13664 m .60457 .15425 L .59552 .12454 L .591 .488 .706 r
F
.59622 .16247 m .59796 .16076 L .62597 .17958 L .721 .708 .837 r
F
.60457 .15425 m .70837 .29248 L .61114 .14778 L .591 .488 .706 r
F
.60457 .15425 m .61114 .14778 L .59552 .12454 L F
.56402 .14822 m .58133 .17437 L .55064 .11227 L .492 .48 .771 r
F
.58133 .17437 m .58329 .16559 L .55064 .11227 L F
.54489 .12966 m .56402 .14822 L .50791 .06345 L .031 .267 .765 r
F
.55239 .1358 m .57028 .1456 L .56235 .15432 L .764 .678 .767 r
F
.54683 .12546 m .57028 .1456 L .55239 .1358 L F
.54683 .12546 m .57359 .14195 L .57028 .1456 L F
.54683 .12546 m .56235 .15432 L .56163 .15366 L F
.56235 .15432 m .57359 .14195 L .57689 .16767 L F
.56163 .15366 m .56235 .15432 L .56211 .15458 L F
.58538 .15623 m .67113 .30843 L .70267 .29833 L .492 .48 .771 r
F
.57359 .14195 m .58443 .16046 L .58538 .15623 L F
.58443 .16046 m .67113 .30843 L .58538 .15623 L F
.57486 .15182 m .58329 .16559 L .57359 .14195 L F
.58329 .16559 m .67927 .32232 L .58443 .16046 L F
.58329 .16559 m .58443 .16046 L .57359 .14195 L F
.58538 .15623 m .59796 .16076 L .59622 .16247 L .721 .708 .837 r
F
.58538 .15623 m .57359 .14195 L .54683 .12546 L F
.58538 .15623 m .54683 .12546 L .55359 .13408 L F
.50254 .06894 m .50679 .0758 L .56929 .1648 L .031 .267 .765 r
F
.50027 .06568 m .56929 .1648 L .56911 .16439 L F
.49489 .09345 m .56211 .15458 L .49361 .08164 L .764 .678 .767 r
F
.56211 .15458 m .55722 .14761 L .49361 .08164 L F
.52704 .12269 m .5533 .13779 L .56211 .15458 L F
.49489 .09345 m .5533 .13779 L .52704 .12269 L F
.49489 .09345 m .54683 .12546 L .5533 .13779 L F
.49828 .10615 m .56929 .14698 L .49832 .09556 L .721 .708 .837 r
F
.56929 .14698 m .58538 .15623 L .57223 .14707 L F
.56929 .14698 m .57223 .14707 L .49832 .09556 L F
.55064 .11227 m .55509 .11954 L .57962 .14722 L .492 .48 .771 r
F
.58585 .15413 m .59796 .16076 L .58538 .15623 L .721 .708 .837 r
F
.58585 .15413 m .58614 .15283 L .59796 .16076 L F
.58121 .1472 m .57962 .14722 L .70837 .29248 L .492 .48 .771 r
F
.55064 .11227 m .57962 .14722 L .58121 .1472 L F
.68963 .15394 m .84299 .17211 L .68248 .14711 L .542 .807 .995 r
F
.70498 .14696 m .71518 .15144 L .70516 .14693 L .643 .396 .53 r
F
.73161 .15891 m .87318 .1477 L .84299 .17211 L .542 .807 .995 r
F
.71518 .15144 m .71956 .15336 L .70516 .14693 L .643 .396 .53 r
F
.71956 .15336 m .71973 .15335 L .70516 .14693 L F
.71956 .15336 m .87318 .1477 L .73161 .15891 L .542 .807 .995 r
F
.70516 .14693 m .71973 .15335 L .8123 .13326 L .643 .396 .53 r
F
.71973 .15335 m .81209 .14859 L .8123 .13326 L F
.71867 .15295 m .74456 .15207 L .71956 .15336 L .542 .807 .995 r
F
.74456 .15207 m .87318 .1477 L .71956 .15336 L F
.8123 .13326 m .81211 .14752 L .84846 .14563 L .643 .396 .53 r
F
.81211 .14752 m .82689 .14752 L .86575 .14473 L F
.81211 .14752 m .81209 .14859 L .82689 .14752 L F
.81209 .14859 m .86447 .14589 L .86575 .14473 L F
.77836 .14526 m .84393 .14695 L .73174 .14982 L .542 .807 .995 r
F
.84393 .14695 m .87318 .1477 L .81137 .14863 L F
.84393 .14695 m .81137 .14863 L .73174 .14982 L F
.49828 .10615 m .53192 .12458 L .52957 .12414 L .721 .708 .837 r
F
.55509 .11954 m .5886 .16014 L .59044 .15942 L .492 .48 .771 r
F
.53192 .12458 m .58585 .15413 L .52957 .12414 L .721 .708 .837 r
F
.52957 .12414 m .58585 .15413 L .58538 .15623 L F
.55359 .13408 m .54683 .12546 L .49832 .09556 L F
.49828 .10615 m .53611 .11923 L .55521 .13206 L F
.49828 .10615 m .55521 .13206 L .55819 .13897 L F
.55819 .13897 m .55521 .13206 L .58614 .15283 L F
.6035 .14833 m .61309 .14585 L .60853 .15035 L F
.6035 .14833 m .60853 .15035 L .59796 .16076 L F
.58614 .15283 m .6035 .14833 L .59796 .16076 L F
.53611 .11923 m .58951 .13769 L .58614 .15283 L F
.58951 .13769 m .61309 .14585 L .58614 .15283 L F
.50205 .11902 m .6231 .15619 L .55778 .13 L .669 .753 .914 r
F
.50205 .11902 m .55494 .12886 L .49828 .10615 L F
.6231 .15619 m .61309 .14585 L .49828 .10615 L F
.6231 .15619 m .66235 .15187 L .6259 .15705 L F
.66235 .15187 m .65753 .15301 L .6259 .15705 L F
.59552 .12454 m .60245 .13484 L .63627 .1557 L .591 .488 .706 r
F
.65753 .15301 m .63716 .15783 L .6259 .15705 L .669 .753 .914 r
F
.60245 .13484 m .62463 .15778 L .63627 .1557 L .591 .488 .706 r
F
.55559 .08106 m .56025 .08334 L .54282 .07568 L .63 .46 .633 r
F
.54229 .07544 m .54282 .07568 L .54159 .07514 L F
.55559 .08106 m .54282 .07568 L .54229 .07544 L F
.54159 .07514 m .55442 .08104 L .55412 .08098 L .643 .396 .53 r
F
.55559 .08106 m .6073 .10383 L .56025 .08334 L .63 .46 .633 r
F
.6073 .10383 m .59611 .09911 L .56025 .08334 L F
.52914 .06941 m .55559 .08106 L .54159 .07514 L F
.57331 .09073 m .57537 .09076 L .57549 .09082 L .25 .737 .923 r
F
.52914 .06941 m .6292 .14786 L .66702 .13014 L .63 .46 .633 r
F
.61759 .14141 m .6292 .14786 L .52914 .06941 L .591 .488 .706 r
F
.56437 .10072 m .59135 .13664 L .59552 .12454 L F
.50205 .11902 m .65341 .14259 L .64615 .14585 L .669 .753 .914 r
F
.50205 .11902 m .64371 .14694 L .6231 .15619 L F
.6635 .15085 m .67104 .15048 L .50205 .11902 L .542 .807 .995 r
F
.50407 .13196 m .6635 .15085 L .50205 .11902 L F
.6975 .14356 m .71535 .15142 L .70498 .14696 L .63 .46 .633 r
F
.71535 .15142 m .71956 .15336 L .70498 .14696 L F
.6975 .14356 m .68536 .15436 L .71535 .15142 L F
.68027 .14764 m .68536 .15436 L .6975 .14356 L F
.68963 .15394 m .68248 .14711 L .50205 .11902 L .542 .807 .995 r
F
.57246 .13487 m .64585 .138 L .57145 .13994 L F
.64585 .138 m .87318 .1477 L .63652 .14161 L F
.64585 .138 m .63652 .14161 L .57145 .13994 L F
.59044 .15942 m .70267 .29833 L .70837 .29248 L .492 .48 .771 r
F
.5886 .16014 m .70267 .29833 L .59044 .15942 L F
.84979 .14754 m .87318 .1477 L .84919 .14667 L .042 .611 .751 r
F
.84979 .14754 m .87426 .14755 L .87318 .1477 L F
.73174 .14982 m .87318 .1477 L .68963 .15394 L .542 .807 .995 r
F
.74553 .16535 m .84299 .17211 L .81576 .19721 L .669 .753 .914 r
F
.81209 .14859 m .81149 .19377 L .86447 .14589 L .643 .396 .53 r
F
.70537 .14338 m .77836 .14526 L .6635 .15085 L .542 .807 .995 r
F
.55819 .13897 m .58614 .15283 L .58585 .15413 L .721 .708 .837 r
F
.6635 .15085 m .68963 .15394 L .67104 .15048 L .542 .807 .995 r
F
.77836 .14526 m .73174 .14982 L .6635 .15085 L F
.57145 .13994 m .70537 .14338 L .6635 .15085 L F
.50407 .13196 m .57246 .13487 L .57145 .13994 L F
.5024 .14514 m .84979 .14754 L .50407 .13196 L .042 .611 .751 r
F
.84979 .14754 m .84919 .14667 L .50407 .13196 L F
.84468 .14021 m .84846 .14563 L .86575 .14473 L .643 .396 .53 r
F
.8123 .13326 m .84846 .14563 L .84468 .14021 L F
.65758 .14621 m .88381 .14624 L .87426 .14755 L .042 .611 .751 r
F
.65758 .14621 m .87426 .14755 L .84979 .14754 L F
.71973 .15335 m .81149 .19377 L .81209 .14859 L .643 .396 .53 r
F
.71956 .15336 m .81149 .19377 L .71973 .15335 L F
.50959 .14519 m .69611 .14571 L .65758 .14621 L .042 .611 .751 r
F
.69611 .14571 m .88381 .14624 L .65758 .14621 L F
.5024 .14514 m .50852 .14516 L .50959 .14519 L F
.50852 .14516 m .88381 .14624 L .50959 .14519 L F
.50027 .06568 m .50158 .06772 L .50254 .06894 L .031 .267 .765 r
F
.50158 .06772 m .50679 .0758 L .50254 .06894 L F
.56911 .16439 m .56929 .1648 L .58517 .18741 L F
.6428 .15852 m .75526 .24669 L .68536 .15436 L .63 .46 .633 r
F
.66546 .13087 m .6659 .13128 L .66702 .13014 L F
.58133 .17437 m .67927 .32232 L .58329 .16559 L .492 .48 .771 r
F
.6318 .15228 m .75526 .24669 L .64082 .15697 L .591 .488 .706 r
F
.71535 .15142 m .81149 .19377 L .71956 .15336 L .63 .46 .633 r
F
.68963 .15394 m .71867 .15295 L .73161 .15891 L .542 .807 .995 r
F
.6635 .15085 m .73174 .14982 L .68963 .15394 L F
.74553 .16535 m .81576 .19721 L .80099 .21082 L .669 .753 .914 r
F
.71535 .15142 m .75526 .24669 L .81149 .19377 L .63 .46 .633 r
F
.68536 .15436 m .75526 .24669 L .71535 .15142 L F
.59796 .16076 m .60038 .16136 L .59948 .16178 L .721 .708 .837 r
F
.59796 .16076 m .70837 .29248 L .60457 .15425 L .591 .488 .706 r
F
.58614 .15283 m .70837 .29248 L .59796 .16076 L .492 .48 .771 r
F
.58517 .18741 m .59286 .19178 L .57689 .16767 L .031 .267 .765 r
F
.58517 .18741 m .57689 .16767 L .57218 .16334 L F
.56163 .15366 m .58517 .18741 L .57218 .16334 L F
.58517 .18741 m .67927 .32232 L .59286 .19178 L F
.70954 .28939 m .71455 .29321 L .714 .29372 L .823 .655 .675 r
F
.63627 .1557 m .70837 .29248 L .75526 .24669 L .591 .488 .706 r
F
.61858 .15885 m .70837 .29248 L .63627 .1557 L F
.56663 .16409 m .56655 .1645 L .56872 .16718 L .031 .267 .765 r
F
.56211 .15458 m .56872 .16718 L .58517 .18741 L F
.67113 .30843 m .67927 .32232 L .67997 .3216 L .492 .48 .771 r
F
.67113 .30843 m .67997 .3216 L .70267 .29833 L F
.51771 .06504 m .56701 .12385 L .56437 .10072 L .591 .488 .706 r
F
.49725 .10227 m .49832 .09556 L .49489 .09345 L .721 .708 .837 r
F
.49828 .10615 m .49832 .09556 L .49725 .10227 L F
.50027 .06568 m .50257 .06899 L .50324 .06481 L .031 .267 .765 r
F
.5817 .19196 m .67164 .33177 L .67188 .33147 L F
.58286 .19393 m .67164 .33177 L .5817 .19196 L F
1 0 0 r
.003 w
.89997 .13477 m
.92474 .10446 L
s
.25 g
.5 Mabswid
.91502 .10419 m
.92474 .10446 L
s
1 0 0 r
.003 w
.92474 .10446 m
.92771 .09544 L
s
.17917 .60288 m .35215 .85848 L .18368 .60593 L .917 .558 .339 r
F
.18368 .60593 m .35215 .85848 L .35193 .86233 L .659 .22 0 r
F
1 0 0 r
.35215 .85848 m
.36554 .82999 L
s
.25 g
.5 Mabswid
.19673 .62428 m
.22952 .66424 L
s
.19243 .61905 m
.19673 .62428 L
s
0 g
.006 w
.17244 .59793 m
.17917 .60288 L
s
.18368 .60593 m .35193 .86233 L .18559 .60582 L .659 .22 0 r
F
0 g
.17917 .60288 m
.18368 .60593 L
s
.25 g
.5 Mabswid
.25466 .71233 m
.35215 .85848 L
s
.18559 .60582 m .36704 .8382 L .1849 .60184 L .135 .302 .769 r
F
.18559 .60582 m .35193 .86233 L .36704 .8382 L F
0 g
.006 w
.18368 .60593 m
.18559 .60582 L
s
.25 g
.5 Mabswid
.49489 .09345 m
.49519 .09363 L
s
.49519 .09363 m
.52546 .11229 L
s
.52546 .11229 m
.5375 .11971 L
s
1 0 0 r
.003 w
.71455 .29321 m
.75558 .25412 L
s
.75558 .25412 m
.80099 .21082 L
s
.25 g
.5 Mabswid
.49361 .08164 m
.49557 .08352 L
s
.49557 .08352 m
.52255 .10936 L
s
.52255 .10936 m
.52588 .11255 L
s
1 0 0 r
.003 w
.68469 .32093 m
.71455 .29321 L
s
.1849 .60184 m .39637 .78844 L .18179 .59416 L .432 .432 .759 r
F
.25 g
.5 Mabswid
.18559 .60582 m
.18806 .60961 L
s
.1849 .60184 m .36704 .8382 L .39637 .78844 L .432 .432 .759 r
F
0 g
.006 w
.1849 .60184 m
.18559 .60582 L
s
.25 g
.5 Mabswid
.1849 .60184 m
.1863 .60366 L
s
.15033 .53437 m .50323 .55757 L .15048 .52239 L .47 .806 .999 r
F
.15033 .53437 m .19593 .53588 L .23114 .53837 L F
.1552 .53469 m .23114 .53837 L .27554 .5415 L F
.1552 .53469 m .27554 .5415 L .27601 .54174 L F
.1552 .53469 m .29258 .5427 L .29329 .54289 L F
.1552 .53469 m .3051 .54359 L .31513 .54521 L F
.15033 .53437 m .23114 .53837 L .1552 .53469 L F
.35576 .54356 m .50323 .55757 L .31731 .54445 L .7 .732 .876 r
F
.16029 .52336 m .50323 .55757 L .16659 .52558 L F
.28652 .5808 m .45198 .62982 L .42625 .67561 L .806 .641 .677 r
F
.3081 .61516 m .42625 .67561 L .40882 .71555 L .866 .607 .544 r
F
.28301 .60873 m .29499 .61771 L .30795 .6146 L .599 .45 .651 r
F
.29499 .61771 m .3122 .63061 L .3081 .61516 L F
.29499 .61771 m .3081 .61516 L .30795 .6146 L F
.28241 .57801 m .288 .56896 L .28652 .5808 L .806 .641 .677 r
F
.35576 .54356 m .31731 .54445 L .23114 .53837 L .7 .732 .876 r
F
.27601 .54174 m .27554 .5415 L .29258 .5427 L .47 .806 .999 r
F
.29329 .54289 m .29258 .5427 L .3051 .54359 L F
.31513 .54521 m .3051 .54359 L .50323 .55757 L F
.28012 .54807 m .50323 .55757 L .4797 .58762 L .7 .732 .876 r
F
.23114 .53837 m .31121 .54402 L .28012 .54807 L F
.31121 .54402 m .50323 .55757 L .28012 .54807 L F
.31357 .54419 m .51715 .54651 L .50323 .55757 L .47 .806 .999 r
F
.16659 .52558 m .35576 .54356 L .23114 .53837 L .7 .732 .876 r
F
.15048 .52239 m .16029 .52336 L .16659 .52558 L F
.15048 .52239 m .23114 .53837 L .1561 .51073 L F
.23114 .53837 m .26844 .54017 L .1561 .51073 L F
.23114 .53837 m .28297 .54087 L .29911 .54262 L .47 .806 .999 r
F
.3051 .54359 m .29911 .54262 L .31357 .54419 L F
.23114 .53837 m .29911 .54262 L .3051 .54359 L F
.23826 .53226 m .22902 .52805 L .1561 .51073 L .7 .732 .876 r
F
.26844 .54017 m .22902 .52805 L .23826 .53226 L F
.27384 .54043 m .22902 .52805 L .26844 .54017 L F
.35579 .56307 m .30539 .5462 L .22902 .52805 L F
.17537 .51848 m .26571 .53901 L .21188 .53318 L .758 .675 .77 r
F
.35579 .56307 m .27384 .54043 L .26844 .54017 L .7 .732 .876 r
F
.19593 .53588 m .25485 .53783 L .28297 .54087 L .47 .806 .999 r
F
.19593 .53588 m .28297 .54087 L .23114 .53837 L F
.16169 .51206 m .30491 .54609 L .17537 .51848 L .758 .675 .77 r
F
.35579 .56307 m .4797 .58762 L .30539 .5462 L .7 .732 .876 r
F
.30491 .54609 m .4797 .58762 L .30143 .54712 L .758 .675 .77 r
F
.30491 .54609 m .30143 .54712 L .17537 .51848 L F
.23114 .53837 m .28012 .54807 L .26844 .54017 L .7 .732 .876 r
F
.28012 .54807 m .29426 .54694 L .26844 .54017 L F
.22634 .54656 m .28486 .54655 L .19593 .53588 L .469 0 0 r
F
.28486 .54655 m .25485 .53783 L .19593 .53588 L F
.22634 .54656 m .26237 .54808 L .27888 .54696 L F
.27912 .54655 m .27888 .54696 L .28486 .54655 L F
.22634 .54656 m .27888 .54696 L .27912 .54655 L F
.26986 .55651 m .4797 .58762 L .45198 .62982 L .758 .675 .77 r
F
.25087 .54887 m .27934 .55369 L .26986 .55651 L F
.27934 .55369 m .4797 .58762 L .26986 .55651 L F
.18053 .56106 m .23488 .56692 L .19624 .55901 L .63 .321 .429 r
F
.25428 .53957 m .29568 .54581 L .27156 .54746 L .758 .675 .77 r
F
.18356 .54755 m .19453 .54793 L .22634 .54656 L .469 0 0 r
F
.28012 .54807 m .35579 .56307 L .29426 .54694 L .7 .732 .876 r
F
.28486 .54655 m .35148 .56591 L .25087 .54887 L .758 .675 .77 r
F
.25087 .54887 m .45198 .62982 L .27555 .54928 L F
.19453 .54793 m .27555 .54928 L .22634 .54656 L .469 0 0 r
F
.29568 .54581 m .35148 .56591 L .28486 .54655 L .758 .675 .77 r
F
.27555 .54928 m .30068 .5497 L .27902 .54879 L .469 0 0 r
F
.27555 .54928 m .27768 .54898 L .22634 .54656 L F
.27768 .54898 m .27783 .54874 L .22634 .54656 L F
.19453 .54793 m .26769 .5504 L .27555 .54928 L F
.25428 .53957 m .27156 .54746 L .25087 .54887 L .758 .675 .77 r
F
.21188 .53318 m .25428 .53957 L .25087 .54887 L F
.26571 .53901 m .29568 .54581 L .21188 .53318 L F
.26237 .54808 m .27902 .54879 L .28486 .54655 L .469 0 0 r
F
.25087 .54887 m .26065 .54903 L .16712 .49979 L .758 .675 .77 r
F
.26065 .54903 m .27555 .54928 L .25604 .54038 L F
.26065 .54903 m .25604 .54038 L .16712 .49979 L F
.27552 .54929 m .27546 .5493 L .25611 .54047 L .806 .641 .677 r
F
.25609 .54044 m .25611 .54047 L .23984 .53305 L F
.27552 .54929 m .25611 .54047 L .25609 .54044 L F
.23488 .56692 m .26691 .57037 L .24271 .56459 L .63 .321 .429 r
F
.2691 .56898 m .28768 .56885 L .28241 .57801 L .806 .641 .677 r
F
.28768 .56885 m .288 .56896 L .28241 .57801 L F
.32093 .57707 m .35263 .59295 L .28944 .56439 L F
.28944 .56439 m .35263 .59295 L .27607 .56453 L F
.28979 .55578 m .45198 .62982 L .28975 .55581 L F
.2955 .56433 m .45198 .62982 L .35263 .59295 L F
.288 .56896 m .45198 .62982 L .28652 .5808 L F
.27607 .56453 m .28768 .56885 L .2691 .56898 L F
.26771 .56896 m .28064 .56914 L .24271 .56459 L .63 .321 .429 r
F
.24271 .56459 m .27071 .56795 L .26156 .55898 L F
.27071 .56795 m .27578 .56472 L .26156 .55898 L F
.2955 .56433 m .27607 .56453 L .2813 .5612 L .806 .641 .677 r
F
.28662 .56909 m .28713 .56289 L .26156 .55898 L .63 .321 .429 r
F
.1561 .51073 m .16169 .51206 L .17537 .51848 L .758 .675 .77 r
F
.1561 .51073 m .25087 .54887 L .16712 .49979 L F
.26156 .55898 m .28029 .56184 L .28479 .55897 L .63 .321 .429 r
F
.19624 .55901 m .24271 .56459 L .26156 .55898 L F
.16167 .55903 m .26156 .55898 L .15464 .54658 L F
.26156 .55898 m .28479 .55897 L .25563 .55619 L F
.26156 .55898 m .25563 .55619 L .15464 .54658 L F
.28479 .55897 m .26769 .5504 L .15464 .54658 L F
.2813 .5612 m .27607 .56453 L .24623 .55346 L .806 .641 .677 r
F
.1683 .50033 m .24008 .53309 L .16754 .50007 L F
.24008 .53309 m .23984 .53305 L .16754 .50007 L F
.26361 .55099 m .2955 .56433 L .24623 .55346 L F
.20875 .52803 m .26361 .55099 L .24623 .55346 L F
.16754 .50007 m .23984 .53305 L .20875 .52803 L F
.23984 .53305 m .45198 .62982 L .20875 .52803 L F
.16712 .49979 m .1683 .50033 L .16754 .50007 L F
.16712 .49979 m .2691 .56898 L .18256 .49004 L F
.25611 .55713 m .27607 .56453 L .2691 .56898 L F
.2691 .56898 m .34824 .62268 L .28655 .56923 L F
.34824 .62268 m .42625 .67561 L .38013 .64049 L F
.34824 .62268 m .38013 .64049 L .28655 .56923 L F
.16947 .57159 m .2698 .57887 L .16167 .55903 L .628 .415 .574 r
F
.2698 .57887 m .29691 .58084 L .25164 .56873 L F
.29691 .58084 m .28504 .57233 L .25164 .56873 L F
.28144 .57972 m .29706 .58573 L .29691 .58084 L F
.28504 .57233 m .29692 .58102 L .28469 .57304 L .866 .607 .544 r
F
.29692 .58102 m .42625 .67561 L .29695 .58192 L F
.29692 .58102 m .29695 .58192 L .28469 .57304 L F
.27045 .59883 m .2925 .60478 L .28144 .57972 L .628 .415 .574 r
F
.2925 .60478 m .29678 .60473 L .28144 .57972 L F
.29678 .60473 m .29706 .58573 L .28144 .57972 L F
.29767 .60617 m .29762 .60472 L .29678 .60473 L F
.29762 .60472 m .29706 .58573 L .29678 .60473 L F
.29983 .58401 m .42625 .67561 L .30952 .61589 L .866 .607 .544 r
F
.30795 .6146 m .30952 .61589 L .3081 .61516 L F
.29983 .58401 m .30952 .61589 L .30795 .6146 L F
.17649 .58366 m .30795 .6146 L .16947 .57159 L .599 .45 .651 r
F
.30827 .61429 m .31789 .61326 L .31017 .60458 L .866 .607 .544 r
F
.2968 .57703 m .38013 .64049 L .29691 .58084 L F
.38013 .64049 m .42625 .67561 L .28504 .57233 L F
.3081 .61516 m .40882 .71555 L .31789 .61326 L F
.30795 .6146 m .31726 .62252 L .31144 .61542 L .599 .45 .651 r
F
.30795 .6146 m .30563 .61269 L .16947 .57159 L F
.29762 .60472 m .29983 .58401 L .3081 .61516 L .866 .607 .544 r
F
.3072 .61178 m .31017 .60458 L .30531 .60463 L F
.3072 .61178 m .30531 .60463 L .2997 .6047 L F
.30658 .61327 m .3072 .61178 L .2997 .6047 L F
.30795 .6146 m .3082 .61466 L .30707 .61388 L .599 .45 .651 r
F
.3082 .61466 m .30932 .61492 L .30707 .61388 L F
.30707 .61388 m .30932 .61492 L .30563 .61269 L F
.32029 .61751 m .40882 .71555 L .321 .61876 L .899 .485 .184 r
F
.31789 .61326 m .33099 .628 L .32029 .61751 L F
.33099 .628 m .40882 .71555 L .32029 .61751 L F
.30827 .61429 m .31017 .60458 L .30658 .61327 L .866 .607 .544 r
F
.30932 .61492 m .31789 .61326 L .30827 .61429 L F
.29762 .60472 m .3081 .61516 L .2997 .6047 L F
.30563 .61269 m .3186 .61585 L .29767 .60617 L .599 .45 .651 r
F
.31017 .60458 m .31789 .61326 L .31101 .60631 L .899 .485 .184 r
F
.3186 .61585 m .31292 .61028 L .29767 .60617 L .599 .45 .651 r
F
.29702 .58423 m .29983 .58401 L .29762 .60472 L .866 .607 .544 r
F
.29767 .60617 m .31292 .61028 L .29706 .58573 L .628 .415 .574 r
F
.31292 .61028 m .302 .58764 L .29706 .58573 L F
.28655 .56923 m .2968 .57703 L .28504 .57233 L .866 .607 .544 r
F
.27071 .56795 m .28932 .57018 L .27578 .56472 L .63 .321 .429 r
F
.27853 .58569 m .29702 .58423 L .29762 .60472 L .866 .607 .544 r
F
.2997 .6047 m .31017 .60458 L .29429 .58672 L F
.2691 .56898 m .27635 .56908 L .18256 .49004 L .806 .641 .677 r
F
.27635 .56908 m .28655 .56923 L .26829 .55533 L F
.27635 .56908 m .26829 .55533 L .18256 .49004 L F
.23103 .52695 m .28655 .56923 L .21564 .52301 L .866 .607 .544 r
F
.29013 .57288 m .28932 .57018 L .28064 .56914 L .63 .321 .429 r
F
.29013 .57288 m .28064 .56914 L .26771 .56896 L F
.26691 .57037 m .28504 .57233 L .26882 .56915 L F
.28504 .57233 m .28519 .57201 L .26882 .56915 L F
.28655 .56923 m .28469 .57304 L .21564 .52301 L .866 .607 .544 r
F
.26691 .57037 m .26882 .56915 L .24271 .56459 L .63 .321 .429 r
F
.16947 .57159 m .27045 .59883 L .28144 .57972 L .628 .415 .574 r
F
.21564 .52301 m .28469 .57304 L .27853 .58569 L .866 .607 .544 r
F
.28469 .57304 m .29983 .58401 L .27853 .58569 L F
.24008 .53309 m .27555 .54928 L .23984 .53305 L .806 .641 .677 r
F
.27555 .54928 m .27552 .54929 L .23984 .53305 L F
.28476 .5861 m .29429 .58672 L .20089 .48166 L .866 .607 .544 r
F
.2997 .6047 m .29429 .58672 L .28476 .5861 L F
.3093 .60459 m .30815 .6046 L .29547 .59062 L .899 .485 .184 r
F
.31789 .61326 m .30815 .6046 L .3093 .60459 L F
.31144 .61542 m .3265 .6285 L .32029 .61751 L .599 .45 .651 r
F
.30932 .61492 m .32029 .61751 L .30563 .61269 L F
.31789 .61326 m .32029 .61751 L .30815 .6046 L .899 .485 .184 r
F
.32029 .61751 m .3164 .6137 L .30815 .6046 L F
.29762 .60472 m .2997 .6047 L .20089 .48166 L .866 .607 .544 r
F
.23628 .52147 m .27092 .56043 L .22963 .51807 L .899 .485 .184 r
F
.27092 .56043 m .2698 .56233 L .22963 .51807 L F
.22963 .51807 m .2698 .56233 L .26756 .56612 L F
.20089 .48166 m .23628 .52147 L .22963 .51807 L F
.20089 .48166 m .26647 .56474 L .22054 .47417 L F
.32029 .61751 m .47255 .65334 L .3186 .61585 L .599 .45 .651 r
F
.47255 .65334 m .47255 .65334 L .3186 .61585 L F
.32029 .61751 m .3186 .61585 L .30563 .61269 L F
.32029 .61751 m .321 .61876 L .3164 .6137 L .899 .485 .184 r
F
.3122 .63061 m .33908 .65075 L .30795 .6146 L .599 .45 .651 r
F
.321 .61876 m .40882 .71555 L .32647 .62843 L .899 .485 .184 r
F
.33908 .65075 m .32856 .63213 L .30795 .6146 L .599 .45 .651 r
F
.2698 .56233 m .321 .61876 L .26756 .56612 L .899 .485 .184 r
F
.321 .61876 m .32647 .62843 L .26756 .56612 L F
.3081 .61516 m .30827 .61429 L .30658 .61327 L .866 .607 .544 r
F
.30563 .61269 m .29767 .60617 L .2925 .60478 L .599 .45 .651 r
F
.30563 .61269 m .2925 .60478 L .16947 .57159 L F
.29429 .58672 m .31017 .60458 L .29547 .59062 L .899 .485 .184 r
F
.31017 .60458 m .31101 .60631 L .29547 .59062 L F
.31726 .62252 m .32856 .63213 L .31144 .61542 L .599 .45 .651 r
F
.32647 .62843 m .40882 .71555 L .33329 .64049 L .899 .485 .184 r
F
.32856 .63213 m .43444 .7222 L .3265 .6285 L .599 .45 .651 r
F
.32856 .63213 m .3265 .6285 L .31144 .61542 L F
.29768 .59798 m .32647 .62843 L .30073 .60815 L .899 .485 .184 r
F
.3081 .61516 m .30932 .61492 L .30827 .61429 L .866 .607 .544 r
F
.32647 .62843 m .33329 .64049 L .30073 .60815 L .899 .485 .184 r
F
.2968 .57703 m .29691 .58084 L .28504 .57233 L .866 .607 .544 r
F
.2955 .56433 m .32093 .57707 L .28944 .56439 L .806 .641 .677 r
F
.29691 .58084 m .50209 .59572 L .28504 .57233 L .628 .415 .574 r
F
.29706 .58573 m .47256 .65334 L .29691 .58084 L F
.47256 .65334 m .47258 .65334 L .47256 .65334 L F
.47256 .65334 m .47256 .65334 L .29691 .58084 L F
.27092 .56043 m .29429 .58672 L .2698 .56233 L .899 .485 .184 r
F
.29429 .58672 m .29547 .59062 L .2698 .56233 L F
.18179 .59416 m .35997 .68446 L .17649 .58366 L .543 .458 .709 r
F
.35474 .67597 m .40882 .71555 L .40624 .73275 L .899 .485 .184 r
F
.35102 .67186 m .35326 .67355 L .35474 .67597 L F
.35326 .67355 m .40882 .71555 L .35474 .67597 L F
.18179 .59416 m .39637 .78844 L .40968 .76527 L .543 .458 .709 r
F
.36562 .69036 m .40624 .73275 L .4051 .74038 L .899 .485 .184 r
F
.35102 .67186 m .40624 .73275 L .36562 .69036 L F
.33329 .64049 m .40882 .71555 L .35102 .67186 L F
.35102 .67186 m .4051 .74038 L .35697 .67096 L F
.37229 .69071 m .41896 .74913 L .43444 .7222 L .543 .458 .709 r
F
.36011 .67546 m .4051 .74038 L .4129 .74154 L 0 .111 .661 r
F
.37109 .68818 m .43444 .7222 L .34251 .65331 L .599 .45 .651 r
F
.33615 .64556 m .36452 .66981 L .32856 .63213 L F
.33908 .65075 m .34251 .65331 L .33615 .64556 L F
.34251 .65331 m .36452 .66981 L .33615 .64556 L F
.36452 .66981 m .37158 .66873 L .32856 .63213 L F
.3186 .61585 m .47258 .65334 L .31292 .61028 L F
.28504 .57233 m .29013 .57288 L .28519 .57201 L .63 .321 .429 r
F
.28979 .55578 m .28975 .55581 L .27546 .5493 L .806 .641 .677 r
F
.28979 .55578 m .27546 .5493 L .27552 .54929 L F
.27555 .54928 m .28979 .55578 L .27552 .54929 L F
.29568 .54581 m .4797 .58762 L .35148 .56591 L .758 .675 .77 r
F
.26769 .5504 m .51742 .55886 L .27555 .54928 L .469 0 0 r
F
.28029 .56184 m .50209 .59572 L .28479 .55897 L .63 .321 .429 r
F
.25485 .53783 m .51715 .54651 L .3631 .54475 L .47 .806 .999 r
F
.25485 .53783 m .3631 .54475 L .28297 .54087 L F
.28297 .54087 m .3631 .54475 L .31357 .54419 L F
.28486 .54655 m .51715 .54651 L .25485 .53783 L .469 0 0 r
F
.28479 .55897 m .51742 .55886 L .26769 .5504 L .63 .321 .429 r
F
.22167 .47581 m .29049 .57507 L .22148 .47545 L 0 .111 .661 r
F
.31292 .61028 m .47255 .65334 L .302 .58764 L .628 .415 .574 r
F
.47255 .65334 m .47258 .65334 L .47256 .65334 L F
.47255 .65334 m .47256 .65334 L .302 .58764 L F
.35697 .67096 m .4051 .74038 L .35707 .67108 L 0 .111 .661 r
F
.35707 .67108 m .4051 .74038 L .35709 .6711 L F
.35709 .6711 m .36011 .67546 L .37169 .68944 L F
.35709 .6711 m .37169 .68944 L .37109 .68818 L F
.37229 .69071 m .43444 .7222 L .37109 .68818 L .543 .458 .709 r
F
.36011 .67546 m .4129 .74154 L .4151 .74187 L 0 .111 .661 r
F
.35552 .67982 m .37109 .68818 L .33908 .65075 L .599 .45 .651 r
F
.37109 .68818 m .34251 .65331 L .33908 .65075 L F
.35102 .67186 m .35697 .67096 L .33905 .6451 L .899 .485 .184 r
F
.35552 .67982 m .33908 .65075 L .28301 .60873 L .599 .45 .651 r
F
.30073 .60815 m .33329 .64049 L .35102 .67186 L .899 .485 .184 r
F
.3265 .6285 m .43444 .7222 L .32029 .61751 L .599 .45 .651 r
F
.3341 .6448 m .33905 .6451 L .29049 .57507 L .899 .485 .184 r
F
.35102 .67186 m .33905 .6451 L .3341 .6448 L F
.29049 .57507 m .35697 .67096 L .29041 .57491 L 0 .111 .661 r
F
.29049 .57507 m .29041 .57491 L .22148 .47545 L F
.35697 .67096 m .35707 .67108 L .22148 .47545 L F
.22171 .47579 m .35707 .67108 L .22166 .47569 L F
.35707 .67108 m .35709 .6711 L .22166 .47569 L F
.35997 .68446 m .37229 .69071 L .35552 .67982 L .543 .458 .709 r
F
.37229 .69071 m .37109 .68818 L .35552 .67982 L F
.37109 .68818 m .37169 .68944 L .4151 .74187 L 0 .111 .661 r
F
.35997 .68446 m .40968 .76527 L .41896 .74913 L .543 .458 .709 r
F
.35997 .68446 m .41896 .74913 L .37229 .69071 L F
.18179 .59416 m .40968 .76527 L .35997 .68446 L F
.35997 .68446 m .35552 .67982 L .17649 .58366 L F
.27923 .63885 m .35552 .67982 L .28301 .60873 L .599 .45 .651 r
F
.26756 .56612 m .29768 .59798 L .30073 .60815 L .899 .485 .184 r
F
.26647 .56474 m .32943 .64451 L .29049 .57507 L F
.32943 .64451 m .35102 .67186 L .3341 .6448 L F
.32943 .64451 m .3341 .6448 L .29049 .57507 L F
.36452 .66981 m .43444 .7222 L .37158 .66873 L .599 .45 .651 r
F
.26647 .56474 m .29049 .57507 L .22054 .47417 L .899 .485 .184 r
F
.47255 .65334 m .47258 .65334 L .47255 .65334 L .599 .45 .651 r
F
.32029 .61751 m .43444 .7222 L .47258 .65334 L F
.28932 .57018 m .28809 .56607 L .28662 .56909 L .63 .321 .429 r
F
.28809 .56607 m .28713 .56289 L .28662 .56909 L F
.29691 .58084 m .47258 .65334 L .50209 .59572 L .628 .415 .574 r
F
.29013 .57288 m .50209 .59572 L .28932 .57018 L .63 .321 .429 r
F
.27555 .54928 m .51742 .55886 L .30068 .5497 L .469 0 0 r
F
.28932 .57018 m .50209 .59572 L .28713 .56289 L .63 .321 .429 r
F
.22166 .47569 m .35709 .6711 L .41861 .74239 L 0 .111 .661 r
F
.35709 .6711 m .4151 .74187 L .41861 .74239 L F
.18256 .49004 m .23103 .52695 L .21564 .52301 L .866 .607 .544 r
F
.18256 .49004 m .29762 .60472 L .20089 .48166 L F
.2925 .60478 m .29767 .60617 L .29678 .60473 L .628 .415 .574 r
F
.2698 .57887 m .25164 .56873 L .16167 .55903 L F
.22148 .47545 m .22171 .47579 L .22166 .47569 L 0 .111 .661 r
F
.22054 .47417 m .22167 .47581 L .22148 .47545 L F
.27768 .54898 m .27902 .54879 L .27783 .54874 L .469 0 0 r
F
.23488 .56692 m .24271 .56459 L .19624 .55901 L .63 .321 .429 r
F
.28479 .55897 m .50209 .59572 L .51742 .55886 L F
.16167 .55903 m .18053 .56106 L .19624 .55901 L F
.28486 .54655 m .27902 .54879 L .29473 .54655 L .469 0 0 r
F
.17649 .58366 m .27923 .63885 L .28301 .60873 L .599 .45 .651 r
F
.29473 .54655 m .51742 .55886 L .51715 .54651 L .469 0 0 r
F
.27902 .54879 m .51742 .55886 L .29473 .54655 L F
.15464 .54658 m .18356 .54755 L .22634 .54656 L F
.15464 .54658 m .22634 .54656 L .15033 .53437 L F
.22634 .54656 m .19593 .53588 L .15033 .53437 L F
0 g
.006 w
.18179 .59416 m
.1849 .60184 L
s
.25 g
.5 Mabswid
.33776 .8002 m
.36704 .8382 L
s
.25527 .69316 m
.33776 .8002 L
s
.19188 .6109 m
.25527 .69316 L
s
.18947 .60777 m
.19188 .6109 L
s
.18711 .60471 m
.18947 .60777 L
s
.1863 .60366 m
.18711 .60471 L
s
.28614 .76088 m
.35193 .86233 L
s
.2227 .66305 m
.28614 .76088 L
s
.19878 .62615 m
.2227 .66305 L
s
.19548 .62107 m
.19878 .62615 L
s
.19184 .61545 m
.19548 .62107 L
s
.18806 .60961 m
.19184 .61545 L
s
.49592 .0727 m
.49921 .07702 L
s
.49921 .07702 m
.52201 .10702 L
s
.52201 .10702 m
.52652 .11294 L
s
.49536 .07197 m
.49592 .0727 L
s
1 0 0 r
.003 w
.67164 .33177 m
.68469 .32093 L
s
.25 g
.5 Mabswid
.27024 .53785 m
.27264 .53842 L
s
.26699 .53708 m
.27024 .53785 L
s
.49828 .10615 m
.52663 .11595 L
s
.52663 .11595 m
.5629 .12849 L
s
1 0 0 r
.003 w
.80099 .21082 m
.81576 .19721 L
s
.81576 .19721 m
.84299 .17211 L
s
.90706 .10968 m
.92771 .09544 L
s
.25 g
.5 Mabswid
.18179 .59416 m
.18274 .59502 L
s
.18349 .5957 m
.23185 .63949 L
s
.18274 .59502 m
.18349 .5957 L
s
.36608 .76102 m
.39637 .78844 L
s
.3173 .71685 m
.36608 .76102 L
s
.29731 .69876 m
.3173 .71685 L
s
.23185 .63949 m
.29731 .69876 L
s
0 g
.006 w
.17649 .58366 m
.18179 .59416 L
s
.25 g
.5 Mabswid
.54562 .08233 m
.56908 .10072 L
s
.53096 .07084 m
.54562 .08233 L
s
.53058 .07054 m
.53096 .07084 L
s
.53028 .07031 m
.53058 .07054 L
s
.52914 .06941 m
.53028 .07031 L
s
.58016 .10941 m
.59482 .1209 L
s
.56908 .10072 m
.58016 .10941 L
s
.6428 .15852 m
.75526 .24669 L
s
.64082 .15697 m
.6428 .15852 L
s
.61247 .13474 m
.61481 .13658 L
s
.60974 .1326 m
.61247 .13474 L
s
.59482 .1209 m
.60974 .1326 L
s
0 g
.006 w
.51771 .06504 m
.52914 .06941 L
s
1 0 0 r
.003 w
.35193 .86233 m
.36704 .8382 L
s
.25 g
.5 Mabswid
.18705 .58934 m
.21248 .60299 L
s
.17649 .58366 m
.18705 .58934 L
s
.27923 .63885 m
.28744 .64326 L
s
.23537 .61529 m
.27923 .63885 L
s
.21248 .60299 m
.23537 .61529 L
s
.35552 .67982 m
.37109 .68818 L
s
.34299 .67309 m
.35552 .67982 L
s
.32024 .66087 m
.34299 .67309 L
s
.28744 .64326 m
.32024 .66087 L
s
0 g
.006 w
.16947 .57159 m
.17649 .58366 L
s
.25 g
.5 Mabswid
.28479 .53578 m
.33033 .54033 L
s
.27936 .53524 m
.28479 .53578 L
s
.27931 .53524 m
.27936 .53524 L
s
.26712 .53402 m
.27931 .53524 L
s
.26455 .53376 m
.26712 .53402 L
s
.51911 .06672 m
.54883 .10216 L
s
.51771 .06504 m
.51911 .06672 L
s
.56338 .11952 m
.56667 .12344 L
s
.54883 .10216 m
.56338 .11952 L
s
.60204 .16564 m
.60536 .16959 L
s
.59796 .16076 m
.60204 .16564 L
s
.56701 .12385 m
.5721 .12993 L
s
.56667 .12344 m
.56701 .12385 L
s
0 g
.006 w
.50791 .06345 m
.51771 .06504 L
s
.25 g
.5 Mabswid
.50027 .06568 m
.50679 .0758 L
s
.50679 .0758 m
.52568 .10514 L
s
.52568 .10514 m
.53346 .11722 L
s
.58286 .19393 m
.67164 .33177 L
s
.58231 .19307 m
.58286 .19393 L
s
.58116 .19128 m
.58231 .19307 L
s
1 0 0 r
.003 w
.67164 .33177 m
.67927 .32232 L
s
.25 g
.5 Mabswid
.16947 .57159 m
.20276 .58057 L
s
.20276 .58057 m
.25872 .59567 L
s
.32308 .61302 m
.33538 .61634 L
s
.47255 .65334 m
.47258 .65334 L
s
.29767 .60617 m
.29957 .60668 L
s
.2925 .60478 m
.29767 .60617 L
s
.27045 .59883 m
.2925 .60478 L
s
.25872 .59567 m
.27045 .59883 L
s
0 g
.006 w
.16167 .55903 m
.16947 .57159 L
s
.25 g
.5 Mabswid
.50791 .06345 m
.53447 .10358 L
s
.53447 .10358 m
.54742 .12314 L
s
.57689 .16767 m
.59286 .19178 L
s
.59286 .19178 m
.67927 .32232 L
s
0 g
.006 w
.50027 .06568 m
.50791 .06345 L
s
.25 g
.5 Mabswid
.50205 .11902 m
.61572 .13672 L
s
1 0 0 r
.003 w
.84299 .17211 m
.87318 .1477 L
s
.25 g
.5 Mabswid
.29371 .57326 m
.30063 .57401 L
s
.30063 .57401 m
.50209 .59572 L
s
.50209 .59572 m
.50209 .59572 L
s
.25164 .56873 m
.26271 .56992 L
s
.23488 .56692 m
.25164 .56873 L
s
.18053 .56106 m
.23488 .56692 L
s
.16167 .55903 m
.18053 .56106 L
s
0 g
.006 w
.15464 .54658 m
.16167 .55903 L
s
.49536 .07197 m
.50027 .06568 L
s
.25 g
.5 Mabswid
.27827 .55076 m
.51742 .55886 L
s
.27707 .55072 m
.27827 .55076 L
s
.19453 .54793 m
.24036 .54948 L
s
.18356 .54755 m
.19453 .54793 L
s
.15464 .54658 m
.18356 .54755 L
s
0 g
.006 w
.15033 .53437 m
.15464 .54658 L
s
.25 g
.5 Mabswid
.27631 .53854 m
.51715 .54651 L
s
.2732 .53844 m
.27631 .53854 L
s
.26928 .53831 m
.2732 .53844 L
s
.26787 .53826 m
.26928 .53831 L
s
.19593 .53588 m
.22063 .5367 L
s
.15033 .53437 m
.19593 .53588 L
s
1 0 0 r
.003 w
.51715 .54651 m
.51742 .55886 L
s
.86575 .14473 m
.90706 .10968 L
s
0 g
.006 w
.49361 .08164 m
.49536 .07197 L
s
1 0 0 r
.003 w
.67927 .32232 m
.70837 .29248 L
s
0 g
.006 w
.15033 .53437 m
.15048 .52239 L
s
1 0 0 r
.003 w
.36704 .8382 m
.39637 .78844 L
s
.31528 .28059 m .58669 .44251 L .32564 .26072 L .761 .684 .777 r
F
.31528 .28059 m .38688 .30974 L .43659 .34277 L F
.43775 .34449 m .43659 .34277 L .44443 .34798 L F
.31528 .28059 m .43659 .34277 L .43775 .34449 L F
.31528 .28059 m .44443 .34798 L .47156 .37383 L F
.32564 .26072 m .33785 .26923 L .3585 .29088 L .824 .651 .667 r
F
.4503 .34753 m .45966 .35405 L .44892 .34751 L F
.45966 .35405 m .45723 .35342 L .38688 .30974 L F
.33785 .26923 m .4503 .34753 L .38688 .30974 L F
.4503 .34753 m .44892 .34751 L .38688 .30974 L F
.47118 .36207 m .4523 .35321 L .38688 .30974 L F
.45966 .35405 m .47118 .36207 L .45723 .35342 L F
.47118 .36207 m .58669 .44251 L .4523 .35321 L F
.44001 .34504 m .62044 .40482 L .58669 .44251 L .761 .684 .777 r
F
.30959 .30183 m .42264 .33929 L .31528 .28059 L .701 .732 .875 r
F
.30959 .30183 m .36805 .31367 L .39932 .32834 L F
.31186 .30259 m .39932 .32834 L .42264 .33929 L F
.30959 .30183 m .39932 .32834 L .31186 .30259 L F
.42264 .33929 m .38688 .30974 L .31528 .28059 L F
.47156 .37383 m .44443 .34798 L .58669 .44251 L .761 .684 .777 r
F
.3585 .29088 m .58669 .44251 L .39932 .32834 L .824 .651 .667 r
F
.39932 .32834 m .58669 .44251 L .56054 .4763 L F
.33785 .26923 m .38688 .30974 L .3585 .29088 L F
.32564 .26072 m .39932 .32834 L .34051 .24331 L F
.42264 .33929 m .62044 .40482 L .38688 .30974 L .701 .732 .875 r
F
.42264 .33929 m .43404 .34088 L .4391 .34474 L F
.39932 .32834 m .4291 .33711 L .34051 .24331 L .824 .651 .667 r
F
.36164 .26912 m .3812 .2895 L .39764 .31311 L .911 .585 .414 r
F
.3812 .2895 m .42093 .33088 L .40931 .32201 L F
.3812 .2895 m .40931 .32201 L .39764 .31311 L F
.42134 .33868 m .4236 .33942 L .42264 .33929 L .701 .732 .875 r
F
.36805 .31367 m .4236 .33942 L .42134 .33868 L F
.42633 .32546 m .65452 .37163 L .43598 .34115 L F
.36805 .31367 m .40931 .32201 L .4236 .33942 L F
.394 .29994 m .4291 .33711 L .36164 .26912 L .911 .585 .414 r
F
.4291 .33711 m .42093 .33088 L .36164 .26912 L F
.40931 .32201 m .42633 .32546 L .4247 .33376 L .701 .732 .875 r
F
.40931 .32201 m .4247 .33376 L .4236 .33942 L F
.42633 .32546 m .43598 .34115 L .4236 .33942 L F
.39932 .32834 m .56054 .4763 L .42605 .33621 L .824 .651 .667 r
F
.4291 .33711 m .43764 .34616 L .42093 .33088 L .911 .585 .414 r
F
.43764 .34616 m .43377 .34425 L .42093 .33088 L F
.3076 .32355 m .42466 .33977 L .30959 .30183 L .57 .8 .986 r
F
.42466 .33977 m .40931 .32201 L .30959 .30183 L F
.38317 .33402 m .41693 .33597 L .42466 .33977 L F
.3572 .32722 m .40658 .33088 L .38317 .33402 L F
.42093 .33088 m .43377 .34425 L .39764 .31311 L .911 .585 .414 r
F
.43377 .34425 m .43249 .34363 L .39764 .31311 L F
.43673 .34733 m .43174 .34726 L .39764 .31311 L F
.42466 .33977 m .5176 .34393 L .40931 .32201 L .57 .8 .986 r
F
.43361 .33288 m .68155 .35125 L .43552 .33705 L F
.43673 .34733 m .56054 .4763 L .43174 .34726 L .911 .585 .414 r
F
.4391 .34474 m .44897 .34296 L .62044 .40482 L .701 .732 .875 r
F
.43739 .34344 m .44897 .34296 L .4391 .34474 L F
.43404 .34088 m .43598 .34115 L .43739 .34344 L F
.43598 .34115 m .44897 .34296 L .43739 .34344 L F
.38607 .26743 m .42138 .31742 L .37544 .25158 L 0 .058 .613 r
F
.44897 .34296 m .65452 .37163 L .6294 .39609 L .701 .732 .875 r
F
.44897 .34296 m .6294 .39609 L .62044 .40482 L F
.43759 .34157 m .47243 .34295 L .65452 .37163 L .57 .8 .986 r
F
.47243 .34295 m .68155 .35125 L .65976 .36768 L F
.47243 .34295 m .65976 .36768 L .65452 .37163 L F
.40658 .33088 m .41693 .33597 L .38317 .33402 L F
.39764 .31311 m .56054 .4763 L .54887 .49789 L .911 .585 .414 r
F
.34051 .24331 m .394 .29994 L .36164 .26912 L F
.34051 .24331 m .41596 .3355 L .35901 .22913 L F
.42466 .33977 m .43702 .34033 L .43759 .34157 L .57 .8 .986 r
F
.43702 .34033 m .68155 .35125 L .43759 .34157 L F
.41596 .3355 m .43602 .33814 L .35901 .22913 L .911 .585 .414 r
F
.42138 .31742 m .43602 .33814 L .41849 .31273 L 0 .058 .613 r
F
.43552 .33705 m .68155 .35125 L .43702 .34033 L .57 .8 .986 r
F
.43764 .34616 m .56054 .4763 L .43377 .34425 L .911 .585 .414 r
F
.43602 .33814 m .54887 .49789 L .43533 .33664 L 0 .058 .613 r
F
.43602 .33814 m .43533 .33664 L .41849 .31273 L F
.41693 .33597 m .43552 .33705 L .42466 .33977 L .57 .8 .986 r
F
.43552 .33705 m .43702 .34033 L .42466 .33977 L F
.41849 .31273 m .43533 .33664 L .42052 .31456 L 0 .058 .613 r
F
.41399 .30541 m .42052 .31456 L .40957 .29823 L F
.41849 .31273 m .42052 .31456 L .41399 .30541 L F
.43533 .33664 m .43334 .33229 L .40957 .29823 L F
.40658 .33088 m .43361 .33288 L .41803 .33577 L .57 .8 .986 r
F
.41596 .3355 m .41803 .33577 L .41693 .33597 L F
.40658 .33088 m .41803 .33577 L .41596 .3355 L F
.43361 .33288 m .43552 .33705 L .41693 .33597 L F
.43377 .34425 m .43673 .34733 L .43249 .34363 L .911 .585 .414 r
F
.41596 .3355 m .54887 .49789 L .43602 .33814 L F
.44403 .34748 m .68155 .35125 L .43361 .33288 L .014 0 0 r
F
.43533 .33664 m .44295 .34746 L .43334 .33229 L 0 .058 .613 r
F
.44295 .34746 m .54887 .49789 L .44393 .34748 L F
.44295 .34746 m .44393 .34748 L .43334 .33229 L F
.45169 .35579 m .54887 .49789 L .55722 .50001 L F
.44564 .34753 m .45009 .35401 L .45169 .35579 L F
.45009 .35401 m .54887 .49789 L .45169 .35579 L F
.65695 .37915 m .66679 .4179 L .68764 .37833 L .619 .321 .443 r
F
.6114 .40553 m .58815 .47809 L .63966 .43199 L .528 .482 .749 r
F
.54711 .38208 m .61371 .40419 L .65695 .37915 L .619 .321 .443 r
F
.59325 .39891 m .61371 .40419 L .54711 .38208 L F
.54711 .38208 m .58815 .47809 L .6114 .40553 L .528 .482 .749 r
F
.51306 .36967 m .57173 .45439 L .54711 .38208 L F
.57173 .45439 m .58815 .47809 L .54711 .38208 L F
.44485 .34751 m .54887 .49789 L .44564 .34753 L 0 .058 .613 r
F
.6114 .40553 m .63966 .43199 L .61371 .40419 L .528 .482 .749 r
F
.61371 .40419 m .63966 .43199 L .65644 .41523 L .587 .474 .692 r
F
.46145 .34778 m .55722 .50001 L .54067 .46567 L .373 .442 .804 r
F
.46145 .34778 m .46689 .35586 L .47213 .34904 L F
.46689 .35586 m .54067 .46567 L .47867 .36017 L F
.46689 .35586 m .47867 .36017 L .47213 .34904 L F
.48211 .36004 m .52735 .36441 L .59681 .35545 L .542 .097 .142 r
F
.47867 .36017 m .48525 .36075 L .48211 .36004 L F
.48525 .36075 m .52735 .36441 L .48211 .36004 L F
.51089 .36653 m .51306 .36967 L .51656 .36781 L .528 .482 .749 r
F
.49991 .36795 m .5046 .37381 L .50087 .36782 L .373 .442 .804 r
F
.5046 .37381 m .56445 .44851 L .51306 .36967 L F
.56445 .44851 m .58815 .47809 L .57173 .45439 L F
.56445 .44851 m .57173 .45439 L .51306 .36967 L F
.5046 .37381 m .51306 .36967 L .51089 .36653 L F
.49991 .36795 m .51089 .36653 L .47867 .36017 L .542 .097 .142 r
F
.51089 .36653 m .52735 .36441 L .48525 .36075 L F
.51089 .36653 m .48525 .36075 L .47867 .36017 L F
.52065 .38279 m .66679 .4179 L .52987 .38255 L .619 .321 .443 r
F
.54421 .39599 m .66679 .4179 L .52065 .38279 L F
.54711 .38208 m .65695 .37915 L .54438 .37409 L F
.65695 .37915 m .68764 .37833 L .65226 .37729 L F
.65695 .37915 m .65226 .37729 L .54438 .37409 L F
.40226 .20968 m .52872 .32811 L .42497 .20201 L .528 .482 .749 r
F
.58844 .38403 m .51306 .36967 L .6114 .40553 L F
.51656 .36781 m .51306 .36967 L .58844 .38403 L F
.51733 .37113 m .65226 .37729 L .52735 .36441 L .542 .097 .142 r
F
.53392 .37378 m .65226 .37729 L .51733 .37113 L F
.65226 .37729 m .66278 .37617 L .52735 .36441 L F
.59681 .35545 m .68764 .37833 L .69445 .35154 L F
.52735 .36441 m .66278 .37617 L .59681 .35545 L F
.66278 .37617 m .68764 .37833 L .67426 .37496 L F
.66278 .37617 m .67426 .37496 L .59681 .35545 L F
.6114 .40553 m .61371 .40419 L .5943 .38341 L .528 .482 .749 r
F
.47867 .36017 m .59681 .35545 L .47149 .34796 L .542 .097 .142 r
F
.59681 .35545 m .69445 .35154 L .58295 .34975 L F
.59681 .35545 m .58295 .34975 L .47879 .34807 L F
.46957 .34792 m .59976 .35001 L .46876 .34789 L .014 0 0 r
F
.46079 .34777 m .46876 .34789 L .4567 .3477 L F
.44564 .34753 m .45169 .35579 L .46145 .34778 L 0 .058 .613 r
F
.45169 .35579 m .55722 .50001 L .46326 .35065 L F
.45169 .35579 m .46326 .35065 L .46145 .34778 L F
.47888 .3484 m .47879 .34807 L .47149 .34796 L .542 .097 .142 r
F
.59681 .35545 m .47879 .34807 L .47888 .3484 L F
.46145 .34778 m .48523 .35059 L .48167 .34814 L .373 .442 .804 r
F
.4459 .34753 m .46634 .34786 L .44475 .3475 L .014 0 0 r
F
.46634 .34786 m .46499 .34784 L .44475 .3475 L F
.46957 .34792 m .4567 .3477 L .44475 .3475 L F
.44403 .34748 m .62215 .35037 L .68155 .35125 L F
.62215 .35037 m .69445 .35154 L .69071 .35146 L F
.62215 .35037 m .69071 .35146 L .68155 .35125 L F
.50087 .36782 m .51089 .36653 L .49833 .3484 L .373 .442 .804 r
F
.59976 .35001 m .61495 .35025 L .4567 .3477 L .014 0 0 r
F
.44475 .3475 m .61495 .35025 L .44403 .34748 L F
.61495 .35025 m .69445 .35154 L .62215 .35037 L F
.61495 .35025 m .62215 .35037 L .44403 .34748 L F
.43334 .33229 m .44393 .34748 L .435 .33326 L 0 .058 .613 r
F
.44393 .34748 m .54887 .49789 L .44485 .34751 L F
.44393 .34748 m .44485 .34751 L .435 .33326 L F
.35098 .34602 m .4468 .34756 L .36611 .34625 L .014 0 0 r
F
.67832 .35142 m .5943 .38341 L .70474 .367 L .587 .474 .692 r
F
.44607 .34754 m .69445 .35154 L .4459 .34753 L .014 0 0 r
F
.45818 .34774 m .69445 .35154 L .44607 .34754 L F
.59976 .35001 m .69445 .35154 L .61495 .35025 L F
.42497 .20201 m .56264 .34949 L .67832 .35142 L .587 .474 .692 r
F
.56264 .34949 m .5943 .38341 L .67832 .35142 L F
.4468 .34756 m .45818 .34774 L .44607 .34754 L .014 0 0 r
F
.4468 .34756 m .4459 .34753 L .36611 .34625 L F
.48867 .34825 m .46592 .3016 L .45739 .29809 L .373 .442 .804 r
F
.50087 .36782 m .49056 .34828 L .48867 .34825 L F
.49056 .34828 m .46592 .3016 L .48867 .34825 L F
.49056 .34828 m .49833 .3484 L .46592 .3016 L F
.50087 .36782 m .49833 .3484 L .49056 .34828 L F
.3826 .38648 m .50313 .41321 L .47692 .38396 L .619 .321 .443 r
F
.30421 .38857 m .36182 .3957 L .3826 .38648 L F
.36182 .3957 m .50313 .41321 L .3826 .38648 L F
.46957 .34792 m .46876 .34789 L .46079 .34777 L .014 0 0 r
F
.35901 .22913 m .44564 .34753 L .37995 .21821 L 0 .058 .613 r
F
.44564 .34753 m .46145 .34778 L .37995 .21821 L F
.45383 .25798 m .49833 .3484 L .55136 .34931 L .528 .482 .749 r
F
.40226 .20968 m .46592 .3016 L .45383 .25798 L F
.46592 .3016 m .49833 .3484 L .45383 .25798 L F
.45739 .29809 m .46592 .3016 L .40226 .20968 L .373 .442 .804 r
F
.59141 .38371 m .5943 .38341 L .42497 .20201 L .528 .482 .749 r
F
.6114 .40553 m .5943 .38341 L .59141 .38371 L F
.61371 .40419 m .66679 .4179 L .65695 .37915 L .619 .321 .443 r
F
.5943 .38341 m .61371 .40419 L .64486 .39147 L .587 .474 .692 r
F
.65226 .37729 m .68764 .37833 L .66278 .37617 L .542 .097 .142 r
F
.5943 .38341 m .64486 .39147 L .70474 .367 L .587 .474 .692 r
F
.51425 .37319 m .53392 .37378 L .51733 .37113 L .542 .097 .142 r
F
.52872 .32811 m .58844 .38403 L .54723 .33547 L .528 .482 .749 r
F
.58844 .38403 m .6114 .40553 L .59141 .38371 L F
.58844 .38403 m .59141 .38371 L .54723 .33547 L F
.52872 .32811 m .54723 .33547 L .42497 .20201 L F
.5046 .37381 m .51089 .36653 L .50087 .36782 L .373 .442 .804 r
F
.51425 .37319 m .52735 .36441 L .49991 .36795 L .542 .097 .142 r
F
.55136 .34931 m .51656 .36781 L .58844 .38403 L .528 .482 .749 r
F
.47213 .34904 m .47867 .36017 L .48523 .35059 L .373 .442 .804 r
F
.47867 .36017 m .54067 .46567 L .49224 .36514 L F
.47867 .36017 m .49224 .36514 L .48523 .35059 L F
.50316 .373 m .55722 .50001 L .58544 .48 L F
.49339 .36753 m .55722 .50001 L .50316 .373 L F
.56445 .44851 m .58544 .48 L .58815 .47809 L F
.5046 .37381 m .58544 .48 L .56445 .44851 L F
.48407 .34818 m .50316 .373 L .5046 .37381 L F
.50316 .373 m .58544 .48 L .5046 .37381 L F
.54421 .39599 m .65909 .43252 L .66679 .4179 L .619 .321 .443 r
F
.47692 .38396 m .56434 .40726 L .54421 .39599 L F
.56434 .40726 m .65909 .43252 L .54421 .39599 L F
.52678 .44226 m .61203 .50752 L .64251 .45894 L .618 .405 .57 r
F
.29808 .40928 m .5709 .49465 L .52678 .44226 L F
.5709 .49465 m .61203 .50752 L .52678 .44226 L F
.43233 .33009 m .435 .33326 L .43139 .32804 L 0 .058 .613 r
F
.43334 .33229 m .435 .33326 L .43233 .33009 L F
.30421 .38857 m .47692 .38396 L .30696 .36705 L .619 .321 .443 r
F
.47692 .38396 m .48425 .38376 L .47622 .38301 L F
.47692 .38396 m .47622 .38301 L .30696 .36705 L F
.48425 .38376 m .52065 .38279 L .47927 .37974 L F
.48425 .38376 m .47927 .37974 L .30696 .36705 L F
.49833 .3484 m .51089 .36653 L .55136 .34931 L .528 .482 .749 r
F
.51089 .36653 m .51656 .36781 L .55136 .34931 L F
.48407 .34818 m .49991 .36795 L .48867 .34825 L .373 .442 .804 r
F
.49991 .36795 m .50087 .36782 L .48867 .34825 L F
.48407 .34818 m .49339 .36753 L .50316 .373 L F
.30696 .36705 m .51425 .37319 L .47867 .36017 L .542 .097 .142 r
F
.30696 .36705 m .47867 .36017 L .30746 .34532 L F
.47867 .36017 m .47149 .34796 L .30746 .34532 L F
.48167 .34814 m .48523 .35059 L .48407 .34818 L .373 .442 .804 r
F
.5985 .42862 m .64251 .45894 L .65909 .43252 L .618 .405 .57 r
F
.29808 .40928 m .64251 .45894 L .5985 .42862 L F
.37995 .21821 m .48407 .34818 L .40226 .20968 L .373 .442 .804 r
F
.48407 .34818 m .48867 .34825 L .40226 .20968 L F
.48425 .38376 m .54421 .39599 L .52065 .38279 L .619 .321 .443 r
F
.47692 .38396 m .48199 .38486 L .48425 .38376 L F
.48199 .38486 m .54421 .39599 L .48425 .38376 L F
.52065 .38279 m .54711 .38208 L .519 .38033 L F
.52065 .38279 m .519 .38033 L .30696 .36705 L F
.46634 .34786 m .46957 .34792 L .46499 .34784 L .014 0 0 r
F
.37995 .21821 m .46145 .34778 L .48407 .34818 L .373 .442 .804 r
F
.54711 .38208 m .54438 .37409 L .30696 .36705 L .619 .321 .443 r
F
.52987 .38255 m .59325 .39891 L .54711 .38208 L F
.61371 .40419 m .65644 .41523 L .70474 .367 L .587 .474 .692 r
F
.50313 .41321 m .65909 .43252 L .47692 .38396 L .619 .321 .443 r
F
.41285 .347 m .4459 .34753 L .41899 .34709 L .014 0 0 r
F
.4459 .34753 m .44475 .3475 L .41899 .34709 L F
.30746 .34532 m .44403 .34748 L .3076 .32355 L F
.3076 .32355 m .3572 .32722 L .38317 .33402 L .57 .8 .986 r
F
.44403 .34748 m .43361 .33288 L .3076 .32355 L .014 0 0 r
F
.42138 .31742 m .41849 .31273 L .37544 .25158 L 0 .058 .613 r
F
.41899 .34709 m .44475 .3475 L .44403 .34748 L .014 0 0 r
F
.43139 .32804 m .44485 .34751 L .44564 .34753 L 0 .058 .613 r
F
.40957 .29823 m .43334 .33229 L .43139 .32804 L F
.36611 .34625 m .41285 .347 L .41899 .34709 L .014 0 0 r
F
.37544 .25158 m .41849 .31273 L .40957 .29823 L 0 .058 .613 r
F
.30746 .34532 m .35098 .34602 L .36611 .34625 L .014 0 0 r
F
.35901 .22913 m .38607 .26743 L .37544 .25158 L 0 .058 .613 r
F
.25 g
.5 Mabswid
.70021 .28274 m
.70837 .29248 L
s
.60536 .16959 m
.70021 .28274 L
s
0 g
.006 w
.49361 .08164 m
.49489 .09345 L
s
.25 g
.5 Mabswid
.31528 .28059 m
.32011 .28256 L
s
.32011 .28256 m
.37281 .30401 L
s
0 g
.006 w
.15048 .52239 m
.1561 .51073 L
s
.49489 .09345 m
.49828 .10615 L
s
.1561 .51073 m
.16712 .49979 L
s
1 0 0 r
.003 w
.50209 .59572 m
.51742 .55886 L
s
.25 g
.5 Mabswid
.50585 .13203 m
.83569 .1461 L
s
.50407 .13196 m
.50585 .13203 L
s
.29049 .57507 m
.3146 .60985 L
s
.3146 .60985 m
.31746 .61397 L
s
.24749 .51305 m
.29049 .57507 L
s
.22203 .47632 m
.24749 .51305 L
s
.31746 .61397 m
.33905 .6451 L
s
.33905 .6451 m
.33905 .6451 L
s
.33905 .6451 m
.35697 .67096 L
s
1 0 0 r
.003 w
.70837 .29248 m
.75526 .24669 L
s
0 g
.006 w
.49828 .10615 m
.50205 .11902 L
s
1 0 0 r
.003 w
.81149 .19377 m
.86264 .14754 L
s
.86414 .14618 m
.86447 .14589 L
s
.86447 .14589 m
.86575 .14473 L
s
.25 g
.5 Mabswid
.36805 .31367 m
.40406 .32095 L
s
.30959 .30183 m
.36805 .31367 L
s
0 g
.006 w
.16712 .49979 m
.18256 .49004 L
s
.50205 .11902 m
.50407 .13196 L
s
.18256 .49004 m
.20089 .48166 L
s
1 0 0 r
.003 w
.39637 .78844 m
.41896 .74913 L
s
.75526 .24669 m
.81149 .19377 L
s
.25 g
.5 Mabswid
.4877 .41129 m
.49524 .42198 L
s
.53968 .48489 m
.54887 .49789 L
s
.38607 .26743 m
.42138 .31742 L
s
.36022 .23085 m
.38607 .26743 L
s
.35901 .22913 m
.36022 .23085 L
s
1 0 0 r
.003 w
.47258 .65334 m
.50209 .59572 L
s
.49577 .15853 m .88381 .14624 L .5024 .14514 L .502 .025 .055 r
F
0 g
.006 w
.5024 .14514 m
.50407 .13196 L
s
.22054 .47417 m .41861 .74239 L .24011 .46639 L 0 .111 .661 r
F
0 g
.20089 .48166 m
.22054 .47417 L
s
.25 g
.5 Mabswid
.22054 .47417 m
.22203 .47632 L
s
.40658 .33088 m
.42313 .33211 L
s
.67753 .35095 m
.68155 .35125 L
s
.3572 .32722 m
.40658 .33088 L
s
.34833 .32657 m
.3572 .32722 L
s
.3076 .32355 m
.34833 .32657 L
s
.49577 .15853 m .86982 .17235 L .88381 .14624 L .502 .025 .055 r
F
.25 g
.5024 .14514 m
.88381 .14624 L
s
.48382 .17159 m .86982 .17235 L .49577 .15853 L .613 .29 .4 r
F
0 g
.006 w
.49577 .15853 m
.5024 .14514 L
s
.24011 .46639 m .45026 .71689 L .25851 .4568 L .313 .404 .796 r
F
.25 g
.5 Mabswid
.33745 .6169 m
.37483 .62698 L
s
.24011 .46639 m .41861 .74239 L .45026 .71689 L .313 .404 .796 r
F
.25 g
.38624 .63006 m
.47255 .65334 L
s
0 g
.006 w
.22054 .47417 m
.24011 .46639 L
s
.25 g
.5 Mabswid
.3014 .56116 m
.3014 .56116 L
s
.24011 .46639 m
.3014 .56116 L
s
1 0 0 r
.003 w
.4129 .74154 m
.41861 .74239 L
s
.41896 .74913 m
.42648 .73606 L
s
.44291 .70692 m
.47258 .65334 L
s
.48382 .17159 m .83092 .22422 L .86982 .17235 L .613 .29 .4 r
F
.46715 .1835 m .83092 .22422 L .48382 .17159 L .627 .394 .545 r
F
.25 g
.5 Mabswid
.49577 .15853 m
.5077 .15897 L
s
.5077 .15897 m
.86982 .17235 L
s
0 g
.006 w
.48382 .17159 m
.49577 .15853 L
s
.25 g
.5 Mabswid
.48424 .17165 m
.49091 .17266 L
s
.48382 .17159 m
.48424 .17165 L
s
.25851 .4568 m .49766 .66394 L .27479 .44419 L .482 .456 .753 r
F
.25851 .4568 m .45026 .71689 L .49766 .66394 L F
.25 g
.3014 .56116 m
.39831 .711 L
s
0 g
.006 w
.24011 .46639 m
.25851 .4568 L
s
.25 g
.5 Mabswid
.39831 .711 m
.41861 .74239 L
s
.46715 .1835 m .77253 .29335 L .83092 .22422 L .627 .394 .545 r
F
.44704 .19361 m .77253 .29335 L .46715 .1835 L .616 .446 .629 r
F
0 g
.006 w
.46715 .1835 m
.48382 .17159 L
s
1 0 0 r
.003 w
.41861 .74239 m
.45026 .71689 L
s
.27479 .44419 m .55472 .58993 L .28819 .42817 L .556 .46 .702 r
F
.25 g
.5 Mabswid
.25851 .4568 m
.26119 .46045 L
s
.27479 .44419 m .49766 .66394 L .55472 .58993 L .556 .46 .702 r
F
0 g
.006 w
.25851 .4568 m
.27479 .44419 L
s
.25 g
.5 Mabswid
.38417 .62725 m
.45026 .71689 L
s
1 0 0 r
.003 w
.86982 .17235 m
.88381 .14624 L
s
.44704 .19361 m .70474 .367 L .77253 .29335 L .616 .446 .629 r
F
.42497 .20201 m .70474 .367 L .44704 .19361 L .587 .474 .692 r
F
.25 g
.5 Mabswid
.49091 .17266 m
.83092 .22422 L
s
.4956 .19373 m
.77253 .29335 L
s
.46715 .1835 m
.4956 .19373 L
s
0 g
.006 w
.44704 .19361 m
.46715 .1835 L
s
.25 g
.5 Mabswid
.51327 .23817 m
.68166 .35147 L
s
.46685 .20694 m
.48623 .21998 L
s
.48623 .21998 m
.51327 .23817 L
s
.68166 .35147 m
.70474 .367 L
s
.44704 .19361 m
.46685 .20694 L
s
.42313 .33211 m
.43361 .33288 L
s
.42138 .31742 m
.43223 .33278 L
s
0 g
.006 w
.42497 .20201 m
.44704 .19361 L
s
.28819 .42817 m .61203 .50752 L .29808 .40928 L .596 .444 .645 r
F
.25 g
.5 Mabswid
.27479 .44419 m
.2781 .44745 L
s
.28819 .42817 m .55472 .58993 L .61203 .50752 L .596 .444 .645 r
F
.25 g
.26119 .46045 m
.38417 .62725 L
s
.31155 .48043 m
.49766 .66394 L
s
.2781 .44745 m
.31155 .48043 L
s
0 g
.006 w
.27479 .44419 m
.28819 .42817 L
s
.25 g
.5 Mabswid
.34625 .46341 m
.55472 .58993 L
s
.28819 .42817 m
.29088 .42981 L
s
.48081 .26182 m
.48887 .27046 L
s
.48887 .27046 m
.56264 .34949 L
s
.44113 .21932 m
.45139 .23032 L
s
.45139 .23032 m
.48081 .26182 L
s
.56264 .34949 m
.5943 .38341 L
s
.42648 .20362 m
.44113 .21932 L
s
.42497 .20201 m
.42648 .20362 L
s
0 g
.006 w
.40226 .20968 m
.42497 .20201 L
s
.25 g
.5 Mabswid
.43154 .30022 m
.43719 .30921 L
s
.43719 .30921 m
.45947 .34462 L
s
.45947 .34462 m
.46145 .34778 L
s
.39832 .24742 m
.43154 .30022 L
s
.38148 .22064 m
.39832 .24742 L
s
.38088 .21968 m
.38148 .22064 L
s
.37995 .21821 m
.38088 .21968 L
s
.46592 .3016 m
.47488 .31455 L
s
.47488 .31455 m
.49833 .3484 L
s
.49833 .3484 m
.51089 .36653 L
s
.45389 .28423 m
.46592 .3016 L
s
.41788 .23225 m
.44703 .27432 L
s
.44703 .27432 m
.45389 .28423 L
s
.40374 .21182 m
.41788 .23225 L
s
.40226 .20968 m
.40374 .21182 L
s
0 g
.006 w
.37995 .21821 m
.40226 .20968 L
s
.25 g
.5 Mabswid
.434 .45182 m
.5709 .49465 L
s
.5709 .49465 m
.61203 .50752 L
s
.29808 .40928 m .65909 .43252 L .30421 .38857 L .618 .405 .57 r
F
.25 g
.30736 .41219 m
.434 .45182 L
s
.29808 .40928 m
.30736 .41219 L
s
.5943 .38341 m
.61371 .40419 L
s
0 g
.006 w
.28819 .42817 m
.29808 .40928 L
s
.25 g
.5 Mabswid
.29183 .43038 m
.34625 .46341 L
s
.29088 .42981 m
.29183 .43038 L
s
0 g
.006 w
.29808 .40928 m
.30421 .38857 L
s
.35901 .22913 m
.37995 .21821 L
s
.25 g
.5 Mabswid
.30421 .38857 m
.50313 .41321 L
s
.58141 .4229 m
.65909 .43252 L
s
.50313 .41321 m
.58141 .4229 L
s
0 g
.006 w
.30421 .38857 m
.30696 .36705 L
s
.25 g
.5 Mabswid
.46951 .37187 m
.51425 .37319 L
s
.30696 .36705 m
.46951 .37187 L
s
.51425 .37319 m
.54438 .37409 L
s
0 g
.006 w
.30696 .36705 m
.30746 .34532 L
s
.34051 .24331 m
.35901 .22913 L
s
.25 g
.5 Mabswid
.30746 .34532 m
.38372 .34654 L
s
.38372 .34654 m
.45818 .34774 L
s
.45818 .34774 m
.47149 .34796 L
s
0 g
.006 w
.30746 .34532 m
.3076 .32355 L
s
.3076 .32355 m
.30959 .30183 L
s
.32564 .26072 m
.34051 .24331 L
s
.30959 .30183 m
.31528 .28059 L
s
.31528 .28059 m
.32564 .26072 L
s
1 0 0 r
.003 w
.45026 .71689 m
.49766 .66394 L
s
.83092 .22422 m
.86982 .17235 L
s
.65909 .43252 m
.66679 .4179 L
s
.66679 .4179 m
.68125 .39045 L
s
.65644 .41523 m
.70474 .367 L
s
.77253 .29335 m
.83092 .22422 L
s
.49766 .66394 m
.55472 .58993 L
s
.61203 .50752 m
.65909 .43252 L
s
.70474 .367 m
.77253 .29335 L
s
.55472 .58993 m
.61203 .50752 L
s
0 g
.25 Mabswid
0 .09414 m
1 .10279 L
s
1 .10279 m
.95998 1.03102 L
s
.95998 1.03102 m
.04376 1.00356 L
s
.04376 1.00356 m
0 .09414 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{279.313, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004G000181000`40O003h00Oogoo67oo000cOomW
001mOol0035oo`<006IoofP001Eoo`00;goo0P000Woo00<007ooOol0bgoo0P0057oo000]Ool20004
Ool00`00Oomoo`3;Ool00`00Ool0000COol002]oo`8000Ioo`03001oogoo0<]oo`03001oo`0001=o
o`00:Goo0P0027oo00<007ooOol0bgoo00@007ooOol0019oo`009goo0P002Woo00<007ooOol0bgoo
00D007ooOomoo`00015oo`009Goo0P0037oo00<007ooOol0bgoo00<007ooOol00Woo00<007ooOol0
3Woo000SOol2000>Ool00`00Oomoo`3;Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool0025oo`80011o
o`03001oogoo0<]oo`03001oogoo00=oo`03001oogoo00eoo`007goo0P004Woo00<007ooOol0bgoo
00<007ooOol017oo00<007ooOol037oo000MOol2000DOol00`00Oomoo`3;Ool00`00Oomoo`05Ool0
0`00Oomoo`0;Ool001]oo`8001Ioo`03001oogoo0<]oo`03001oogoo00Ioo`03001oogoo00Yoo`00
6Goo0P0067oo00<007ooOol0bgoo00<007ooOol01Woo00<007ooOol02Woo000GOol2000JOol00`00
Oomoo`3;Ool00`00Oomoo`07Ool00`00Oomoo`09Ool001Eoo`8001aoo`03001oogoo0<]oo`03001o
ogoo00Qoo`03001oogoo00Qoo`004goo0P007Woo00<007ooOol0bWoo00<007ooOol02Woo00<007oo
Ool01goo000AOol2000QOol00`00Oomoo`1FOol2001aOol00`00Oomoo`0:Ool00`00Oomoo`07Ool0
00moo`8002=oo`03001oogoo05Aoo`8000031ALLi`00008006ioo`03001oogoo00]oo`03001oogoo
00Ioo`003Goo0P009Goo00<007ooOol0Dgoo00P000DH7>L55acW?OPieacW0P00K7oo00<007ooOol0
37oo00<007ooOol01Goo000;Ool2000WOol00`00Oomoo`1BOol03@007>MbBacW0AL561cW?OPieacW
BODLidgC06Yoo`03001oogoo00eoo`03001oogoo00Aoo`002Goo0P00:Goo00<007ooOol0DWoo00D0
01cWMT`55acW00855`057>Lmn1cWBOI9m@027>L00dgCCI1oo`1VOol00`00Oomoo`0>Ool00`00Oomo
o`03Ool000Moo`8002]oo`03001oogoo059oo`0D001ZUAcWMT`55acW0ALLicWG?OPLidWfBOE9mQcW
DMA=de6@CHmAT6=oo`03001oogoo00ioo`03001oogoo00=oo`001Goo0P00;Goo00<007ooOol0DWoo
010006JDMT`LigI<7>L560DG7>Lmf3gh7>M9mTWeBOHLi`==d`06CI1AT4f@DI1=T56@GWoo00<007oo
Ool03goo00<007ooOol00Woo0003Ool2000_Ool00`00Oomoo`1BOol090007>MVU7I<7>MfC1cW1APL
icgh>MLmn1cWBOI9mDWf7>MAe4gCCMA=ddd:CI1AT4f?DI1=T56@CHm=2TSYC@Y8jDd:B>U=2U=oo`03
001oogoo011oo`03001oogoo005oo`0000=oo`000000<Goo00<007ooOol0DWoo014005jg7>MVU7I<
7>L55acW1APLicgh?MPmn1cWBOI9mDWf008Li`E=d`0:DI1=T56@CI1AT4f@DI1=T56@CI03C>X01DSY
C>Y<jTcZB>T00dcZ00=8jDcZC>X0Agoo00<007ooOol04Goo0@000Goo0Goo00160013Ool0?000H[QN
]acWIY@Lig9;7>L55`DH7>Lmn3WG7>M5mDWfBOE9mTGe7>M=ddgDCM=Ae4gCCMA=Se6@CI1AT4f?DI1=
T56@CHmAT4f@DI18jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2P<`0005
=00`0300<00d0003<0001C@0<00`0300=0000c0000Dd0300<00`03@000<`0005=00`0300<00d0003
<0001C@0<00`0300=0000c0000Dd0300<00`03@000<`0005=00`0300<00d0003<0000c@0<01l000A
Ool10001Ool1Ool00003001oogoo035oo`03001oogoo00mooh/00003C>X`030002``00=l019oo`40
005oo`0000<007ooOol0<Goo00<007ooOol0Dgoo00D005[I7>LLif:h00<Li`0o1AP55acW>MLmn3WG
7>M5mDWfBOE9mTGe7>M=ddgDCM=Ae4gCCMA=de7DCM==e4f?DI1=T56@CHmAT4f@DI1=Se6@CI1AT4f?
DI1=T4d:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:04H00000
00<007ooOol0<Goo00<007ooOol0Dgoo00@001cWF]YJfPDLi`855`0:7>Liecgh?MPLidWeBOI9mDWf
BOD27>L:CM<0556@CI1AT4f@DI1=T56@CI1AT4f@DI1=T56@CI1AT4f@DI1=T4cZB>T3C>X01DSYC>Y<
jTcZB>T00dcZ00E8jDcZC>Y<jTSY00=<jP05B>U<jTcZC>Y8j@03C>X01DSYC>Y<jTcZB>T00dcZ00E8
jDcZC>Y<jTSY00=<jQ<`009l008Li`03O01oogoo019oo`40000000<007ooOol0<Goo00<007ooOol0
Dgoo00H005;l7>LLie[JF]T47>L0K@DH7>Lmn3WG?OPieacWAOE9mTWeBOI5mDWf7>M=e4gCDMA=ddgD
CM=Ae4gCCMA=de7DCI1AT4f?DI1=T56@CHmAT4f@DI1=Se6@CI1AT4f?DI1=T56@CHmAT4SYC@Y8jDd:
B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:
B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>Ul04LNBcm77W`0
01Eoo`40000000<007ooOol0<Goo00<007ooOol0E7oo00<005;lD_`00acW00=JfQcW7>L00PDG00dL
icgh>MLmn1cWBOI9mDWfBOE9mTWeBOHLi`0:CM<06EKlCM=AT4f@DI1=T56@CI1AT4f@DI1=T56@CI1A
T4f@DI1=T56@CI1AT4f@DI1=T56@009<jP05B>U<jTcZC>Y8j@03C>X01DSYC>Y<jTcZB>T00dcZ00E8
jDcZC>Y<jTSY00=<jP05B>U<jTcZC>Y8j@03C>X01DSYC>Y<jTcZB>T00dcZ00E8jDcZC>Y<jTSY00=<
jP09B>U<jTcZO017?T/nAcil000001Eoo`40000000<007ooOol0<Goo00<007ooOol0E7oo00H005Kl
D_aFoE;lE_`47>L03P4G?OPLicgh>MLmn1cWBOI5mDWfBOE9mTGeBOH27>L0G4gCDMA=ddgDCM=Ae4gC
CMA=de7D7>M=e4f?DI1=T56@CHmAT4f@DI1=Se6@CI1AT4f?DI1=T56@CHmAT4f@DI1=Se6@CI1AT4f?
C@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSY
C@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYO0177T/oAail07oo000EOol100000003
001oogoo035oo`03001oogoo05Aoo`04000LiacW7>L2D_`00eKlD_aBo0047>L03SgH?OPiecgh7>M9
mTWeBOI9mDWfBOE9mTWe7>L<CM<07AcWCM==T56@CI1AT4f@DI1=T56@CI1AT4f@DI1=T56@CI1AT4f@
DI1=T56@CI1AT4f@DI1=T56@CI000dcZ00E8jDcZC>Y<jTSY00=<jP05B>U<jTcZC>Y8j@03C>X01DSY
C>Y<jTcZB>T00dcZ00E8jDcZC>Y<jTSY00=<jP06B>U<jTcZC>Y8jDcZ0W`000A7?T/nAcil009oo`03
001oogoo01=oo`40000000<007ooOol0<Goo00<007ooOol0Dgoo0P0000=7?d<nAcl01QcW00=Bo5Kl
7>L00acW06<iecgh7>M9mTGeBOI9mDWfAOE9mTWe7>M=de7DCM==e4gCDMA=ddgDCM=Ae4gCCMA=dacW
CM=AT4f?DI1=T56@CHmAT4f@DI1=Se6@CI1AT4f?DI1=T56@CHmAT4f@DI1=Se6@CI1AT4f?DI1=T56@
B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:
B>U=2TSYC@Y8jDd:O01;?dLNBcm77T/oO0000Woo00<007ooOol04goo0@0000000`00Oomoo`0aOol0
0`00Oomoo`1COol00`007>L00008@cl87>L02Sgh7>M9mTWeBOI9mDWfBOE9mTWe0QcW3DgC02<LidgC
CI1AT4f@DI1=T56@CI1AT4f@DI1=T56@CI1AT4f@DI1=T56@CI1AT4f@DI1=T56@CI1AT4f@DI1=T56@
CI1AT4SY00=<jP05B>U<jTcZC>Y8j@03C>X01DSYC>Y<jTcZB>T00dcZ00E8jDcZC>Y<jTSY00=<jP09
B>U<jW`0Bci7?T/nAci;?W`000=oo`03001oogoo01=oo`40000000<007ooOol0<Goo00<007ooOol0
DWoo00@0047h?ML000/Li`03Acm3?TLo00LLi`1JBOI9mDWfAOE9mTWeBOHLie7DCM==e4gCDMA=ddgD
CM=Ae4gCCMA=de7DCM==e1cWDMA=T56@CHmAT4f@DI1=Se6@CI1AT4f?DI1=T56@CHmAT4f@DI1=Se6@
CI1AT4f?DI1=T56@CHmAT4f@DI1=Se6@CI1=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:B>U=2TSYC@Y8jDd:
B>U=2TSYC@Y8jDd:B>U=2W`0Bcm77T/oAai;?g`017oo00<007ooOol04goo0@0000000goo001oo`0a
Ool00`00Oomoo`1BOol01000?MLmm`002`Ig5acW34gC02QJfTgCDI1=T56@CI1AT4f@DI1=T56@CI1A
T4f@DI1=T56@CI1AT4f@DI1=T56@CI1AT4f@DI1=T56@CI1AT4f@DI1=T56@CI1AT4f@DI18j@=<jP05
B>U<jTcZC>Y8j@03C>X024SYC>Y<jTcZB>U<jW`0E_`47>L00g`0Oomoo`03Ool00`00Oomoo`0COol1
00000003Ool007oo035oo`03001oogoo059oo`037>Lmn00001`6M`@Li`<6MaLLi`0/DI1=Se6@CI1A
T4f?DI1=T56@CHmAT4f@DI1=Se6@CI1AT4f?DI1=T56@CHmAT4f@DI1=Se6@CI1AT4f?DI18jDd:B>U=
2TSYC@Y8jDd:B>U=2TSYC@Y8j@9l0006E_aBo5KlD_]Fo7`01Woo00<007ooOol04goo0@0000000goo
001oo`0aOol00`00Oomoo`1AOol01000BODLi`00>PIg5acW011AT4f@DI1=T56@CI1AT4f@DI1=T56@
CI1AT4f@C>Y8j@=<jP09B>Ul05;lE_aBo5KlD_aFo7`000Moo`03001oogoo01=oo`40000000=oo`00
Ool0<Goo00<007ooOol0DGoo00@004WDCOD006TLi`03O01Fo7`000Qoo`03001oogoo019oo`40005o
o`0000=oo`00Ool0<Goo00<007ooOol0DGoo00<Lidge0000JS`100=l05;lO00027oo00<007ooOol0
4Woo0@000Goo00000goo001oo`0aOol00`00Oomoo`1AOol00`007>L0001Y?0400g`0D_al0009Ool0
0`00Oomoo`0BOol10001Ool00003Ool007oo035oo`03001oogoo051oo`03001=/P0006Xl0@9l00Yo
o`03001oogoo019oo`40005oo`0000=oo`00Ool0<Goo00<007ooOol0D7oo00<0056b000051cWEC`1
0W`02Woo00<007ooOol04goo0@000Goo00000goo001oo`0aOol00`00Oomoo`1@Ool200004Td/B@a=
;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa930<l0B8Lic<l0@03O01oogoo00Uoo`03001oogoo
01=oo`40005oo`0000=oo`00Ool0<Goo00<007ooOol0D7oo03L004d/B@]=;4T;CBa92dd/B@]=;4T;
CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;
CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92`02?04R7>L@?0400g`0Oomoo`0:Ool00`00Oomoo`0C
Ool10001Ool00003Ool007oo035oo`03001oogoo04moo`1L001=;4T<CBa934d/B@a=;4T<CBa934d/
B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/
B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/
B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;10Li`03O01oogoo00Yoo`03001o
ogoo01=oo`40005oo`0000=oo`00Ool0<Goo00<007ooOol0CWoo00<004fA7>L011cW06I=;4T;CBa9
2dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa9
2dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa9
2dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa9
2dd/B@]=;4T;CBa92dd/O00=Ool00`00Oomoo`0COol10001Ool00003Ool007oo039oo`03001oogoo
04aoo`03001=TDf@009=T003CI5=T4f@00LLi`1OCBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/
B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/
B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/
B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@al000=Ool00`00Oomoo`0COol10001
Ool00003Ool007oo039oo`03001oogoo04]oo`0@001=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@
CI467>L0F4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa9
2dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa9
2dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa9
2g`03Woo00<007ooOol04goo0@000Goo00000goo001oo`0bOol00`00Oomoo`19Ool200001AcWCI1=
T4f@CI400df@00E=TDf@CI1=T4fA00==T006CI5=T4f@CI1=TDf@1acW051934d/B@a=;4T<CBa934d/
B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/
B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/
B@a=;4T<CBa934d/B@a=;4T<CBa937`03goo00<007ooOol04goo0@000Goo00000goo001oo`0bOol0
0`00Oomoo`16Ool300000dVcCMA9/`047>L064fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@
CI5=T4fACI1=TDf@CI5=T0LLi`18B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=
;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=
;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92g`047oo00<007ooOol04goo
0@000Goo00000goo001oo`0bOol00`00Oomoo`14Ool200002TVcCM==/dgCBK==ddfcCM=9/df@0acW
0Tf@00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03CI001DfACI1=T4f@CI400df@00==TDf@7>L0
1QcW045934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=
;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=
;4T<CBa934d/B@a=;7`0011oo`03001oogoo01=oo`40005oo`0000=oo`00Ool0<Woo00<007ooOol0
@Woo0P0000m9mQcWCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCI400acW021=TDf@CI5=T4fACI1=TDf@
CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@1acW03U92dd/B@]=
;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=
;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/O0004Goo00<007ooOol0
4goo0@000Goo00000goo001oo`0bOol00`00Oomoo`10Ool20004BMD27>L034VcCM==/dgCBK==ddfc
CM=9/dgCCK==d`9=T08Li`==T005CI5=T4f@CI1=T@03CI001DfACI1=T4f@CI400df@00E=TDf@CI1=
T4fA00==T005CI5=T4f@CI1=T@03CI000dfACI0Li`057>L0<Td/B@a=;4T<CBa934d/B@a=;4T<CBa9
34d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa9
34d/B@a=;4T<CBa934d/O00BOol00`00Oomoo`0COol10001Ool00003Ool007oo039oo`03001oogoo
03eoo`<0000HBOE5eDWfAME9mDGEBOI5eAcWBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4f@0acW
02Q=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@
CI5=T4fACI1=TDf@CI5=T4fACI1=T@LLi`0ZCBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=
;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;7`04goo00<007oo
Ool04goo0@000Goo00000goo001oo`0bOol00`00Oomoo`0iOol40002@OL00acWBME9e@07BMD04QcW
BK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM==T0<Li`==T005CI5=T4f@CI1=T@03CI001DfA
CI1=T4f@CI400df@00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03CI001DfACI1=T4f@CI400df@
00==TAcW7>L01AcW02==;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa934d/
B@a=;4T<CBa934d/B@a=;4T<CBa937`001=oo`03001oogoo01=oo`40005oo`000Woo00<007ooOol0
<7oo00<007ooOol0=Woo0P00018Lid7G@OLmeT7g@MM1mcgF7>M5eDWeAME9mTGEBOE5eDWfAMD27>L0
4TgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA=T0<Li`0`CI1=TDf@CI5=T4fACI1=TDf@
CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@
CI5=T4fACI1=TDf@CI5=T4fA1acW01]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=;4T;CBa92dd/B@]=
;4T;CBa92dd/B@]=;4T;O00057oo00<007ooOol04goo0@000Goo0002Ool00`00Oomoo`0`Ool00`00
Oomoo`0cOol30002;KT00d7g7>M1m`05@OL00acWBME9e@09BMD05AcWCM==/dgCBK==ddfcCM=9/dgC
CK==ddVcCM==/dgCBK==ddfcCM==T0037>L3CI001DfACI1=T4f@CI400df@00E=TDf@CI1=T4fA00==
T005CI5=T4f@CI1=T@03CI001DfACI1=T4f@CI400df@00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=
T@03CI000dfA7>LLi`057>L04dd/B@a=;4T<CBa934d/B@a=;4T<CBa934d/B@a=;4T<CBa937`001Eo
o`03001oogoo01=oo`40005oo`000Woo00<007ooOol0<7oo00<007ooOol0<Goo0P0001X]^2gI:KP]
fBfh@OLLid7g@MM1mcgF@OM1ed7g7>M9mTGEBOE5eDWfAME9mDGEBOI5eDWe0QcW01E9/dgCBK==e4Vc
CM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDCI000QcW03U=TDf@CI5=T4fACI1=TDf@CI5=T4fA
CI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fA
CI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI401QcW00a92dd/B@]=;4T;CBa92dd/B@]=;4T;
O00FOol00`00Oomoo`0COol10001Ool0009oo`03001oogoo031oo`03001oogoo02moo`80000303<L
ibfi008]^@05;KP]^Bfi@OLLi`07@OL00acWBME9e@0:BMD05acWCK==ddVcCM==/dgCBK==ddfcCM=9
/dgCCK==ddVcCM==/dgCBK==ddfcCI400acW00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03CI00
1DfACI1=T4f@CI400df@00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03CI001DfACI1=T4f@CI40
0df@00E=TDf@CI1=T4fA00==T004CI5=T4f@CI077>L01DT<CBa934d/O0005Woo00<007ooOol04goo
0@000Goo0002Ool00`00Oomoo`0`Ool00`00Oomoo`0]Ool200008@0b03<0<RgI7>L]fBfh;MTY^2gI
;KQ1macW@OM1ed7g?MI1md7G@OLLidWfAME9mDGEBOI5eDWeAME9mTGEBOE5e@027>L05dgCBK==e4Vc
CM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCI400acW041=TDf@CI5=T4fACI1=TDf@
CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@
CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T0<Li`03O01o
ogoo01Eoo`03001oogoo01=oo`40005oo`000Woo00<007ooOol0<7oo00<007ooOol0:goo0P0000P0
<`0b03<0<P0c038Libfh0bfi00@]^2fi;KTLi`Q1m`037>M9eDWE00]9e@0J7>M=ddVcCM==/dgCBK==
ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==T@<Li`05CI5=T4f@CI1=T@03CI001DfA
CI1=T4f@CI400df@00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03CI001DfACI1=T4f@CI400df@
00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03CI001DfACI1=T4f@CI400Tf@00=l07ooOol05Woo
00<007ooOol04goo0@000Goo0002Ool00`00Oomoo`0`Ool00`00Oomoo`0ZOol0A@00LT`Li`0b03<0
<P0c0380<`0b7>LY^2gI;KP]fBVh;MU1eacW?MI1md7G@OLmeT7g@MM1macWBOI5eDWeAME9mTGEBOE5
eDWfAME9mDGEBOHLidgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9
/dgCBK==T@037>L0?4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=
T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=
T4fACI1=TDf@CI5l01Uoo`03001oogoo019oo`40005oo`5oo`000Woo00<007ooOol0<7oo00<007oo
Ool0:7oo0P000W9<00]ooacW0380<`0b03<0<P0c7>L]^Bfh00<]^@04;KP]^D7g7>L8@OL00acWBME9
e@0;BMD27>L074VcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVc
CM==/dfA0QcW00==T4fACI000Tf@00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03CI001DfACI1=
T4f@CI400df@00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03CI001DfACI1=T4f@CI400df@00A=
TDf@CI1l01Yoo`03001oogoo019oo`40005oo`5oo`000Woo00<007ooOol0<7oo00<007ooOol09goo
00<007I=LT`00W9<04QfCAcW03<0<P0c0380<`0b03<LibgI:KP]fBfh;MTY^2gI7>M1mcgF@OM1ed7g
?MI1md7G@OLLidWfAME9mDGEBOI5eDWeAME9mTGEBOE5eDWfAMDLidVcCMA9/dgCBK==e4VcCM=9/dgD
BK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK<37>L0=Tf@CI5=T4fACI1=TDf@CI5=
T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=
T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1l01Yoo`03001oogoo019oo`40005oo`5oo`000Woo
00<007ooOol0<7oo00<007ooOol09Woo00<0079<LT`01G9<00PLi`0c0380<`0b03<0<QcW0Rfi00L]
^2fi;KT]^Bfh@OLLi`09@OL00acWBME9e@0<BMD27>L07TgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgC
CK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==T0<Li`03CI1=TDf@009=T005CI5=T4f@CI1=
T@03CI001DfACI1=T4f@CI400df@00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03CI001DfACI1=
T4f@CI400df@00E=TDf@CI1=T7`001]oo`03001oogoo019oo`40005oo`5oo`000Woo00<007ooOol0
<7oo00<007ooOol09Goo00<006ZELT`00W9<051fCG9<LTabC7I=7>L0<`0b03<0<P0c038Libfh;MTY
^2gI;KP]fBVh@OLLid7g?MI1md7G@OLmeT7g@MM1macWBOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5
eDWe7>M=e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9
/dgDBK==ddf@0acW02i=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@
CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1l01aoo`03001oogoo019o
o`40005oo`5oo`000Woo00<007ooOol0<7oo00<007ooOol097oo00@006JDIYAVU0MbC009OolLi`0c
0380<`0b03<0<QcW008]^@06;KP]^Bfi;KT]^1cW2T7g00<LidWEBMD03DWE0QcW025=/dgCBK==ddfc
CM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCI000QcW
0Tf@00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03CI001DfACI1=T4f@CI400df@00E=TDf@CI1=
T4fA00==T005CI5=T4f@CI1=T@03CI000g`0Oomoo`0KOol00`00Oomoo`0BOol10001Ool1Ool0009o
o`03001oogoo031oo`03001oogoo02Aoo`05001VU6ZEIYAfC@03LT`0DgI=LTabC79<7>L0<P0c0380
<`0b03<LibgI;KP]fBVh;MT]^2gI:KPLid7G@OLmeT7g@MM1mcgF@OM1ed7g7>M9mTGEBOE5eDWfAME9
mDGEBOI5eDWeAME9mTGEBOE5eAcWBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==
e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM<00acW02M=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=
TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@O0007Woo00<0
07ooOol04Woo0@000Goo0Goo0002Ool00`00Oomoo`0`Ool00`00Oomoo`0SOol00`00IYAVU003IY@8
LT`021cW0380<`0b03<0<P0c7>L3;KT01Rfh;KT]^Bfi@OLLi`Y1m`037>M9eDWE00i9e@8Li`0SCM=9
/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==
/dgCBK==d`037>L2CI001DfACI1=T4f@CI400df@00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03
CI001DfACI1=T4f@CI400df@0W`07Woo00<007ooOol04Woo0@000Goo0Goo0002Ool00`00Oomoo`0`
Ool00`00Oomoo`0ROol02@00IYAZUFJDJYEVU6ZEIYAfC@03LT`0EgI=LTabC00b7>L0<P0c0380<`0b
03<LibgI;KP]fBVh;MT]^2gI7>M1md7G@OLmeT7g@MM1mcgF@OM1ed7g7>M9mTGEBOE5eDWfAME9mDGE
BOI5eDWeAME9mTGEBOE5eDWf7>M=ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4Vc
CM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==d`037>L084fACI1=TDf@CI5=T4fACI1=TDf@
CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fAO00NOol00`00Oomoo`0COol1
0001Ool1Ool0009oo`03001oogoo031oo`03001oogoo025oo`03001N^6JD00MVU0MbC0097>L0<`0b
03<0<P0c038Libfh00<]^@05;KP]^Bfi;KTLi`0;@OL00acWBME9e@0?BMD27>L09TVcCM==/dgCBK==
ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==
ddVcCI037>L2CI001DfACI1=T4f@CI400df@00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03CI00
0dfAO01oo`0NOol00`00Oomoo`0COol10001Ool1Ool0009oo`03001oogoo031oo`03001oogoo025o
o`0<001R^5jgJYEVU6ZEIYAZUFJDJYEVU7I=0g9<05]fCG9<LT`Li`0c0380<`0b03<0<QcW:KP]fBfh
;MTY^2gI;KP]fAcW@OM1ed7g?MI1md7G@OLmeT7g@MM1macWBOI5eDWeAME9mTGEBOE5eDWfAME9mDGE
BOI5eDWeAME9mTGE7>M9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4Vc
CM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==T@027>L064f@CI5=T4fACI1=TDf@CI5=T4fA
CI1=TDf@CI5=T4fACI1=TDf@CI5=T4fACI1=T@9l01moo`03001oogoo01=oo`40005oo`5oo`000Woo
00<007ooOol0<7oo00<007ooOol087oo00<005jhG[P00Ujh1fJD1g9<00X0<acW03<0<P0c0380<`0b
7>L]^0<]^@04;KP]^Bfi7>L<@OL00acWBME9e@0@BMD27>L0:4gCCK==ddVcCM==/dgCBK==ddfcCM=9
/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVc0acW
0df@00E=TDf@CI1=T4fA00==T005CI5=T4f@CI1=T@03CI000dfAO01l000POol00`00Oomoo`0COol1
0001Ool1Ool0009oo`03001oogoo031oo`03001oogoo021oo`0?001N]f:hG[MR^5jgJYEVU6ZEIYAZ
UFJDJYEbC7I=00=bC01NMTebC1cW0380<`0b03<0<P0c7>L]fBVh;MT]^2gI:KP]fBfh7>LmeT7g@MM1
mcgF@OM1ed7g?MI1md7G@OLLidWfAME9mDGEBOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5eDWe7>M=
e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==
ddVcCMA9/dgCBK==e4VcCM=9/dgDBK<37>L044f@CI5=T4fACI1=TDf@CI5=T4fACI1=TDf@CI5=T4fA
0W`08Goo00<007ooOol04goo0@000Goo0Goo0002Ool00`00Oomoo`0`Ool00`00Oomoo`0OOol00`00
G[QN^005G[P7IY@7LT`02QcW0380<`0b03<0<P0c7>L]^Bfh0bfi00@]^2fi;KTLi`a1m`037>M9eDWE
0159e@8Li`0[CK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==
ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK<00acW0df@00E=TDf@CI1=T4fA00==T003
CI5l07`0029oo`03001oogoo01=oo`40005oo`5oo`000Woo00<007ooOol0<7oo00<007ooOol07goo
018001cW7>LLiejgH[QN]f:hG[MR^6JDJYEVU6ZEIYAZUG9<MTd3LT`0HWI=LT`Li`0b03<0<P0c0380
<acW;MTY^2gI;KP]fBVh;MTLid7g?MI1md7G@OLmeT7g@MM1mcgF@OM1ed7g7>M9mTGEBOE5eDWfAME9
mDGEBOI5eDWeAME9mTGEBOE5eDWfAME9mDGE7>M9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==
e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK<3
7>L02Df@CI5=T4fACI1=TDf@CI5=T002O00ROol00`00Oomoo`0COol10001Ool1Ool000=oo`03001o
ogoo02moo`03001oogoo01moo`04001FnejhG[P27>L5G[P6IY@6LT`0200b7>L0<P0c0380<`0b7>L2
;KT01bfh;KT]^Bfi;KP]^AcW00e1m`037>M9eDWE0199e@8Li`0^CM=9/dgCCK==ddVcCM==/dgCBK==
ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==
ddVcCM==/dgCCI027>L01TfACI1=T4f@CI5=T09l02=oo`03001oogoo01=oo`40005oo`5oo`000goo
00<007ooOol0;goo00<007ooOol07goo00H005[kE]YJnejgH[P27>L035jgH[QN]f:hIYAZUFJDJYEV
U6ZELTafC@=bC01UMTdLi`0c0380<`0b03<0<QcW;KP]fBVh;MT]^2gIIY@]fAcW@OLmeT7g@MM1mcgF
@OM1ed7g?MI1md7G@OLLidWfAME9mDGEBOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5eDWeAME9mQcW
CM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVc
CMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e0037>L014fACI1l07`097oo00<007ooOol0
4goo0@000Goo0Goo0003Ool00`00Oomoo`0`Ool00`00Oomoo`0MOol01000E_]Fne[k0eKk00=Jnejh
7>L00QcW0Ujh1FJD1g9<00PLi`0c0380<`0b03<]^1cW0Rfi00L]^2fi;KT]^Bfh;KTLi`0<@OL00acW
BME9e@0DBMD27>L0=4VcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==
ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==dacWO01Ffg`097oo
00<007ooOol04goo0@000Goo0Goo0003Ool00`00Oomoo`0`Ool00`00Oomoo`0MOol03000E]YJneKK
F_]FfU[kE]]JneKJH[QN]`8Li`06H[QVU6ZEIYAZUFJD0W9<03YfCG9<LTabC00c7>L0<`0b03<0<P0c
7>L]fBfh;MTY^2gI;KP]fBVh7>M1ed7g?MI1md7G@OLmeT7g@MM1mcgF@OM1eacWAME9mTGEBOE5eDWf
AME9mDGEBOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5e@8Li`0aCMA9/dgCBK==e4VcCM=9/dgDBK==
ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==
e4VcCM=9/dgDBK=l01cWO0009Goo00<007ooOol04goo0@000Goo0Goo0003Ool00`00Oomoo`0`Ool0
0`00Oomoo`0MOol00`00F_]Fn`02E_/01E[kE_]FneKkF_/00eKk00=N^1cW7>L01FJD1W9<00PLi`0b
03<0<P0c0380<acW0bfi00H]^2fi;KUVUBfh7>L=@OL00acWBME9e@0FBMD0<1cWCM==/dgCBK==ddfc
CM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVc
CM==/dgCBK==ddfcCM=9/g`0F[Ul02Ioo`03001oogoo01=oo`40005oo`5oo`000goo00<007ooOol0
<7oo00<007ooOol07Goo010001cW7>MFfU[kE]]JneKJF_]Ffe[kE]YJneKKF_]N]`8Li`04JYEVU6ZE
IY@2LT`0>gI=LTabC79<7>L0<P0c0380<`0b7>LY^2gI;KP]fBVh;MT]^2gI:KPLid7G@OLmeT7g@MM1
mcgF@OM1ed7g?MI1md7G7>M5eDWfAME9mDGEBOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5eDWeAME9
mTGEBOD00QcW02e9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9
/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcO01J^E[JO0009Woo00<007ooOol04goo0@00
0Goo0Goo0003Ool00`00Oomoo`0`Ool00`00Oomoo`0MOol00`00Acm7?P057>L3E_/01E[kE_]FneKk
F_/00UKk16JD1g9<00PLi`0b03<0<P0c038Libfh0bfi00H]^2fi;KT]^D7g7>L=@OL00acWBME9e@0G
BMD0;1cWCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVc
CM==/dgCBK==ddfcCM=9/dgCCK==ddVcO01J^EZjO00WOol00`00Oomoo`0COol10001Ool1Ool000=o
o`03001oogoo031oo`03001oogoo01eoo`080017?T/oAci7?dLnBcm7?PHLi`09F_]Ffe[kE]YJnfJD
JYEVU6ZE00=bC00lMTebC79<038Li`0b03<0<P0c7>L]fBVh;MT]^2gI:KP]fFJD;MTLid7g@MM1mcgF
@OM1ed7g?MI1md7G@OLmeT7g@MLLidGEBOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5eDWeAME9mTGE
BOE5eDWfAME9mDGE0QcW02Q=ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9
/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK=l05ZiF]Yl02Qoo`03001oogoo01=oo`40005oo`5o
o`000goo00<007ooOol0<7oo00<007ooOol077oo00l004LnAcm7?TLoAci7?dLnAcm7?TLoAci7?dLn
Acl01AcW0UKk0fJD1W9<00TLi`0c0380<`0b03<Libfi;KP00bfi00D]^2fi;KT]^AcW00e1m`03HYHL
idWE01U9e@0X7>M=ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==
ddVcCM==/dgCBK==ddfcCM=9/dgCO01J^UZiO00XOol00`00Oomoo`0BOol00`00Oomoo`01Ool000=o
o`03001oogoo031oo`03001oogoo01aoo`0D001;?dLnAcm7?T/oAci7?dLnBcm7?TLoAci;?dLnAcm7
?T/oAci7?`DLi`05JYEbC79<LTafC@02LT`0>QcW03<0<P0c038Libfh;MTY^2gI;KP]fBVh;MT]^47g
7>M1md7G@OLmeT7g@MM1mcgF@OM1ed7g?MI1md7G7>M5eDWfAME9mDGEBOI5eDWeAME9mTGEBOE5eDWf
AME9mDGEBOI5eDWeAME9mTGEBOE5eDWf0QcW02A9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==
ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCO01JfUZiO00YOol00`00Oomoo`0BOol00`00
Oomoo`01Ool000=oo`03001oogoo031oo`03001oogoo01aoo`0I0017?TLoAci7?dLnAcm7?TLoAci7
?dLnAcm7?TLoAci7?dLnAcm7?TLoAci7?dLnAcl00acW179<00L0<acW03<0<P0c038Li`02;KT022fh
;KT]^Bfi;KQVUBfi7>L?@OL00acWBME9e@0IBMD08acWBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==
ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCO01J^UZiO000:Woo00<007ooOol04Woo00<0
07ooOol00Goo0003Ool00`00Oomoo`0`Ool00`00Oomoo`0LOol00`007>LLi`0:7>L03dLoAci;?dLn
Acm7?T/oAci7?dLnBcm7?TLoAcifC@03LT`0?WI=LT`0<acW03<0<P0c038Libfh;MTY^2gI;KP]fBVh
;MT]^1cW?MI1md7G@OLmeT7g@MM1mcgF@OM1ed7g?MI1md7G7>M5eDWfAME9mDGEBOI5eDWeAME9mTGE
BOE5eDWfAME9mDGEBOI5eDWeAME9mTGEBOE5eDWfAMD27>L084gDBK==ddVcCMA9/dgCBK==e4VcCM=9
/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==dg`0F]YJ^E[JO00ZOol00`00Oomoo`0BOol00`00
Oomoo`01Ool000=oo`03001oogoo031oo`03001oogoo01aoo`T00004Aci7?dLnAcl87>L01dLnAcm7
?TLoAci7?dLn00IbC0067>L0<P0c0380<acW0bfi00D]^2fi;KT]^Bfh008]^@037>M1md7g00e1m`03
7>M9eDWE01Y9e@0L7>M=ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgC
BK==dg`0F[X2F[T00g`0Oomoo`0YOol00`00Oomoo`0BOol00`00Oomoo`01Ool000=oo`03001oogoo
031oo`03001oogoo01aooaD000lLi`0l0380<`0b03<LibgI;KP]fBVh;MT]^2gI:KP]fAcW@OLmeT7g
@MM1mcgF@OM1ed7g?MI1md7G@OLmeT7g7>M9mDGEBOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5eDWe
AME9mTGEBOE5eDWfAME9mDGEBOI5eDWe0QcW01a9/dgCBK==e4VcCM=9/dgDBK==ddVcCMA9/dgCBK==
e4VcCM=9/dgDBK==dg`0F]YJ^E[JF[Ul02]oo`03001oogoo019oo`03001oogoo005oo`000goo00<0
07ooOol0<7oo00<007ooOol077oo900000H0<`0b03<0<P0c7>L3;KT01bfh;KT]^Bfi;KP]^AcW00m1
m`037>M9eDWE01a9e@0G7>M=/dgCBK==ddfcCM=9/dgCCK==ddVcCM==/dgCBK==ddfcCM=9/dgCO01J
^P03F[T00g`0Oomoo`0ZOol00`00Oomoo`0BOol00`00Oomoo`01Ool000=oo`03001oogoo031oo`03
001oogoo01aoobD0000n03<0<P0c038LibVh;MT]^2gI:KP]fBfh;MTY^2gI7>M1mcgF@OM1ed7g?MI1
md7G@OLmeT7g@MM1mcgF@OLLidWeAME9mTGEBOE5eDWfAME9mDGEBOI5eDWeAME9mTGEBOE5eDWfAME9
mDGEBOI5eDWeAME9mTGEBOE5e@8Li`0GCM=9/dgDBK==ddVcCMA9/dgCBK==e4VcCM=9/dgDBK==dg`0
F]YJ^E[JF[Ul000]Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000=oo`03001oogoo031oo`03001o
ogoo01aoobD000070380<`0b03<0<QcW;KP00bfi00H]^2fi;KT]^Bfh7>L@@OL00acWBME9e@0LBMD0
4dgC7>M=ddVcCM==/dgCBK==ddfcCM=9/dgCCK==ddVcCM=l05Zj00=J^@03F[Yl07oo02aoo`03001o
ogoo019oo`03001oogoo005oo`000goo00<007ooOol0<7oo00<007ooOol077oo00<001cW7>L0;1cW
03L]fBVh;MT]^2gI:KPLid7G@OLmeT7g@MM1mcgF@OM1ed7g?MI1md7G@OLmeT7g7>M9mDGEBOI5eDWe
AME9mTGEBOE5eDWfAME9mDGEBOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5eDWeAME9mP027>L04dVc
CMA9/dgCBK==e4VcCM=9/dgDBK==dg`0F]YJ^E[JF[UJfW`002ioo`03001oogoo019oo`03001oogoo
005oo`000goo00<007ooOol0<7oo00<007ooOol077oo03800413@4A0@d14@4=0A413@4A0@d14@4=0
A413@4A0@d14@4=0A413@4A0@d14@4=0A413@4A0@d14@4=0A413@4A0@d14@4=0A413@4A0@d14@4=0
A413@4A0@d14@4=0A4130bfi00<]^1cW@OL03d7g00<LidWEBMD07DWE00i=/acWBK==ddfcCM=9/dgC
CK==ddVcCM==/g`00eZi00=J^W`0Ool0;Woo00<007ooOol04Woo00<007ooOol00Goo0003Ool00`00
Oomoo`0`Ool00`00Oomoo`0LOol0J@00A4A0@dA4@4=4A413A4A0@dA4@4=4A413A4A0@dA4@4=4A413
A4A0@dA4@4=4A413A4A0@dA4@4=4A413A4A0@dA4@4=4A413A4A0@dA4@4=4A413A4A0@dA4@4<]fBfh
;MTY^2gI;KP]fAcW@OM1ed7g?MI1md7G@OLmeT7g@MM1mcgF@OM1ed7g?MI1macWBOE5eDWfAME9mDGE
BOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5e@027>L02TgD
BK==ddVcCMA9/dgCBK=l05jh0QcW00=JfUZiO000;goo00<007ooOol04Woo00<007ooOol00Goo0003
Ool00`00Oomoo`0`Ool00`00Oomoo`0LOol0<000@4=0A413@4A0@d14@4=0A413@4A0@d14@4=0A413
@4A0@d14@4=0A413@4A0@d14@4=0A413@4A0@d14@4=0A413@4A0@d14@4=0A413@4A0@d14@4=0A413
@4A0@`<]^@05;KP]^Bfi;KTLi`0>@OL01414@OM1macW84WE00U=dacWCM==/dgCBK==ddfcO00015jh
0QcW<7oo00<007ooOol04Woo00<007ooOol00Goo0004Ool00`00Oomoo`0_Ool00`00Oomoo`0LOol0
LP00A4A0@dA4@4=4A413A4A0@dA4@4=4A413A4A0@dA4@4=4A413A4A0@dA4@4=4A413A4A0@dA4@4=4
A413A4A0@dA4@4=4A413A4A0@dA4@4=4A413A4A0@dA4@4=4A2Vh;MT]^2gI:KP]fBfh;MTLid7g@MM1
mcgF@OM1ed7g?MI1md7G@OLmeT7g@MM4A3gF@OLLidWeAME9mTGEBOE5eDWfAME9mDGEBOI5eDWeAME9
mTGEBOE5eDWfAME9mDGEBOI5eDWeAME9mTGEBOE5eDWfAME9mAcWCMA9/dgCBK=l009N^004F[MN^5jh
O00`Ool00`00Oomoo`0COol00`00Oomoo`01Ool000Aoo`03001oogoo02moo`03001oogoo01aoo`0f
0010@d14@4=0A413@4A0@d14@4=0A413@4A0@d14@4=0A413@4A0@d14@4=0A413@4A0@d14@4=0A413
@4A0@d14@4=0A413@4A0@d14@4=0A413@4A0@d14@4=0A413@4A0@bfi@4<]^Bfh0Rfi00<Lid7g@OL0
3D7g00A0A47g@OLLib59e@8Li`03CK=l05jh00AN^003O01oogoo02moo`03001oogoo01=oo`03001o
ogoo005oo`0017oo00<007ooOol0;goo00<007ooOol077oo00<001cW7>L051cW05U4A413A4A0@dA4
@4=4A413A4A0@dA4@4=4A413A4A0@dA4@4=4A413A4A0@dA4@4=4A413A4A0@dA4@4=4A413A4A0@acW
?MI1md7G@OLmeT7g@MM1mcgF@OM1ed7g?MI1md7G@OLmeT7g7>M9mDGEBOI5eDWeAME9mTGEBOE5eDWf
AME9mDGEBOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5eDWeAME9mTGEBOE5eG`0009N^004F[MN^5jh
O00bOol00`00Oomoo`0COol00`00Oomoo`01Ool000Aoo`03001oogoo02moo`03001oogoo01aoo`0A
001=;De=CBe=CDd]Oom=;De=CBe=CDd]CDe=;De=CBe=C@06C>TW7>L?@OL00acWBME9e@0NBMD00g`0
G[QN^003G[P00g`0Oomoo`0aOol00`00Oomoo`0COol00`00Oomoo`01Ool000Aoo`03001oogoo02mo
o`03001oogoo01aoo`0n001=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>C>U=CDT]CDi9
;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9
;De>BBe=CDT]CDi9;De=BBe=CPDLi`0[@OLmeT7g@MM1mcgF@OM1ed7g?MI1macWBOE5eDWfAME9mDGE
BOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5eDWeAME9mTGEBOE5eDWfG[Q9mDGEO0000Ujh00EJ]ejh
G[QN^7`003=oo`03001oogoo01=oo`03001oogoo005oo`0017oo00<007ooOol0;goo00<007ooOol0
6goo04@004e=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=
CDd]CDe=;DcYCBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=
CDd]CDe=;De=CBe=CDd]CDe=;De=347g00<LidWEBMD05DWE00=0@dWEBMD00TWE00=l05jhG[P015jh
00=l07ooOol0<Woo00<007ooOol04goo00<007ooOol00Goo0004Ool00`00Oomoo`0_Ool00`00Oomo
o`0KOol0K@00BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=
CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9;@0c039=CDT]CDi9;De=BBe=
CTT]CDe9;De>BBe=CDT]CDi9;De=BBe1md7G@OLmeT7g@MM1mcgF@OM1ed7g?MI1macWBOE5eDWfAME9
mDGEBOI5eDWeAME9mTGEBOE5eDWfAME9mDGEBOI5eDWeAME9mTGEBOE5eG`0009N^005F[MN^5jhG[Ql
000eOol00`00Oomoo`0COol00`00Oomoo`01Ool000Aoo`03001oogoo02moo`03001oogoo01]oo`17
001=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=
CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=
CBe=CDd]CDe=;De=CBe=CDd]CDe=;@0;@OL00acWBME9e@0>BMD00de=BME9e@05BMD00g`0G[QN^004
G[P00g`0Oomoo`0dOol00`00Oomoo`0COol00`00Oomoo`01Ool000Aoo`03001oogoo02moo`03001o
ogoo01]oo`1Y000LiacW7>M=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9
;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9
;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]@OM9;D7g@MM1mcgF@OM1ed7g?MI1macWBOE5
eDWfAME9mDGEBOI5eDWeAME9mTT]CDe5eDWfAME9mDGEBOI5eDWe009l009N^005F[MN^5jhG[Ql000g
Ool00`00Oomoo`0COol00`00Oomoo`01Ool000Aoo`03001oogoo02moo`03001oogoo01]oo`04001=
TDfACI487>L0@Dd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]
CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]
CDe=;De=CBe=CDd]CDe=;D7gCBd01d7g00<LidWEBMD01TWE00==CDd]BMD024WE0W`01Ujh00=l07oo
Ool0=Woo00<007ooOol04goo00<007ooOol00Goo0004Ool00`00Oomoo`0_Ool00`00Oomoo`0JOol0
3@00CI99TDfABI5=TTVACI59TDfBBI5=TDVA00PLi`1CCDi9;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9
;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9
;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe1mdT]@OM1ed7g?MHLidGEBOE5eDWfAME9mDT]BOI5
eDWeAME9mTGEBOE5eDWfAME9m@02O002G[P01EZgG[QN^5jhO000>Goo00<007ooOol04goo00<007oo
Ool00Goo0004Ool00`00Oomoo`0_Ool00`00Oomoo`0JOol00`00CI5=T@0BCI487>L0=Dd]CDe=;De=
CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=
CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBd0147g00<LidWEBMD03TWE0W`01Ujh
00=l07ooOol0>7oo00<007ooOol04Woo00<007ooOol00Woo0004Ool00`00Oomoo`0_Ool00`00Oomo
o`0IOol07P00BI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=
TDVACI99T@PLi`16CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]
CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]@OLmeQcWAME9mDGE
BOI5eDWeAME9mTGEBOE5eDWfAME9mG`0CDil05jhF[L3G[P00eZgO01oo`0iOol00`00Oomoo`0BOol0
0`00Oomoo`02Ool000Aoo`03001oogoo02moo`03001oogoo01Uoo`03000LidfA02==T@PLi`0]CBe=
CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe1mde=CBe=
CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]00]9e@04O01=CG`07>L5G[P00g`0Oomoo`0iOol00`00
Oomoo`0BOol00`00Oomoo`02Ool000Aoo`03001oogoo031oo`03001oogoo01Qoo`030019/acW008L
i`0YBI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59
TDfBBI5=TDVACI99TDfABI5=TTVACI59T@087>L0=4e>BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=
CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=CDT]CDi5eDWeAME9
mTGEBOEl04e>BBel05jF0QcW00=N^5ZgO000?7oo00<007ooOol04Woo00<007ooOol00Woo0004Ool0
0`00Oomoo`0`Ool00`00Oomoo`0GOol01000BKA9]4Vc0TVd0acW0TfA00=FfTfACI40:DfA2QcW02i=
;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=
;De=CBe=CDd]CDel04e=CBel06:FHYMRUV:G7>Ml03eoo`03001oogoo019oo`03001oogoo009oo`00
17oo00<007ooOol0<7oo00<007ooOol05goo00T004WDBK=9e4VcBMA9/dWDBK<00acW03E9TDfBBI5=
TDVACI9FfTfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TEKKBI5=TDVACI99TDfABI5=
TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TDVA00XLi`0SCDe9;De>BBe=CDT]CDi9
;De=BBe=CTT]CDe9;De>BBe=CDT]CDi9;De=BBe=CTT]CDe9;De>BBe=CG`0HYMNUV:GGYIl000nOol0
0`00Oomoo`0BOol00`00Oomoo`02Ool000Aoo`03001oogoo031oo`03001oogoo01Moo`030019/dVd
0099]005BK=9]4VdBKA9/`02BK@47>L8CI400eKKOom=T@0HCI400cgGCI5=T@0DCI400de=7>LLi`07
7>L06De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=CBe=CDd]CDe=;De=O01RUf:FHYMRUW`003moo`03
001oogoo019oo`03001oogoo009oo`0017oo00<007ooOol0<7oo00<007ooOol05Woo014004VcBMA9
/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWD00<Li`11CI99TDfABI5=TTVACI59TDfBBI5=TE;JOom9
TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59
TDfBBI4]fDVACI99TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABBe=CP077>L04De>BBe=CDT]CDi9
;De=BBe=CTT]CDe9;G`0GYIRUejFO000@7oo00<007ooOol04Woo00<007ooOol00Woo0004Ool00`00
Oomoo`0`Ool00`00Oomoo`0FOol27>L2BK@01DVcBKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]0<L
i`m=T@03OomFfdfA039=T@03CDdLiacW00HLi`08CBe=CDd]O01RUV:GHYIl045oo`03001oogoo019o
o`03001oogoo009oo`0017oo00<007ooOol0<7oo00<007ooOol05Goo00<004GFBK<00QcW01=9e4Vc
BMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e0037>L0BTfBBI5=TDVACI99TDfABI5=TTVA
CI59TDfBBI5=TDVACI99TEKKD]YFfdVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TDVA
CI99TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVA
CI59TDfBBI437>L017`0HYMNUW`0@Woo00<007ooOol04Woo00<007ooOol00Woo0005Ool00`00Oomo
o`0_Ool00`00Oomoo`0DOol01P00AME5eDGFAME9]08Li`05BK=9]4VdBKA9/`03BK@01DVcBKA9]4Vd
BK<00dVd00A9/dVdBKA9]0<LiaI=T@=Ffc1=T@05O01RUf:FHYMl0012Ool00`00Oomoo`0BOol00`00
Oomoo`02Ool000Eoo`03001oogoo02moo`03001oogoo01=oo`0P0015eT7EAMI1eDGF@ME5eTVc7>M9
/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e0@Li`19BI5=TDVACI99TDfA
BI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfB>MLmf79<MTe9TDfABI5=TTVACI59TDfB
BI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfA
BI5=TTVAO01NUV:GO000@goo00<007ooOol04Woo00<007ooOol00Woo0005Ool00`00Oomoo`0_Ool0
0`00Oomoo`0BOol01000AME5eDGF0dGE00A5eTGEAME9]08Li`=9]005BK=9]4VdBKA9/`03BK@01DVc
BKA9]4VdBK<00dVd00E9/dVdBKA9]5Zi00<Liai=T@8]^B5=T@04O01RUV:GO014Ool00`00Oomoo`0B
Ool00`00Oomoo`02Ool000Eoo`03001oogoo02moo`03001oogoo015oo`0>000meacWAMI1eDGF@ME5
eT7EAMI1eDGF@ME9e08Li`0IBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4Vc
BMA9/dWDBK<00acW0459TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TDVA
CI99TDfABI5=TTVACI59TDfB;KP]fBVh;MU9TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVA
CI59TDfBBI5=TDVACI99TF:GO01RUg`004Eoo`03001oogoo019oo`03001oogoo009oo`001Goo00<0
07ooOol0;goo00<007ooOol03goo0P000SWG00DmeacWAME5eDGF00=5e@07AMI5eDGEAME5eTVc7>L0
0TVd00E9/dVdBKA9]4Vc00=9]005BK=9]4VdBKA9/`03BK@01DVcBKA9]4VdBK<00dVd00A9/acW7>LL
ibE=T@91ma9=T@04HYMl06:GO016Ool00`00Oomoo`0BOol00`00Oomoo`02Ool000Eoo`03001oogoo
02moo`03001oogoo00ioo`0D000iecgG>MLmecWG?MLLidGF@ME5eT7EAMI1eDGF@ME5eT7EAMI9/`8L
i`0LBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK<3
7>L0>DVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfB
BI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TCgFCI99TDfABI5=TTVACI59TDfBBI5=TG`0HYMl0017
Ool00`00Oomoo`0BOol00`00Oomoo`02Ool000Eoo`03001oogoo02moo`03001oogoo00aoo`8000<i
e`06?MLiecWG>MLmeacW0TGE00E5eTGEAME5eDGF00=5e@03AMI5eDVd008Li`05BK=9]4VdBKA9/`03
BK@01DVcBKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]005BK=9]4VdBKA9/`037>LbCI400f:FO01l
0018Ool00`00Oomoo`0BOol00`00Oomoo`02Ool000Eoo`03001oogoo02moo`03001oogoo00Yoo`80
000j9ITUV1cW>MLmecWG?MLiecgG>MLmeacWAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EBMA9/acWBK=9
e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK<4
7>L0;TfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVA
CI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TEjF0W`0B7oo00<007ooOol04goo00<007oo
Ool00Woo0005Ool00`00Oomoo`0_Ool00`00Oomoo`07Ool300000bFH9ITUV0029IP01AcW>MLiecWG
?ML00cWG00DmeacWAME5eDGF00=5e@05AMI5eDGEAME5eP02AMD00dVd7>LLi`03BK@01DVcBKA9]4Vd
BK<00dVd00E9/dVdBKA9]4Vc00=9]005BK=9]4VdBKA9/`03BK@01TVcBKA9]4VdBK=J^@<LibY=T@03
O01RUW`004Qoo`03001oogoo01=oo`03001oogoo009oo`001Goo00<007ooOol0;goo00<007ooOol0
1Goo0P000P1d020LibFI9IPUVBFH9ITLicgG>MLmecWG?MLiecgG>MLmeacWAMI1eDGF@ME5eT7EAMI1
eDGF@ME5eT7EAMI1eDWD0QcW0299/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWD
BK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=J^@<Li`0WCI59TDfBBI5=TDVACI99TDfABI5=TTVACI59
TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TAcW009l04Uoo`03
001oogoo01=oo`03001oogoo009oo`001Goo00<007ooOol0;goo00<007ooOol00goo0P00101d00DL
ibFH9IPUV2FI008UV0037>LmecWG008ie`06?MLiecWG>MLmeacW0TGE00E5eTGEAME5eDGF00=5e@07
AMI5eDGEAME9]4Vc7>L00TVd00E9/dVdBKA9]4Vc00=9]005BK=9]4VdBKA9/`03BK@01DVcBKA9]4Vd
BK<00dVd00E9/dVdBKA9]4Vc00=9]003BK=9]1cW008Lib==T@9l04Yoo`03001oogoo01=oo`03001o
ogoo009oo`001Goo00<007ooOol0;goo00@007ooOomoo`8000037>L0M@1d0080M00T07D0M1cW9IPU
VBFH9ITUV2FI7>LmecWG?MLiecgG>MLmecWG?MLLidGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5
eTVc0QcW02E9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4Vc
BMA9/dWDBK=9e4VcBMA9/dWDBK=9e0037>L08DfABI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVA
CI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfBIYAl001;Ool00`00Oomoo`0COol00`00Oomoo`02
Ool000Eoo`03001oogoo02moo`04001oo`000003LND707@01AcW9IPUV2FH9IT00RFH00<LicgG>ML0
0SWG00HmecWG>MLiecgG7>L2AMD01DGFAME5eDGEAMH00dGE00Y5eTGEAME5eDGFAME9]1cWBKA9/`=9
]005BK=9]4VdBKA9/`03BK@01DVcBKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]005BK=9]4VdBKA9
/`03BK@00dVcBK@Li`027>LLCI400g`0Oomoo`1:Ool00`00Oomoo`0COol00`00Oomoo`02Ool000Eo
o`03001oogoo02ioo`<00008KNEaiFgTLNE]iAcW07@0M@<0M00U07DLibFI9IPUVBFH9ITUV1cW>MLm
ecWG?MLiecgG>MLmecWG?MLLidGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EBM@00QcW02Q9
/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9
/dWDBK=9e4VcBMA9/dWDBK=9e0@Li`0HBI5=TTVACI59TDfBBI5=TDVACI99TDfABI5=TTVACI59TDfB
BI5=TDVACI99TG`0CGoo00<007ooOol04Woo00<007ooOol00goo0005Ool00`00Oomoo`0/Ool20000
0fi`KW5ai@06LND00acW07@0M00407@00acW9ITUV0029IP01BFI9IPLicWG?ML00cWG00HmecWG>MLi
ecgG7>L2AMD01DGFAME5eDGEAMH00dGE00E5eTGEAME5eDGF0095e@03BK@LiacW00=9]005BK=9]4Vd
BKA9/`03BK@01DVcBKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]005BK=9]4VdBKA9/`03BK@01dVc
BKA9]4VdBK=9]00b00<Lia==T@9l04eoo`03001oogoo019oo`03001oogoo00=oo`001Goo00<007oo
Ool0:Woo0P0000m^LFY@KW5ZD6iaKNAaiFgULNE]i77UKNDLi`1d07D00`1d05@LibFH9ITUV2FI9IPU
VBFH7>LiecgG>MLmecWG?MLiecgG>MLmeacWAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5
eT7EBM@LidWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9
e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWD:KP37>L04DVACI99TDfABI5=TTVACI59TDfB
BI5=TDVACI99TDfAO000CWoo00<007ooOol04Woo00<007ooOol00goo0005Ool00`00Oomoo`0YOol0
1P00IYA^L6i`KW5ZL09^L0Qai@H0M0037>LUV2FI00<UV0059ITUV1cW>MLme`03>ML01SgG>MLiecWG
?MLLi`95e@05AMI5eDGEAME5eP03AMD01DGFAME5eDGEAMH00dGE00=9]1cW7>L00TVd00E9/dVdBKA9
]4Vc00=9]005BK=9]4VdBKA9/`03BK@01DVcBKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]005BK=9
]4VdBKA9/`03BK@00dVcBK@]^@037>L<CI400g`0Oomoo`1=Ool00`00Oomoo`0BOol00`00Oomoo`03
Ool000Eoo`03001oogoo02Moo`80000AHYAVUF:DKW5ZD6iaJU1^LFY@LNE]i77UKNEaiFgTLNDLi`02
07@0G01e07@0M01d7>LUV2FI9IPUVBFH9ITLicgG>MLmecWG?MLiecgG>MLmecWG?MLLidGF@ME5eT7E
AMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGFBK<LidVcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4Vc
BMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4Vc
BMA9/dWDBK<37>L02TVACI99TDfABI5=TTVACI59TG`0Cgoo00<007ooOol04Woo00<007ooOol00goo
0005Ool00`00Oomoo`0VOol00`00IYEVU003IYD01FJDKW1^L6iaJW000Vi`1g7U00<Li`1d07@00`1d
00@LibFH9IPUV@<UV0059ITLicWG>MLme`03>ML01SgG>MLiecWG?MLLi`95e@05AMI5eDGEAME5eP03
AMD01DGFAME5eDGEAMH00dGE00I5eTGE7>LLidVdBK<3BK@01DVcBKA9]4VdBK<00dVd00E9/dVdBKA9
]4Vc00=9]005BK=9]4VdBKA9/`03BK@01DVcBKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]003BK=9
]4Vd00<Li`E=T@03O01oogoo04ioo`03001oogoo019oo`03001oogoo00=oo`001Goo00<007ooOol0
9Goo01L006:hHYAVUF:DIYERU6JEHYA^LFY@KW5ZD6iaJU1aiFgTLNE]iG7UKNAaiAcW0080M00]07D0
M01d7>LUVBFH9ITUV2FI9IPUVAcW?MLiecgG>MLmecWG?MLiecgG>MLmeacWAMI1eDGF@ME5eT7EAMI1
eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDWD008Li`0aBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9
e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9
e4VcBMA9/dWDBK<00acW00=9TDfBO000D7oo00<007ooOol04Woo00<007ooOol00goo0005Ool00`00
Oomoo`0TOol00`00G[QN]`02G[P00fJEIYAVU@02IYD01FJDKW1^L6iaJW000Vi`1W7U00<Li`1d07@0
101d00@LibFH9IPUV@<UV0059ITLicWG>MLme`03>ML01SgG>MLiecWG?MLLi`95e@05AMI5eDGEAME5
eP03AMD01DGFAME5eDGEAMH00dGE00I5eTGEAME9]1cWBK<3BK@01DVcBKA9]4VdBK<00dVd00E9/dVd
BKA9]4Vc00=9]005BK=9]4VdBKA9/`03BK@01DVcBKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]005
BK=9]4VdBKA9/`02BK@00acWO01oo`1@Ool00`00Oomoo`0BOol00`00Oomoo`03Ool000Ioo`03001o
ogoo029oo`0J001R^5jgH[QN]f:hG[MVUF:DIYERU6JEHYA^LFY@KW5ZD6iaKNEaiFgTLNE]iG7UKN@L
i`<0M00^07D0M1cW9IPUVBFH9ITUV2FI9IPLicWG?MLiecgG>MLmecWG?MLiecgG>MLmeacWAMI1eDGF
@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@MD27>L0<TWDBK=9e4VcBMA9/dWDBK=9
e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9
e4VcBMA9/dWDBK=9e4VcBMA9/dWDO01BOol00`00Oomoo`0BOol00`00Oomoo`03Ool000Ioo`03001o
ogoo025oo`03001JneKk00=N^005G[MN^5jhG[QVU003IYD01VJDKW1^L6iaJW1^L0Mai@037>L0M01d
00<0M0057>LUV2FH9IPUV@039IP01AcW>MLiecWG?ML00cWG00HmecWG>MLiecgG7>L2AMD01DGFAME5
eDGEAMH00dGE00E5eTGEAME5eDGF00=5e@06AMI5eDGEAME9]1cW0dVd00E9/dVdBKA9]4Vc00=9]005
BK=9]4VdBKA9/`03BK@01DVcBKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]005BK=9]4VdBKA9/`03
BK@01TVcBKA9]4VdBK=l059oo`03001oogoo019oo`03001oogoo00=oo`001Woo00<007ooOol08Goo
01d005KKF_]Ffe[kG[MR^5jgH[QN]f:hHYAVUF:DIYERU6iaJU1^LFY@KW5]iG7UKNAaiFgULNDLibFH
00<0M00_07DLibFI9IPUVBFH9ITUV2FI9IPLicWG?MLiecgG>MLmecWG?MLiecgG>MLmeacWAMI1eDGF
@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eP027>L0;TVcBMA9/dWDBK=9e4Vc
BMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4Vc
BMA9/dWDBK=9e4VcBMA9/g`0Dgoo00<007ooOol04Woo00<007ooOol00goo0006Ool00`00Oomoo`0P
Ool01@00E_]FneKkF_/00eKk00=JnejgG[P00Ujh00EN]fJEIYEVUFJD009^L003KW5ZL6i`00Iai@03
7>L0M01d00<0M0037>LUVBFH008UV0059ITUV2FH9IPLi`03>ML01CgG>MLiecWG?ML00cWG00DmeacW
AME5eDGF00=5e@05AMI5eDGEAME5eP03AMD01DGFAME5eDGEAMH00dGE00I5eTVc7>LLidVdBK<3BK@0
1DVcBKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]005BK=9]4VdBKA9/`03BK@01DVcBKA9]4VdBK<0
0dVd00I9/dVdBKA9]4VcO01DOol00`00Oomoo`0BOol00`00Oomoo`03Ool000Ioo`03001oogoo021o
o`0P000k?c/oF_]Ffe[kE]]JneKKF_]Fff:hG[MR^5jgIYERU6JEHYA^LFY@KW5ZD6iaKNEaiFgTLNE]
iG7U7>L0M@<0M01L07DLibFI9IPUVBFH9ITUV2FI7>LmecWG?MLiecgG>MLmecWG?MLiecgG>MLmeacW
AMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EBM@LidWDBK=9e4Vc
BMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4Vc
BMA9/dWDBK=9e4VcBMAl05Aoo`03001oogoo019oo`03001oogoo00=oo`001Woo00<007ooOol087oo
00<003/o>cl01S/o00=Fne[kE_/00UKk00=N^5jgG[P00VJE00IVU6i`KW1^LFY`KW05LND00acW9IP0
M00307@00acW9IPUV@039IP01BFI9IPUV1cW?ML00cWG00DmecWG>MLiecgG00<ie`05?MLLidGEAME5
eP03AMD01DGFAME5eDGEAMH00dGE00E5eTGEAME5eDGF00=5e@03AMI5eDGE008Li`05BK=9]4VdBKA9
/`03BK@01DVcBKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]005BK=9]4VdBKA9/`03BK@01dVcBKA9
]4VdBK=9]7`005Eoo`03001oogoo019oo`03001oogoo00=oo`001Woo00<007ooOol087oo00<001cW
7>L011cW23/o01=JneKKH[QRU6JEHYA^LFY@KW5ZD77UKNEaiFgTLNE]iAcW07@0M@0307@0<QcW9IPU
VBFH9ITUV2FI9IPUVAcW?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLLidGF@ME5eT7EAMI1eDGF@ME5
eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGFBK<27>L094WDBK=9e4VcBMA9/dWDBK=9e4Vc
BMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMAl05Ioo`03001o
ogoo019oo`03001oogoo00=oo`001Woo00<007ooOol08Goo00<003P0>0000cP03QcW00EVU6i`KW1^
LFY`00Iai@037>L0M01d00<0M0037>LUV2FI00<UV0059ITUV2FH7>Lme`03>ML01CgG>MLiecWG?ML0
0cWG00DmeacWAME5eDGF00=5e@05AMI5eDGEAME5eP03AMD01DGFAME5eDGEAMH00dGE00I5eTGEAME5
eDVd7>L3BK@01DVcBKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]005BK=9]4VdBKA9/`03BK@01dVc
BKA9]4VdBK=9]7`005Moo`03001oogoo019oo`03001oogoo00=oo`001Woo00<007ooOol08Goo00<0
03P0>0004CP000mVUF:DKW5ZD6iaJU1aiFgULNE]i77U7>Lh001d07D00P1d03@LibFI9IPUVBFH9ITU
V2FI9IPLicWG?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLLidGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1
eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eP8Li`0PBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWD
BK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=l05Moo`03001oogoo019oo`03001o
ogoo00=oo`001Woo00<007ooOol08Woo00<003P0>0004CP000IVUFJDKW1^L6iaJW05LND00acW>000
M00307@011cW9IPUV2FI0bFH00DUVBFH7>LiecgG00<ie`05?MLiecWG>MLme`03>ML01CgG7>M5eDGE
AMH00dGE00E5eTGEAME5eDGF00=5e@05AMI5eDGEAME5eP03AMD01dGFAME5eDGEAMI9/acW0099]005
BK=9]4VdBKA9/`03BK@01DVcBKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]004BK=9]4VdO01HOol0
0`00Oomoo`0BOol00`00Oomoo`03Ool000Ioo`03001oogoo029oo`03000LiacW01DLi`09JU1^LFY@
LNE]iG7UKNAaiAcW0080M00h07D0M1cW9IPUVBFH9ITUV2FI9IPUVBFH7>LiecgG>MLmecWG?MLiecgG
>MLmecWG?MLiecgG7>M5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF
@ME5eT7EAMI1e@8Li`0KBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9
e4VcBMA9/g`005Uoo`03001oogoo019oo`03001oogoo00=oo`001Woo00<007ooOol08Woo01P004d]
CDe=;4e=CBe=CDd/CDe=;De=CBa=CDd]CDe=;4e=CBe=CDd/CDe=;De=IY@2KW000fiaJW1ai@03LND0
0acW07@0M00307@01AcW9IPUV2FH9IT00bFH00DUVAcW>MLiecgG00<ie`05?MLiecWG>MLme`03>ML0
1CgG7>M5eDGEAMH00dGE00E5eTGEAME5eDGF00=5e@05AMI5eDGEAME5eP03AMD01DGFAME5eDGEAMH0
0TGE0QcW00E9/dVdBKA9]4Vc00=9]005BK=9]4VdBKA9/`03BK@01DVcBKA9]4VdBK<00dVd00=l07oo
Ool0Egoo00<007ooOol04Woo00<007ooOol00goo0006Ool00`00Oomoo`0SOol08P00CBa=CDd/DDe=
;4e=CBaACDd/CDe=;55=CBa=CDd/DDe=;4e=CBaACDd/CDe=;6iaJU1^LFgTLNE]iG7UKN@Lidd/0P1d
0580M@1d7>LUV2FI9IPUVBFH9ITUV2FI7>LmecWG?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLLidGF
@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI9/acW
BK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMAl05Yoo`03001oogoo019o
o`03001oogoo00=oo`001Woo00<007ooOol08goo01T001cW7>M=CDd/CDe=;De=CBa=CDd]CDe=;4e=
CBe=CDd/CDe=;De=CBa=CDd]CDe=;002KW000fiaLNEai@03LND00acWIYD0M00207@00acW9ITLi`02
9IP01RFI9IPUV2FH9ITLi`8ie`05?MLiecWG>MLme`03>ML01SgG>MLiecWG?MLLi`95e@05AMI5eDGE
AME5eP03AMD01DGFAME5eDGEAMH00dGE00E5eTGEAME5eDGF00=5e@04AMI5eDGEAMD27>L3BK@01DVc
BKA9]4VdBK<00dVd00E9/dVdBKA9]4Vc00=9]003O01oogoo05Uoo`03001oogoo019oo`03001oogoo
00=oo`001Woo00<007ooOol097oo00<004fb7>L02QcW01EACDd/CDe=;55=CBa=CDd/DDe=;4e=CBa^
LFY@KW5]i77UKNEaiAcW07D00`1d04l0MAcW9ITUV2FI9IPUVBFH9ITUV2FI7>LmecWG?MLiecgG>MLm
ecWG?MLiecgG>MLmecWG?MLLidGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5
eT7EAMI1eDGF@ME5eT7EAMI1eDGF7>M9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=l
001JOol00`00Oomoo`0COol00`00Oomoo`03Ool000Ioo`03001oogoo02Eoo`0<001=/DfACK5=TDfa
CI5=/DfACK5=TDfa2QcW00==;De=CB`00Vi`00=^LG7ULND00W7U00<Li`1d07@00`1d00<LibFI9IP0
0RFH00DUVBFH9IPUV1cW00<ie`05?MLiecWG>MLme`03>ML01SgG>MLiecWG?MLLi`95e@05AMI5eDGE
AME5eP03AMD01DGFAME5eDGEAMH00dGE00E5eTGEAME5eDGF00=5e@05AMI5eDGEAME5eP027>L2BK@0
1DVcBKA9]4VdBK<00dVd00I9/dVdBKA9]4VcO01KOol00`00Oomoo`0BOol00`00Oomoo`04Ool000Io
o`03001oogoo02Eoo`0F001=TDfbCI5=/TfACK9=TDfbCI5=/TfACK9=TDfbCI5=/TfACK9=TDfbCI46
7>L01fiaKNAaiFgULNDLie5=00<0M00l7>LUV2FI9IPUVBFH9ITUV2FI9IPLicWG?MLiecgG>MLmecWG
?MLiecgG>MLmecWG?MLiecgG7>M5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7E
AMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7E0QcW00e9e4VcBMA9/dWDBK=9e4VcBMA9/dWDBK=l001LOol0
0`00Oomoo`0BOol00`00Oomoo`04Ool000Ioo`03001oogoo025oo`03000LiacW008Li`0J000LiacW
CI5=/DfACK5=TDfaCI5=/DfACK5=TDfaCI5=/DfACK5=TDfaCI5=/DfACK5=T@9^L007KW5aiG7ULNDL
i`1d7>L00`1d00<LibFH9IT00bFH00DUVBFH9IPUV1cW00<ie`05?MLiecWG>MLme`03>ML01CgG>MLi
ecWG?ML00QcW00=5eDGFAMD00TGE00E5eTGEAME5eDGF00=5e@05AMI5eDGEAME5eP03AMD01DGFAME5
eDGEAMH00dGE00I5eTGEBK@LidVdBK<3BK@01TVcBKA9]4VdBK=l05eoo`03001oogoo019oo`03001o
ogoo00Aoo`001Woo00<007ooOol087oo00<001cW7>L011cW00<001cW7>L00acW01e=/TfACK9=TDfb
CI5=/TfACK9=TDfbCI5=/TfACK9=TDfbCI5=/TfAKW5ZD77UKNAaiFgU7>L0M01e00<0M00m7>LUV2FI
9IPUVBFH9ITUV2FI9IPLicWG?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLiecgG>MLLid7EAMI1eDGF
@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMH00QcW
00U9/dWDBK=9e4VcBMA9/dWDO000GGoo00<007ooOol04Woo00<007ooOol017oo0006Ool00`00Oomo
o`0QOol00`00E]]Ff`03E]/00`00BMA9e002BM@00eKK7>LLi`027>L04DfACK5=TDfaCI5=/DfACK5=
TDfaCI5=/DfACK5=TDfaCI400Vi`177U00<Li`1d07@00P1d00@LibFH9IPUV@<UV0059ITUV2FH7>Lm
e`03>ML01CgG>MLiecWG?ML00cWG00TmecWG>MLiecgG>MLLidGEAMH00dGE00E5eTGEAME5eDGF00=5
e@05AMI5eDGEAME5eP03AMD01DGFAME5eDGEAMH00dGE00I5eTGEAME5eAcWBK<3BK@00dVcBKAl001N
Ool00`00Oomoo`0BOol00`00Oomoo`04Ool000Ioo`03001oogoo025oo`037>L001cW00<Li`0:F]/0
04WDBK==e4VcBMA9/dgDE]X47>L05dfbCI5=/TfACK9=TDfbCI5=/TfACK9=TDfbCI5^LFY@LNE]i77U
JU0LidfA07D00P1d03lLibFI9IPUVBFH9ITUV2FI9IPUVAcW?MLiecgG>MLmecWG?MLiecgG>MLmecWG
?MLiecgG>MLmecWG7>M1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7E
AMI1eDGF@ME5eT7EAMI1eDGF@MD00QcW00A9e4VcBMAl05moo`03001oogoo019oo`03001oogoo00Ao
o`001Woo00<007ooOol08Woo00<001cW7>L00Ujh00@Li`007>LLi`U9e003E]/LiacW008Li`0;CI5=
/DfACK5=TDfaCI5=/DfACK5=T@02KW03LND00acW07@0M00307@011cW9IPUV2FI0bFH00DUVBFH9IPL
icgG00<ie`05?MLiecWG>MLme`03>ML02CgG>MLiecWG?MLieacWAME5eP03AMD01DGFAME5eDGEAMH0
0dGE00E5eTGEAME5eDGF00=5e@05AMI5eDGEAME5eP03AMD01DGFAME5eDGEAMH00QcW00=9]7`0Ool0
GWoo00<007ooOol04Woo00<007ooOol017oo0007Ool00`00Oomoo`0ROol200047>L03`00@MDLiacW
CMA9/dWDBK==e4VcBMA9/dgDBK=9e0057>L03TfbCI5=/TfACK9=TDfbCI5^LFgULNE]i77U7>L207@0
A@1e07@LibFH9ITUV2FI9IPUVBFH9ITUV2FI7>LmecWG?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLi
ecgG>MLLid7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1
eDGF@ME5eT7EAMI1eDGF@MEl001POol00`00Oomoo`0BOol00`00Oomoo`04Ool000Moo`03001oogoo
02Aoo`08001RUV:FG[P001cW@MI5eP8Li`a9e0HLi`06CI5=/DfACK5=TFi`177U00<Li`1d07@00P1d
00DLibFH9IPUV2FI00<UV0059ITUV1cW>MLme`03>ML01CgG>MLiecWG?ML00cWG00TmecWG>MLiecgG
>MLLidGEAMH00dGE00E5eTGEAME5eDGF00=5e@05AMI5eDGEAME5eP03AMD01DGFAME5eDGEAMH00dGE
00E5eTGEAME5eG`0065oo`03001oogoo019oo`03001oogoo00Aoo`001goo00<007ooOol09Goo00T0
01cWGYIRUP007>M1eDGF@MD00QcW00i9e4VcCMA9/dWDBK==e4VcBMA9/dgDBK=9e4Vc1AcW04a=TDfb
CI5^LFgULNE]i4fb7>M=/P1d07D0M1cW9IPUVBFH9ITUV2FI9IPUVBFH7>LiecgG>MLmecWG?MLiecgG
>MLmecWG?MLiecgG>MLmecWG?MLieacW@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF
@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@MEl069oo`03001oogoo019oo`03001oogoo00Aoo`001goo
00<007ooOol09Woo0P0000PLi`00@MDLid7FAMI1eD7F0QcW44WD00IJ^1cW7>LLidfAKW03LND00acW
07@0M00207@00acW9ITUV0029IP02BFI9IPUV2FH9ITUV1cW>MLme`03>ML01CgG>MLiecWG?ML00cWG
00TmecWG>MLiecgG>MLLidGEAMH00dGE00E5eTGEAME5eDGF00=5e@05AMI5eDGEAME5eP03AMD01DGF
AME5eDGEAMH00dGE00=5eW`0Ool0HGoo00<007ooOol04Woo00<007ooOol017oo0007Ool00`00Oomo
o`0WOol02fY`000LiacW@MDLid7EAMI1eDGF@MD00QcW019=e4VcBMA9/dgDBK=9e4VcCMA9/dWDBK==
e4VcBMA9/dgDBK<47>L00g7UKN@Li`0307@0?P1e7>LUVBFH9ITUV2FI9IPUVBFH9ITUV1cW>MLmecWG
?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLiecgG>MLLid7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7E
AMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGFO01SOol00`00Oomoo`0BOol00`00Oomoo`04Ool0
00Moo`03001oogoo02Moo`0:KW5b:W8Z7>Le]d7E7>M1eTGF@MD2@MH00f:F7>M9e00CBM@4LND00acW
07@0M00207@00acW9ITUV0029IP01RFI9IPUV2FH9ITLi`8ie`05?MLiecWG>MLme`03>ML01CgG>MLi
ecWG?ML00cWG00DmecWG7>M5eDGF00=5e@05AMI5eDGEAME5eP03AMD01DGFAME5eDGEAMH00dGE00I5
eTGEAME5eDGFO01TOol00`00Oomoo`0BOol00`00Oomoo`04Ool000Moo`03001oogoo02Qoo`0=KW5b
:A4h7>Le^36g7>M1eDGF@ME5eT7EAMH00QcW01M9/dWDBK==e4VcBMA9/dgDBK=9e4VcCMA9/dWDFYQ=
e4VcBMA9/g7UKNEaiDVc008Li`80M00i7>LUV2FI9IPUVBFH9ITUV2FI9IPUVAcW?MLiecgG>MLmecWG
?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLieacW@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7E
AMI1eDGF@ME5eT7EAMI1eDGF009l06Aoo`03001oogoo019oo`03001oogoo00Aoo`001goo00<007oo
Ool0:Goo00A^LG8Z7>LLi`8e]`047>M1eTGF@MD2@MH00dGF@MDLi`0?BM@015jhBMA9e4WD0g7U00<0
M1cW07@00P1d00<LibFH9IT00bFH00HUVBFH9IPUV2FI7>L2>ML01CgG>MLiecWG?ML00cWG00DmecWG
>MLiecgG00<ie`05?MLieacWAME5eP03AMD01DGFAME5eDGEAMH00dGE00E5eTGEAME5eDGF00=5e@03
AMIl07`006Eoo`03001oogoo019oo`03001oogoo00Aoo`001goo00<007ooOol0:Woo00if:QcW7>LL
icFh<KLLid7EAMI1eDGF@ME5eT7E0QcW01M9e4VcCMA9/dWDBK==e4VcBMA9/dgDBK=9e4VcG[Q9/dWD
KNAaiFgULNDLi`1e00<0M00g7>LUV2FI9IPUVBFH9ITUV2FI9IPUVAcW?MLiecgG>MLmecWG?MLiecgG
>MLmecWG?MLiecgG>MLmecWG?MLieacW@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF
@ME5eT7EO000IWoo00<007ooOol04Woo00<007ooOol017oo0007Ool00`00Oomoo`0[Ool00g8Z3CLL
i`03=KL011cW@MI5eT7E0T7F00=5eT7E@MH00QcW3DWD00=N^4WDBM@0177U00DLidWD07@0M1cW008U
V0059ITUV2FH9IPUV@039IP01AcW>MLiecWG?ML00cWG00DmecWG>MLiecgG00<ie`09?MLiecWG>MLm
ecWG7>M5eDGF00=5e@05AMI5eDGEAME5eP03AMD01TGFAME5eDGEAMI5e@9l06Ioo`03001oogoo019o
o`03001oogoo00Aoo`001goo00<007ooOol0;7oo011f:QcW7>La]cFh<KLLid7EAMI1eDGF@ME5eT7E
AMI1e@8Li`0ECMA9/dWDBK==e4VcBMA9/dgDBK=9e4VcCMA9/dWDKNAaiFgUBM@LidgD0080M00c7>LU
VBFH9ITUV2FI9IPUVBFH7>LUV1cW>MLmecWG?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLiecgG>MLm
ecWG7>M1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7E009l06Moo`03001oogoo019oo`03
001oogoo00Aoo`001goo00<007ooOol0;7oo00A^L@dh7>LLi`<e]`047>M1eTGF@MD2@MH01DGF@ME1
eT7FAMH00QcW3TWD0g7U00<Li`1d07@00P1d00@LibFH9IPUV@<UV0059ITUV2FH9IPLi`03>ML01CgG
>MLiecWG?ML00cWG00DmecWG>MLiecgG00<ie`05?MLieacWAME5eP03AMD01DGFAME5eDGEAMH00dGE
00A5eTGEO01l06Qoo`03001oogoo019oo`03001oogoo00Aoo`001goo00<007ooOol0;Goo01=b:AcW
3CLLic6g=KPa]acW@ME5eT7EAMI1eDGF@ME5eT7EAMI1e@027>L0A4WDBK==e4VcBMA9/dgDBK=9e4Vc
CMA9/g7UKNAaiFgU7>L0M01e07@LibFH9ITUV2FI9IPUVBFH9ITUV2FI9IPLicWG?MLiecgG>MLmecWG
?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLieacW@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@MD2O01Y
Ool00`00Oomoo`0BOol00`00Oomoo`04Ool000Moo`03001oogoo02ioo`04LRXLi`dg7>L3=KL011cW
@MI5eT7E0T7F00M5eT7E@MI1eTGF@ME1eP027>L;BM@4LND01AcWBM@0M01d7>L00bFH00DUVBFH9IPU
V2FI008UV0037>LmecWG008ie`05?MLiecWG>MLme`03>ML01CgG>MLiecWG?ML00cWG00DmecWG7>M5
eDGF00=5e@05AMI5eDGEAME5eP02AMD2O01YOol00`00Oomoo`0BOol00`00Oomoo`04Ool000Moo`03
001oogoo02moo`0E7>LA>0dg7>La]cFh<KLLid7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7E008Li`0>
CMA9/dWDBK==e4VcBMA9/dgDBK=aiFgTLNDLi`80M00_07DLibFI9IPUVBFH9ITUV2FI9IPUVBFH9ITL
icgG>MLmecWG?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLiecgG>MLmecWG7>M1eDGF@ME5eT7EAMI1
eDGF@ME5eP02O01ZOol00`00Oomoo`0BOol00`00Oomoo`04Ool000Moo`03001oogoo02moo`04LRXL
i`dh7>L4=KL011cW@MI5eT7E0T7F00I5eT7E@MI1eTGF@MD2@MH00dGF7>LLi`09BM@3LND01QcW07@0
M01d7>LUV@<UV0059ITUV2FH9IPUV@029IP00acW?MLie`02>ML01CgG>MLiecWG?ML00cWG00DmecWG
>MLiecgG00<ie`05?MLieacWAME5eP03AMD00dGFAME5e@02O01[Ool00`00Oomoo`0BOol00`00Oomo
o`04Ool000Moo`03001oogoo02moo`0I001f:QcW4CPLicFh<KLe^36g7>M1eDGF@ME5eT7EAMI1eDGF
@ME5eT7EAMI1eDGFGYD00QcW00a9e4VcCMA9/dWDBK==e4VcLNE]i77U7>L207@0;P1e7>LUVBFH9ITU
V2FI9IPUVBFH9ITUV2FI7>LmecWG?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLi
eacW@ME5eT7EAMI1eDGFO01VUG`0Jgoo00<007ooOol04Woo00<007ooOol017oo0007Ool00`00Oomo
o`0_Ool01P00OolLi`dg3CPLi`@e]`047>M1eTGF@MD2@MH01TGF@ME1eT7FAMI1e@91eP03AMI1eF:F
008Li`I9e0=ai@077>L0M4WD07@LibFH9IT00bFH00TUVBFH9IPUV2FI9IPLicWG?ML00cWG00DmecWG
>MLiecgG00<ie`05?MLiecWG>MLme`03>ML01CgG>MLLidGEAMH00TGE00=l06JEO000K7oo00<007oo
Ool04Goo00<007ooOol01Goo0007Ool00`00Oomoo`0_Ool02`00Oomb:AcW3CLA>1cW=KPa]cFh<KL0
0QcW0115eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI9/`8Li`09CMA9/dWDBK==e6gULNE]i1cW
00<0M00X7>LUV2FI9IPUVBFH9ITUV2FI9IPUVBFH7>LiecgG>MLmecWG?MLiecgG>MLmecWG?MLiecgG
>MLmecWG?MLiecgG>MLmecWG7>M1eDGF@MD2O01]Ool00`00Oomoo`0AOol00`00Oomoo`05Ool000Mo
o`03001oogoo02moo`08001oogoo7>L=>0dg=KLLi`De]`037>M5eT7E0091eP06AMI1eD7F@MI5eT7E
0T7F00E5eT7E@MI1eTWD008Li`A9e0=ai@077>L0M01d07@LibFH9IT00bFH00TUVBFH9IPUV2FI9IPL
icWG?ML00cWG00DmecWG>MLiecgG00<ie`05?MLiecWG>MLme`03>ML013gG>MLLidGE0W`0KWoo00<0
07ooOol04Goo00<007ooOol01Goo0007Ool00`00Oomoo`0_Ool08@00Oomoogoo7>LA>0dg7>La]cFh
<KLe^36g=KPLidGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI9/`027>L01dWDBK==e6gU
LNE]i1cW0080M00X7>LUVBFH9ITUV2FI9IPUVBFH9ITUV2FI9IPLicWG?MLiecgG>MLmecWG?MLiecgG
>MLmecWG?MLiecgG>MLmecWG?MLiecgG>MMl06JDO01]Ool00`00Oomoo`0BOol00`00Oomoo`05Ool0
00Qoo`03001oogoo02ioo`09001oogooOomb:QcW3CP==acW00He]`037>M5eT7E0091eP06AMI1eD7F
@MI5eT7E0T7F00Q5eT7E@MI1eTGFHYI9e1cW0TWD0g7U00DLi`1dBM@0M1cW008UV0059ITUV2FH9IPU
V@039IP01BFI7>LiecWG?ML00cWG00DmecWG>MLiecgG00<ie`05?MLiecWG>MLme`03>ML00g`0IYAl
001^Ool00`00Oomoo`0BOol00`00Oomoo`05Ool000Qoo`03001oogoo02ioo`03001oogoo009oo`0O
7>L==a4h3CLLic6g=KPa]cFh<KLe^1cWAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7E
CM@00QcW00I9/g7UKNEaiAcW07D207@091cW9ITUV2FI9IPUVBFH9ITUV2FI9IPUVAcW?MLiecgG>MLm
ecWG?MLiecgG>MLmecWG?MLiecgG>MLmecWG?MLieg`0IYAl06moo`03001oogoo019oo`03001oogoo
00Eoo`0027oo00<007ooOol0;Woo00<007ooOol00goo00DLi`dg3CPe]acW00He]`037>M5eT7E0091
eP06AMI1eD7F@MI5eT7E0T7F00U5eT7E@MI1eTGF@ME1eTWD7>L014WD0`1d00DLibFH9IPUV2FI00<U
V0069ITUV2FH9IPUVAcW0SWG00DmecWG>MLiecgG00<ie`05?MLiecWG>MLme`03>ML00g`0IYAl001`
Ool00`00Oomoo`0BOol00`00Oomoo`05Ool000Qoo`03001oogoo02ioo`03001oogoo00=oo`0QLRTL
i`dg4CPa]acW<KLe^36g=KPa]cFh7>M5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5
eT7E008Li`0XCMA9/dWD07@0M@1d7>LUV2FI9IPUVBFH9ITUV2FI9IPUVBFH9ITLicgG>MLmecWG?MLi
ecgG>MLmecWG?MLiecgG>MLmecWG?MMl06JEO01`Ool00`00Oomoo`0BOol00`00Oomoo`05Ool000Qo
o`03001oogoo02ioo`03001oogoo00Aoo`067>L=>0dg3CPe]acW1SFg00<LidGF@MD00T7F00I5eT7E
@MI1eTGF@MD2@MH01TGF@ME1eT7FAMI1e@91eP04AMHLiacWBM@207@00dWD07@Li`039IP01BFI9IPU
V2FH9IT00bFH00DLicWG>MLiecgG00<ie`05?MLiecWG>MLme`03>ML013gGO01VU7`0LGoo00<007oo
Ool04Woo00<007ooOol01Goo0008Ool00`00Oomoo`0^Ool00`00Oomoo`05Ool031cW4CP==a4h7>Le
^36g=KPa]cFh<KLe^08Li`0E@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7E
008Li`80M00P07DLibFI9IPUVBFH9ITUV2FI9IPUVBFH9ITUV1cW>MLmecWG?MLiecgG>MLmecWG?MLi
ecgG>MLmeg`0IYEl079oo`03001oogoo019oo`03001oogoo00Eoo`0027oo00<007ooOol0;Woo00<0
07ooOol01Woo00DLi`dh3CL=>1cW00Pe]`067>M1eD7F@MI5eT7E0T7F00I5eT7E@MI1eTGF@MD2@MH0
1dGF@ME1eT7FAMI1eD7F008Li`80M0037>LUVBFH008UV0059ITUV2FH9IPUV@039IP01AcW>MLiecWG
?ML00cWG00PmecWG>MLiecgGO01VU7`0Lgoo00<007ooOol04Woo00<007ooOol01Goo0008Ool00`00
Oomoo`0^Ool00`00Oomoo`06Ool09QcW3CLA>0dg=KPLicFh<KLe^36g=KPa]cFh<KLLid7EAMI1eDGF
@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@MD207@07@1e7>LUVBFH9ITUV2FI9IPU
VBFH9ITUV2FI9IPLicWG?MLiecgG>MLmecWG?MLiecgGO00LifJDO000Lgoo00<007ooOol04Woo00<0
07ooOol01Goo0008Ool00`00Oomoo`0^Ool00`00Oomoo`07Ool01QcW3CL=>0dg=KLLi`Pe]`067>M1
eD7F@MI5eT7E0T7F00I5eT7E@MI1eTGF@MD2@MH01TGF@ME1eT7FAMI1e@91eP80M0037>LUV2FI00<U
V0059ITUV2FH9IPUV@029IP00acW?MLie`02>ML02CgG>MLiecWG?MMl06ibJW8Li`1dOol00`00Oomo
o`0BOol00`00Oomoo`05Ool000Qoo`03001oogoo02ioo`/0000U7>L==a4h3CLe^1cW=KPa]cFh<KLe
^36g=KPa]acW@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMH00`1d01TL
ibFH9ITUV2FI9IPUVBFH9ITUV2FI9IPUVAcW?MLiecgG>MLmecWG?MMl06jBJW5l001eOol00`00Oomo
o`0BOol00`00Oomoo`05Ool000Qoo`03001oogoo02eoo`03001oogoo00Uoo`067>L=>0dg3CP==acW
2CFg00HLid7E@MI1eTGF@MD2@MH01TGF@ME1eT7FAMI1e@91eP06AMI1eD7F@MI5eT7E101d00<LibFH
9IT00bFH00DUVBFH9IPUV2FI008UV0037>LmecWG008ie`05?MMl06ibJW9l001fOol00`00Oomoo`0B
Ool00`00Oomoo`05Ool000Qoo`03001oogoo02eoo`03001oogoo00Yoo`0V7>LA>0dg4CPa]acW<KLe
^36g=KPa]cFh<KLe^36g7>M1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@MD0
M@80M00F7>LUVBFH9ITUV2FI9IPUVBFH9ITUV2FI9IPUVAcW?MLiecgG>MMl06YaO00_0018Ool00`00
Oomoo`0BOol00`00Oomoo`05Ool000Qoo`03001oogoo02aoo`03001oogoo00aoo`067>L=>0dg3CPe
]acW2CFg0QcW0T7F00I5eT7E@MI1eTGF@MD2@MH01TGF@ME1eT7FAMI1e@91eP03AMI1e@1d0080M004
7>LUV2FH9IT39IP03BFI9IPUV2FH9ITUV1cW>MLmecWGO01ZLW`0031ooc0001Qoo`03001oogoo019o
o`03001oogoo00Eoo`0027oo00<007ooOol0;7oo00<007ooOol037oo02LLi`dg4CP==a4h<KLLic6g
=KPa]cFh<KLe^36g=KPa]cFh7>M5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7E
AMH00P1d018LibFI9IPUVBFH9ITUV2FI9IPUVBFH9ITUV1cW>MMl06YaO01QOolI000DOol00`00Oomo
o`05Ool000Qoo`03001oogoo02]oo`03001oogoo00ioo`067>L==`dh3CL=>1cW2cFg00DLid7F@MI5
eT7E0091eP06AMI1eD7F@MI5eT7E0T7F00I5eT7E@MI1eTGF@MD207@01AcW9IPUV2FH9IT00bFH00XU
VBFH9IPUV2FI9IQl06YbKW9l07Uoo`03001oogoo019oo`03001oogoo00Eoo`0027oo00<007ooOol0
:goo00<007ooOol03Woo03T==acW3CLA>0dg4CPLicFh<KLe^36g=KPa]cFh<KLe^36g=KPLidGF@ME5
eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@MD0M@1d7>LUV2FI9IPUVBFH9ITUV2FI9IPU
VBFHO01ZLFjBO000NWoo00<007ooOol04Woo00<007ooOol01Goo0008Ool00`00Oomoo`0ZOol00`00
Oomoo`0@Ool01acW3CP==`dh3CLe]acW00/e]`057>M1eT7FAMI1e@02@MH01TGF@ME1eT7FAMI1e@91
eP05AMI1eD7F@MI5eP0307@01AcW9IPUV2FH9IT00bFH00HUVG`0O01ZLVibO01lOol00`00Oomoo`0A
Ool00`00Oomoo`05Ool000Qoo`03001oogoo02Yoo`03001oogoo015oo`0e7>LA>0dg4CP==cFh7>Le
^36g=KPa]cFh<KLe^36g=KPa]cFh7>M5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5
eP1d07DLibFI9IPUVBFH9ITUV2FIO01fBacWKY9l001mOol00`00Oomoo`0AOol00`00Oomoo`05Ool0
00Qoo`03001oogoo02Uoo`03001oogoo019oo`073CPLi`dh3CL=>0dg7>L033Fg00DLid7F@MI5eT7E
0091eP06AMI1eD7F@MI5eT7E0T7F00E5eT7E@MI1eTGF0080M0037>LUVBFH008UV0039IUl07I;009f
B`03O01oogoo07aoo`03001oogoo015oo`03001oogoo00Eoo`0027oo00<007ooOol0:Goo00<007oo
Ool04goo02`Li`dg4CP==a4h3CLLic6g=KPa]cFh<KLe^36g=KPa]cFh<KLe^1cWAMI1eDGF@ME5eT7E
AMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMH0M01e7>LUVBFH0W`000AfBg9;O01l07moo`03001oogoo
011oo`03001oogoo00Ioo`0027oo00<007ooOol0:7oo00<007ooOol05Goo00LLi`dg3CP==`dh=KLL
i`0<=KL27>L00d7FAMI1e@02@MH01TGF@ME1eT7FAMI1e@91eP0:AMI1eD7F@MI5eP1d7>LUV7`0LT/2
MT/00g`0Oomoo`1oOol00`00Oomoo`0@Ool00`00Oomoo`06Ool000Uoo`03001oogoo02Moo`03001o
ogoo01Eoo`0W3CLLi`dg4CP==a4h<KLLic6g=KPa]cFh<KLe^36g=KPa]cFh<KLe^36g7>M1eDGF@ME5
eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7E00Ml08=oo`03001oogoo00moo`03001oogoo00Ioo`00
2Goo00<007ooOol09Woo00<007ooOol05goo00PLi`dh3CL=>0dg3CPe]acW3CFg00@Lid7FAMI1e@91
eP06AMI1eD7F@MI5eT7E0T7F00Q5eT7E@MI1eTGFO01oog`0QGoo00<007ooOol03goo00<007ooOol0
1Woo0009Ool00`00Oomoo`0VOol00`00Oomoo`0HOol0:1cW4CP==a4h3CLA>1cW=KPa]cFh<KLe^36g
=KPa]cFh<KLe^36g=KPa]acW@ME5eT7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7EAMI1eG`0Qgoo00<0
07ooOol03goo00<007ooOol01Woo0009Ool00`00Oomoo`0UOol00`00Oomoo`0IOol020dh7>L=>0dg
3CP==cFg7>L>=KL011cW@MI5eT7E0T7F00I5eT7E@MI1eTGF@MD2@MH00dGF@MEl0028Ool00`00Oomo
o`0?Ool00`00Oomoo`06Ool000Uoo`03001oogoo02Eoo`03001oogoo01Yoo`0V7>L==a4h3CLA>0dg
=KPLicFh<KLe^36g=KPa]cFh<KLe^36g=KPa]cFh<KLLid7EAMI1eDGF@ME5eT7EAMI1eDGF@ME5eT7E
AMIl08Qoo`03001oogoo00moo`03001oogoo00Ioo`002Goo00<007ooOol097oo00<007ooOol06goo
00T==acW3CL=>0dg3CP==cFg7>L03SFg00@Lid7FAMI1e@91eP08AMI1eD7F@MI5eT7E@MIl08Yoo`03
001oogoo00ioo`03001oogoo00Ioo`002Goo00<007ooOol08goo00<007ooOol07Goo02@==acW3CLA
>0dg4CP==acW<KLe^36g=KPa]cFh<KLe^36g=KPa]cFh<KLe^36g7>M1eDGF@ME5eT7EAMI1eDGF@ME5
eT7EO02:Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool000Uoo`03001oogoo02=oo`03001oogoo01io
o`087>L=>0dg3CP==`dh3CLLi`le]`047>M1eTGF@MD2@MH01DGF@ME1eT7FO000Rgoo00<007ooOol0
3Woo00<007ooOol01Woo0009Ool00`00Oomoo`0ROol00`00Oomoo`0OOol08Q4h7>LA>0dg4CP==a4h
<KLLic6g=KPa]cFh<KLe^36g=KPa]cFh<KLe^36g=KPa]acW@ME5eT7EAMI1eDGF@ME5eW`0Rgoo00<0
07ooOol03Woo00<007ooOol01Woo0009Ool00`00Oomoo`0ROol00`00Oomoo`0POol02AcW3CL=>0dg
3CP==`dh=KLLi`0?=KL27>L01TGF@ME1eT7FAMIl08aoo`03001oogoo00ioo`03001oogoo00Ioo`00
2Goo00<007ooOol08Goo00<007ooOol08Woo01lLi`dg4CP==a4h3CLA>1cW=KPa]cFh<KLe^36g=KPa
]cFh<KLe^36g=KPa]cFh<KLe^1cWAMI1eDGF@MEl002<Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool0
00Uoo`03001oogoo025oo`03001oogoo029oo`093CLLi`dg3CP==`dh3CL=>1cW014e]`047>M5eT7E
O02>Ool00`00Oomoo`0=Ool00`00Oomoo`06Ool000Uoo`03001oogoo021oo`03001oogoo02Aoo`0M
7>LA>0dg4CP==a4h3CLe^1cW=KPa]cFh<KLe^36g=KPa]cFh<KLe^36g=KPa]cFh<KLe^1cWAMIl002>
Ool00`00Oomoo`0=Ool00`00Oomoo`06Ool000Uoo`03001oogoo021oo`03001oogoo02Eoo`097>L=
>0dg3CP==`dh3CLe]acW014e]`03O01oogoo08eoo`03001oogoo00eoo`03001oogoo00Ioo`002Goo
00<007ooOol07goo00<007ooOol09Woo01XA>1cW4CP==a4h3CLA>0dg7>La]cFh<KLe^36g=KPa]cFh
<KLe^36g=KPa]cFh<KLe^7`0T7oo00<007ooOol03Goo00<007ooOol01Woo0009Ool00`00Oomoo`0O
Ool00`00Oomoo`0WOol02AcW3CL=>0dg3CP==`dh3CLLi`0?=KL00g`0Oomoo`2>Ool00`00Oomoo`0=
Ool00`00Oomoo`06Ool000Uoo`03001oogoo01ioo`03001oogoo02Uoo`0G7>L==a4h3CLA>0dg4CP=
=acW<KLe^36g=KPa]cFh<KLe^36g=KPa]cFh<KMl002BOol00`00Oomoo`0<Ool00`00Oomoo`06Ool0
00Uoo`03001oogoo01ioo`03001oogoo02Uoo`0:7>L=>0dg3CP==`dh3CL=>3Fg7>L<=KL00g`0Oomo
o`2@Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool000Uoo`03001oogoo01eoo`03001oogoo02]oo`0E
7>LA>0dg4CP==a4h3CLA>1cW=KPa]cFh<KLe^36g=KPa]cFh<KLe^7`009=oo`03001oogoo00aoo`03
001oogoo00Ioo`002Goo00<007ooOol07Goo00<007ooOol0:goo00X=>1cW3CP==`dh3CL=>0dg3CPL
i`Xe]`03O01oogoo095oo`03001oogoo00aoo`03001oogoo00Ioo`002Goo00<007ooOol077oo00<0
07ooOol0;Goo01<Li`dg4CP==a4h3CLA>0dg4CPLicFh<KLe^36g=KPa]cFh<KMl002DOol00`00Oomo
o`0<Ool00`00Oomoo`06Ool000Yoo`03001oogoo01]oo`03001oogoo02ioo`0:7>L==`dh3CL=>0dg
3CP==cFg7>L6=KL00g`0Oomoo`2DOol00`00Oomoo`0;Ool00`00Oomoo`06Ool000Yoo`03001oogoo
01Yoo`03001oogoo02moo`0A3CLLi`dg4CP==a4h3CLA>0dg7>La]cFh<KLe^36g=KQl002FOol00`00
Oomoo`0:Ool00`00Oomoo`07Ool000Yoo`03001oogoo01Uoo`03001oogoo035oo`0:7>L=>0dg3CP=
=`dh3CL=>0dg7>L4=KL00g`0Oomoo`2EOol00`00Oomoo`0:Ool00`00Oomoo`07Ool000Yoo`03001o
ogoo01Uoo`03001oogoo039oo`0>7>LA>0dg4CP==a4h3CLA>0dg7>La]cFh<KMl09Moo`03001oogoo
00Yoo`03001oogoo00Moo`002Woo00<007ooOol067oo00<007ooOol0<goo00dLi`dg3CP==`dh3CL=
>0dg3CPe]acW=KMl002HOol00`00Oomoo`0:Ool00`00Oomoo`07Ool000Yoo`03001oogoo01Qoo`03
001oogoo03Aoo`0<7>L==a4h3CLA>0dg4CP==a4h7>Le^7`0VGoo00<007ooOol02Goo00<007ooOol0
1goo000:Ool00`00Oomoo`0GOol00`00Oomoo`0fOol02QcW3CL=>0dg3CP==`dh3CL=>7`0VWoo00<0
07ooOol02Goo00<007ooOol01goo000:Ool00`00Oomoo`0GOol00`00Oomoo`0fOol02AcW4CP==a4h
3CLA>0dg4CQl002KOol00`00Oomoo`09Ool00`00Oomoo`07Ool000Yoo`03001oogoo01Ioo`03001o
ogoo03Qoo`087>L=>0dg3CP==`dh3CMl09]oo`03001oogoo00Uoo`03001oogoo00Moo`002Woo00<0
07ooOol05Woo00<007ooOol0>7oo00LA>1cW4CP==a4h3CMl002LOol00`00Oomoo`09Ool00`00Oomo
o`07Ool000Yoo`03001oogoo01Eoo`03001oogoo03Yoo`057>L==`dh3CMl002NOol00`00Oomoo`08
Ool00`00Oomoo`07Ool000Yoo`03001oogoo01Eoo`03001oogoo03]oo`037>L==g`009moo`03001o
ogoo00Qoo`03001oogoo00Moo`002Woo00<007ooOol057oo00<007ooOol0?7oo00<Li`dhO000Wgoo
00<007ooOol027oo00<007ooOol01goo000:Ool00`00Oomoo`0DOol00`00Oomoo`0mOol00g`0Oomo
o`2NOol00`00Oomoo`08Ool00`00Oomoo`07Ool000Yoo`03001oogoo01=oo`03001oogoo0=moo`03
001oogoo00Qoo`03001oogoo00Moo`002Woo00<007ooOol04goo00<007ooOol0h7oo00<007ooOol0
1goo00<007ooOol01goo000:Ool00`00Oomoo`0BOol00`00Oomoo`3QOol00`00Oomoo`07Ool00`00
Oomoo`07Ool000Yoo`03001oogoo019oo`03001oogoo0>5oo`03001oogoo00Moo`03001oogoo00Mo
o`002Woo00<007ooOol04Goo00<007ooOol0hWoo00<007ooOol01goo00<007ooOol01goo000:Ool0
0`00Oomoo`0@Ool00`00Oomoo`3SOol00`00Oomoo`07Ool00`00Oomoo`07Ool000Yoo`03001oogoo
011oo`03001oogoo0>=oo`03001oogoo00Moo`03001oogoo00Moo`002goo00<007ooOol03Woo00<0
07ooOol0iGoo00<007ooOol01Woo00<007ooOol01goo000;Ool00`00Oomoo`0>Ool00`00Oomoo`3U
Ool00`00Oomoo`06Ool00`00Oomoo`07Ool000]oo`03001oogoo00eoo`03001oogoo0>Ioo`03001o
ogoo00Ioo`03001oogoo00Moo`002goo00<007ooOol03Goo00<007ooOol0iWoo00<007ooOol01Goo
00<007ooOol027oo000;Ool00`00Oomoo`0<Ool00`00Oomoo`3WOol00`00Oomoo`05Ool00`00Oomo
o`08Ool000]oo`03001oogoo00aoo`03001oogoo0>Qoo`03001oogoo00Aoo`03001oogoo00Qoo`00
2goo00<007ooOol02goo00<007ooOol0jGoo00<007ooOol017oo00<007ooOol027oo000;Ool00`00
Oomoo`0;Ool00`00Oomoo`3YOol00`00Oomoo`04Ool00`00Oomoo`08Ool000]oo`03001oogoo00Yo
o`03001oogoo0>Yoo`03001oogoo00Aoo`03001oogoo00Qoo`002goo00<007ooOol02Woo00<007oo
Ool0jWoo00<007ooOol017oo00<007ooOol027oo000;Ool00`00Oomoo`09Ool00`00Oomoo`3/Ool0
0`00Oomoo`03Ool00`00Oomoo`08Ool000]oo`03001oogoo00Uoo`03001oogoo0>aoo`03001oogoo
00=oo`03001oogoo00Qoo`002goo00<007ooOol027oo00<007ooOol0kGoo00<007ooOol00goo00<0
07ooOol027oo000;Ool00`00Oomoo`08Ool00`00Oomoo`3]Ool00`00Oomoo`03Ool00`00Oomoo`08
Ool000]oo`03001oogoo00Moo`03001oogoo0>ioo`03001oogoo00=oo`03001oogoo00Qoo`002goo
00<007ooOol01Woo00<007ooOol0l7oo00<007ooOol00Woo00<007ooOol027oo000;Ool00`00Oomo
o`06Ool00`00Oomoo`3`Ool00`00Oomoo`02Ool00`00Oomoo`08Ool000]oo`03001oogoo00Eoo`03
001oogoo0?5oo`03001oogoo009oo`03001oogoo00Qoo`002goo00<007ooOol01Goo00<007ooOol0
lGoo00<007ooOol00Woo00<007ooOol027oo000;Ool00`00Oomoo`04Ool00`00Oomoo`3bOol00`00
Oomoo`02Ool00`00Oomoo`08Ool000]oo`03001oogoo00Aoo`03001oogoo0?=oo`05001oogooOol0
000:Ool000aoo`03001oogoo009oo`03001oogoo0?Aoo`05001oogooOol0000:Ool000aoo`03001o
ogoo009oo`03001oogoo0?Aoo`05001oogooOol0000:Ool000aoo`05001oogooOol0003gOol01@00
Oomoogoo00002Woo000<Ool01@00Oomoogoo0000mgoo00D007ooOomoo`0000Yoo`0037oo00@007oo
Ool00?Qoo`05001oogooOol0000:Ool000aoo`04001oogoo003iOol01000Oomoo`002Woo000<Ool0
0`00Ool0003jOol00`00Ool0000;Ool000aoo`03001oo`000?Yoo`03001oo`0000]oo`0037oo0P00
ngoo00<007oo00002goo000<Ool2003kOol00`00Ool0000;Ool000aooa<00>]oo`8000]oo`007goo
9000agoo0P002goo0013OolU002ROol2000;Ool006Qoob@007ioo`8000]oo`00S7oo9000FWoo0P00
2goo002`OolU000fOol00`00Oomoo`09Ool00=Eoob@0019oo`03001oogoo00Uoo`00nGoo4`002goo
0000
\>"],
  ImageRangeCache->{{{0, 278.313}, {287, 0}} -> {0.0408935, 0.102734, 
  0.00312668, 0.00312668}}]
}, Open]]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

5 .73903 L
s
.25 g
.5 Mabswid
.43245 .62997 m
.45167 .73888 L
s
.50236 .62168 m .56214 .71286 ,

Cell[CellGroupData[{

Cell["\<\

clear;top=100;kappa[s_]:=Cos[s];tau[s_]:=Cos[s];

 ds:=0.1;width=1.0;pribbonfrenet
\
\>", "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.42842 .55657 m .50214 .66812 L .52464 .67355 L .563 .696 .93 r
F
.41905 .54963 m .50214 .66812 L .42842 .55657 L .569 .692 .924 r
F
.41905 .54963 m .47827 .65979 L .50214 .66812 L F
.43718 .56239 m .52464 .67355 L .54521 .67594 L .558 .701 .936 r
F
.42842 .55657 m .52464 .67355 L .43718 .56239 L .563 .696 .93 r
F
1 0 0 r
.003 w
.50214 .66812 m
.52464 .67355 L
s
.25 g
.5 Mabswid
.52347 .67207 m
.52464 .67355 L
s
.40921 .54162 m .47827 .65979 L .41905 .54963 L .575 .689 .918 r
F
.40921 .54162 m .45358 .64883 L .47827 .65979 L F
.25 g
.50078 .66606 m
.50214 .66812 L
s
1 0 0 r
.003 w
.47827 .65979 m
.50214 .66812 L
s
.25 g
.5 Mabswid
.52246 .67078 m
.52347 .67207 L
s
.44516 .56704 m .54521 .67594 L .56337 .67522 L .555 .707 .941 r
F
.43718 .56239 m .54521 .67594 L .44516 .56704 L .558 .701 .936 r
F
1 0 0 r
.003 w
.52464 .67355 m
.54521 .67594 L
s
.25 g
.5 Mabswid
.54328 .67384 m
.54374 .67433 L
s
.54374 .67433 m
.54434 .67499 L
s
.54434 .67499 m
.54521 .67594 L
s
.39906 .53265 m .45358 .64883 L .40921 .54162 L .583 .686 .912 r
F
.39906 .53265 m .42864 .63559 L .45358 .64883 L F
.25 g
.49948 .66409 m
.50078 .66606 L
s
.52147 .66953 m
.52246 .67078 L
s
.47685 .65715 m
.47827 .65979 L
s
1 0 0 r
.003 w
.45358 .64883 m
.47827 .65979 L
s
.25 g
.5 Mabswid
.54282 .67334 m
.54328 .67384 L
s
.45221 .57052 m .56337 .67522 L .57869 .67148 L .554 .713 .946 r
F
.44516 .56704 m .56337 .67522 L .45221 .57052 L .555 .707 .941 r
F
1 0 0 r
.003 w
.54521 .67594 m
.56337 .67522 L
s
.25 g
.5 Mabswid
.42919 .55773 m
.43026 .55935 L
s
.43718 .56239 m
.43811 .56357 L
s
.56279 .67468 m
.56337 .67522 L
s
.44516 .56704 m
.44532 .56722 L
s
.38873 .5228 m .42864 .63559 L .39906 .53265 L .59 .684 .906 r
F
.38873 .5228 m .40395 .62048 L .42864 .63559 L F
.25 g
.41905 .54963 m
.41964 .55074 L
s
.42842 .55657 m
.42919 .55773 L
s
.41964 .55074 m
.42049 .55231 L
s
.41025 .54415 m
.41107 .54613 L
s
.40964 .54266 m
.41025 .54415 L
s
.40921 .54162 m
.40964 .54266 L
s
.47539 .65443 m
.47685 .65715 L
s
.42049 .55231 m
.4216 .55438 L
s
.45224 .64559 m
.45358 .64883 L
s
.41107 .54613 m
.41211 .54864 L
s
1 0 0 r
.003 w
.42864 .63559 m
.45358 .64883 L
s
.45819 .57283 m .57869 .67148 L .59086 .66489 L .555 .721 .951 r
F
.45221 .57052 m .57869 .67148 L .45819 .57283 L .554 .713 .946 r
F
.25 g
.5 Mabswid
.43026 .55935 m
.43165 .56145 L
s
.43811 .56357 m
.43938 .56519 L
s
.44532 .56722 m
.44623 .56821 L
s
1 0 0 r
.003 w
.56337 .67522 m
.57869 .67148 L
s
.25 g
.5 Mabswid
.4216 .55438 m
.42299 .55697 L
s
.41339 .55172 m
.45224 .64559 L
s
.41211 .54864 m
.41339 .55172 L
s
.45235 .57065 m
.45357 .5718 L
s
.45221 .57052 m
.45235 .57065 L
s
.37834 .51218 m .40395 .62048 L .38873 .5228 L .598 .681 .9 r
F
.37834 .51218 m .37999 .60395 L .40395 .62048 L F
.25 g
.40026 .53681 m
.42752 .63172 L
s
.42752 .63172 m
.42864 .63559 L
s
.39972 .53496 m
.40026 .53681 L
s
.39906 .53265 m
.39972 .53496 L
s
1 0 0 r
.003 w
.40395 .62048 m
.42864 .63559 L
s
.25 g
.5 Mabswid
.38886 .52363 m
.40395 .62048 L
s
.38873 .5228 m
.38886 .52363 L
s
.36795 .50091 m .37999 .60395 L .37834 .51218 L .605 .679 .894 r
F
.36795 .50091 m .35713 .58647 L .37999 .60395 L F
1 0 0 r
.003 w
.37999 .60395 m
.40395 .62048 L
s
.25 g
.5 Mabswid
.37834 .51218 m
.37999 .60395 L
s
.463 .57402 m .59086 .66489 L .59967 .65576 L .558 .729 .954 r
F
.45819 .57283 m .59086 .66489 L .463 .57402 L .555 .721 .951 r
F
.25 g
.43165 .56145 m
.43337 .56405 L
s
.43938 .56519 m
.44102 .56727 L
s
.44623 .56821 m
.44768 .56979 L
s
.42299 .55697 m
.42468 .56011 L
s
1 0 0 r
.003 w
.57869 .67148 m
.59086 .66489 L
s
.25 g
.5 Mabswid
.45831 .57292 m
.45967 .57403 L
s
.45819 .57283 m
.45831 .57292 L
s
.35765 .48908 m .35713 .58647 L .36795 .50091 L .611 .676 .887 r
F
.35765 .48908 m .33569 .56851 L .35713 .58647 L F
1 0 0 r
.003 w
.35713 .58647 m
.37999 .60395 L
s
.46656 .57418 m .59967 .65576 L .60507 .64447 L .563 .738 .958 r
F
.25 g
.5 Mabswid
.59042 .66458 m
.59086 .66489 L
s
.463 .57402 m .59967 .65576 L .46656 .57418 L .558 .729 .954 r
F
.25 g
.43337 .56405 m
.43543 .56717 L
s
.44102 .56727 m
.44301 .56981 L
s
.44768 .56979 m
.44951 .57178 L
s
.45357 .5718 m
.45498 .57312 L
s
.42468 .56011 m
.42668 .56383 L
s
1 0 0 r
.003 w
.59086 .66489 m
.59967 .65576 L
s
.25 g
.5 Mabswid
.46454 .57511 m
.46651 .57651 L
s
.463 .57402 m
.46454 .57511 L
s
.34744 .47678 m .33569 .56851 L .35765 .48908 L .616 .673 .881 r
F
.25 g
.35713 .58647 m
.36795 .50091 L
s
.34744 .47678 m .31589 .5505 L .33569 .56851 L .616 .673 .881 r
F
1 0 0 r
.003 w
.33569 .56851 m
.35713 .58647 L
s
.33734 .46412 m .31589 .5505 L .34744 .47678 L .62 .669 .875 r
F
.33734 .46412 m .29787 .53284 L .31589 .5505 L F
.25 g
.5 Mabswid
.3377 .56125 m
.35765 .48908 L
s
.33569 .56851 m
.3377 .56125 L
s
1 0 0 r
.003 w
.31589 .5505 m
.33569 .56851 L
s
.15271 .26459 m .28146 .39903 L .27435 .40455 L .825 .749 .779 r
F
.15271 .26459 m .26309 .39159 L .15805 .26692 L F
.26309 .39159 m .2625 .39076 L .15805 .26692 L F
.26689 .39596 m .26616 .395 L .15805 .26692 L F
.26992 .39945 m .26894 .39821 L .15805 .26692 L F
.27237 .40226 m .27066 .40018 L .15805 .26692 L F
.26309 .39159 m .26689 .39596 L .2625 .39076 L F
.26689 .39596 m .26992 .39945 L .26616 .395 L F
.26992 .39945 m .27237 .40226 L .26894 .39821 L F
.27237 .40226 m .27435 .40455 L .27066 .40018 L F
.15805 .26692 m .27435 .40455 L .2665 .40886 L .834 .76 .782 r
F
.15805 .26692 m .25376 .39219 L .16477 .27068 L F
.25376 .39219 m .25322 .39122 L .16477 .27068 L F
.258 .39774 m .25728 .39658 L .16477 .27068 L F
.26142 .40221 m .2596 .3995 L .25631 .39502 L F
.25728 .39658 m .25631 .39502 L .16477 .27068 L F
.26142 .40221 m .25631 .39502 L .25728 .39658 L F
.2558 .40836 m .2665 .40886 L .25827 .4121 L .843 .773 .784 r
F
.25376 .39219 m .258 .39774 L .25322 .39122 L .834 .76 .782 r
F
.258 .39774 m .26142 .40221 L .25728 .39658 L F
.16528 .27146 m .2596 .3995 L .2558 .40836 L .843 .773 .784 r
F
.26142 .40221 m .2665 .40886 L .2596 .3995 L .834 .76 .782 r
F
.2596 .3995 m .2665 .40886 L .2558 .40836 L .843 .773 .784 r
F
.16586 .27216 m .2665 .40886 L .16528 .27146 L F
.16477 .27068 m .16586 .27216 L .16528 .27146 L F
.16477 .27068 m .24467 .39153 L .17269 .27588 L F
.24467 .39153 m .24918 .39835 L .24424 .39044 L F
.24467 .39153 m .24424 .39044 L .17269 .27588 L F
.24918 .39835 m .24853 .39701 L .17269 .27588 L F
.25282 .40386 m .25109 .40067 L .24768 .39525 L F
.24853 .39701 m .24768 .39525 L .17269 .27588 L F
.25282 .40386 m .24768 .39525 L .24853 .39701 L F
.24918 .39835 m .25282 .40386 L .24853 .39701 L F
.25282 .40386 m .25827 .4121 L .25109 .40067 L F
.17327 .27692 m .2539 .40515 L .25006 .4145 L .853 .787 .786 r
F
.17269 .27588 m .17362 .27737 L .17327 .27692 L F
.17362 .27737 m .25827 .4121 L .17327 .27692 L F
.17269 .27588 m .23629 .38983 L .18163 .28249 L F
.23629 .38983 m .23608 .38868 L .18163 .28249 L F
.24086 .39801 m .23977 .39465 L .18163 .28249 L F
.18199 .28327 m .18215 .28358 L .18209 .28349 L .866 .804 .787 r
F
.24086 .39801 m .25006 .4145 L .23977 .39465 L .853 .787 .786 r
F
.18215 .28358 m .25006 .4145 L .18209 .28349 L .866 .804 .787 r
F
.18163 .28249 m .18215 .28349 L .18199 .28327 L F
.18215 .28349 m .25006 .4145 L .18199 .28327 L F
.18163 .28249 m .22915 .38734 L .19138 .29041 L F
.22915 .38734 m .22926 .38621 L .19138 .29041 L F
.23352 .397 m .23331 .39542 L .19138 .29041 L F
.23705 .40479 m .23604 .40088 L .23305 .3935 L F
.23331 .39542 m .23305 .3935 L .19138 .29041 L F
.23705 .40479 m .23305 .3935 L .23331 .39542 L F
.19178 .29138 m .19193 .29176 L .19176 .29136 L .883 .825 .785 r
F
.23705 .40479 m .24229 .41634 L .23604 .40088 L .866 .804 .787 r
F
.19193 .29176 m .24229 .41634 L .19191 .29173 L .883 .825 .785 r
F
.19193 .29176 m .19191 .29173 L .19176 .29136 L F
.23629 .38983 m .24086 .39801 L .23608 .38868 L .853 .787 .786 r
F
.2115 .34018 m .25006 .4145 L .24229 .41634 L .866 .804 .787 r
F
.19142 .29051 m .19178 .29138 L .19141 .29049 L .883 .825 .785 r
F
.19178 .29138 m .19176 .29136 L .19141 .29049 L F
.22915 .38734 m .23352 .397 L .22926 .38621 L .866 .804 .787 r
F
.23352 .397 m .23705 .40479 L .23331 .39542 L F
.19165 .29117 m .24229 .41634 L .22761 .39557 L .883 .825 .785 r
F
.22761 .39557 m .24229 .41634 L .23532 .41796 L F
.19141 .29049 m .19176 .29136 L .19165 .29117 L F
.19176 .29136 m .24229 .41634 L .19165 .29117 L F
.19138 .29041 m .19142 .29051 L .19141 .29049 L F
.19138 .29041 m .22761 .39557 L .20173 .29952 L F
.22761 .39557 m .22778 .39395 L .20173 .29952 L F
.23073 .40465 m .23052 .4022 L .2279 .39286 L F
.22778 .39395 m .2279 .39286 L .20173 .29952 L F
.23073 .40465 m .2279 .39286 L .22778 .39395 L F
.22761 .39557 m .23073 .40465 L .22778 .39395 L F
.23073 .40465 m .23326 .41198 L .23052 .4022 L F
.23326 .41198 m .23233 .40742 L .23037 .4005 L F
.23052 .4022 m .23037 .4005 L .22507 .38181 L F
.23052 .4022 m .22507 .38181 L .22489 .38213 L F
.23326 .41198 m .23037 .4005 L .23052 .4022 L F
.22489 .38213 m .22507 .38181 L .20173 .29952 L F
.2019 .30025 m .23233 .40742 L .2295 .41972 L .906 .852 .778 r
F
.20177 .29967 m .20199 .30045 L .20176 .29965 L F
.23326 .41198 m .23532 .41796 L .23233 .40742 L .883 .825 .785 r
F
.20199 .30045 m .23532 .41796 L .20197 .30042 L .906 .852 .778 r
F
.20199 .30045 m .20197 .30042 L .20176 .29965 L F
.20176 .29965 m .20197 .30042 L .2019 .30025 L F
.20197 .30042 m .23532 .41796 L .2019 .30025 L F
.20173 .29952 m .20177 .29967 L .20176 .29965 L F
.20173 .29952 m .22354 .39391 L .21246 .30969 L F
.22354 .39391 m .22598 .40447 L .225 .39064 L F
.22598 .40447 m .22648 .40019 L .225 .39064 L F
.22354 .39391 m .225 .39064 L .21246 .30969 L F
.22598 .40447 m .2295 .41972 L .22648 .40019 L F
.22599 .39705 m .22768 .40799 L .22599 .39705 L .94 .889 .754 r
F
.22599 .39705 m .22599 .39705 L .22396 .384 L F
.22396 .38397 m .22599 .39705 L .22396 .384 L F
.22396 .38397 m .22396 .384 L .21255 .31041 L F
.21259 .31059 m .22396 .38397 L .21255 .31041 L F
.22768 .40799 m .22768 .408 L .21255 .31041 L F
.21257 .31048 m .21255 .31041 L .21252 .31025 L F
.21259 .31059 m .21255 .31041 L .21257 .31048 L F
.21255 .31049 m .2295 .41972 L .2251 .42196 L F
.21252 .31025 m .21258 .31059 L .21255 .31049 L F
.21258 .31059 m .2295 .41972 L .21255 .31049 L F
.21248 .30985 m .21259 .31059 L .21252 .31025 L F
.21246 .30969 m .21249 .30988 L .21248 .30985 L F
.21249 .30988 m .2295 .41972 L .21248 .30985 L F
.21246 .30969 m .22423 .4142 L .2234 .32076 L F
.22423 .4142 m .2251 .42196 L .22488 .40895 L F
.22423 .4142 m .22488 .40895 L .2234 .32076 L F
.22483 .40592 m .2251 .42196 L .22234 .42501 L .974 .925 .663 r
F
.22339 .3214 m .22339 .32151 L .22339 .32148 L F
.22339 .32151 m .2251 .42196 L .22339 .32148 L F
.22341 .32154 m .22341 .32175 L .22341 .3215 L F
.22341 .32175 m .2251 .42196 L .22341 .32168 L F
.22341 .32175 m .22341 .32168 L .22341 .3215 L F
.2234 .32097 m .22341 .32154 L .2234 .32094 L F
.22341 .32154 m .22341 .3215 L .2234 .32094 L F
.2234 .32094 m .22341 .3215 L .22339 .3214 L F
.22341 .3215 m .2251 .42196 L .22339 .3214 L F
.2234 .32076 m .2234 .32097 L .2234 .32094 L F
.2234 .32076 m .22234 .42501 L .23439 .33257 L F
.2343 .33325 m .23428 .33339 L .23431 .33323 L .803 .76 .245 r
F
.23428 .33339 m .22234 .42501 L .23429 .33335 L F
.23428 .33339 m .23429 .33335 L .23431 .33323 L F
.22768 .40799 m .2295 .41972 L .22768 .408 L .94 .889 .754 r
F
.24519 .34549 m .22135 .42915 L .22222 .43461 L 0 0 .494 r
F
.24527 .34518 m .24516 .34554 L .24519 .34549 L F
.24516 .34554 m .22135 .42915 L .24519 .34549 L F
.24533 .34495 m .24526 .3452 L .24527 .34518 L F
.24526 .3452 m .22135 .42915 L .24527 .34518 L F
.23233 .40742 m .23532 .41796 L .2295 .41972 L .906 .852 .778 r
F
.2343 .33327 m .23429 .33332 L .2343 .33325 L .803 .76 .245 r
F
.23429 .33332 m .22234 .42501 L .2343 .33325 L F
.23436 .3328 m .2343 .33327 L .23436 .33277 L F
.2343 .33327 m .23431 .33323 L .23436 .33277 L F
.23431 .33315 m .22234 .42501 L .22135 .42915 L F
.23436 .33277 m .23431 .33323 L .23431 .33315 L F
.23431 .33323 m .22234 .42501 L .23431 .33315 L F
.23439 .33257 m .23436 .3328 L .23436 .33277 L F
.2539 .40515 m .25827 .4121 L .25006 .4145 L .853 .787 .786 r
F
.25 g
.5 Mabswid
.27066 .40018 m
.27435 .40455 L
s
.2682 .39726 m
.27066 .40018 L
s
.26518 .3937 m
.2682 .39726 L
s
.24375 .36833 m
.26518 .3937 L
s
.24034 .3643 m
.24375 .36833 L
s
1 0 0 r
.003 w
.27435 .40455 m
.28146 .39903 L
s
.25 g
.5 Mabswid
.27853 .39597 m
.28146 .39903 L
s
.27646 .3938 m
.27853 .39597 L
s
.27386 .3911 m
.27646 .3938 L
s
.27061 .3877 m
.27386 .3911 L
s
.2464 .36242 m
.27061 .3877 L
s
.23595 .3515 m
.24174 .35755 L
s
.24201 .35783 m
.2464 .36242 L
s
1 0 0 r
.003 w
.2665 .40886 m
.27435 .40455 L
s
.46882 .5734 m .60507 .64447 L .60713 .63148 L .569 .747 .961 r
F
.25 g
.5 Mabswid
.5976 .65449 m
.59967 .65576 L
s
.59031 .6645 m
.59042 .66458 L
s
.46656 .57418 m .60507 .64447 L .46882 .5734 L .563 .738 .958 r
F
.25 g
.43543 .56717 m
.43783 .57081 L
s
.44301 .56981 m
.44537 .57281 L
s
.44951 .57178 m
.45172 .57418 L
s
.45498 .57312 m
.45695 .57498 L
s
.42668 .56383 m
.429 .56815 L
s
.45967 .57403 m
.46113 .57523 L
s
1 0 0 r
.003 w
.59967 .65576 m
.60507 .64447 L
s
.25 g
.5 Mabswid
.26232 .40318 m
.2665 .40886 L
s
.25631 .39502 m
.26232 .40318 L
s
.25227 .38954 m
.25631 .39502 L
s
.24728 .38275 m
.25227 .38954 L
s
.24109 .37434 m
.24728 .38275 L
s
.23862 .37099 m
.24109 .37434 L
s
1 0 0 r
.003 w
.25827 .4121 m
.2665 .40886 L
s
.25 g
.5 Mabswid
.25109 .40067 m
.25827 .4121 L
s
.24768 .39525 m
.25109 .40067 L
s
.24353 .38863 m
.24768 .39525 L
s
.23842 .3805 m
.24353 .38863 L
s
.23682 .37796 m
.23842 .3805 L
s
1 0 0 r
.003 w
.25006 .4145 m
.25827 .4121 L
s
.32734 .45116 m .29787 .53284 L .33734 .46412 L .622 .663 .869 r
F
.25 g
.5 Mabswid
.33717 .46442 m
.33734 .46412 L
s
.32734 .45116 m .28172 .5159 L .29787 .53284 L .622 .663 .869 r
F
.25 g
.31589 .5505 m
.31968 .54163 L
s
1 0 0 r
.003 w
.29787 .53284 m
.31589 .5505 L
s
.25 g
.5 Mabswid
.24582 .40631 m
.25006 .4145 L
s
.24308 .40103 m
.24582 .40631 L
s
.23977 .39465 m
.24308 .40103 L
s
.23574 .38686 m
.23977 .39465 L
s
.23493 .3853 m
.23574 .38686 L
s
1 0 0 r
.003 w
.24229 .41634 m
.25006 .4145 L
s
.31739 .43798 m .28172 .5159 L .32734 .45116 L .621 .655 .862 r
F
.25 g
.5 Mabswid
.32718 .45138 m
.32734 .45116 L
s
.31968 .54163 m
.34744 .47678 L
s
.31739 .43798 m .26749 .49995 L .28172 .5159 L .621 .655 .862 r
F
.25 g
.29787 .53284 m
.30453 .52126 L
s
1 0 0 r
.003 w
.28172 .5159 m
.29787 .53284 L
s
.25 g
.5 Mabswid
.2385 .40696 m
.24229 .41634 L
s
.23291 .39314 m
.23305 .3935 L
s
1 0 0 r
.003 w
.23532 .41796 m
.24229 .41634 L
s
.25 g
.5 Mabswid
.2307 .40169 m
.23532 .41796 L
s
1 0 0 r
.003 w
.2295 .41972 m
.23532 .41796 L
s
.46977 .57181 m .60713 .63148 L .60606 .6173 L .577 .756 .963 r
F
.25 g
.5 Mabswid
.60111 .6424 m
.60507 .64447 L
s
.59641 .65376 m
.5976 .65449 L
s
.58998 .66427 m
.59031 .6645 L
s
.46882 .5734 m .60713 .63148 L .46977 .57181 L .569 .747 .961 r
F
.25 g
.44058 .57497 m
.49948 .66409 L
s
.43783 .57081 m
.44058 .57497 L
s
.44808 .57625 m
.52147 .66953 L
s
.44537 .57281 m
.44808 .57625 L
s
.45428 .57698 m
.54282 .67334 L
s
.45172 .57418 m
.45428 .57698 L
s
.45695 .57498 m
.45928 .57718 L
s
.43165 .57307 m
.47539 .65443 L
s
.429 .56815 m
.43165 .57307 L
s
.46113 .57523 m
.46316 .5769 L
s
1 0 0 r
.003 w
.60507 .64447 m
.60713 .63148 L
s
.30745 .42463 m .26749 .49995 L .31739 .43798 L .617 .644 .855 r
F
.25 g
.5 Mabswid
.31701 .43844 m
.31739 .43798 L
s
.30745 .42463 m .25517 .48524 L .26749 .49995 L .617 .644 .855 r
F
.25 g
.31447 .50395 m
.33717 .46442 L
s
.30453 .52126 m
.31447 .50395 L
s
.28172 .5159 m
.29399 .49849 L
s
1 0 0 r
.003 w
.26749 .49995 m
.28172 .5159 L
s
.25 g
.5 Mabswid
.22821 .41138 m
.2295 .41972 L
s
1 0 0 r
.003 w
.22554 .42174 m
.2295 .41972 L
s
.29746 .41119 m .25517 .48524 L .30745 .42463 L .608 .629 .846 r
F
.25 g
.5 Mabswid
.30718 .42495 m
.30745 .42463 L
s
.29746 .41119 m .24476 .47195 L .25517 .48524 L .608 .629 .846 r
F
.25 g
.31667 .4663 m
.32718 .45138 L
s
.29855 .46137 m
.31701 .43844 L
s
1 0 0 r
.003 w
.25517 .48524 m
.26749 .49995 L
s
.22234 .42501 m
.22262 .4247 L
s
.28737 .39771 m .24476 .47195 L .29746 .41119 L .591 .606 .835 r
F
.25 g
.5 Mabswid
.29731 .41136 m
.29746 .41119 L
s
.29399 .49849 m
.31667 .4663 L
s
.28737 .39771 m .23626 .4602 L .24476 .47195 L .591 .606 .835 r
F
.25 g
.26749 .49995 m
.29855 .46137 L
s
1 0 0 r
.003 w
.24476 .47195 m
.25517 .48524 L
s
.25 g
.5 Mabswid
.23305 .3935 m
.2385 .40696 L
s
.27714 .38426 m .23626 .4602 L .28737 .39771 L .559 .569 .82 r
F
.25 g
.28714 .39799 m
.28737 .39771 L
s
.29724 .41145 m
.29731 .41136 L
s
.3067 .4255 m
.30718 .42495 L
s
.27714 .38426 m .22967 .45006 L .23626 .4602 L .559 .569 .82 r
F
1 0 0 r
.003 w
.23626 .4602 m
.24476 .47195 L
s
.23439 .33257 m .22135 .42915 L .24533 .34495 L .803 .76 .245 r
F
.25 g
.5 Mabswid
.28711 .39803 m
.28714 .39799 L
s
.25612 .35778 m .22222 .43461 L .22499 .44154 L .357 .363 .729 r
F
.24533 .34495 m .22222 .43461 L .25612 .35778 L 0 0 .494 r
F
.25 g
.28703 .39813 m
.28711 .39803 L
s
.29713 .41156 m
.29724 .41145 L
s
1 0 0 r
.003 w
.22135 .42915 m
.22222 .43461 L
s
.25 g
.5 Mabswid
.24512 .34568 m
.24515 .34558 L
s
.24515 .34558 m
.24526 .3452 L
s
.24526 .3452 m
.24533 .34495 L
s
.26673 .37092 m .22967 .45006 L .27714 .38426 L .497 .503 .793 r
F
.25 g
.27693 .38455 m
.27714 .38426 L
s
.26673 .37092 m .22499 .44154 L .22967 .45006 L .497 .503 .793 r
F
1 0 0 r
.003 w
.22967 .45006 m
.23626 .4602 L
s
.25612 .35778 m .22499 .44154 L .26673 .37092 L .357 .363 .729 r
F
.25 g
.5 Mabswid
.26657 .37119 m
.26673 .37092 L
s
.26644 .37141 m
.26657 .37119 L
s
.22499 .44154 m
.23994 .41625 L
s
.23994 .41625 m
.25304 .39408 L
s
.25304 .39408 m
.26644 .37141 L
s
1 0 0 r
.003 w
.22499 .44154 m
.22967 .45006 L
s
.25 g
.5 Mabswid
.22135 .42915 m
.22607 .41257 L
s
1 0 0 r
.003 w
.22222 .43461 m
.22499 .44154 L
s
.25 g
.5 Mabswid
.22967 .45006 m
.25706 .4121 L
s
.25706 .4121 m
.2769 .38459 L
s
.2769 .38459 m
.27693 .38455 L
s
.22222 .43461 m
.23092 .4149 L
s
.23092 .4149 m
.23763 .39968 L
s
.23763 .39968 m
.24708 .37825 L
s
.24708 .37825 m
.25585 .3584 L
s
.24476 .47195 m
.29709 .41162 L
s
.29709 .41162 m
.29713 .41156 L
s
.23626 .4602 m
.28703 .39813 L
s
.23396 .38486 m
.24 .36366 L
s
.22607 .41257 m
.22949 .40059 L
s
.22949 .40059 m
.23396 .38486 L
s
.25517 .48524 m
.3067 .4255 L
s
.256 .35804 m
.25612 .35778 L
s
.25588 .35833 m
.256 .35804 L
s
.25585 .3584 m
.25588 .35833 L
s
.24 .36366 m
.24512 .34568 L
s
.46944 .56953 m .60606 .6173 L .6022 .60245 L .585 .766 .965 r
F
.25 g
.60106 .62884 m
.60713 .63148 L
s
.59866 .64112 m
.60111 .6424 L
s
.59475 .65274 m
.59641 .65376 L
s
.58914 .66367 m
.58998 .66427 L
s
.46977 .57181 m .60606 .6173 L .46944 .56953 L .577 .756 .963 r
F
.25 g
.46195 .57969 m
.56279 .67468 L
s
.45928 .57718 m
.46195 .57969 L
s
.46554 .57884 m
.57869 .67148 L
s
.46316 .5769 m
.46554 .57884 L
s
.46805 .5776 m
.58914 .66367 L
s
.46651 .57651 m
.46805 .5776 L
s
1 0 0 r
.003 w
.60606 .6173 m
.60713 .63148 L
s
0 g
.006 w
.41905 .54963 m
.42842 .55657 L
s
.40921 .54162 m
.41905 .54963 L
s
.43401 .56029 m
.43718 .56239 L
s
.42842 .55657 m
.43401 .56029 L
s
.39906 .53265 m
.40921 .54162 L
s
.38873 .5228 m
.39906 .53265 L
s
.43718 .56239 m
.44516 .56704 L
s
.37834 .51218 m
.38873 .5228 L
s
.44516 .56704 m
.45221 .57052 L
s
.36795 .50091 m
.37834 .51218 L
s
.45221 .57052 m
.45819 .57283 L
s
.35765 .48908 m
.36795 .50091 L
s
.45819 .57283 m
.463 .57402 L
s
.34744 .47678 m
.35765 .48908 L
s
.33734 .46412 m
.34744 .47678 L
s
.463 .57402 m
.46656 .57418 L
s
.46788 .5667 m .6022 .60245 L .59599 .58744 L .594 .776 .967 r
F
.25 g
.5 Mabswid
.59766 .61436 m
.60606 .6173 L
s
.59717 .62715 m
.60106 .62884 L
s
.59545 .63945 m
.59866 .64112 L
s
.59229 .65123 m
.59475 .65274 L
s
.46944 .56953 m .6022 .60245 L .46788 .5667 L .585 .766 .965 r
F
.25 g
.46656 .57418 m
.46788 .57499 L
s
.46955 .57601 m
.4702 .57641 L
s
.46788 .57499 m
.46955 .57601 L
s
.47151 .57721 m
.47286 .57804 L
s
.4702 .57641 m
.47151 .57721 L
s
.47286 .57804 m
.59229 .65123 L
s
.47169 .5749 m
.47526 .57676 L
s
.4701 .57407 m
.47169 .5749 L
s
.46882 .5734 m
.4701 .57407 L
s
.47526 .57676 m
.47869 .57855 L
s
.47869 .57855 m
.59545 .63945 L
s
.47969 .57612 m
.59717 .62715 L
s
1 0 0 r
.003 w
.6022 .60245 m
.60606 .6173 L
s
0 g
.006 w
.32734 .45116 m
.33734 .46412 L
s
.46656 .57418 m
.46882 .5734 L
s
.31739 .43798 m
.32734 .45116 L
s
.30745 .42463 m
.31739 .43798 L
s
.29746 .41119 m
.30745 .42463 L
s
.46517 .56344 m .59599 .58744 L .58791 .57276 L .603 .786 .968 r
F
.25 g
.5 Mabswid
.59125 .59953 m
.6022 .60245 L
s
.59218 .61244 m
.59766 .61436 L
s
.46788 .5667 m .59599 .58744 L .46517 .56344 L .594 .776 .967 r
F
.25 g
.47246 .57298 m
.47969 .57612 L
s
.47099 .57234 m
.47246 .57298 L
s
.46977 .57181 m
.47099 .57234 L
s
.47056 .56992 m
.48348 .57444 L
s
.46944 .56953 m
.47056 .56992 L
s
.48348 .57444 m
.59218 .61244 L
s
1 0 0 r
.003 w
.59599 .58744 m
.6022 .60245 L
s
0 g
.006 w
.46882 .5734 m
.46977 .57181 L
s
.28737 .39771 m
.29746 .41119 L
s
.46944 .56953 m
.46977 .57181 L
s
.27714 .38426 m
.28737 .39771 L
s
.26673 .37092 m
.27714 .38426 L
s
.25612 .35778 m
.26673 .37092 L
s
.24533 .34495 m
.25612 .35778 L
s
.46142 .55988 m .58791 .57276 L .57852 .55881 L .612 .796 .97 r
F
.25 g
.5 Mabswid
.5822 .58491 m
.59599 .58744 L
s
.58401 .5976 m
.59125 .59953 L
s
.46517 .56344 m .58791 .57276 L .46142 .55988 L .603 .786 .968 r
F
.25 g
.46888 .56696 m
.58401 .5976 L
s
.46788 .5667 m
.46888 .56696 L
s
.46517 .56344 m
.5822 .58491 L
s
1 0 0 r
.003 w
.58791 .57276 m
.59599 .58744 L
s
0 g
.006 w
.46788 .5667 m
.46944 .56953 L
s
.46517 .56344 m
.46788 .5667 L
s
.23439 .33257 m
.24533 .34495 L
s
.15271 .26459 m
.15805 .26692 L
s
.22574 .32328 m
.23439 .33257 L
s
.2234 .32076 m
.22574 .32328 L
s
.15805 .26692 m
.16477 .27068 L
s
.21415 .3114 m
.2234 .32076 L
s
.21246 .30969 m
.21415 .3114 L
s
.16477 .27068 m
.17269 .27588 L
s
.20173 .29952 m
.21246 .30969 L
s
.17269 .27588 m
.18163 .28249 L
s
.19138 .29041 m
.20173 .29952 L
s
.18163 .28249 m
.19138 .29041 L
s
.45674 .55611 m .57852 .55881 L .56836 .54595 L .62 .807 .972 r
F
.46142 .55988 m .57852 .55881 L .45674 .55611 L .612 .796 .97 r
F
1 0 0 r
.003 w
.57852 .55881 m
.58791 .57276 L
s
0 g
.006 w
.46142 .55988 m
.46517 .56344 L
s
.25 g
.5 Mabswid
.46142 .55988 m
.58791 .57276 L
s
.45674 .55611 m .56836 .54595 L .45126 .55222 L .62 .807 .972 r
F
0 g
.006 w
.45674 .55611 m
.46142 .55988 L
s
.25 g
.5 Mabswid
.45674 .55611 m
.57852 .55881 L
s
.45126 .55222 m .56836 .54595 L .55797 .53446 L .627 .819 .974 r
F
1 0 0 r
.003 w
.56836 .54595 m
.57852 .55881 L
s
.45126 .55222 m .55797 .53446 L .44509 .54826 L .627 .819 .974 r
F
0 g
.006 w
.45126 .55222 m
.45674 .55611 L
s
.25 g
.5 Mabswid
.45126 .55222 m
.56836 .54595 L
s
.44509 .54826 m .54783 .52454 L .43836 .54428 L .631 .831 .977 r
F
.44509 .54826 m .55797 .53446 L .54783 .52454 L F
0 g
.006 w
.44509 .54826 m
.45126 .55222 L
s
.25 g
.5 Mabswid
.44509 .54826 m
.55797 .53446 L
s
1 0 0 r
.003 w
.55797 .53446 m
.56836 .54595 L
s
.43836 .54428 m .53834 .51633 L .43119 .54028 L .632 .845 .982 r
F
.43836 .54428 m .54783 .52454 L .53834 .51633 L F
0 g
.006 w
.43836 .54428 m
.44509 .54826 L
s
.25 g
.5 Mabswid
.43836 .54428 m
.54783 .52454 L
s
1 0 0 r
.003 w
.54783 .52454 m
.55797 .53446 L
s
.7035 .79149 m .77157 .9075 L .79814 .91114 L .567 .737 .956 r
F
.69169 .78443 m .77157 .9075 L .7035 .79149 L .574 .732 .95 r
F
.69169 .78443 m .74379 .9008 L .77157 .9075 L F
.71475 .79734 m .79814 .91114 L .82293 .91161 L .562 .743 .961 r
F
.7035 .79149 m .79814 .91114 L .71475 .79734 L .567 .737 .956 r
F
1 0 0 r
.77157 .9075 m
.79814 .91114 L
s
.25 g
.5 Mabswid
.79711 .90972 m
.79814 .91114 L
s
.43119 .54028 m .52987 .50993 L .42368 .53626 L .627 .862 .987 r
F
.43119 .54028 m .53834 .51633 L .52987 .50993 L F
0 g
.006 w
.43119 .54028 m
.43836 .54428 L
s
1 0 0 r
.003 w
.53834 .51633 m
.54783 .52454 L
s
.67949 .77622 m .74379 .9008 L .69169 .78443 L .581 .728 .944 r
F
.67949 .77622 m .71535 .89122 L .74379 .9008 L F
.25 g
.5 Mabswid
.77039 .90549 m
.77157 .9075 L
s
1 0 0 r
.003 w
.74379 .9008 m
.77157 .9075 L
s
.25 g
.5 Mabswid
.79623 .90853 m
.79711 .90972 L
s
.72527 .80197 m .82293 .91161 L .84544 .90893 L .558 .75 .967 r
F
.71475 .79734 m .82293 .91161 L .72527 .80197 L .562 .743 .961 r
F
1 0 0 r
.003 w
.79814 .91114 m
.82293 .91161 L
s
.25 g
.5 Mabswid
.82133 .90981 m
.82167 .91019 L
s
.82167 .91019 m
.82217 .91075 L
s
.82217 .91075 m
.82293 .91161 L
s
.66706 .76694 m .71535 .89122 L .67949 .77622 L .589 .724 .937 r
F
.66706 .76694 m .68683 .87907 L .71535 .89122 L F
.25 g
.69169 .78443 m
.69222 .78562 L
s
.76927 .90358 m
.77039 .90549 L
s
.7035 .79149 m
.70421 .79271 L
s
.7954 .9074 m
.79623 .90853 L
s
.7426 .89815 m
.74379 .9008 L
s
.69222 .78562 m
.69298 .78731 L
s
1 0 0 r
.003 w
.71535 .89122 m
.74379 .9008 L
s
.42368 .53626 m .52266 .5054 L .41593 .53222 L .607 .88 .991 r
F
.25 g
.5 Mabswid
.43119 .54028 m
.43131 .54025 L
s
.42368 .53626 m .52987 .50993 L .52266 .5054 L .607 .88 .991 r
F
.25 g
.44307 .53762 m
.53834 .51633 L
s
.43131 .54025 m
.44307 .53762 L
s
0 g
.006 w
.42368 .53626 m
.43119 .54028 L
s
.73491 .80537 m .84544 .90893 L .86521 .90325 L .556 .757 .971 r
F
.72527 .80197 m .84544 .90893 L .73491 .80537 L .558 .75 .967 r
F
1 0 0 r
.003 w
.82293 .91161 m
.84544 .90893 L
s
.25 g
.5 Mabswid
.70421 .79271 m
.70522 .79442 L
s
.71475 .79734 m
.71564 .79857 L
s
.69298 .78731 m
.69396 .78952 L
s
.84505 .90856 m
.84544 .90893 L
s
1 0 0 r
.003 w
.52987 .50993 m
.53834 .51633 L
s
.65452 .75667 m .68683 .87907 L .66706 .76694 L .598 .721 .931 r
F
.65452 .75667 m .65873 .86472 L .68683 .87907 L F
.25 g
.5 Mabswid
.68102 .78112 m
.71432 .8879 L
s
.71432 .8879 m
.71535 .89122 L
s
.68035 .77897 m
.68102 .78112 L
s
.67984 .77735 m
.68035 .77897 L
s
.67949 .77622 m
.67984 .77735 L
s
1 0 0 r
.003 w
.68683 .87907 m
.71535 .89122 L
s
.25 g
.5 Mabswid
.66724 .76798 m
.68683 .87907 L
s
.66706 .76694 m
.66724 .76798 L
s
.41593 .53222 m .51689 .50278 L .40806 .52811 L .554 .892 .984 r
F
.25 g
.42368 .53626 m
.42369 .53626 L
s
.41593 .53222 m .52266 .5054 L .51689 .50278 L .554 .892 .984 r
F
.25 g
.42369 .53626 m
.52987 .50993 L
s
0 g
.006 w
.41593 .53222 m
.42368 .53626 L
s
.74351 .80759 m .86521 .90325 L .88191 .89482 L .556 .766 .976 r
F
.73491 .80537 m .86521 .90325 L .74351 .80759 L .556 .757 .971 r
F
.25 g
.5 Mabswid
.72527 .80197 m
.72633 .80315 L
s
.70522 .79442 m
.70651 .79663 L
s
.71564 .79857 m
.71687 .80025 L
s
1 0 0 r
.003 w
.84544 .90893 m
.86521 .90325 L
s
.25 g
.5 Mabswid
.73491 .80537 m
.73505 .8055 L
s
.6952 .79228 m
.7426 .89815 L
s
.69396 .78952 m
.6952 .79228 L
s
.642 .74552 m .65873 .86472 L .65452 .75667 L .606 .718 .924 r
F
.642 .74552 m .63153 .84861 L .65873 .86472 L F
1 0 0 r
.003 w
.65873 .86472 m
.68683 .87907 L
s
.25 g
.5 Mabswid
.65452 .75667 m
.65873 .86472 L
s
1 0 0 r
.003 w
.52266 .5054 m
.52987 .50993 L
s
.40806 .52811 m .51264 .50209 L .40016 .52392 L .401 .851 .907 r
F
.40806 .52811 m .51689 .50278 L .51264 .50209 L F
.25 g
.5 Mabswid
.41593 .53222 m
.52266 .5054 L
s
0 g
.006 w
.40806 .52811 m
.41593 .53222 L
s
.25 g
.5 Mabswid
.40806 .52811 m
.40806 .52811 L
s
.62957 .7336 m .63153 .84861 L .642 .74552 L .614 .715 .917 r
F
.62957 .7336 m .60561 .83122 L .63153 .84861 L F
1 0 0 r
.003 w
.63153 .84861 m
.65873 .86472 L
s
.25 g
.5 Mabswid
.63153 .84861 m
.642 .74552 L
s
1 0 0 r
.003 w
.51689 .50278 m
.52266 .5054 L
s
.75095 .8087 m .88191 .89482 L .89528 .88397 L .558 .775 .979 r
F
.74351 .80759 m .88191 .89482 L .75095 .8087 L .556 .766 .976 r
F
.25 g
.5 Mabswid
.72633 .80315 m
.72776 .80476 L
s
.70651 .79663 m
.70811 .79935 L
s
.71687 .80025 m
.71845 .80239 L
s
.73505 .8055 m
.7361 .80648 L
s
1 0 0 r
.003 w
.86521 .90325 m
.88191 .89482 L
s
.25 g
.5 Mabswid
.74362 .80768 m
.74501 .80877 L
s
.74351 .80759 m
.74362 .80768 L
s
.40016 .52392 m .51264 .50209 L .50992 .50331 L .009 0 0 r
F
.40016 .52392 m .50992 .50331 L .39234 .51962 L F
.25 g
.49742 .50504 m
.51264 .50209 L
s
0 g
.006 w
.40016 .52392 m
.40806 .52811 L
s
.25 g
.5 Mabswid
.40806 .52811 m
.51689 .50278 L
s
.61729 .72102 m .60561 .83122 L .62957 .7336 L .621 .711 .91 r
F
.61729 .72102 m .58126 .81301 L .60561 .83122 L F
1 0 0 r
.003 w
.60561 .83122 m
.63153 .84861 L
s
.51264 .50209 m
.51689 .50278 L
s
.75713 .80879 m .89528 .88397 L .90523 .87114 L .562 .786 .983 r
F
.25 g
.5 Mabswid
.88121 .89436 m
.88191 .89482 L
s
.75095 .8087 m .89528 .88397 L .75713 .80879 L .558 .775 .979 r
F
.25 g
.72776 .80476 m
.72956 .80678 L
s
.70811 .79935 m
.71002 .80261 L
s
.71845 .80239 m
.72036 .805 L
s
.7361 .80648 m
.73769 .80797 L
s
1 0 0 r
.003 w
.88191 .89482 m
.89528 .88397 L
s
.25 g
.5 Mabswid
.75095 .8087 m
.75253 .80974 L
s
.39234 .51962 m .50992 .50331 L .50863 .50642 L .475 .025 .102 r
F
.39234 .51962 m .50863 .50642 L .38473 .51519 L F
.25 g
.4655 .50947 m
.50992 .50331 L
s
0 g
.006 w
.39234 .51962 m
.40016 .52392 L
s
1 0 0 r
.003 w
.50992 .50331 m
.51264 .50209 L
s
.60517 .70789 m .58126 .81301 L .61729 .72102 L .627 .707 .903 r
F
.25 g
.5 Mabswid
.60561 .83122 m
.62957 .7336 L
s
.60517 .70789 m .55871 .79448 L .58126 .81301 L .627 .707 .903 r
F
1 0 0 r
.003 w
.58126 .81301 m
.60561 .83122 L
s
.38473 .51519 m .50863 .50642 L .50858 .51135 L .66 .357 .448 r
F
.38473 .51519 m .50858 .51135 L .37746 .51063 L F
.37746 .51063 m .50858 .51135 L .50953 .518 L .725 .506 .594 r
F
.37746 .51063 m .50953 .518 L .37067 .50596 L F
.37067 .50596 m .50953 .518 L .51113 .52621 L .756 .584 .664 r
F
.37067 .50596 m .51113 .52621 L .36452 .50124 L F
.36452 .50124 m .51113 .52621 L .51301 .53575 L .775 .631 .702 r
F
.36452 .50124 m .51301 .53575 L .3592 .49652 L F
.3592 .49652 m .51301 .53575 L .51476 .54635 L .789 .663 .724 r
F
.3592 .49652 m .51476 .54635 L .35489 .49193 L F
.35489 .49193 m .51476 .54635 L .51598 .55766 L .802 .687 .738 r
F
.35489 .49193 m .51598 .55766 L .35176 .4876 L F
.35176 .4876 m .51598 .55766 L .51632 .56931 L .814 .706 .747 r
F
.35176 .4876 m .51632 .56931 L .35 .48371 L F
.35 .48371 m .51632 .56931 L .51546 .5809 L .825 .723 .753 r
F
.35 .48371 m .51546 .5809 L .34976 .48042 L F
.34976 .48042 m .51546 .5809 L .51323 .59207 L .835 .738 .757 r
F
.34976 .48042 m .51242 .59153 L .35117 .47796 L F
.51242 .59153 m .51219 .59134 L .35117 .47796 L F
.50903 .60209 m .51323 .59207 L .50952 .60248 L .846 .752 .759 r
F
.51242 .59153 m .51322 .59207 L .51219 .59134 L .835 .738 .757 r
F
.35117 .47796 m .51322 .59207 L .50903 .60209 L .846 .752 .759 r
F
.51322 .59207 m .51323 .59207 L .50903 .60209 L F
.35117 .47796 m .50652 .60012 L .35428 .47652 L F
.50652 .60012 m .50804 .60131 L .5061 .59974 L F
.50652 .60012 m .5061 .59974 L .35428 .47652 L F
.50804 .60131 m .5076 .60093 L .35428 .47652 L F
.50903 .60209 m .50858 .60171 L .50738 .60075 L F
.5076 .60093 m .50738 .60075 L .35428 .47652 L F
.50903 .60209 m .50738 .60075 L .5076 .60093 L F
.50804 .60131 m .50903 .60209 L .5076 .60093 L F
.50903 .60209 m .50952 .60248 L .50858 .60171 L F
.35428 .47652 m .50952 .60248 L .50439 .61185 L .856 .766 .761 r
F
.35428 .47652 m .49658 .60481 L .35914 .47627 L F
.49658 .60481 m .49942 .60737 L .49608 .60425 L F
.49658 .60481 m .49608 .60425 L .35914 .47627 L F
.49942 .60737 m .49886 .60677 L .35914 .47627 L F
.5016 .60933 m .50044 .60816 L .35914 .47627 L F
.49629 .61824 m .50439 .61185 L .49799 .62 L .867 .779 .762 r
F
.49942 .60737 m .5016 .60933 L .49886 .60677 L .856 .766 .761 r
F
.36007 .47724 m .50044 .60816 L .49629 .61824 L .867 .779 .762 r
F
.5016 .60933 m .50439 .61185 L .50044 .60816 L .856 .766 .761 r
F
.50044 .60816 m .50439 .61185 L .49629 .61824 L .867 .779 .762 r
F
.35914 .47627 m .36059 .47763 L .36007 .47724 L F
.36059 .47763 m .50439 .61185 L .36007 .47724 L F
.35914 .47627 m .48787 .60952 L .36568 .47739 L F
.48787 .60952 m .48733 .60879 L .36568 .47739 L F
.49136 .61314 m .49071 .61231 L .36568 .47739 L F
.49411 .61599 m .49325 .61496 L .36568 .47739 L F
.49629 .61824 m .49482 .61659 L .4926 .6142 L F
.49325 .61496 m .4926 .6142 L .36568 .47739 L F
.49629 .61824 m .4926 .6142 L .49325 .61496 L F
.48787 .60952 m .49136 .61314 L .48733 .60879 L F
.49136 .61314 m .49411 .61599 L .49071 .61231 L F
.49411 .61599 m .49629 .61824 L .49325 .61496 L F
.36656 .47845 m .49482 .61659 L .49059 .62686 L .878 .794 .763 r
F
.49629 .61824 m .49799 .62 L .49482 .61659 L .867 .779 .762 r
F
.49482 .61659 m .49799 .62 L .49059 .62686 L .878 .794 .763 r
F
.36654 .47832 m .36706 .47888 L .3663 .47813 L F
.36706 .47888 m .49799 .62 L .36671 .47858 L F
.36706 .47888 m .36671 .47858 L .3663 .47813 L F
.3663 .47813 m .36671 .47858 L .36656 .47845 L F
.36671 .47858 m .49799 .62 L .36656 .47845 L F
.36568 .47739 m .36654 .47832 L .3663 .47813 L F
.36568 .47739 m .47866 .61258 L .37381 .47998 L F
.47866 .61258 m .47815 .61167 L .37381 .47998 L F
.48268 .61738 m .482 .61633 L .37381 .47998 L F
.48589 .62123 m .48421 .61883 L .4811 .61491 L F
.482 .61633 m .4811 .61491 L .37381 .47998 L F
.48589 .62123 m .4811 .61491 L .482 .61633 L F
.37441 .48082 m .37472 .48121 L .37461 .48109 L .889 .809 .764 r
F
.48589 .62123 m .49059 .62686 L .48421 .61883 L .878 .794 .763 r
F
.37472 .48121 m .49059 .62686 L .37461 .48109 L .889 .809 .764 r
F
.37439 .48078 m .37444 .48085 L .37441 .48082 L F
.37444 .48085 m .49059 .62686 L .37441 .48082 L F
.37381 .47998 m .37462 .481 L .37439 .48078 L F
.37462 .481 m .49059 .62686 L .37439 .48078 L F
.37381 .47998 m .46944 .61406 L .38337 .48411 L F
.46944 .61406 m .47381 .62018 L .46903 .61299 L F
.46944 .61406 m .46903 .61299 L .38337 .48411 L F
.47381 .62018 m .47319 .61891 L .38337 .48411 L F
.47732 .62511 m .47566 .62213 L .47236 .6172 L F
.47319 .61891 m .47236 .6172 L .38337 .48411 L F
.47732 .62511 m .47236 .6172 L .47319 .61891 L F
.47866 .61258 m .48268 .61738 L .47815 .61167 L .878 .794 .763 r
F
.48268 .61738 m .48589 .62123 L .482 .61633 L F
.41687 .53421 m .49059 .62686 L .48256 .63245 L .889 .809 .764 r
F
.38409 .48519 m .38446 .48574 L .38388 .48496 L .901 .825 .763 r
F
.47732 .62511 m .48256 .63245 L .47566 .62213 L .889 .809 .764 r
F
.38446 .48574 m .48256 .63245 L .38416 .48537 L .901 .825 .763 r
F
.38446 .48574 m .38416 .48537 L .38388 .48496 L F
.47381 .62018 m .47732 .62511 L .47319 .61891 L .889 .809 .764 r
F
.38405 .48525 m .48256 .63245 L .46523 .62168 L .901 .825 .763 r
F
.46523 .62168 m .48256 .63245 L .4743 .63691 L F
.38388 .48496 m .38416 .48537 L .38405 .48525 L F
.38416 .48537 m .48256 .63245 L .38405 .48525 L F
.38337 .48411 m .38409 .48519 L .38388 .48496 L F
.38337 .48411 m .46073 .61412 L .39416 .48979 L F
.46073 .61412 m .46051 .61292 L .39416 .48979 L F
.46523 .62168 m .46415 .61828 L .39416 .48979 L F
.39458 .49066 m .39478 .49104 L .3947 .49093 L .914 .844 .761 r
F
.46523 .62168 m .4743 .63691 L .46415 .61828 L .901 .825 .763 r
F
.39478 .49104 m .4743 .63691 L .3947 .49093 L .914 .844 .761 r
F
.39416 .48979 m .39476 .4909 L .39458 .49066 L F
.39476 .4909 m .4743 .63691 L .39458 .49066 L F
.39416 .48979 m .4531 .61298 L .40594 .49699 L F
.4531 .61298 m .45318 .61172 L .40594 .49699 L F
.45747 .62212 m .45725 .62047 L .40594 .49699 L F
.46099 .62949 m .45996 .62551 L .45697 .6184 L F
.45725 .62047 m .45697 .6184 L .40594 .49699 L F
.46099 .62949 m .45697 .6184 L .45725 .62047 L F
.4064 .4981 m .4066 .49857 L .40639 .49808 L .93 .865 .754 r
F
.46099 .62949 m .46625 .64047 L .45996 .62551 L .914 .844 .761 r
F
.4066 .49857 m .46625 .64047 L .40659 .49854 L .93 .865 .754 r
F
.4066 .49857 m .40659 .49854 L .40639 .49808 L F
.46073 .61412 m .46523 .62168 L .46051 .61292 L .901 .825 .763 r
F
.43263 .56049 m .4743 .63691 L .46625 .64047 L .914 .844 .761 r
F
.40596 .49705 m .4064 .4981 L .40596 .49704 L .93 .865 .754 r
F
.4064 .4981 m .40639 .49808 L .40596 .49704 L F
.4531 .61298 m .45747 .62212 L .45318 .61172 L .914 .844 .761 r
F
.45747 .62212 m .46099 .62949 L .45725 .62047 L F
.40625 .49786 m .46625 .64047 L .45101 .62175 L .93 .865 .754 r
F
.45101 .62175 m .46625 .64047 L .45884 .64342 L F
.40596 .49704 m .40639 .49808 L .40625 .49786 L F
.40639 .49808 m .46625 .64047 L .40625 .49786 L F
.40594 .49699 m .40596 .49705 L .40596 .49704 L F
.40594 .49699 m .45101 .62175 L .41846 .50561 L F
.45101 .62175 m .45116 .61997 L .41846 .50561 L F
.45417 .63049 m .45394 .62795 L .45127 .61874 L F
.45116 .61997 m .45127 .61874 L .41846 .50561 L F
.45417 .63049 m .45127 .61874 L .45116 .61997 L F
.45101 .62175 m .45417 .63049 L .45116 .61997 L F
.45417 .63049 m .45673 .63759 L .45394 .62795 L F
.45673 .63759 m .45577 .63294 L .45377 .62612 L F
.45394 .62795 m .45377 .62612 L .44838 .60773 L F
.45394 .62795 m .44838 .60773 L .4482 .60817 L F
.4482 .60817 m .44838 .60773 L .41846 .50561 L F
.45673 .63759 m .45377 .62612 L .45394 .62795 L F
.41867 .50647 m .45577 .63295 L .45248 .64612 L .948 .89 .739 r
F
.4185 .50573 m .41878 .50669 L .41848 .50571 L F
.45673 .63759 m .45884 .64342 L .45577 .63294 L .93 .865 .754 r
F
.41878 .50669 m .45884 .64342 L .41876 .50667 L .948 .89 .739 r
F
.41878 .50669 m .41876 .50667 L .41848 .50571 L F
.41848 .50571 m .41876 .50667 L .41867 .50647 L F
.41876 .50667 m .45884 .64342 L .41867 .50647 L F
.41846 .50561 m .4185 .50573 L .41848 .50571 L F
.41846 .50561 m .44635 .62081 L .43148 .51553 L F
.44635 .62081 m .44884 .6311 L .44778 .61688 L F
.44884 .6311 m .44931 .62642 L .44778 .61688 L F
.44635 .62081 m .44778 .61688 L .43148 .51553 L F
.4482 .61952 m .45057 .63424 L .4482 .61953 L .967 .915 .703 r
F
.4482 .61952 m .4482 .61953 L .44602 .60599 L F
.44602 .60596 m .4482 .61952 L .44602 .60599 L F
.44602 .60596 m .44602 .60599 L .43159 .51639 L F
.43166 .5167 m .44602 .60596 L .43159 .51639 L F
.44884 .6311 m .45248 .64612 L .44931 .62642 L .948 .89 .739 r
F
.45057 .63424 m .45057 .63425 L .43159 .51639 L .967 .915 .703 r
F
.43161 .51646 m .43159 .51639 L .43156 .51622 L F
.43166 .5167 m .43159 .51639 L .43161 .51646 L F
.4316 .51651 m .45248 .64612 L .4475 .64894 L F
.43156 .51622 m .43163 .51664 L .4316 .51651 L F
.43163 .51664 m .45248 .64612 L .4316 .51651 L F
.4315 .51568 m .43166 .5167 L .43156 .51622 L F
.43148 .51553 m .43151 .51571 L .4315 .51568 L F
.43151 .51571 m .45248 .64612 L .4315 .51568 L F
.43148 .51553 m .44657 .64119 L .44478 .5266 L F
.44657 .64119 m .4475 .64894 L .4472 .63558 L F
.44657 .64119 m .4472 .63558 L .44478 .5266 L F
.44705 .62886 m .4475 .64894 L .44417 .65224 L .969 .925 .606 r
F
.47139 .55177 m .47123 .55234 L .4714 .55174 L 0 0 .264 r
F
.44421 .64332 m .44417 .65224 L .44602 .63724 L .969 .925 .606 r
F
.44478 .52755 m .4475 .64894 L .44477 .5275 L F
.44481 .52785 m .4475 .64894 L .4448 .52778 L F
.44479 .52752 m .4475 .64894 L .44478 .52738 L F
.44421 .64332 m .44602 .63724 L .45816 .53865 L F
.45803 .53969 m .44417 .65224 L .45803 .53968 L .838 .805 .315 r
F
.45803 .53964 m .44417 .65224 L .45805 .53949 L F
.45806 .53937 m .44417 .65224 L .44268 .65637 L F
.45805 .53948 m .44417 .65224 L .45806 .53937 L F
.47123 .55234 m .44268 .65637 L .47128 .55216 L 0 0 .264 r
F
.47123 .55234 m .47128 .55216 L .4714 .55174 L F
.44478 .52738 m .44478 .52755 L .44477 .5275 L .969 .925 .606 r
F
.4448 .52756 m .44481 .52785 L .44479 .52752 L F
.44481 .52785 m .4448 .52778 L .44479 .52752 L F
.44478 .52682 m .4448 .52756 L .44478 .52679 L F
.4448 .52756 m .44479 .52752 L .44478 .52679 L F
.44478 .52679 m .44479 .52752 L .44478 .52738 L F
.44478 .5266 m .44478 .52682 L .44478 .52679 L F
.44478 .5266 m .44421 .64332 L .45816 .53865 L F
.45805 .53949 m .45803 .53969 L .45805 .53948 L .838 .805 .315 r
F
.45803 .53969 m .45803 .53968 L .45805 .53948 L F
.47129 .55216 m .44268 .65637 L .44315 .66162 L 0 0 .264 r
F
.4714 .55174 m .47126 .55225 L .47129 .55216 L F
.47126 .55225 m .44268 .65637 L .47129 .55216 L F
.47146 .5515 m .47139 .55177 L .4714 .55174 L F
.45577 .63295 m .45884 .64342 L .45248 .64612 L .948 .89 .739 r
F
.45805 .53953 m .45803 .53964 L .45805 .53949 L .838 .805 .315 r
F
.45813 .5389 m .45805 .53953 L .45813 .53886 L F
.45805 .53953 m .45805 .53948 L .45813 .53886 L F
.45813 .53886 m .45805 .53948 L .45806 .53937 L F
.45057 .63424 m .45248 .64612 L .45057 .63425 L .967 .915 .703 r
F
.45816 .53865 m .45813 .5389 L .45813 .53886 L .838 .805 .315 r
F
.25 g
.5 Mabswid
.49654 .59195 m
.49818 .59328 L
s
.49139 .58777 m
.49654 .59195 L
s
.48464 .58229 m
.49139 .58777 L
s
.46446 .56591 m
.46695 .56794 L
s
.46718 .56813 m
.48464 .58229 L
s
.45568 .55879 m
.46446 .56591 L
s
.49818 .59328 m
.50284 .59706 L
s
.50284 .59706 m
.50603 .59965 L
s
.50603 .59965 m
.50805 .60129 L
s
.50805 .60129 m
.50915 .60218 L
s
.50915 .60218 m
.50952 .60248 L
s
1 0 0 r
.003 w
.50863 .50642 m
.50992 .50331 L
s
0 g
.006 w
.38473 .51519 m
.39234 .51962 L
s
1 0 0 r
.003 w
.50439 .61185 m
.50952 .60248 L
s
.50952 .60248 m
.51323 .59207 L
s
.25 g
.5 Mabswid
.49817 .60604 m
.49902 .60684 L
s
.49527 .60334 m
.49817 .60604 L
s
.49155 .59987 m
.49527 .60334 L
s
.48678 .59541 m
.49155 .59987 L
s
.48063 .58967 m
.48678 .59541 L
s
.47273 .5823 m
.48063 .58967 L
s
.46265 .57289 m
.46499 .57508 L
s
.46532 .57538 m
.47273 .5823 L
s
.45484 .5656 m
.46265 .57289 L
s
.49902 .60684 m
.50197 .60959 L
s
.50197 .60959 m
.50375 .61126 L
s
.50375 .61126 m
.50439 .61185 L
s
1 0 0 r
.003 w
.49799 .62 m
.50439 .61185 L
s
.25 g
.5 Mabswid
.50136 .58372 m
.50151 .58382 L
s
.49589 .57987 m
.50136 .58372 L
s
.48859 .57473 m
.49589 .57987 L
s
.46625 .559 m
.46889 .56086 L
s
.46903 .56095 m
.48859 .57473 L
s
.4565 .55213 m
.46625 .559 L
s
.50151 .58382 m
.50633 .58722 L
s
.50633 .58722 m
.50971 .5896 L
s
.50971 .5896 m
.51193 .59116 L
s
.51193 .59116 m
.51323 .59207 L
s
1 0 0 r
.003 w
.51323 .59207 m
.51546 .5809 L
s
.25 g
.5 Mabswid
.46803 .55214 m
.47082 .55383 L
s
.47085 .55385 m
.50469 .57437 L
s
.4573 .54563 m
.46803 .55214 L
s
.50469 .57437 m
.5096 .57735 L
s
.5096 .57735 m
.51309 .57947 L
s
.51309 .57947 m
.51546 .5809 L
s
1 0 0 r
.003 w
.51546 .5809 m
.51632 .56931 L
s
.25 g
.5 Mabswid
.4926 .6142 m
.49477 .61653 L
s
.48985 .61122 m
.4926 .6142 L
s
.4864 .60751 m
.48985 .61122 L
s
.48206 .60283 m
.4864 .60751 L
s
.47657 .59692 m
.48206 .60283 L
s
.46961 .58942 m
.47657 .59692 L
s
.46083 .57995 m
.46301 .5823 L
s
.46343 .58275 m
.46961 .58942 L
s
.45398 .57257 m
.46083 .57995 L
s
.49477 .61653 m
.49742 .61939 L
s
.49742 .61939 m
.49799 .62 L
s
1 0 0 r
.003 w
.49059 .62686 m
.49799 .62 L
s
.25 g
.5 Mabswid
.44395 .51099 m
.50863 .50642 L
s
1 0 0 r
.003 w
.50858 .51135 m
.50863 .50642 L
s
.25 g
.5 Mabswid
.45807 .53933 m
.4678 .54434 L
s
.4678 .54434 m
.50786 .56496 L
s
.50786 .56496 m
.51277 .56748 L
s
.51277 .56748 m
.51632 .56931 L
s
1 0 0 r
.003 w
.51598 .55766 m
.51632 .56931 L
s
0 g
.006 w
.37746 .51063 m
.38473 .51519 L
s
.25 g
.5 Mabswid
.48675 .62203 m
.49059 .62686 L
s
.48421 .61883 m
.48675 .62203 L
s
.4811 .61491 m
.48421 .61883 L
s
.47725 .61008 m
.4811 .61491 L
s
.47247 .60406 m
.47725 .61008 L
s
.45899 .58712 m
.461 .58963 L
s
.4615 .59026 m
.47247 .60406 L
s
.4531 .5797 m
.45899 .58712 L
s
1 0 0 r
.003 w
.48256 .63245 m
.49059 .62686 L
s
.25 g
.5 Mabswid
.47154 .5387 m
.47213 .53895 L
s
.44621 .5279 m
.47154 .5387 L
s
.47213 .53895 m
.51116 .5556 L
s
.51116 .5556 m
.51598 .55766 L
s
1 0 0 r
.003 w
.51476 .54635 m
.51598 .55766 L
s
.59323 .6943 m .55871 .79448 L .60517 .70789 L .631 .702 .896 r
F
.59323 .6943 m .53809 .77605 L .55871 .79448 L F
.25 g
.5 Mabswid
.58126 .81301 m
.5844 .805 L
s
1 0 0 r
.003 w
.55871 .79448 m
.58126 .81301 L
s
.25 g
.5 Mabswid
.42767 .51091 m
.50858 .51135 L
s
1 0 0 r
.003 w
.50858 .51135 m
.50953 .518 L
s
.25 g
.5 Mabswid
.4365 .51971 m
.4902 .53799 L
s
.4902 .53799 m
.51476 .54635 L
s
1 0 0 r
.003 w
.51301 .53575 m
.51476 .54635 L
s
.25 g
.5 Mabswid
.42512 .51068 m
.50953 .518 L
s
1 0 0 r
.003 w
.50953 .518 m
.51113 .52621 L
s
.25 g
.5 Mabswid
.4941 .53093 m
.49553 .53129 L
s
.43035 .51467 m
.4941 .53093 L
s
.49553 .53129 m
.51301 .53575 L
s
1 0 0 r
.003 w
.51113 .52621 m
.51301 .53575 L
s
.25 g
.5 Mabswid
.45713 .59443 m
.45894 .59713 L
s
.45951 .59798 m
.4607 .59977 L
s
.4522 .58705 m
.45713 .59443 L
s
.47837 .62619 m
.48256 .63245 L
s
.47566 .62213 m
.47837 .62619 L
s
.4607 .59977 m
.47566 .62213 L
s
1 0 0 r
.003 w
.4743 .63691 m
.48256 .63245 L
s
.25 g
.5 Mabswid
.42659 .51181 m
.50186 .52463 L
s
.50186 .52463 m
.51113 .52621 L
s
.762 .80799 m .90523 .87114 L .91179 .85683 L .568 .796 .985 r
F
.25 g
.89286 .88265 m
.89528 .88397 L
s
.88093 .89418 m
.88121 .89436 L
s
.75713 .80879 m .90523 .87114 L .762 .80799 L .562 .786 .983 r
F
.25 g
.72956 .80678 m
.73172 .80921 L
s
.71002 .80261 m
.71224 .8064 L
s
.72036 .805 m
.72262 .80808 L
s
.73769 .80797 m
.73965 .80981 L
s
.74501 .80877 m
.74649 .80993 L
s
1 0 0 r
.003 w
.89528 .88397 m
.90523 .87114 L
s
.25 g
.5 Mabswid
.75713 .80879 m
.76094 .81087 L
s
.45525 .60194 m
.45682 .60484 L
s
.45745 .60599 m
.4579 .60682 L
s
.47011 .62923 m
.4743 .63691 L
s
.46741 .62427 m
.47011 .62923 L
s
.4579 .60682 m
.46741 .62427 L
s
1 0 0 r
.003 w
.46625 .64047 m
.4743 .63691 L
s
0 g
.006 w
.37067 .50596 m
.37746 .51063 L
s
.58142 .68034 m .53809 .77605 L .59323 .6943 L .634 .695 .889 r
F
.25 g
.5 Mabswid
.59298 .69466 m
.59323 .6943 L
s
.5844 .805 m
.61729 .72102 L
s
.58142 .68034 m .51947 .75813 L .53809 .77605 L .634 .695 .889 r
F
.25 g
.55871 .79448 m
.564 .78461 L
s
1 0 0 r
.003 w
.53809 .77605 m
.55871 .79448 L
s
.25 g
.5 Mabswid
.45697 .6184 m
.46177 .62981 L
s
.45332 .60971 m
.45463 .61283 L
s
.45529 .6144 m
.45697 .6184 L
s
.46177 .62981 m
.46625 .64047 L
s
1 0 0 r
.003 w
.45884 .64342 m
.46625 .64047 L
s
.25 g
.5 Mabswid
.45377 .62612 m
.45727 .63804 L
s
.45135 .61784 m
.45233 .62121 L
s
.45298 .6234 m
.45377 .62612 L
s
.45727 .63804 m
.45884 .64342 L
s
1 0 0 r
.003 w
.45248 .64612 m
.45884 .64342 L
s
.56969 .66609 m .51947 .75813 L .58142 .68034 L .634 .686 .881 r
F
.25 g
.5 Mabswid
.58079 .68113 m
.58142 .68034 L
s
.56969 .66609 m .50289 .74106 L .51947 .75813 L .634 .686 .881 r
F
.25 g
.57114 .77131 m
.60517 .70789 L
s
.564 .78461 m
.57114 .77131 L
s
.53809 .77605 m
.54679 .76315 L
s
1 0 0 r
.003 w
.51947 .75813 m
.53809 .77605 L
s
0 g
.006 w
.36452 .50124 m
.37067 .50596 L
s
.76552 .80644 m .91179 .85683 L .91513 .84156 L .574 .807 .987 r
F
.25 g
.5 Mabswid
.90077 .86918 m
.90523 .87114 L
s
.89144 .88188 m
.89286 .88265 L
s
.88039 .89382 m
.88093 .89418 L
s
.762 .80799 m .91179 .85683 L .76552 .80644 L .568 .796 .985 r
F
.25 g
.73422 .81202 m
.82133 .90981 L
s
.73172 .80921 m
.73422 .81202 L
s
.71478 .81071 m
.76927 .90358 L
s
.71224 .8064 m
.71478 .81071 L
s
.7252 .8116 m
.7954 .9074 L
s
.72262 .80808 m
.7252 .8116 L
s
.73965 .80981 m
.74198 .81199 L
s
.74649 .80993 m
.74855 .81156 L
s
.75253 .80974 m
.75404 .81073 L
s
1 0 0 r
.003 w
.90523 .87114 m
.91179 .85683 L
s
.25 g
.5 Mabswid
.45057 .63424 m
.45248 .64612 L
s
.44931 .62642 m
.4499 .63007 L
s
.45042 .63333 m
.45057 .63424 L
s
1 0 0 r
.003 w
.4475 .64894 m
.45248 .64612 L
s
.55799 .65163 m .50289 .74106 L .56969 .66609 L .63 .673 .873 r
F
.25 g
.5 Mabswid
.56917 .66668 m
.56969 .66609 L
s
.55799 .65163 m .48833 .72513 L .50289 .74106 L .63 .673 .873 r
F
.25 g
.55954 .74425 m
.59298 .69466 L
s
.54679 .76315 m
.55954 .74425 L
s
.51947 .75813 m
.53461 .73912 L
s
1 0 0 r
.003 w
.50289 .74106 m
.51947 .75813 L
s
.25 g
.5 Mabswid
.44741 .64503 m
.4475 .64894 L
s
1 0 0 r
.003 w
.44604 .65039 m
.4475 .64894 L
s
0 g
.006 w
.3592 .49652 m
.36452 .50124 L
s
.54624 .63704 m .48833 .72513 L .55799 .65163 L .621 .656 .863 r
F
.25 g
.5 Mabswid
.55761 .65204 m
.55799 .65163 L
s
.54624 .63704 m .47579 .71057 L .48833 .72513 L .621 .656 .863 r
F
.25 g
.56121 .70571 m
.58079 .68113 L
s
1 0 0 r
.003 w
.48833 .72513 m
.50289 .74106 L
s
.53438 .62239 m .47579 .71057 L .54624 .63704 L .604 .631 .851 r
F
.25 g
.5 Mabswid
.54561 .63771 m
.54624 .63704 L
s
.53698 .7028 m
.56917 .66668 L
s
.53461 .73912 m
.56121 .70571 L
s
.53438 .62239 m .46524 .69753 L .47579 .71057 L .604 .631 .851 r
F
.25 g
.50289 .74106 m
.53698 .7028 L
s
1 0 0 r
.003 w
.47579 .71057 m
.48833 .72513 L
s
.45816 .53865 m .44268 .65637 L .47146 .5515 L .838 .805 .315 r
F
0 g
.006 w
.35489 .49193 m
.3592 .49652 L
s
.52232 .60776 m .46524 .69753 L .53438 .62239 L .574 .594 .835 r
F
.25 g
.5 Mabswid
.53402 .62278 m
.53438 .62239 L
s
.55373 .65613 m
.55761 .65204 L
s
.52232 .60776 m .45669 .68612 L .46524 .69753 L .574 .594 .835 r
F
1 0 0 r
.003 w
.46524 .69753 m
.47579 .71057 L
s
.48458 .56498 m .44315 .66162 L .44563 .66823 L .186 .192 .632 r
F
.47146 .5515 m .44315 .66162 L .48458 .56498 L 0 0 .264 r
F
1 0 0 r
.44268 .65637 m
.44315 .66162 L
s
.25 g
.5 Mabswid
.53401 .62279 m
.53402 .62278 L
s
.47119 .55246 m
.47124 .55229 L
s
.47124 .55229 m
.47139 .55177 L
s
.47139 .55177 m
.47146 .5515 L
s
.76552 .80644 m .91513 .84156 L .76773 .80426 L .574 .807 .987 r
F
.25 g
.78296 .80811 m
.91513 .84156 L
s
.76773 .80426 m
.78296 .80811 L
s
1 0 0 r
.003 w
.91179 .85683 m
.91513 .84156 L
s
.25 g
.5 Mabswid
.77616 .8101 m
.91179 .85683 L
s
.76552 .80644 m
.77616 .8101 L
s
.76882 .811 m
.90077 .86918 L
s
.76334 .80859 m
.76882 .811 L
s
.762 .80799 m
.76334 .80859 L
s
.76094 .81087 m
.89144 .88188 L
s
.75612 .8121 m
.88039 .89382 L
s
.75404 .81073 m
.75612 .8121 L
s
.75095 .81344 m
.86521 .90325 L
s
.74855 .81156 m
.75095 .81344 L
s
.74462 .81447 m
.84505 .90856 L
s
.74198 .81199 m
.74462 .81447 L
s
.49744 .57894 m .44563 .66823 L .45015 .67636 L .415 .422 .759 r
F
.48458 .56498 m .44563 .66823 L .49744 .57894 L .186 .192 .632 r
F
.25 g
.44268 .65637 m
.44735 .63936 L
s
.53391 .6229 m
.53401 .62279 L
s
1 0 0 r
.003 w
.44315 .66162 m
.44563 .66823 L
s
.25 g
.5 Mabswid
.48445 .56527 m
.48458 .56498 L
s
.48427 .5657 m
.48445 .56527 L
s
.48422 .56581 m
.48427 .5657 L
s
.46723 .56691 m
.47119 .55246 L
s
.51002 .59324 m .45669 .68612 L .52232 .60776 L .52 .533 .809 r
F
.25 g
.52169 .60851 m
.52232 .60776 L
s
.51002 .59324 m .45015 .67636 L .45669 .68612 L .52 .533 .809 r
F
1 0 0 r
.003 w
.45669 .68612 m
.46524 .69753 L
s
.49744 .57894 m .45015 .67636 L .51002 .59324 L .415 .422 .759 r
F
.25 g
.5 Mabswid
.50978 .59357 m
.51002 .59324 L
s
.45015 .67636 m
.47302 .64461 L
s
.47302 .64461 m
.49378 .61579 L
s
.50967 .59372 m
.50978 .59357 L
s
.49378 .61579 m
.50967 .59372 L
s
1 0 0 r
.003 w
.45015 .67636 m
.45669 .68612 L
s
.25 g
.5 Mabswid
.44735 .63936 m
.45061 .62746 L
s
.44315 .66162 m
.45162 .64187 L
s
1 0 0 r
.003 w
.44563 .66823 m
.45015 .67636 L
s
.25 g
.5 Mabswid
.45669 .68612 m
.49876 .63589 L
s
.49876 .63589 m
.52169 .60851 L
s
.44563 .66823 m
.45956 .64423 L
s
.45956 .64423 m
.47051 .62535 L
s
.47051 .62535 m
.48623 .59827 L
s
.48623 .59827 m
.49707 .57958 L
s
.45162 .64187 m
.4578 .62744 L
s
.4578 .62744 m
.466 .60831 L
s
.466 .60831 m
.47722 .58214 L
s
.46524 .69753 m
.53391 .6229 L
s
.45061 .62746 m
.45477 .61231 L
s
.45477 .61231 m
.46014 .59275 L
s
.47579 .71057 m
.54561 .63771 L
s
.48833 .72513 m
.55373 .65613 L
s
.49726 .57925 m
.49744 .57894 L
s
.49707 .57958 m
.49726 .57925 L
s
.47722 .58214 m
.48422 .56581 L
s
.46014 .59275 m
.46723 .56691 L
s
0 g
.006 w
.69169 .78443 m
.7035 .79149 L
s
.67949 .77622 m
.69169 .78443 L
s
.66706 .76694 m
.67949 .77622 L
s
.7035 .79149 m
.71475 .79734 L
s
.65452 .75667 m
.66706 .76694 L
s
.71475 .79734 m
.72527 .80197 L
s
.642 .74552 m
.65452 .75667 L
s
.72527 .80197 m
.73491 .80537 L
s
.35176 .4876 m
.35489 .49193 L
s
.62957 .7336 m
.642 .74552 L
s
.73491 .80537 m
.74351 .80759 L
s
.61729 .72102 m
.62957 .7336 L
s
.60517 .70789 m
.61729 .72102 L
s
.74351 .80759 m
.75095 .8087 L
s
.35 .48371 m
.35176 .4876 L
s
.59323 .6943 m
.60517 .70789 L
s
.75095 .8087 m
.75713 .80879 L
s
.58142 .68034 m
.59323 .6943 L
s
.34976 .48042 m
.35 .48371 L
s
.56969 .66609 m
.58142 .68034 L
s
.75713 .80879 m
.762 .80799 L
s
.55799 .65163 m
.56969 .66609 L
s
.34976 .48042 m
.35117 .47796 L
s
.54624 .63704 m
.55799 .65163 L
s
.762 .80799 m
.76552 .80644 L
s
.53438 .62239 m
.54624 .63704 L
s
.35117 .47796 m
.35428 .47652 L
s
.76552 .80644 m
.76773 .80426 L
s
.52232 .60776 m
.53438 .62239 L
s
.51002 .59324 m
.52232 .60776 L
s
.35428 .47652 m
.35914 .47627 L
s
.49744 .57894 m
.51002 .59324 L
s
.35914 .47627 m
.36568 .47739 L
s
.48458 .56498 m
.49744 .57894 L
s
.47146 .5515 m
.48458 .56498 L
s
.36568 .47739 m
.37381 .47998 L
s
.45816 .53865 m
.47146 .5515 L
s
.37381 .47998 m
.38337 .48411 L
s
.44696 .52857 m
.45816 .53865 L
s
.44478 .5266 m
.44696 .52857 L
s
.38337 .48411 m
.39416 .48979 L
s
.43148 .51553 m
.44478 .5266 L
s
.39416 .48979 m
.40594 .49699 L
s
.41846 .50561 m
.43148 .51553 L
s
.40594 .49699 m
.41846 .50561 L
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.313, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`400049000181000`40O003h00Oogoo2Woo002`Ool2
001GOol00:ioo`800003Ool0000005Ioo`00Zgoo0`000goo0P00EWoo002YOol20006Ool00`00Ool0
001EOol00:Moo`8000Qoo`03001oo`0005Eoo`00Y7oo0`002Woo00@007ooOol005Aoo`00XWoo0P00
3Goo00D007ooOomoo`0005=oo`00Wgoo0`003goo00D007ooOomoo`0005=oo`00WGoo0P004Woo00<0
07ooOol00Woo00<007ooOol0D7oo002KOol2000EOol00`00Oomoo`02Ool00`00Oomoo`1?Ool009Qo
o`<001Moo`03001oogoo009oo`03001oogoo04moo`00UWoo0P006Woo00<007ooOol00goo00<007oo
Ool0CWoo002COol3000LOol00`00Oomoo`03Ool00`00Oomoo`1>Ool0095oo`8001moo`03001oogoo
00Aoo`03001oogoo04eoo`00Sgoo0P008Goo00<007ooOol01Goo00<007ooOol0C7oo002<Ool3000S
Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool008Yoo`8002Ioo`03001oogoo00Ioo`03001oogoo04]o
o`00Qgoo0`00:7oo00<007ooOol01goo00<007ooOol0BWoo0025Ool2000[Ool00`00Oomoo`07Ool0
0`00Oomoo`1:Ool008=oo`8002eoo`03001oogoo00Qoo`03001oogoo04Uoo`00P7oo0`00;goo00<0
07ooOol027oo00<007ooOol0BGoo001nOol2000bOol00`00Oomoo`09Ool00`00Oomoo`18Ool007]o
o`<003Aoo`03001oogoo00Yoo`03001oogoo04Moo`00NGoo0P00=goo00<007ooOol02Woo00<007oo
Ool0Agoo001gOol2000iOol00`00Oomoo`0;Ool00`00Oomoo`16Ool007Aoo`<003]oo`03001oogoo
00aoo`03001oogoo04Eoo`00LWoo0P00?goo00<007ooOol02goo00<007ooOol0AGoo001_Ool30011
Ool00`00Oomoo`0<Ool00`00Oomoo`14Ool006eoo`8004Aoo`03001oogoo00aoo`03001oogoo04Ao
o`00Jgoo0P00AWoo00<007ooOol03Goo00<007ooOol0@goo001XOol30018Ool00`00Oomoo`0>Ool0
0`00Oomoo`12Ool006Ioo`8004]oo`03001oogoo00ioo`03001oogoo049oo`00Hgoo0`00CGoo00<0
07ooOol03goo00<007ooOol0@Goo001QOol2001@Ool00`00Oomoo`0@Ool00`00Oomoo`10Ool005io
o`<0059oo`03001oogoo011oo`03001oogoo041oo`00G7oo0P00EGoo00<007ooOol04Goo00<007oo
Ool0?goo001JOol2001GOol00`00Oomoo`0AOol00`00Oomoo`0oOol005Moo`<005Uoo`03001oogoo
019oo`03001oogoo03ioo`00EGoo0P00G7oo00<007ooOol04goo00<007ooOol0?Goo001BOol3001N
Ool00`00Oomoo`0COol00`00Oomoo`0mOol0051oo`80065oo`03001oogoo01Aoo`03001oogoo03ao
o`00CWoo0P00Hgoo00<007ooOol05Goo00<007ooOol0>goo001;Ool3001UOol00`00Oomoo`0EOol0
0`00Oomoo`0kOol004Uoo`8006Uoo`03001oogoo01Eoo`03001oogoo03Yoo`00AWoo0`00Jgoo00<0
07ooOol05Goo00<007ooOol0>Woo0014Ool2001^Ool00`00Oomoo`0FOol00`00Oomoo`0iOol0049o
o`80071oo`03001oogoo01Moo`03001oogoo03Qoo`00?goo0`00LWoo00<007ooOol05goo00<007oo
Ool0>7oo000mOol2001eOol00`00Oomoo`0HOol00`00Oomoo`0gOol003Yoo`<007Moo`03001oogoo
01Uoo`03001oogoo03Ioo`00>7oo0P00NWoo00<007ooOol06Goo00<007ooOol0=Woo000fOol2001l
Ool00`00Oomoo`0JOol00`00Oomoo`0eOol003=oo`<007ioo`03001oogoo01Yoo`03001oogoo03Eo
o`00<Goo0P00PGoo00<007ooOol06goo00<007ooOol0=7oo000^Ool30023Ool00`00Oomoo`0LOol0
0`00Oomoo`0cOol002aoo`8008Ioo`03001oogoo01aoo`03001oogoo03=oo`00:Woo0P00R7oo00<0
07ooOol07Goo00<007ooOol0<Woo000WOol3002:Ool00`00Oomoo`0NOol00`00Oomoo`0aOol002Eo
o`8008eoo`03001oogoo01ioo`03001oogoo035oo`008Woo0`00Sgoo00<007ooOol07goo00<007oo
Ool0<7oo000POol2002COol00`00Oomoo`0NOol00`00Oomoo`0`Ool001ioo`8009Eoo`03001oogoo
01moo`03001oogoo02moo`006goo0`00Ugoo00<007ooOol087oo00<007ooOol0;Woo000IOol2002J
Ool00`00Oomoo`0POol00`00Oomoo`0^Ool001Moo`8009aoo`03001oogoo025oo`03001oogoo02eo
o`005goo0P00W7oo00<007ooOol08Woo00<007ooOol0;7oo000GOol00`00Ool0002KOol00`00Oomo
o`0ROol00`00Oomoo`0/Ool001Moo`04001oogoo002JOol00`00Oomoo`0SOol00`00Oomoo`0[Ool0
01Ioo`03001oogoo009oo`03001oogoo09Moo`03001oogoo02=oo`03001oogoo02]oo`005Woo00<0
07ooOol00goo00<007ooOol02Goo00<007ooOol0RWoo00<007ooOol097oo00<007ooOol0:Woo000F
Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`29Ool00`00Oomoo`0UOol00`00Oomoo`0Y
Ool001Ioo`03001oogoo00Eoo`03001oogoo00Uoo`8008Uoo`03001oogoo02Eoo`03001oogoo02Uo
o`005Woo00<007ooOol01Woo00<007ooOol02Goo00=Vn0000000Qgoo00<007ooOol09Woo00<007oo
Ool0:7oo000FOol00`00Oomoo`07Ool00`00Oomoo`08Ool3JaP20025Ool00`00Oomoo`0WOol00`00
Oomoo`0WOol001Eoo`03001oogoo00Uoo`03001oogoo00Qoo`9[6003KcQ[600008Aoo`03001oogoo
02Moo`03001oogoo02Moo`005Goo00<007ooOol02Woo00<007ooOol027oo0f/H00=[>000Ool0PWoo
00<007ooOol0:7oo00<007ooOol09Woo000EOol00`00Oomoo`0;Ool00`00Oomoo`08Ool2JaP00flh
JcP00022Ool00`00Oomoo`0XOol00`00Oomoo`0VOol001Eoo`03001oogoo00aoo`03001oogoo00Mo
o`06I_Q[66/HKcQ_F000PWoo00<007ooOol0:7oo00<007ooOol09Goo000EOol00`00Oomoo`0=Ool0
0`00Oomoo`07Ool00fKhKcU[6002KcP00`00Oomoo`1oOol00`00Oomoo`0YOol00`00Oomoo`0TOol0
01Eoo`03001oogoo00ioo`03001oogoo00Moo`9[6004KcQ_F6mH0020Ool00`00Oomoo`0YOol00`00
Oomoo`0TOol001Eoo`03001oogoo00moo`03001oogoo00Moo`05JaQ_>FlhLeQ_E`02001nOol00`00
Oomoo`0ZOol00`00Oomoo`0SOol001Aoo`03001oogoo015oo`03001oogoo00Ioo`9[609_F004LgQc
F7=h001mOol00`00Oomoo`0[Ool00`00Oomoo`0ROol001Aoo`03001oogoo019oo`03001oogoo00Io
o`07KcQ[>7=HKcQcN6mG0000OGoo00<007ooOol0:goo00<007ooOol08Woo000DOol00`00Oomoo`0C
Ool00`00Oomoo`06Ool01V/HKeQ_F7=HLgQgU`8007]oo`03001oogoo02aoo`03001oogoo025oo`00
57oo00<007ooOol057oo00<007ooOol01Goo00U[66lhKcQcN7=HMiMgMgNH0000NWoo00<007ooOol0
;7oo00<007ooOol08Goo000DOol00`00Oomoo`0EOol00`00Oomoo`05Ool016/HKeQcF7=h0gNG00<0
07ooOol0N7oo00<007ooOol0;Goo00<007ooOol087oo000DOol00`00Oomoo`0FOol00`00Oomoo`05
Ool026lhLeQ_EgNHMgMgUg^d001iOol00`00Oomoo`0^Ool00`00Oomoo`0OOol001=oo`03001oogoo
01Moo`03001oogoo00Eoo`04JaQ_F7=hLeP2MiL2Nk@00`00Oomoo`1fOol00`00Oomoo`0^Ool00`00
Oomoo`0OOol001=oo`03001oogoo01Qoo`03001oogoo00Eoo`9cF003LgQgMgNH009k]003H^H007oo
07Ioo`03001oogoo02moo`03001oogoo01ioo`004goo00<007ooOol06Goo00<007ooOol017oo00=_
F7=hLeP00WNG0W^d00=W1f;W0000MWoo00<007ooOol0<7oo00<007ooOol07Goo000COol00`00Oomo
o`0JOol00`00Oomoo`04Ool02FmGLgQgMgNGNkAo]F;VI`L0001fOol00`00Oomoo`0`Ool00`00Oomo
o`0MOol001=oo`03001oogoo01]oo`03001oogoo00=oo`04KeQcF7NGMiL2Nk@01FL7I^MW1`007>L0
M7oo00<007ooOol0<Goo00<007ooOol077oo000COol00`00Oomoo`0LOol00`00Oomoo`03Ool02W=h
MgMgV7^dI`MRiVL7H^HLi`00M7oo00<007ooOol0<Goo00<007ooOol077oo000BOol00`00Oomoo`0N
Ool00`00Oomoo`02Ool02g=HMiMgUg^dI^MW1f;W00lLi`0?0000Lgoo00<007ooOol0<Woo00<007oo
Ool06goo000BOol00`00Oomoo`0OOol04000OomoogooLgQgMgNGNkAW1f;VI`LLi`0?00h03`00LWoo
00<007ooOol0<goo00<007ooOol06Woo000BOol00`00Oomoo`0POol01000Oomoogoo0WNG00Ek]6;W
I`MViacW00<03`037>L007oo075oo`03001oogoo039oo`03001oogoo01Yoo`004Woo00<007ooOol0
8Goo010007ooOomgMgNHNkAW1f;VI`LLi`0?00hLibUf;GL0075oo`03001oogoo03=oo`03001oogoo
01Uoo`004Woo00<007ooOol08Woo00T007ooLgQgUg^dI^MW1`0?7>L00P0?00@LibUf:GH0075oo`03
001oogoo03Aoo`03001oogoo01Qoo`004Woo00<007ooOol08goo00l007=HMiMk]6L7H^HLi`0>00lY
MQcW:GH]MbUf0000L7oo00<007ooOol0=7oo00<007ooOol067oo000BOol00`00Oomoo`0TOol01P00
NkAk]6;WI`LLi`803`077>LYMRef:GHLicgh0000Kgoo00<007ooOol0=Goo00<007ooOol05goo000A
Ool00`00Oomoo`0VOol03gneKcQW1acW00l03Reg7>L]MbUf;GLLicgi?OP0001^Ool00`00Oomoo`0e
Ool00`00Oomoo`0GOol0015oo`03001oogoo02Ioo`04NkAW1fKW7>L200l01QcW;GHYMRUf7>Lmn@<m
n003001oogoo06]oo`03001oogoo03Ioo`03001oogoo01Ioo`004Goo00<007ooOol09Woo015k]6;V
I`LLi`0?:GHLibUf;GLLicgi?OPmnCWh7>M6>@0006aoo`03001oogoo03Moo`03001oogoo01Eoo`00
4Goo00<007ooOol09Woo00=k]6L77>L00P0?00DLibUf:GHYMQcW00<mn0047>M6>DHi001/Ool00`00
Oomoo`0gOol00`00Oomoo`0EOol0015oo`03001oogoo02Ioo`0COkERiQcW00h03acW;GLYMQcW?OPm
nCWh7>M6>DII@SU6FP007>L0JWoo00<007ooOol0>7oo00<007ooOol057oo000AOol00`00Oomoo`0V
Ool01G^dI`LLi`0?7>L00RUf00HLicgh?OPmn3gi7>L4AST00`00Oomoo`1YOol00`00Oomoo`0iOol0
0`00Oomoo`0COol0011oo`03001oogoo02Moo`0CNkARiQcW00hLibUf;GLLicgi>OPmnAcWAUU2>DIJ
ASTLidII0000JWoo00<007ooOol0>Goo00<007ooOol04goo000@Ool00`00Oomoo`0WOol01g^d7>L0
3acW:GH]MQcW008mn003?OTLidHi00=6>@057>M:NTYjBWT0001YOol00`00Oomoo`0jOol00`00Oomo
o`0BOol0011oo`03001oogoo02Qoo`0D7>L03acW;GLYMQcW>OPmnAcWAUU2>DIJASU6FAcWBWY:FDYj
AUT006Qoo`03001oogoo03Yoo`03001oogoo019oo`0047oo00<007ooOol09goo00URiacW:GHLibUf
7>Lmn3gi7>L01DHi00<LidYjBWT00TYj00<LidYj0000Igoo00<007ooOol0>Woo0P004goo000@Ool0
0`00Oomoo`0WOol05fL77>LLibUf;GLLicgi?OPLid8iAUY6>DII7>M:NTYIBWY6FAcWBWY>VTYj0000
IWoo00<007ooOol0=goo0`0000=oo`00Ool04Woo000@Ool00`00Oomoo`0WOol021cW;GHLibUf7>Lm
nCgh7>L4AST00acWBWY:N@02BWX01QcWBWY:NTYjCWX006Ioo`03001oogoo03Aoo`<000Aoo`03001o
ogoo015oo`0047oo00<007ooOol09goo0QcW01H]McWh7>Lmn1cW@SU6FTHiAUTLidYjBUU:NTII7>M:
NTjJBWY>VTYjCYX006Ioo`03001oogoo031oo`<000Moo`03001oogoo015oo`003goo00<007ooOol0
:7oo0QcW00@YMQcW?OPLi`A6>@037>M:NTYi00=:NP047>M:NTYjCWX2BWX00acWCYX0001UOol00`00
Oomoo`0]Ool3000;Ool00`00Oomoo`0@Ool000moo`03001oogoo02Qoo`0I7>LYMQcW?OPmnAcWAUY6
>DII@STLidYIBWY6FDYj7>M>VTYjCYY:NTjJ7>M>VdZJ0000IGoo00<007ooOol0:Woo0`003Woo00<0
07ooOol047oo000?Ool00`00Oomoo`0YOol017`07>Lmn1cW14Hi00<LidYiBWX00TYj00@LidYjBWY>
NP9:NP037>M>VTZJ009>VP03001oogoo069oo`03001oogoo02Moo`<0015oo`03001oogoo011oo`00
3goo00<007ooOol0:Goo01Yl03gi7>M6FTHiAUU2>AcWBUU:NTIIBWXLidjJBWY>VTYjCYXLidjKBYY>
VdZJ7>M:VP00Hgoo00<007ooOol08goo100057oo00<007ooOol047oo000?Ool00`00Oomoo`0ZOol0
0g`07>M6>@02AST00acWBWU:NP02BWX011cWBWY:NTij0dYj00TLidZJCYY>VQcWCYY>VdjJ0000HWoo
00<007ooOol087oo0`0067oo00<007ooOol047oo000?Ool00`00Oomoo`0ZOol06QcWASU6FD8i7>M:
FDYjAUU:NQcWCYY:NTjJBWY>VTYj7>M:VTjKBYXLidZJCY]:VTjK001ROol00`00Oomoo`0MOol3000K
Ool00`00Oomoo`0@Ool000ioo`03001oogoo02aoo`04O016>DHi7>L3BWX011cWBWY:NTij0dYj00<L
idZJCYX00TjJ00LLidjKCYY>VdjJCY/0001QOol00`00Oomoo`0JOol3000NOol00`00Oomoo`0@Ool0
00ioo`03001oogoo02aoo`0KO016FQcWBWY6FDYj7>M>VTYjCYY:NTjJBWXLidZJCY]:VTjK7>M>VdZJ
CY]:VTjK7>M>^`00061oo`03001oogoo01Moo`<0025oo`03001oogoo011oo`003Woo00<007ooOol0
;Goo00PLidYjBWY:NTYi7>M:NTij0dYj00<LidZJCYX00TjJ00LLidjKCYY>VdjJCY/Li`03CY/00`00
Oomoo`1MOol00`00Oomoo`0DOol3000UOol00`00Oomoo`0?Ool000ioo`03001oogoo02ioo`0KO01:
NTYI7>M:NTjJBWY>VTYj7>M:VTjKBYY>VacWCY]:VTjKBYY>VdZJ7>M>VTjkBYY>^`0005ioo`03001o
ogoo015oo`<002Qoo`03001oogoo00moo`003Woo00<007ooOol0;Woo00El04Yi7>M:NTij00=:NP03
7>M:VTjJ009>VP08BYXLidjJCY]>VTjKCYXLi`A>V`037>M>^`0005eoo`03001oogoo00ioo`<002]o
o`03001oogoo00moo`003Woo00<007ooOol0;goo01/LidYjCYY:NTjJBWXLidZJCY]:VTjKBYXLidZJ
CY]:VTjKBYXLidjJC[]:VTjkCYXLidZJ0000GGoo00<007ooOol02goo0`00;Woo00<007ooOol03goo
000>Ool00`00Oomoo`0`Ool01W`0BWY:NTYjCWXLi`=>VP08BYXLidjJCY]>VTjKCYXLi`E>V`067>M>
^djkC[/007oo0P00FGoo00<007ooOol027oo0`00<Goo00<007ooOol03goo000=Ool00`00Oomoo`0b
Ool06G`0BWY>VQcWCY]:VTjKBYXLidZJCY]:VTjKBYY>VacWC[]:VTjkCYY>^acWC[]:Vdjk00800003
J_M_600000@005Aoo`03001oogoo00Eoo`<003Aoo`03001oogoo00moo`003Goo00<007ooOol0<Woo
00=l04ij7>L00djJ00U:VTjJ7>M>VdjJCY]>VTjK7>L01DjK00<LidjkC[/00Tjk00HLi`00J_MZmflG
JaL2KcL00g<h0000001BOol00`00Oomoo`02Ool3000gOol00`00Oomoo`0?Ool000eoo`03001oogoo
03=oo`0S7>M>VdZJCY]:VTjK7>M>VdZJCY]:VTjK7>M>^dZJC[]>VTjkBYXLidZKC[]:VQcWB[/006Kg
J_QZmflHJaM_>6lgLcQ_=`02001@Ool00`00Ool00002000kOol00`00Oomoo`0>Ool000eoo`03001o
ogoo03Aoo`0;O01>VTZJCYXLidjKCYY>VdjJCY/Li`06CY/00acWC[]>^`02C[/01AcWC[]>^`00I]L0
0V[g00E_5f/GKcM_=g<h009cE`03001oogoo04aoo`<003ioo`03001oogoo00ioo`003Goo00<007oo
Ool0=Goo02Al04jK7>M>VdZJCY]:VTjKBYXLidZJC[]>VTjkBYY>^acWC[]:VTjk7>M>^dZkC[`006Jg
H[IZn6[gJ_Q_5g<hKcMc>6lgMeP20019Ool30002Ool00`00Oomoo`0lOol00`00Oomoo`0>Ool000eo
o`03001oogoo03Eoo`09O01>VQcWCYY>VdjJCY]>VQcW00I>V`037>M>^djk009>^`097>M>^djkB[/L
i`00I[MR]VJg009Zm`=_=`05LeQcEg=GLeL00014Ool40005Ool00`00Oomoo`0lOol00`00Oomoo`0>
Ool000aoo`03001oogoo03Moo`0I7>M:VTjKBYY>VdZJ7>M:VTjkCYY>^dZJC[]:VacWBYY>^dZKC[/L
idjlB[]>^acWC[`00P0000]R]VJgI_MZn6lGLcQ_=g=HLeMgF7=g008001Qoo`037>Ml07`002Aoo`<0
00Uoo`03001oogoo03aoo`03001oogoo00ioo`0037oo00<007ooOol0>7oo00Il04jJCY]>VTjK7>L5
CY/00djk7>M>^`03C[/00acWC[]:^`02C[/02AcWB[]>^dZk001NE6:FI[IZm`02KcL017=GLeQcEg=G
0WMg00<007ooOol047oo1AcW00=l04NN7>L00W`07goo0`0037oo00<007ooOol0?7oo00<007ooOol0
3Woo000<Ool00`00Oomoo`0iOol0:7`0BYY>VacWC[]>VTjkBYY>^djJ7>M:VTjkBY]>^dZJ7>M:^djk
B[]>_1cWC[a:^djl7>L005WbGQ9NE6[hKaMc>6lgLeQcEgMhLgMkU`002Woo21cW00UAKU5=DFiACG`0
7>M?Wd]n7>L00W`06Woo0`003goo00<007ooOol0?7oo00<007ooOol03Woo000<Ool00`00Oomoo`0j
Ool00g`0CYXLi`05CY/00acWC[]>^`03C[/00acWB[]>^`02C[/021cWC[]:^djlB[/LidZk0003FO80
0flHKcMcE`02LeL2MgL2MiL2000D7>L027`07>LLiacWCgi?OdmnO00FOol3000BOol00`00Oomoo`0m
Ool00`00Oomoo`0=Ool000aoo`03001oogoo03]oo`0JO01>VTjkBYY>^djJC[/LidjkBY]>^dZJC[/L
idjkB[]>_4Zk7>M:^djlB[/LidZkC[a:^`80000=?0<h0VlhKcMcF7=GLeQcMgMhMgIkUacW00001acW
00=REAcW7>L02AcW00Il04mnCgm?OTmoCgh27>L00g`0Oomoo`0@Ool3000EOol00`00Oomoo`0mOol0
0`00Oomoo`0=Ool000aoo`03001oogoo03aoo`03O01>VdjK009>V`037>M>^djk00=>^`0?7>M>^djk
C[]:^djk7>M>_4ZkC[/LidZlB[]:_1cW00@00004KcQcEg=GLeL2MgL3MiL00g^E000Li`037>L00f9e
HWHLi`067>L5GU@00g`0CglLi`037>L014mNCem?GW`03Woo0`0067oo00<007ooOol0?Goo00<007oo
Ool03Goo000;Ool00`00Oomoo`0nOol077`0CYY>^acWC[]:VdjkBYY>^dZK7>M:^djlB[]>^dZk7>M:
^djlB[/LidZkC[a:^acWB[/007oo0P0000]_>6lgMeQcEgMgMgIkUgMfNkIgU@0000LLi`05HYINMF:F
GUARE@057>L025iDO01CGdmNCem?GU=OCeh27>L00g`0Oomoo`08Ool3000KOol00`00Oomoo`0mOol0
0`00Oomoo`0=Ool000]oo`03001oogoo03moo`03O01>VacW00I>^`037>M>^dZk009>^`0<7>M:^djk
B[]>_1cWB[a:^dZl7>M:_1cW0P0000=oo`00LeP00W=G00MgMgNGMiIgUg^ENkIkU@0200000fJg7>LL
i`02HYH47>L3HWD00f9fHWERM@087>L3Ceh00g`0Oomoo`04Ool3000NOol00`00Oomoo`0mOol00`00
Oomoo`0=Ool000]oo`03001oogoo041oo`0IO01:VdjkBYY>^dZKC[/LidjlB[]>^dZkC[`LidjlB[]>
_4Zk7>M:^djlB[/LidZk7>L00TZl014007ooOomcF7=GMgQcMg^GMgIk]W^ENkIk/VKG000Lif:f00<L
i`03HYIV]f:F00DLi`0>GWERUW`0Cem?GU=OCei?GdmNDem?GTmOCeil009oo`<0025oo`03001oogoo
03eoo`03001oogoo00eoo`002goo00<007ooOol0@Goo00=l04jkC[/00djk00<LidZkC[/00Tjk00e:
^acWB[]>_4ZkC[/LidZlB[]:_1cWB[`Li`02B[`011cW001oogoo0W=G00MgMgNGMiMgUW^eNiEk/`02
Nk801@007>LLifJgI[H00acW1F:F0QcW00=l04mNCeh01DmN11cW00=l0000Ool08goo00<007ooOol0
?Goo00<007ooOol03Goo000;Ool00`00Oomoo`12Ool0:g`0BY]>^dZJ7>M:^djkB[]>_4ZkC[`Lidjl
B[]>_4Zk7>M:^djlB[/LidZkB[`LidZl7>M:_000Oom_=g=HLgMkUgMfNiMgUG^fNk9k/g^bNk<006KG
00<Li`03I[MR]QcW008Li`05HYIV]f:FH[Il00077>L01TlnCem??TmNCcil02Aoo`03001oogoo03eo
o`03001oogoo00eoo`002goo00<007ooOol0@goo00Al04jkC[/Li`=>^`0=B[]>^acWC[a:^djkB[]>
_1cWB[a:^dZl7>L00TZl00XLidZlB[`LidZl001oog=GMgMgUP9gU`09NkIkUG^bNk9k/g^bJbT001cW
009Ve`<Li`03I[MV]QcW00<Li`03HYIl04ln00]??P03O01oogoo025oo`03001oogoo03ioo`03001o
ogoo00aoo`002goo00<007ooOol0A7oo02Yl01cWC[]:^djlB[]>^dZk7>M:^djlB[]>_1cWC[a:^djl
B[/LidZkC[`LidZlA[/LidJl7>L007=HLeMkUgMfNiMkUG^fNk9k/g^b7>MW:F/Y00027>L2I]L03fJg
7>LLif:fI[MR]VJg7>Ml04lnCem??TmNCci?G`077>L00g`0Oomoo`0POol00`00Oomoo`0nOol00`00
Oomoo`0<Ool000Yoo`03001oogoo04Ioo`04O01>^djkB[/2C[/034jl7>M>^dZkC[a:^acWB[]:_4Zk
B[`Li`9:_0057>M:_4Zl7>M:_0027>L02000LeMgMgNGMiIk]G^ENk<2Nk801QcWJbU[:F/Y001Ze`8L
i`=Ve`<Li`03H[IV]g`000HLi`Q??P03O01oogoo01moo`03001oogoo03ioo`03001oogoo00aoo`00
2Woo00<007ooOol0Agoo01Al04ZkC[]:^djlB[/LidZkC[a:^djl7>M>_4ZkC[a:^acWB[]:_1cW0dZl
01DLidZm7>M:_@00MgQgMW^GMiEk]W^bNk=k/V/YIbU[:FLY7>L006[gI]L00QcW00AVefKFI]MR]P8L
i`0@O01;?TlnBci??T/nCci;?TlnBci??T/nCci;?TlnO00ROol00`00Oomoo`0mOol00`00Oomoo`0<
Ool000Yoo`03001oogoo04Qoo`0@O01>^djkB[/LidZkC[a:^djkB[/LidZkB[a:^dZl7>L2B[`01acW
B[a:_4Zl7>M6_4Zl008Li`05LeMgUgNGNkIkU@02Nk800g^cJbU[:@02JbT011cW00L006[G0VKG0QcW
16KG00=l01cW7>L03AcW00=l07ooOol07goo00<007ooOol0?Goo00<007ooOol037oo000:Ool00`00
Oomoo`19Ool0;W`0B[]>^acWC[a:^djlB[]>_1cWC[a:^djlB[/LidZkC[a:^acWA[]:_1cWB[a6_1cW
A[`LigMfNiMkUG^fNk9k/g^bJbUW:F/Y7>L0200700P001cWI]MZmfKG0QcW0VKG019l04/NCci;7Tln
Bai??T/NCci;7TlnBai??T/NCci;7TlnO00POol00`00Oomoo`0mOol00`00Oomoo`0<Ool000Yoo`03
001oogoo04Yoo`0>O00LidjlB[]>^dZkC[a:^acWB[]:_4ZkB[`Li`=:_0047>M:_4Zl7>L2B[`024Jl
7>LLig=GMiIk]G^ENk<2Nk83JbT01QcW00L020077>L0008Li`9Ve`0FJ]LLifKGO00Lid/nCci;?Tln
Bci??T/nCci;?TlnBci??T/nCci;?TlnO00OOol00`00Oomoo`0mOol00`00Oomoo`0<Ool000Yoo`03
001oogoo04]oo`0AO01:^djlB[]>_4ZkC[`LidjlB[]>_4Zk7>M:^dZlB[/Li`02B[`064Jk7>M6_4Zl
7>M:_AcWNiMgMW^fNk9k/g^bJbUW:F/Y7>L0200700PLiaCD001Zm`8Li`05I]MZmacWO01;7P0<7>L0
1DlnBai??T/NO0007goo00<007ooOol0?Woo00<007ooOol02goo0009Ool00`00Oomoo`1=Ool037`0
B[]>_4ZkC[]:^acWB[]:_4ZkB[`Li`=:_0057>M:_4ZlB[`Li`02B[`00acWA[a6_@02MiL017^ENk9k
/QcW0V/Y00DLi`0800L01acW00<D/`07001ZmfKG7>MVef[GO00011cW2D/N1QcW7Woo00<007ooOol0
?Woo00<007ooOol02goo0009Ool00`00Oomoo`1>Ool047`0B[]>_4Zk7>M:^djlB[]>_4Zk7>M:^djl
B[/LidJk0TZl01hLidJlB[e6_1cWA[akUgMfNkIk/W^cNk9[:FLY7>L01`0800LLiaBc5=<@/`00I_MZ
mfKg7>MVeg`0Bad2Bah00dln7>LLi`037>L02dlnBai??T/MCci;7TlnBae??T/NO0007Goo00<007oo
Ool0?Woo00<007ooOol02goo0009Ool00`00Oomoo`1?Ool2O00024jl7>M:_4ZkB[a:^dZl7>L3B[`0
0acWB[a:_002B[`02acWA[a:_1cWB[e6_7NGNiEk/g^b7>L00V/Y00DLi`0700L021cW00@D/`06001Z
mf[gI_LLig`011cW1D/N1AcW1D/N00=l07ooOol06goo00<007ooOol0?Woo00<007ooOol02goo0009
Ool00`00Oomoo`1AOol037`07>M:^djlB[]>_4Zk7>M:^dZlB[/Li`9:_00RA[]:_1cWB[a6_4Zm7>M:
_GMfNkIk/W^cIbU[:FLY7>L01`0800LLia2c5=@D/acW<KL006KgJ_MVmg`07>M;7TLMBah47>L2Bah0
14/MBai;7Tln11cW00=;7DlnO0006goo0P00@7oo00<007ooOol02goo0009Ool00`00Oomoo`1BOol0
1g`0B[a:^dZlB[]:_1cW00A:_0057>M:_4ZlB[`Li`02B[`01DJl7>M6_7NGNiD00W^b0V/Y00DLi`07
00P01acW00@D/`087>La]c6g000Lig`0A_i;7P<Li`A;7P@Li`I;7P8Li`03O01oogoo01Ioo`<0009o
o`03001oogoo03eoo`03001oogoo00]oo`002Goo00<007ooOol0Dgoo0W`000U:^djlB[/LidZkC[a:
^dZl7>L00dZl0216^acWA[a:_1cWB[egMW^fNk9k/fLYJbTLi`0800L021cW5=@D/aCC7>Le^36g=KPa
]`00O00LidKmBai6oD/N0QcW00=77T/NAad00d/N11cW00I;7D/NBai;7T/MO00COol40006Ool00`00
Oomoo`0lOol00`00Oomoo`0;Ool000Uoo`03001oogoo05Eoo`04O01:^dZl7>L4B[`00acWB[a:_002
B[`02AcWB[a:_4Zl7>MgUg^ENk=k/P02JbT011cW00L01acW11Bc00LLic6g<KLa]acW?QT000047>L0
0dKnB_i6oP037>L01DLNBai;7T/NAah00T/N0QcW0d/N00=l07ooOol03Woo0`002Woo00<007ooOol0
?7oo00<007ooOol02goo0008Ool00`00Oomoo`1GOol2O00021cWB[]:_4ZkC[`LidZlA[/2B[`07QcW
A[a:_DJl7>M6_7^GNk9k/fLYJbTLi`0800LLiaBc5=<@/acW<KLe^36g=KPLid8I?QP001cWA_i6o@8L
i`04Bai6oD/NAah37>L01TLNBai77D/NAai;7P<Li`03Bail07oo00]oo`<000ioo`03001oogoo03ao
o`03001oogoo00Yoo`0027oo00<007ooOol0FGoo00=l04ZlB[`00TZl00<LidZlB[`00dZl00HLidJl
B[a6_1cWMiH2Nk801F/Y7>L01`077>L00aBc00<Lic6g<KL00S6g00HLid8I@QU26ChI00027>L2A_h2
7>L3A_h00d[nAahLi`027>L024LNBai;7T/NAai;7QcWO009Ool3000BOol00`00Oomoo`0kOol00`00
Oomoo`0:Ool000Qoo`03001oogoo05Yoo`05O01>_4ZkB[`Li`03B[`07dJkB[`LidZlA[a:_AcWNiMk
/WMhIbTLi`0700PLiaCC4;<De1cW=KPa]cFh7>M26ChH@QTn6D8I7>L004Km008Li`03B_i6oAcW008L
i`05A_e;7TKmBai77P037>L01DLNBai77D/NO0001Woo0`005Woo00<007ooOol0>Woo00<007ooOol0
2Woo0008Ool00`00Oomoo`1KOol01G`0B[a:_4Zl7>L014Zl00LLidZlB[a6_1cWMiMk/`02JbT011cW
00P01acW0QBc00HLic6g<KLa]chI7>L2@QT01ShI@QTLidIJAUT00096oP8Li`=6oP8Li`06B_i6oTKn
A_i:oTLN0QcW00E;7TLNBail07oo00@001Yoo`03001oogoo03Uoo`03001oogoo00Yoo`0027oo00<0
07ooOol0G7oo0W`000=:^acWA[/00dZl024LidZmA[a:_4Jl7>Mk/V/YIbTLi`077>L@/aCD5;<Lic6g
=KPa]acW?QQ26ChI@QTLidYJAUU:FTII0016oDKnA_d00QcW00=6oTKmB_h00acW00E;7TKmBai6oD/N
008Li`<001moo`03001oogoo03Qoo`03001oogoo00Yoo`0027oo00<007ooOol0GWoo00=l01cWB[`0
14Zl00PLidZlB[a:_1cWNk9[:AcW0P0700@LiaBc5;<Li`<a]`047>M26D8I?QT2@QT00acWAUU6FP02
AUX01`007>LLidKnA_e6oQcW00E6oP8Li`03A_i:oP00008000037>Ml07oo01moo`03001oogoo03Qo
o`03001oogoo00Yoo`001goo00<007ooOol0H7oo00Al04ZlB[a6^`9:_00S7>M6_4ZmA[a:_G^bJbTL
i`087>LDe1Bc=KPLicFh<KM26AcW@QTn6D8I?QPLidIIBUY6FDYJAUU:FP00A_hLidKnA_e6oP027>L0
14KmB_i6oDKn0`0000E;7TKmBai6oG`0025oo`03001oogoo03Moo`03001oogoo00Yoo`001goo00<0
07ooOol0HGoo0W`00dZl00<LidZlA[`00TZl00Ek/f/Y7>L01acW008D/`077>La]c6g@QTLid8I?QT0
0T8I00<LidIIAUX00TIJ00I6FDIJ7>M:NP00A_h27>L014KmA_i6oQcW0`000dKn0QcW0TKn00=l07oo
Ool087oo00<007ooOol0=goo00<007ooOol02Goo0007Ool00`00Oomoo`1SOol2O00024JkB[dLidZl
A[a:_G^bJbT27>L06ABc5=<LicFh<KLe^1cW@QTn6D8I?QPLidIIBUY6FDYJAUU:FQcWCY]:NTjJ0016
oT;M00@00008A_hLiacWA_e6oTKmB_i6o@8Li`03O01oogoo025oo`03001oogoo03Ioo`03001oogoo
00Uoo`001goo00<007ooOol0Hgoo00D007ooO01l01cW009:_096_0067>L021cW5;<a]acW0S6g00=2
6AcW?QT00d8I00LLidIJAUY6FTIIAUXLi`04BWX300000dKMA_hLi`03A_h00dKm7>LLi`05A_h00g`0
Oomoo`0ROol00`00Oomoo`0eOol00`00Oomoo`09Ool000Moo`03001oogoo06=oo`09001oogooOoml
04ZmA[a:_4Jl008Li`0D5=<@/acW<KLe^3hH7>Ln6D8I?QQ26AcWBUY6FDYJAUU:FQcWCY]:NP<00006
BWX001cWA_i2gDKn0QcW00A6oDKnA_e6oP8Li`03A_e:oW`002Eoo`03001oogoo03Eoo`03001oogoo
00Uoo`001goo00<007ooOol0Hgoo00<007ooOol00Woo0W`000M:_6/Y7>LLiaBc<KLLi`02<KL00d8I
7>M26@02@QT01acWAUY6FTIJAUU6FQcW00<000=:NP037>M>VP00008Li`04A]e6oTKM7>L2A_h00dKm
A_i6oP027>L00g`0Oomoo`0TOol00`00Oomoo`0dOol00`00Oomoo`09Ool000Moo`03001oogoo06=o
o`03001oogoo00Aoo`0BO01W:AcW7>LDe1cW=KPa]d8I7>M26ChH@QTLidYJAUU:FTII0`0000m:NTjJ
BWY>VdYj7>M:VTjKBYX004;M7>M2gDKn@]d00QcW00I6oTKmA_i6oDKnO00WOol00`00Oomoo`0cOol0
0`00Oomoo`09Ool000Ioo`03001oogoo06Aoo`03001oogoo00Eoo`8Li`065;<Lic6g<KM26AcW0d8I
00<LidIJ00000`0000<LidYjBWX014Yj00PLidjJCY]>VTjK0016gTKM0QcW00=6oTKMA_h00QcW00A6
oDKnA_il02Qoo`03001oogoo039oo`03001oogoo00Uoo`001Woo00<007ooOol0I7oo00<007ooOol0
1Goo0QcW00Pa]acW<KM26AcW@QTn648I0`0001Y:FTIIBUXLidjKBWY>VTYjCY]:NQcWBYY>VdZJCY]:
VTjK0016gT;MA]hLidKn@]e6oT;M0QcW00=l07ooOol0:7oo00<007ooOol0<Goo00<007ooOol02Goo
0006Ool00`00Oomoo`1TOol00`00Oomoo`05Ool00acW5;<Li`02<KL00acW@QT0000200001QcWAUY6
FTIIAUXLi`I:NP0;7>M>VTjKCYY>VdjJCY/Lidjk0016gP02A]d01acWA_i6gDKnA]dLig`002Yoo`03
001oogoo039oo`03001oogoo00Qoo`001Woo00<007ooOol0I7oo00<007ooOol01Goo0QcW00<a]cFh
00000P0001e26ChI7>M6FDYJAUU:FQcWCY]:NTjJBWY>VdYj7>M:VTjKBYY>VdZJCY/LidjkC[YB^`00
A]i2gDKN008Li`03@]e6oW`002aoo`03001oogoo035oo`03001oogoo00Qoo`001Woo00<007ooOol0
I7oo00<007ooOol01Goo00El0000000001cW00926@05?QTLidIJAUY6F@02AUX00acWBWY:NP03BWX0
21cWCYY>VdjJCY]>VTjK7>L4C[/00`007>M6gP03A]d27>L^Ool00`00Oomoo`0`Ool00`00Oomoo`08
Ool000Ioo`03001oogoo06Aoo`03001oogoo009oo`@0000M=KPn6AcW?QQ26ChI7>M6FDYJAUU:FTII
7>M:NTjJBWY>VdYj7>M:VTjKBYY>VdZJCY/LidjkC[YB^`02C[/01Djj000LidKN@]d00W`0<7oo00<0
07ooOol0;goo00<007ooOol027oo0005Ool00`00Oomoo`1UOol00`00Ool000020004Ool01W`07>M2
6D8I?QTLi`96FP04AUU6FTIJ7>L5BWX021cWCYY>VdjJCY]>VTjK7>L6C[/01AcWC[/001cWO000<goo
00<007ooOol0;Woo00<007ooOol027oo0005Ool00`00Oomoo`1TOol30007Ool06g`0?QQ26ChI@QTL
idYJAUU:FTII7>M:NTjJBWY>VdYj7>M:VTjKBYY>VdZJCY/LidjkC[YB^`02C[/01Tjj7>M>^e:kC[/0
03Eoo`03001oogoo02eoo`03001oogoo00Qoo`001Goo00<007ooOol0HGoo0`0000=oo`00Ool027oo
00Il03hI@QTLidIJAUT2AUX00acWBWY:NP03BWX021cWCYY>VdjJCY]>VTjK7>L6C[/00acWC[]>^`03
C[/00`00Oomoo`0bOol00`00Oomoo`0]Ool00`00Oomoo`08Ool000Eoo`03001oogoo05ioo`<000Ao
o`03001oogoo00Moo`0HO0126AcWBUY6FDYJAUTLidYjCYY:NTjKBWXLidZJCY]:VTjKBYY>VacWC[]>
^U:k0Tjk00Y>^QcWC[]B^djkD[a>^e;L7>L003Aoo`03001oogoo02eoo`03001oogoo00Moo`001Goo
00<007ooOol0FWoo10001goo00<007ooOol027oo00<LidIJAUT00TIJ00<LidYjBWX00dYj00PLidjJ
CY]>VTjKCYY>VacW1Tjk00<LidjkC[/014jk00@LidjlC[/003Aoo`03001oogoo02aoo`03001oogoo
00Moo`001Goo00<007ooOol0Egoo0`002goo00<007ooOol02Goo01Al04YJAUTLidYjCYY:NTjKBWXL
idZJCY]:VTjKBYY>VacWC[]>^U:k0Tjk00e>^QcWC[]B^djkD[a>^e:k7>MBg4jkD]`0000eOol00`00
Oomoo`0[Ool00`00Oomoo`07Ool000Eoo`03001oogoo05Aoo`<000ioo`03001oogoo00Uoo`03O016
FQcW00E:NP097>M>VTjKCYY>VdjJCY]>VQcW00E>^`037>M>^djk00A>^`037>M>_4jk009>^`03C[`0
07oo03Aoo`03001oogoo02Yoo`03001oogoo00Moo`0017oo00<007ooOol0DWoo0`004Goo00<007oo
Ool02Woo014LidYjCYY:NTjKBWXLidZJCY]:VTjKBYY>VdZJ7>M>^U:k009>^`0AC[XLidjkD[]>^e:l
C[]B^djk7>M>^e;LC[]Bg1cWC]`0000dOol00`00Oomoo`0ZOol00`00Oomoo`07Ool000Aoo`03001o
ogoo04ioo`@001Aoo`03001oogoo00]oo`0=O01:NTYjBWXLidjJCY]>VTjKCYY>VdjJ7>L01Djk00<L
idjkC[/01Djk00LLidjkC[]>^djlC[/Li`02C]`00`00Oomoo`0bOol00`00Oomoo`0YOol00`00Oomo
o`07Ool000Aoo`03001oogoo04]oo`<001Qoo`03001oogoo00aoo`0=O01:NQcWBYY>VdZJCY]:VTjK
BYXLidjjD[/00Tjk01A>^QcWC[]B^djkD[a>^e:kC[/LidjkD]a>^e;LC[/LidjkD]a>^`00=Goo00<0
07ooOol0:7oo00<007ooOol01goo0004Ool00`00Oomoo`18Ool3000KOol00`00Oomoo`0=Ool02AcW
CYY>VdjJCY]>VTjKCYXLi`05C[/00acWC[]>^`05C[/01acWC[]>^djkC[a>^acW009>g004C]]>g4kL
000eOol00`00Oomoo`0XOol00`00Oomoo`06Ool000Aoo`03001oogoo04Eoo`<001ioo`03001oogoo
00ioo`09O01:VTjKBYY>VdZJ7>M>^U:k009>^`0HC[XLidjkD[]>^e:lC[]B^djk7>M>^e;LC[]Bg4jk
D]`Lie;LC[]>g4jk7>M>g000=Goo00<007ooOol09goo00<007ooOol01Woo0004Ool00`00Oomoo`12
Ool3000QOol00`00Oomoo`0?Ool01G`0CYY>VdjJ7>L01Djk00<LidjkC[/01Djk00E>_1cWC[]>^djl
009>^`037>M>g4kK00=>g0037>M>g4kL008003=oo`03001oogoo02Moo`03001oogoo00Ioo`000goo
00<007ooOol0?goo100097oo00<007ooOol047oo00El04ZJ7>M>^U:k009>^`0IC[XLidjkD[]>^e:l
C[]B^djkD[`Lie;LC[]Bg4jkD]`Lie;LC[]>g4jkD]`LidkLC]/00dkL00<007ooOol0<Goo00<007oo
Ool09Woo00<007ooOol01Woo0003Ool00`00Oomoo`0lOol3000XOol00`00Oomoo`0AOol00acWC[]>
^`04C[/00acWC[]>^`05C[/011cWC[]>^djl0Tjk00<LidkLC]/00dkL00=>facWC]`014kL00<Li`00
Ool0<Woo00<007ooOol09Goo00<007ooOol01Woo0003Ool00`00Oomoo`0iOol3000[Ool00`00Oomo
o`0BOol077`0C[]>^djjD[/Lie:kC[]B_4jkD[]>^e:l7>MBg4jkD]a>^e;LC[/LidjkC]a>^e;LC[/L
idkK0dkL00E>facWB]a>g00003=oo`03001oogoo02Aoo`03001oogoo00Ioo`000goo00<007ooOol0
=Woo0`00;Goo00<007ooOol057oo00Al04jkC[/Li`Q>^`037>M>^djl00=>^`037>M>fdkL009>g003
C]]>g1cW00E>g0057>M>g4kLC]`0000cOol00`00Oomoo`0SOol00`00Oomoo`06Ool000=oo`03001o
ogoo03=oo`<0031oo`03001oogoo01Aoo`0IO01B^acWD[]>^e:lC[]B^djkD[a>^acWC[]Bg4jkD]a>
^acWC[]>g4jkD]a>^dkL7>L00dkL00U>fdkL7>M>g4[LC]a:g1cW0000<goo00<007ooOol08Woo00<0
07ooOol01Woo0003Ool00`00Oomoo`0_Ool4000cOol00`00Oomoo`0EOol00acWC[]>^`06C[/00acW
C[]>_003C[/00djl7>M>g002C]`00dkKC]`Li`06C]`00acWC]a>g002C]`00acWC]`0000bOol00`00
Oomoo`0SOol00`00Oomoo`05Ool0009oo`03001oogoo02eoo`<003Moo`03001oogoo01Ioo`0FO01B
_4jkD[]>^e:lC[/LidjkD]a>^e;LC[]Bg1cWC]a>^e;LC[]>g4jk7>L2C]`034kKC]a>g4kL7>M>g4[L
C]`LidkMB]`003=oo`03001oogoo029oo`03001oogoo00Eoo`000Woo00<007ooOol0:Woo0`00>Woo
00<007ooOol05goo00=l04jkC[/00Tjk00<LidjkC[`00djk00=>_1cWC]`00TkL00A>fdkLC]`Li`I>
g0037>M>g4kL009>g0057>M:g4kLC]`0000cOol00`00Oomoo`0QOol00`00Oomoo`05Ool0009oo`03
001oogoo02Moo`<003eoo`03001oogoo01Qoo`0EO01B_4jkD[/Lie;LC[]Bg4jkD]a>^acWC[]Bg4jk
C]a>^e;L7>M>g4kK00=>g00<C]/Lid[LC]a:g4kL7>M>gD[LC]dLi`00<goo00<007ooOol087oo00<0
07ooOol01Goo0002Ool00`00Oomoo`0TOol30010Ool00`00Oomoo`0IOol017`0C[/Lidjl0djk00=>
_4jk7>L00TkL00E>fdkLC]a>g1cW00I>g0037>M>g4kL00=>g0077>M>g4kLB]`Lid[L0000<goo00<0
07ooOol07goo00<007ooOol01Goo0002Ool00`00Oomoo`0POol40013Ool00`00Oomoo`0JOol04G`0
D]a>^e;LC[]Bg4jkD]`Lie;LC[]>g4jkD]a>^acWC]/00dkL011>fdkL7>M>g4[LC]a:g1cWB]a>gD[L
C]dLidkMB]`0039oo`03001oogoo01moo`03001oogoo00Eoo`000Woo00<007ooOol07Goo0`00Agoo
00<007ooOol06goo00Al04jkC[]>_09>^`037>M>g4kK00=>g003C]/LidkL00E>g0037>M>g4kL00=>
g0037>M>g4[L009>g0047>M:g4[M7>L2000aOol00`00Oomoo`0NOol00`00Oomoo`05Ool0009oo`03
001oogoo01Yoo`<004Yoo`03001oogoo01aoo`0=O01Bg4jkD]`Lie;LC[]>g4jkD]a>^dkL7>L00dkL
01A>fdkLC]`Lid[LC]a:g4kLB]`Lid[LC]e:g1cWB]a>gD[L7>M:g4[M0P00<7oo00<007ooOol07Woo
00<007ooOol017oo00000goo001oo`0IOol3001=Ool00`00Oomoo`0MOol01G`0C[]>^acWC]/00dkL
00=>fdkL7>L01dkL00<LidkLC]`00dkL00TLidkLC]a>g1cWB]e:g4kM7>L00d[M00<Li`00Ool0;goo
00<007ooOol07Goo00<007ooOol017oo00000goo001oo`0FOol3001@Ool00`00Oomoo`0NOol02W`0
7>M>^dkLC[]Bg4jkC]a>^acW0TkL01Y>fdkLC]a>g1cWC]a:g4kLB]a>g1cWC]e:g4kMB]`Lid[LC]e:
g1cWB]a>gD[L7>M6g000<7oo00<007ooOol077oo00<007ooOol017oo00000goo001oo`0BOol4001C
Ool00`00Oomoo`0OOol01G`0C]a>g4kLC]/00TkL00<LidkLC]`01DkL00<LidkLC]`00dkL00XLidkL
C]a:g4kL7>M>gD[LB]dLi`=:g@047>M:gD[M000_Ool00`00Oomoo`0LOol00`00Oomoo`04Ool00003
Ool007oo00moo`<005Moo`03001oogoo021oo`09O01Bg4jkC]a>^e;L7>M>g4kK00=>g00IC]/Lid[L
C]a:g4kLB]a>g1cWC]e:g4kMB]`Lid[LC]e:g1cWB]a:gD[LC]dLid[mA]d00P00;Woo00<007ooOol0
6goo00<007ooOol017oo00000goo001oo`0<Ool3001JOol00`00Oomoo`0QOol01W`0C]a>g4kLC]/L
i`I>g0037>M>g4kL00A>g0037>M:g4kL009>g0067>M:gD[LC]e:g1cW0d[M00HLid[MB]dLid[m000^
Ool00`00Oomoo`0JOol00`00Oomoo`04Ool00003Ool007oo00Uoo`<005eoo`03001oogoo029oo`05
O01Bg4jk7>M>f`03C]`07TkKC]a>g1cWB]a>g4[LC]a:g4kL7>M>gD[LC]e:g1cWB]a>gD[LC]dLidkM
B]a:gAcWB_e6gD[m7>M:oP8002eoo`03001oogoo01Uoo`03001oogoo00Aoo`0000<007ooOol01Woo
0`00H7oo00<007ooOol08goo00=l04kL7>L01TkL00<LidkLC]`014kL00`LidkLC]a>g4[LC]`LidkM
B]a:gD[L7>L3B]d021cWB]e:gDKM7>M6gAcWA_d2000/Ool00`00Oomoo`0HOol00`00Oomoo`04Ool0
0003001oogoo009oo`@006=oo`03001oogoo02Aoo`05O01>g4kLC]a>f`03C]`081cWC]a:g4kLB]a>
g4[L7>M:g4kMB]a>gD[L7>M:g4kMB]a>gAcWB]e:g4kM7>M:oDKLB_dLid[m7>M:oTKM7>L2000[Ool0
0`00Oomoo`0HOol00`00Oomoo`03Ool00003001oo`00008006Moo`03001oogoo02Eoo`9l00A>g003
7>M>g4kL00E>g0037>M>g4[L009>g0077>M:g4[MB]a>gD[L7>L00d[M00PLid[MB]e:gAcWA]e:oAcW
0TKm00@LidKm000002Uoo`03001oogoo01Qoo`03001oogoo00=oo`000P00JWoo00<007ooOol09goo
02Ml04kLC]a>facWB]a>g4[LC]a:g4kLB]`Lid[LC]e:g4kM7>M>gD[LC]e:g4kM7>M>gD[LB]e:g1cW
A]e:oDKM7>M6gAcWA]e:oQcWA_h00QcW10001goo00<001cWOol077oo00<007ooOol05goo00<007oo
Ool00goo00000goo0000001YOol00`00Oomoo`0XOol2O0000acWC]a>g005C]`00acWB]a>g002C]`0
24[L7>M:g4kMB]a:gD[L7>L4B]d03QcWB]e:gD[M7>M:oDKM7>M6oDKn7>M6oQcWA_h37>L800057>LJ
Ool00`00Oomoo`0FOol00`00Oomoo`03Ool000=oo`03001oogoo06Ioo`03001oogoo02Yoo`0YO01>
g4[LC]a:g4kLB]a>g1cWC]e:g4kMB]a>gAcWC]e:g4kMB]a>gAcWB]e:g4kMB]`LidKLB_e6gAcWA]e:
oQcWB_i6gAcWA_e6oQcWA_i2oP067>L00dLO7>LLi`047>L00dLn7>LLi`027>LGOol00`00Oomoo`0E
Ool00`00Oomoo`03Ool000Aoo`03001oogoo06Eoo`03001oogoo02]oo`9l00E>g0047>M>g4kLB]`2
C]`01acWB]a:gD[LC]e:g1cW00A:g@0?7>M:gD[MB]e6gAcWA]e:oAcWA_i6oAcWA_e6oQcW0096oP8L
i`03A_hLidLN00@Li`03AahLiacW00<Li`03Aci7?acW00<LiaAoo`03001oogoo01Aoo`03001oogoo
00=oo`001Goo0P00IGoo00<007ooOol0;Goo02Ql04[LC]a:g4kL7>M>gD[LC]e:g4kM7>M>gD[LC]e:
g4kM7>M>gD[LB]e:g1cWA]e:oDKLB_dLid[mA]dLidKMB_hLid[nA_e6oQcWA_i2oP8Li`06AahLidLN
@ahLid<N0QcW00A7?acW7>M77P<Li`03Aci;?dLn00@Lia1oo`03001oogoo01Aoo`03001oogoo00=o
o`001goo00<007ooOol0HWoo00<007ooOol0;Woo00Il04kLC]`LidkLB]`3C]`024[L7>M:g4kMB]a:
gD[L7>L4B]d00acWB]e:g@02B]d02acWA]e:oDKM7>M6oDKn7>M6oTKm7>L00dKn0QcW00A6oQcW7>M7
7P8Li`04AahLiacWAah37>L024Ln7>LLiacWAci7?dLnAcl47>L=Ool00`00Oomoo`0DOol00`00Oomo
o`02Ool000Qoo`80069oo`03001oogoo02moo`9l000V7>M:g4kMB]a>gD[LC]dLidkMB]a>gD[LC]dL
id[MB]a>gD[LB]dLid[mA]e:oAcWB_i6gD[m7>M:oTKMA_hLid[nA_dLid;mA_i2oP8Li`08Aai2oQcW
@ai77acWAam37P8Li`06Acm37QcW7>M7?dLN0acW00E7?T/oAci;?dLn00@Li`Yoo`03001oogoo01=o
o`03001oogoo009oo`002Woo00<007ooOol0Ggoo00<007ooOol0<Goo00El04kLC]a>g4[L009>g007
7>M:g4[MB]a>gD[L7>L01D[M00<Lid[MB]d00T[M00DLid[mA]e6oQcW0096o@057>M6oDKnA_dLi`02
A_h00acWA_hLi`02A_h00acWAai77P027>L2Aah011cWAam77TLN0QcW00=7?TLoAch00acW00I7?TLo
Aci7?dLnAcl47>L7Ool00`00Oomoo`0BOol00`00Oomoo`02Ool000]oo`8005ioo`03001oogoo03=o
o`0[O01>gD[LC]e:g1cWB]a>gD[LC]e:g4kM7>M>gD[LB]e:g4kM7>M:oDKLB_e6gAcWA]e:oTKM7>M6
gD[nA]dLidKmB_i6oAcW@_e6oQcWA_hLidLN@_h00QcW00E77d<N7>M37TLO008Li`03@ai7?dLN00<L
i`03Aai7?dLN008Li`08Bcm7?T/oAci;?dLnBcm7?P@Li`Aoo`03001oogoo015oo`03001oogoo009o
o`003Goo00<007ooOol0Fgoo00<007ooOol0=7oo00el04kLC]a>g1cWB]e:g4kMB]a:gD[LC]dLi`04
B]d00acWB]e:g@02B]d01QcWB_e6gD[mA_dLi`96o@057>M6oTKmA_hLi`03A_h011cWA_hLiacW0TKn
00<LidLNAah00QcW0TLN0QcW0TLN00M77dLn7>LLidLoAci7?`037>L02DLoAci7?dLnAcm7?TLoAci7
?`047>L00`00Oomoo`0AOol00`00Oomoo`02Ool000ioo`03001oogoo05Yoo`03001oogoo03Eoo`9l
000bB]`Lid[LC]e:g4kMB]a>gD[L7>M:g4kMB]a:gAcWB_e6gD[mA]a:oAcWB_e6gD[n7>M:oTKMB_hL
idKnA_e:oQcWA_i2oDKn7>M6oT;m7>M2oTLN7>M77d<NAahLidLO@ai77`8Li`04Aai7?d<NAcl27>L0
14LNBcm77TLo0acW00a;?dLnBcm7?T/oAci;?dLnBcm7?QcW000BOol00`00Oomoo`02Ool000moo`80
05Yoo`03001oogoo03Moo`0:O00LidkMB]a:gD[LC]e:g4[M7>L4B]d00acWB]e:g@03B]d03QcWA]e:
oDKMA_dLidKnA_e6oQcWA_i6oDKn7>L3A_h011cWA_i6oQcW0TKn0QcW0TLN0QcW0dLN00<LidLNAal0
0dLN0acW00A7?TLoAci7?`<Li`0:Acm7?TLoAci7?dLnAcm7?W`0000AOol00`00Oomoo`02Ool0015o
o`03001oogoo05Moo`03001oogoo03Qoo`0dO01:g4kMB]a>gD[LC]e:g1cWB]a:gD[LC]e:g1cWA]a:
oDKMB_dLid[nA]e:oDKM7>M6gD[nA]dLidKmA_i6oDKn7>M6oT;mA_hLidKn@_dLid;nAai2oQcW@ai7
7T<N7>M37TLO@ah27>L01TLo@ai7?dLNAcm77P8Li`05Acm77T/oAai7?`037>L01D/oAci;?dLnO000
0Woo00<007ooOol03Woo00<007ooOol00Woo000BOol2001GOol00`00Oomoo`0iOol2O0001TkMB]a:
gD[LC]dLi`E:g@037>M:gD[M009:g@067>M6gD[mA]e:oAcW0TKm00M6oTKm7>M6oDKnA_dLi`04A_h0
11cWA_i6oQcW0dKn00@LidLNAai77P8Li`=77P8Li`=77P03Aam77TLo008Li`06Aci7?dLnAcm7?TLo
0acW00=7?g`0Ool00Woo00<007ooOol03Woo00<007ooOol00Goo000DOol00`00Oomoo`1DOol00`00
Oomoo`0kOol2O000<d[LC]e:g1cWB]a>gD[LB]e:g1cWA]e:oDKLB_e6gAcWA]e:oTKMB_dLid[nA]e:
oTKm7>M6oDKnA_dLidKmA_i2oDKn7>M6oT;m7>M2oTLN@_hLid<NAai37TLO7>M77d<NAam37P027>L0
1TLoAai7?d<NAcm77P<Li`06Aai7?dLNBcm77TLo0QcW17oo00<007ooOol03Goo00<007ooOol00Goo
000EOol00`00Oomoo`1COol00`00Oomoo`0mOol2O0000d[M7>M:g@04B]d00acWB]e:g@03B]d01QcW
B_e6gD[mA]dLi`=6o@04A_hLidKnA_d2A_h00acWA_i6oP02A_h011cWA_i6oQcW0dKn0QcW0dLN0QcW
14LN0QcW00=77TLOAah00TLN00Y77dLn7>LLidLoAci7?dLnAcml00Aoo`03001oogoo00eoo`03001o
ogoo005oo`005Woo0P00Dgoo00<007ooOol0?goo0W`003a:g4[MB]a>gD[L7>M6g4[mA]e:oDKL7>M6
gD[mA]e:oTKM7>M6gD[nA]e6oQcWB_i6oDKn@_dLidKmA_i2oAcW@_i6oT;m7>M2oTLN@_i77QcWAai3
7TLO@ahLid<NAam37TLO@ahLidLNAcm37TLoAai7?d<NBcl27>L00dLNBcml0006Ool00`00Oomoo`0<
Ool00`00Oomoo`01Ool001Qoo`03001oogoo051oo`03001oogoo045oo`9l00=:g@037>M:gD[M00A:
g@077>M6gD[mA]e:oAcWA_h00dKm00HLidKmA_i6oDKn7>L4A_h01AcWA_i6oTKn7>L014Kn00<LidLN
Aah00TLN0QcW14LN0QcW00E77dLNAai77TLO00977P04AchLiacWO007Ool00`00Oomoo`0;Ool00`00
Oomoo`01Ool001Uoo`80051oo`03001oogoo04=oo`9l000VB]a>gAcWB_e6g4[mA]e:oAcWB_i6gD[m
A]e:oQcWB_i6gD[nA]dLidKmB_i6oDKn7>M6oTKmA_i2oAcW@_i6oT;m7>M2oTLN@_i77P8Li`0:@ai7
7d<NAahLidLO@ai77d<NAal27>L02D<NAcm77TLo@ai7?dLNAcml0008Ool00`00Oomoo`0:Ool00`00
Oomoo`01Ool001]oo`03001oogoo04eoo`03001oogoo04Eoo`9l00037>M:gD[M00=:g@097>M6gD[m
A]e:oDKM7>M6oDKn00=6o@067>M6oDKnA_e6oQcW14Kn00DLidKnA_i6oQcW00E6oP037>M77TLN0097
7P8Li`E77P8Li`977P04Aam77TLNO00:Ool00`00Oomoo`09Ool00`00Oomoo`01Ool001aoo`8004eo
o`03001oogoo04Moo`9l000bA]e:oDKLB_dLid[mA]e:oTKMB_e6gAcWA]e:oTKMB_hLidKnA_e:oTKm
A_hLidKnA_e6oT;m7>M2oTKn@_dLid;nAai2oTLN@_hLid<NAam37TLN@ahLid<NAam37TLO@ai77`8L
i`03Aai7?g`000]oo`03001oogoo00Yoo`40005oo`5oo`007Woo00<007ooOol0BWoo00<007ooOol0
BGoo0W`00d[M00LLid[mA]e:oDKMB_dLi`02A_d02DKnA_e6oQcWA_i6oDKnA_dLi`05A_h01AcWA_i6
oTKn7>L01DKn0QcW14LN0QcW1TLN00<Lig`0Ool037oo00<007ooOol02Goo0@000Goo0Goo000OOol0
0`00Oomoo`19Ool00`00Oomoo`1;Ool3O00071cWA]e:oDKMB_i6gD[n7>M:oTKMB_i6gD[n7>M6oTKm
B_i6oAcW@_e6oTKmA_i2oAcW@_i6oT;m0QcW01977T;nAai2oTLN7>M77d<NAai37TLO7>M77d<NAam3
7TLOO00?Ool00`00Oomoo`08Ool10001Ool1Ool0021oo`8004Uoo`03001oogoo04ioo`=l0005B_e6
gD[mA]dLi`03A_d01TKnA_dLidKmA_i6o@96oP037>M6oTKn00=6oP037>M6oTKn0096oP037>M6oTKn
00=6oP037>M77TLN00=77P8Li`977P03O01oogoo00moo`03001oogoo00Moo`40005oo`5oo`008Woo
00<007ooOol0AWoo00<007ooOol0DGoo0W`00216gD[nA]dLidKMB_i6gD[nA_dLidKmA_i6oD[nA_dL
id;mA_i6oDKn7>M6oT;nA_i2oDKn7>M77T;nAai2oTLN0QcW00M37TLN@ai77d<N7>Ml000COol00`00
Oomoo`06Ool10001Ool1Ool002=oo`8004Ioo`03001oogoo05=oo`9l0003B_dLidKn00=6o@08A_hL
idKnA_e6oTKmA_hLi`E6oP037>M6oTKn00=6oP037>M6oTKn00A6oP037>M77TLN009l01Eoo`03001o
ogoo00Ioo`40005oo`5oo`009Goo00<007ooOol0@goo00<007ooOol0EGoo1G`001i:oTKMA_hLid[n
A_e6oTKmB_hLidKn@_e6oTKmA_hLidKn@_i6oT;mA_hLidLN@_i77T;nAail01cWO00HOol00`00Oomo
o`05Ool10001Ool1Ool002Ioo`8004=oo`03001oogoo05Yoo`=l00087>Ml07`0O016oTKmA_hLi`E6
oP037>M6oTKn00=6oP037>M6oTKn009l01aoo`03001oogoo00Eoo`40005oo`00:7oo00<007ooOol0
@7oo00<007ooOol0HGoo0g`000<Lig`0O00017`000<Lig`0O0000g`000<Lig`0Ool07Woo00<007oo
Ool017oo0@000Goo000YOol00`00Oomoo`0oOol00`00Oomoo`2COol00`00Oomoo`03Ool10001Ool0
02Yoo`8003moo`03001oogoo09Aoo`03001oogoo009oo`40005oo`00;7oo00<007ooOol0?7oo00<0
07ooOol0U7oo00<007ooOol00Woo0@000Goo000]Ool2000lOol00`00Oomoo`2EOol01@00Oomoogoo
00000Goo000_Ool00`00Oomoo`0iOol00`00Oomoo`2FOol01000Oomoo`000Goo000`Ool00`00Oomo
o`0hOol00`00Oomoo`2GOol00`00Ool00001Ool0035oo`8003Moo`03001oogoo09Uoo`40005oo`40
0000<goo00<007ooOol0=7oo00<007ooOol0VGoo0@000Goo0@00000dOol2000dOol00`00Oomoo`2J
Ool2000003Ioo`03001oogoo035oo`03001oogoo09Uoo`<00000=goo0P00<Goo00<007ooOol0UGoo
10000goo000iOol00`00Oomoo`0^Ool00`00Oomoo`2@Ool50007Ool003Yoo`03001oogoo02eoo`03
001oogoo08aoo`@000aoo`00>goo0P00;Goo00<007ooOol0R7oo100047oo000mOol00`00Oomoo`0Z
Ool00`00Oomoo`23Ool5000DOol003ioo`8002Yoo`03001oogoo07moo`@001Uoo`00@7oo00<007oo
Ool09goo00<007ooOol0NWoo1@007Goo0011Ool00`00Oomoo`0VOol00`00Oomoo`1fOol4000ROol0
049oo`8002Ioo`03001oogoo079oo`@002Ioo`00A7oo00<007ooOol08goo00<007ooOol0KGoo1@00
:Woo0015Ool2000SOol00`00Oomoo`1YOol4000_Ool004Moo`03001oogoo021oo`03001oogoo06Ao
o`D003=oo`00B7oo0P0087oo00<007ooOol0H7oo1000>7oo001:Ool00`00Oomoo`0MOol00`00Oomo
o`1KOol5000lOol004]oo`03001oogoo01aoo`03001oogoo05Moo`@0045oo`00C7oo0P0077oo00<0
07ooOol0Dgoo1000AGoo001>Ool00`00Oomoo`0IOol00`00Oomoo`1>Ool50019Ool004moo`8001Uo
o`03001oogoo04Yoo`@004ioo`00DGoo00<007ooOol05Woo00<007ooOol0AGoo1@00DWoo001BOol2
000FOol00`00Oomoo`11Ool4001GOol005Aoo`03001oogoo01=oo`03001oogoo03eoo`@005]oo`00
EGoo00<007ooOol04Woo00<007ooOol0>7oo1@00Ggoo001FOol2000AOol00`00Oomoo`0eOol4001T
Ool005Qoo`03001oogoo00ioo`03001oogoo031oo`D006Qoo`00FGoo0P003Woo00<007ooOol0;7oo
1000KGoo001KOol00`00Oomoo`0;Ool00`00Oomoo`0WOol5001aOol005aoo`03001oogoo00Yoo`03
001oogoo02=oo`@007Ioo`00GGoo0P002Woo00<007ooOol07goo1000NWoo001OOol00`00Oomoo`07
Ool00`00Oomoo`0JOol5001nOol0061oo`8000Moo`03001oogoo01Ioo`@008=oo`00HWoo00<007oo
Ool017oo00<007ooOol04Goo1@00Qgoo001SOol20004Ool00`00Oomoo`0=Ool4002<Ool006Eoo`05
001oogooOol0000;Ool4002@Ool006Ioo`04001oogoo0006Ool5002DOol006Moo`<0009oo`@009Uo
o`00JGoo0`00WGoo0000
\>"],
  ImageRangeCache->{{{0, 264.313}, {287, 0}} -> {0.0486402, -0.000148683, 
  0.00324458, 0.00324458}}]
}, Open]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[CellGroupData[{

Cell["Show[%,ViewPoint->{3.119,-0.998,0.852}]", "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9947 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.116359 1.13652 5.55112e-017 1.13652 [
[ 0 0 0 0 ]
[ 1 .9947 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02976 .29805 m
0 .97475 L
s
0 .97475 m
.66695 .9947 L
s
.66695 .9947 m
.6538 .36525 L
s
.6538 .36525 m
.02976 .29805 L
s
.16533 0 m
.95682 .11407 L
s
.95682 .11407 m
1 .91909 L
s
1 .91909 m
.1381 .88379 L
s
.1381 .88379 m
.16533 0 L
s
.02976 .29805 m
0 .97475 L
s
0 .97475 m
.1381 .88379 L
s
.1381 .88379 m
.16533 0 L
s
.16533 0 m
.02976 .29805 L
s
.6538 .36525 m
.95682 .11407 L
s
.95682 .11407 m
1 .91909 L
s
1 .91909 m
.66695 .9947 L
s
.66695 .9947 m
.6538 .36525 L
s
0 0 m
1 0 L
1 .9947 L
0 .9947 L
closepath
clip
newpath
.38624 .44256 m .44627 .47428 L .47982 .48099 L .305 .708 .977 r
F
.38226 .44092 m .38479 .44224 L .38624 .44256 L F
.38479 .44224 m .44627 .47428 L .38624 .44256 L F
.37894 .43956 m .38102 .44063 L .38226 .44092 L F
.38102 .44063 m .44627 .47428 L .38226 .44092 L F
.37624 .43845 m .3779 .4393 L .37894 .43956 L F
.3779 .4393 m .44627 .47428 L .37894 .43956 L F
.37409 .43757 m .37536 .43822 L .37624 .43845 L F
.37536 .43822 m .44627 .47428 L .37624 .43845 L F
.37336 .43736 m .44627 .47428 L .37409 .43757 L F
.37185 .4367 m .44627 .47428 L .37245 .43689 L F
.37047 .43612 m .44627 .47428 L .37125 .4364 L F
.37 .43589 m .38874 .44359 L .38654 .44282 L F
.38654 .44282 m .47982 .48099 L .51451 .48718 L .279 .705 .969 r
F
.39772 .4467 m .50051 .48233 L .40892 .45163 L F
.50051 .48233 m .50803 .485 L .41203 .45269 L F
.41196 .45266 m .41203 .45269 L .40661 .45087 L F
.50051 .48233 m .41203 .45269 L .41196 .45266 L F
.50051 .48233 m .40661 .45087 L .40655 .45084 L F
.40655 .45084 m .40661 .45087 L .4026 .44952 L F
.39444 .44556 m .39772 .4467 L .40655 .45084 L F
.39772 .4467 m .40892 .45163 L .40655 .45084 L F
.39444 .44556 m .40655 .45084 L .4026 .44952 L F
.50051 .48233 m .51451 .48718 L .50803 .485 L F
.42088 .45489 m .51451 .48718 L .54957 .49271 L .25 .698 .957 r
F
.4026 .44952 m .41577 .45395 L .42088 .45489 L F
.41577 .45395 m .51451 .48718 L .42088 .45489 L F
.51602 .48285 m .51418 .48255 L .42581 .4581 L F
.41618 .45351 m .51602 .48285 L .42581 .4581 L F
.5282 .48643 m .53619 .48897 L .423 .45734 L F
.5282 .48643 m .423 .45734 L .42293 .4573 L F
.42293 .4573 m .423 .45734 L .418 .45594 L F
.51602 .48285 m .5282 .48643 L .51418 .48255 L F
.41618 .45351 m .42581 .4581 L .418 .45594 L F
.5282 .48643 m .54957 .49271 L .53619 .48897 L F
.418 .45594 m .54957 .49271 L .58412 .49746 L .217 .688 .94 r
F
.55544 .49029 m .5559 .49041 L .55534 .49028 L F
.55544 .49029 m .55534 .49028 L .43849 .46344 L F
.42952 .45882 m .55544 .49029 L .43849 .46344 L F
.5559 .49041 m .56403 .49277 L .44201 .46428 L F
.4419 .46422 m .44201 .46428 L .43253 .46207 L F
.5559 .49041 m .44201 .46428 L .4419 .46422 L F
.42952 .45882 m .43849 .46344 L .43253 .46207 L F
.5559 .49041 m .58412 .49746 L .56403 .49277 L F
.43253 .46207 m .58412 .49746 L .61717 .50135 L .184 .676 .921 r
F
.5381 .48453 m .58339 .49416 L .44595 .46789 L F
.58339 .49416 m .61717 .50135 L .59135 .4963 L F
.58339 .49416 m .59135 .4963 L .44595 .46789 L F
.46088 .47058 m .61717 .50135 L .64769 .50432 L .153 .664 .899 r
F
.44595 .46789 m .45694 .47004 L .46088 .47058 L F
.45694 .47004 m .61717 .50135 L .46088 .47058 L F
.6105 .4976 m .61141 .49783 L .59457 .49507 L F
.61141 .49783 m .61794 .49946 L .59457 .49507 L F
.59457 .49507 m .61794 .49946 L .466 .47469 L F
.46595 .47465 m .466 .47469 L .45846 .47346 L F
.59457 .49507 m .466 .47469 L .46595 .47465 L F
.6105 .4976 m .45846 .47346 L .45845 .47346 L F
.44595 .46789 m .6105 .4976 L .45845 .47346 L F
.6105 .4976 m .64769 .50432 L .61794 .49946 L F
.46936 .47512 m .64769 .50432 L .67462 .50634 L .126 .652 .877 r
F
.45845 .47346 m .45846 .47346 L .45801 .47339 L .153 .664 .899 r
F
.45801 .47339 m .466 .47469 L .46936 .47512 L .126 .652 .877 r
F
.466 .47469 m .64769 .50432 L .46936 .47512 L F
.63706 .50063 m .64364 .50217 L .47723 .47976 L F
.63706 .50063 m .47723 .47976 L .47722 .47974 L F
.63706 .50063 m .47345 .47925 L .47343 .47923 L F
.63706 .50063 m .4689 .47864 L .46889 .47864 L F
.45203 .47066 m .45845 .47346 L .45801 .47339 L .153 .664 .899 r
F
.44595 .46789 m .45845 .47346 L .45203 .47066 L F
.45842 .47345 m .63706 .50063 L .47072 .47887 L .126 .652 .877 r
F
.63706 .50063 m .67462 .50634 L .64364 .50217 L F
.4763 .47957 m .67462 .50634 L .69695 .50745 L .106 .643 .856 r
F
.47343 .47923 m .47345 .47925 L .4689 .47864 L .126 .652 .877 r
F
.46889 .47864 m .4689 .47864 L .46846 .47858 L F
.45842 .47345 m .47072 .47887 L .46846 .47858 L F
.46846 .47858 m .47345 .47925 L .4763 .47957 L .106 .643 .856 r
F
.47722 .47974 m .47723 .47976 L .47345 .47925 L .126 .652 .877 r
F
.47345 .47925 m .67462 .50634 L .4763 .47957 L .106 .643 .856 r
F
.66292 .50315 m .66442 .50348 L .63256 .49994 L F
.66442 .50348 m .66827 .50432 L .63256 .49994 L F
.63256 .49994 m .66827 .50432 L .47931 .48371 L F
.66292 .50315 m .47931 .48371 L .4793 .48371 L F
.4793 .48371 m .47931 .48371 L .47705 .48347 L F
.46885 .47863 m .4706 .47885 L .47955 .48373 L F
.4706 .47885 m .66292 .50315 L .48215 .48401 L F
.4706 .47885 m .48215 .48401 L .47955 .48373 L F
.46846 .47858 m .46885 .47863 L .47746 .48351 L F
.46885 .47863 m .47955 .48373 L .47746 .48351 L F
.47394 .4817 m .47746 .48351 L .47705 .48347 L F
.46846 .47858 m .47746 .48351 L .47394 .4817 L F
.66292 .50315 m .69695 .50745 L .66827 .50432 L F
.4817 .48394 m .69695 .50745 L .71379 .50771 L .093 .638 .839 r
F
.47705 .48347 m .47931 .48371 L .4817 .48394 L F
.47931 .48371 m .69695 .50745 L .4817 .48394 L F
.48283 .48645 m .70163 .50646 L .48626 .48831 L F
.47741 .4835 m .4817 .48394 L .48283 .48645 L F
.4817 .48394 m .70163 .50646 L .48283 .48645 L F
.47741 .4835 m .48626 .48831 L .48357 .48808 L F
.70163 .50646 m .70375 .50685 L .48357 .48808 L F
.70163 .50646 m .71379 .50771 L .70375 .50685 L F
.48357 .48808 m .71379 .50771 L .72444 .50724 L .089 .638 .828 r
F
.48357 .48808 m .72238 .50708 L .48814 .49248 L F
.72238 .50708 m .72249 .50709 L .72243 .50708 L F
.72238 .50708 m .72243 .50708 L .48814 .49248 L F
.72249 .50709 m .72316 .50714 L .72272 .50711 L F
.72249 .50709 m .72272 .50711 L .48814 .49248 L F
.72316 .50714 m .72342 .50717 L .48814 .49248 L F
.48683 .49143 m .48814 .49248 L .48784 .49246 L F
.48357 .48808 m .48814 .49248 L .48683 .49143 L F
.72412 .50722 m .72419 .50723 L .48784 .49246 L F
.72316 .50714 m .72412 .50722 L .72342 .50717 L F
.72412 .50722 m .72444 .50724 L .72419 .50723 L F
.48784 .49246 m .72444 .50724 L .72841 .50621 L .094 .644 .822 r
F
.48784 .49246 m .72841 .50621 L .48997 .49666 L F
.48942 .49593 m .48997 .49666 L .48975 .49665 L F
.48784 .49246 m .48997 .49666 L .48942 .49593 L F
.47705 .48347 m .47741 .4835 L .48357 .48808 L .093 .638 .839 r
F
.43253 .46207 m .5381 .48453 L .44595 .46789 L .184 .676 .921 r
F
.45801 .47339 m .45842 .47345 L .46846 .47858 L .126 .652 .877 r
F
.38654 .44282 m .39444 .44556 L .4026 .44952 L .279 .705 .969 r
F
.4026 .44952 m .41618 .45351 L .418 .45594 L .25 .698 .957 r
F
.418 .45594 m .42952 .45882 L .43253 .46207 L .217 .688 .94 r
F
.37245 .43689 m .37336 .43736 L .37409 .43757 L .305 .708 .977 r
F
.37125 .4364 m .37185 .4367 L .37245 .43689 L F
.37 .43589 m .37047 .43612 L .37125 .4364 L F
.35311 .42874 m .44627 .47428 L .37 .43589 L .325 .708 .982 r
F
.35311 .42874 m .41448 .46716 L .44627 .47428 L F
1 0 0 r
.003 w
.44627 .47428 m
.46884 .47879 L
s
.09873 .31742 m .29181 .35729 L .283 .36429 L .78 .721 .798 r
F
.09063 .31253 m .29181 .35729 L .09873 .31742 L .768 .714 .802 r
F
.09063 .31253 m .30033 .34993 L .29181 .35729 L F
.10884 .32268 m .283 .36429 L .27455 .37098 L .793 .728 .791 r
F
.09873 .31742 m .283 .36429 L .10884 .32268 L .78 .721 .798 r
F
.25 g
.5 Mabswid
.27955 .35476 m
.29181 .35729 L
s
1 0 0 r
.003 w
.283 .36429 m
.29181 .35729 L
s
.33599 .42142 m .41448 .46716 L .35311 .42874 L .338 .704 .983 r
F
.33599 .42142 m .38496 .45979 L .41448 .46716 L F
.25 g
.5 Mabswid
.43931 .47077 m
.44627 .47428 L
s
1 0 0 r
.003 w
.41448 .46716 m
.44627 .47428 L
s
.08475 .30797 m .30033 .34993 L .09063 .31253 L .758 .708 .805 r
F
.08475 .30797 m .30794 .34217 L .30033 .34993 L F
1 0 0 r
.29181 .35729 m
.30033 .34993 L
s
.25 g
.5 Mabswid
.28932 .34796 m
.30033 .34993 L
s
.28224 .3467 m
.28932 .34796 L
s
.12071 .3283 m .27455 .37098 L .26711 .37744 L .811 .734 .78 r
F
.10884 .32268 m .27455 .37098 L .12071 .3283 L .793 .728 .791 r
F
1 0 0 r
.003 w
.27455 .37098 m
.283 .36429 L
s
.25 g
.5 Mabswid
.27166 .35313 m
.27955 .35476 L
s
.26978 .36113 m
.283 .36429 L
s
.2737 .34518 m
.28224 .3467 L
s
.31872 .41396 m .38496 .45979 L .33599 .42142 L .343 .696 .982 r
F
.31872 .41396 m .35809 .45228 L .38496 .45979 L F
.25 g
.37 .43589 m
.37047 .43612 L
s
.37047 .43612 m
.37122 .43651 L
s
.37122 .43651 m
.37231 .43705 L
s
.37231 .43705 m
.37377 .43779 L
s
.37377 .43779 m
.37566 .43874 L
s
.37566 .43874 m
.43034 .46626 L
s
.43034 .46626 m
.43931 .47077 L
s
.40713 .46256 m
.41448 .46716 L
s
1 0 0 r
.003 w
.38496 .45979 m
.41448 .46716 L
s
.08124 .30373 m .30794 .34217 L .08475 .30797 L .749 .702 .807 r
F
.08124 .30373 m .31406 .33401 L .30794 .34217 L F
1 0 0 r
.30033 .34993 m
.30794 .34217 L
s
.25 g
.5 Mabswid
.29846 .34072 m
.30794 .34217 L
s
.29232 .33977 m
.29846 .34072 L
s
.28488 .33864 m
.29232 .33977 L
s
.27578 .33724 m
.28488 .33864 L
s
.13408 .33427 m .26711 .37744 L .26127 .38374 L .833 .739 .76 r
F
.12071 .3283 m .26711 .37744 L .13408 .33427 L .811 .734 .78 r
F
1 0 0 r
.003 w
.26711 .37744 m
.27455 .37098 L
s
.25 g
.5 Mabswid
.26214 .35117 m
.27166 .35313 L
s
.26329 .34332 m
.2737 .34518 L
s
.26456 .33552 m
.27578 .33724 L
s
.14867 .34058 m .26127 .38374 L .25751 .38998 L .863 .739 .724 r
F
.13408 .33427 m .26127 .38374 L .14867 .34058 L .833 .739 .76 r
F
.25 g
.26123 .35909 m
.26978 .36113 L
s
1 0 0 r
.003 w
.26127 .38374 m
.26711 .37744 L
s
.25 g
.5 Mabswid
.13511 .3346 m
.13542 .33471 L
s
.13408 .33427 m
.13511 .3346 L
s
.30136 .4064 m .35809 .45228 L .31872 .41396 L .335 .682 .979 r
F
.30136 .4064 m .33412 .44474 L .35809 .45228 L F
.25 g
.35311 .42874 m
.35344 .42894 L
s
.35344 .42894 m
.35398 .42928 L
s
.35398 .42928 m
.35478 .42978 L
s
.35478 .42978 m
.39712 .4563 L
s
.39712 .4563 m
.40713 .46256 L
s
.33599 .42142 m
.33658 .42188 L
s
.33658 .42188 m
.37676 .45336 L
s
.37676 .45336 m
.38496 .45979 L
s
1 0 0 r
.003 w
.35809 .45228 m
.38496 .45979 L
s
.08016 .29976 m .31406 .33401 L .08124 .30373 L .74 .696 .809 r
F
.08016 .29976 m .31828 .3255 L .31406 .33401 L F
.25 g
.5 Mabswid
.10016 .31772 m
.10071 .31783 L
s
.09873 .31742 m
.10016 .31772 L
s
.10071 .31783 m
.10078 .31785 L
s
.09063 .31253 m
.0928 .31292 L
s
.11058 .3231 m
.11067 .32312 L
s
.11016 .323 m
.11058 .3231 L
s
.10897 .32271 m
.11016 .323 L
s
.10884 .32268 m
.10897 .32271 L
s
1 0 0 r
.003 w
.30794 .34217 m
.31406 .33401 L
s
.25 g
.5 Mabswid
.12071 .3283 m
.1209 .32835 L
s
.1209 .32835 m
.12231 .32874 L
s
.0928 .31292 m
.09285 .31292 L
s
.08707 .30833 m
.26456 .33552 L
s
.08475 .30797 m
.08707 .30833 L
s
.30639 .33302 m
.31406 .33401 L
s
.30128 .33235 m
.30639 .33302 L
s
.29505 .33154 m
.30128 .33235 L
s
.28736 .33054 m
.29505 .33154 L
s
.2778 .3293 m
.28736 .33054 L
s
.08124 .30373 m
.2778 .3293 L
s
1 0 0 r
.003 w
.31406 .33401 m
.31828 .3255 L
s
.14867 .34058 m .22031 .3731 L .16421 .34719 L .863 .739 .724 r
F
.22031 .3731 m .23607 .38025 L .21999 .37286 L F
.22031 .3731 m .21999 .37286 L .16421 .34719 L F
.23607 .38025 m .23388 .37918 L .20293 .36497 L F
.20247 .36479 m .20293 .36497 L .16421 .34719 L F
.23607 .38025 m .20293 .36497 L .20247 .36479 L F
.24822 .3987 m .25782 .40261 L .26242 .40913 L .875 .436 .082 r
F
.24815 .38573 m .24282 .38325 L .16421 .34719 L .863 .739 .724 r
F
.23607 .38025 m .24815 .38573 L .23388 .37918 L F
.24815 .38573 m .25751 .38998 L .24282 .38325 L F
.16421 .34719 m .25751 .38998 L .25626 .39625 L .903 .726 .652 r
F
.16421 .34719 m .21407 .37377 L .18046 .35408 L F
.21407 .37377 m .23264 .38366 L .21644 .3741 L F
.23264 .38366 m .23059 .38197 L .21644 .3741 L F
.24643 .39547 m .25626 .39625 L .25782 .40261 L .942 .665 .486 r
F
.21407 .37377 m .21644 .3741 L .18046 .35408 L .903 .726 .652 r
F
.18078 .35428 m .23062 .38199 L .24643 .39547 L .942 .665 .486 r
F
.23264 .38366 m .25626 .39625 L .23059 .38197 L .903 .726 .652 r
F
.23062 .38199 m .25626 .39625 L .24643 .39547 L .942 .665 .486 r
F
.18046 .35408 m .18103 .35439 L .18078 .35428 L F
.18103 .35439 m .25626 .39625 L .18078 .35428 L F
.18046 .35408 m .23008 .38521 L .19722 .3612 L F
.23008 .38521 m .25782 .40261 L .23036 .38385 L F
.23008 .38521 m .23036 .38385 L .19722 .3612 L F
.23178 .37614 m .23187 .37624 L .23181 .37615 L 0 .4 .833 r
F
.2566 .40178 m .25782 .40261 L .25713 .40233 L .875 .436 .082 r
F
.2566 .40178 m .25713 .40233 L .24822 .3987 L F
.23042 .3839 m .2566 .40178 L .24822 .3987 L F
.19771 .36154 m .25782 .40261 L .19761 .36149 L F
.23187 .37624 m .27021 .41585 L .23188 .37622 L 0 .4 .833 r
F
.23187 .37624 m .23188 .37622 L .23181 .37615 L F
.19761 .36149 m .23042 .3839 L .24822 .3987 L .875 .436 .082 r
F
.19722 .3612 m .19771 .36154 L .19761 .36149 L F
.19722 .3612 m .26242 .40913 L .21431 .36851 L F
.21464 .36879 m .26242 .40913 L .21464 .36879 L .476 0 0 r
F
.21465 .36879 m .21467 .36881 L .21464 .36879 L F
.21467 .36881 m .26242 .40913 L .21464 .36879 L F
.2319 .37624 m .27021 .41585 L .28126 .42278 L 0 .4 .833 r
F
.23181 .37615 m .23189 .37624 L .2319 .37624 L F
.23189 .37624 m .27021 .41585 L .2319 .37624 L F
.23161 .37597 m .23178 .37614 L .23181 .37615 L F
.21464 .36879 m .26242 .40913 L .27021 .41585 L .476 0 0 r
F
.21431 .36851 m .21465 .36879 L .21464 .36879 L F
.25 g
.5 Mabswid
.24055 .36155 m
.25158 .36461 L
s
.22711 .35782 m
.24055 .36155 L
s
.12231 .32874 m
.22711 .35782 L
s
.2383 .35361 m
.25088 .35662 L
s
.11067 .32312 m
.2383 .35361 L
s
.23646 .34586 m
.25057 .34878 L
s
.10078 .31785 m
.23646 .34586 L
s
1 0 0 r
.003 w
.25751 .38998 m
.26127 .38374 L
s
.25 g
.5 Mabswid
.14976 .341 m
.20955 .36392 L
s
.21745 .36132 m
.2317 .36595 L
s
.13542 .33471 m
.21745 .36132 L
s
.25158 .36461 m
.26067 .36713 L
s
.25088 .35662 m
.26123 .35909 L
s
.25057 .34878 m
.26214 .35117 L
s
.09285 .31292 m
.25054 .34105 L
s
.14953 .34091 m
.14976 .341 L
s
.1489 .34067 m
.14953 .34091 L
s
.14867 .34058 m
.1489 .34067 L
s
.25054 .34105 m
.26329 .34332 L
s
1 0 0 r
.003 w
.25626 .39625 m
.25751 .38998 L
s
.28393 .39878 m .33412 .44474 L .30136 .4064 L .311 .66 .972 r
F
.28393 .39878 m .31326 .43726 L .33412 .44474 L F
.25 g
.5 Mabswid
.31911 .41434 m
.34758 .44205 L
s
.34758 .44205 m
.35809 .45228 L
s
.31872 .41396 m
.31911 .41434 L
s
1 0 0 r
.003 w
.33412 .44474 m
.35809 .45228 L
s
.25626 .39625 m
.2572 .40009 L
s
.25 g
.5 Mabswid
.31263 .32489 m
.31828 .3255 L
s
.30863 .32445 m
.31263 .32489 L
s
.30365 .32392 m
.30863 .32445 L
s
.29742 .32324 m
.30365 .32392 L
s
.28958 .32239 m
.29742 .32324 L
s
.08016 .29976 m
.28958 .32239 L
s
.26647 .39115 m .31326 .43726 L .28393 .39878 L .26 .622 .959 r
F
.26647 .39115 m .29562 .42993 L .31326 .43726 L F
.25 g
.30143 .40649 m
.31381 .42097 L
s
.31381 .42097 m
.33412 .44474 L
s
.30136 .4064 m
.30143 .40649 L
s
1 0 0 r
.003 w
.31326 .43726 m
.33412 .44474 L
s
.25 g
.5 Mabswid
.26067 .36713 m
.27455 .37098 L
s
.24902 .38352 m .29562 .42993 L .26647 .39115 L .156 .552 .928 r
F
.24902 .38352 m .28126 .42278 L .29562 .42993 L F
.25 g
.28397 .39884 m
.31326 .43726 L
s
.28393 .39878 m
.28397 .39884 L
s
1 0 0 r
.003 w
.29562 .42993 m
.31326 .43726 L
s
.25895 .40421 m
.26242 .40913 L
s
.2897 .42698 m
.29562 .42993 L
s
.62424 .50204 m
.64769 .50432 L
s
.23161 .37597 m .28126 .42278 L .24902 .38352 L 0 .4 .833 r
F
1 0 0 r
.28126 .42278 m
.2897 .42698 L
s
.21431 .36851 m .27021 .41585 L .23161 .37597 L .476 0 0 r
F
.25 g
.5 Mabswid
.23161 .37597 m
.23178 .37614 L
s
.23178 .37614 m
.23181 .37617 L
s
.23181 .37617 m
.23187 .37624 L
s
.24804 .39294 m
.27021 .41585 L
s
.23187 .37624 m
.24804 .39294 L
s
1 0 0 r
.003 w
.27021 .41585 m
.28126 .42278 L
s
.25 g
.5 Mabswid
.23689 .3744 m
.24672 .37817 L
s
.25281 .3728 m
.26711 .37744 L
s
.24672 .37817 m
.26127 .38374 L
s
.26648 .39116 m
.2666 .39131 L
s
.26665 .39139 m
.29562 .42993 L
s
.2666 .39131 m
.26665 .39139 L
s
.26647 .39115 m
.26648 .39116 L
s
.24924 .38379 m
.28126 .42278 L
s
.24922 .38377 m
.24924 .38379 L
s
.24918 .38373 m
.24922 .38377 L
s
.24916 .3837 m
.24918 .38373 L
s
.24904 .38355 m
.24916 .3837 L
s
.24902 .38352 m
.24904 .38355 L
s
.2317 .36595 m
.24331 .36971 L
s
.24331 .36971 m
.25281 .3728 L
s
.20955 .36392 m
.22471 .36973 L
s
.22471 .36973 m
.23689 .3744 L
s
.63679 .50254 m
.64769 .50432 L
s
1 0 0 r
.003 w
.64769 .50432 m
.67462 .50634 L
s
.25 g
.5 Mabswid
.65044 .50308 m
.67071 .50581 L
s
.67071 .50581 m
.67462 .50634 L
s
1 0 0 r
.003 w
.67462 .50634 m
.69695 .50745 L
s
.25 g
.5 Mabswid
.6607 .5035 m
.6763 .5052 L
s
.6763 .5052 m
.69695 .50745 L
s
1 0 0 r
.003 w
.69695 .50745 m
.71379 .50771 L
s
.25 g
.5 Mabswid
.66758 .50377 m
.70375 .50685 L
s
.70375 .50685 m
.71379 .50771 L
s
1 0 0 r
.003 w
.71379 .50771 m
.72444 .50724 L
s
0 g
.006 w
.08016 .29976 m
.08124 .30373 L
s
.08124 .30373 m
.08475 .30797 L
s
.25 g
.5 Mabswid
.67111 .50391 m
.72316 .50716 L
s
.72316 .50716 m
.72351 .50718 L
s
.72351 .50718 m
.72357 .50719 L
s
.72357 .50719 m
.72444 .50724 L
s
0 g
.006 w
.08475 .30797 m
.09063 .31253 L
s
.09063 .31253 m
.09873 .31742 L
s
.09873 .31742 m
.10884 .32268 L
s
.10884 .32268 m
.12071 .3283 L
s
.37 .43589 m
.38654 .44282 L
s
.35311 .42874 m
.37 .43589 L
s
.33599 .42142 m
.35311 .42874 L
s
.38654 .44282 m
.4026 .44952 L
s
.31872 .41396 m
.33599 .42142 L
s
.4026 .44952 m
.418 .45594 L
s
.30136 .4064 m
.31872 .41396 L
s
.12071 .3283 m
.13408 .33427 L
s
.418 .45594 m
.43253 .46207 L
s
.48975 .49665 m .72841 .50621 L .72553 .50479 L .108 .656 .823 r
F
1 0 0 r
.003 w
.72444 .50724 m
.72841 .50621 L
s
0 g
.006 w
.28393 .39878 m
.30136 .4064 L
s
.26647 .39115 m
.28393 .39878 L
s
.43253 .46207 m
.44595 .46789 L
s
.13408 .33427 m
.14867 .34058 L
s
.24902 .38352 m
.26647 .39115 L
s
.23161 .37597 m
.24902 .38352 L
s
.14867 .34058 m
.16421 .34719 L
s
.21431 .36851 m
.23161 .37597 L
s
.44595 .46789 m
.45801 .47339 L
s
.16421 .34719 m
.18046 .35408 L
s
.19722 .3612 m
.21431 .36851 L
s
.18046 .35408 m
.19722 .3612 L
s
.45801 .47339 m
.46846 .47858 L
s
.46846 .47858 m
.47705 .48347 L
s
.47705 .48347 m
.48357 .48808 L
s
.48975 .49665 m .72553 .50479 L .48923 .5007 L .108 .656 .823 r
F
.48923 .5007 m .72553 .50479 L .7159 .5032 L .131 .673 .831 r
F
1 0 0 r
.003 w
.72553 .50479 m
.72841 .50621 L
s
.25 g
.5 Mabswid
.66825 .5038 m
.72841 .50621 L
s
0 g
.006 w
.48357 .48808 m
.48784 .49246 L
s
.48784 .49246 m
.48975 .49665 L
s
.48923 .5007 m .7159 .5032 L .48629 .50467 L .131 .673 .831 r
F
.48629 .50467 m .7159 .5032 L .69996 .50166 L .161 .695 .843 r
F
1 0 0 r
.003 w
.7159 .5032 m
.72553 .50479 L
s
.25 g
.5 Mabswid
.72469 .50477 m
.72553 .50479 L
s
.65591 .50358 m
.72469 .50477 L
s
0 g
.006 w
.48923 .5007 m
.48975 .49665 L
s
.48629 .50467 m .69996 .50166 L .48102 .50861 L .161 .695 .843 r
F
0 g
.48629 .50467 m
.48923 .5007 L
s
.25 g
.5 Mabswid
.63518 .50372 m
.7159 .5032 L
s
.48102 .50861 m .69996 .50166 L .67841 .50037 L .197 .72 .859 r
F
1 0 0 r
.003 w
.69996 .50166 m
.7159 .5032 L
s
.48102 .50861 m .67841 .50037 L .47355 .51259 L .197 .72 .859 r
F
0 g
.006 w
.48102 .50861 m
.48629 .50467 L
s
.25 g
.5 Mabswid
.60768 .50459 m
.69996 .50166 L
s
.47355 .51259 m .67841 .50037 L .65219 .49952 L .237 .746 .877 r
F
.47355 .51259 m .65219 .49952 L .46407 .51664 L F
0 g
.006 w
.47355 .51259 m
.48102 .50861 L
s
1 0 0 r
.003 w
.67841 .50037 m
.69996 .50166 L
s
.46407 .51664 m .65219 .49952 L .6224 .49926 L .279 .772 .896 r
F
.46407 .51664 m .6224 .49926 L .45281 .52083 L F
0 g
.006 w
.46407 .51664 m
.47355 .51259 L
s
.25 g
.5 Mabswid
.66894 .50094 m
.67841 .50037 L
s
.57535 .50652 m
.66894 .50094 L
s
1 0 0 r
.003 w
.65219 .49952 m
.67841 .50037 L
s
.45281 .52083 m .6224 .49926 L .59023 .4997 L .321 .798 .913 r
F
.45281 .52083 m .59023 .4997 L .44 .52517 L F
0 g
.006 w
.45281 .52083 m
.46407 .51664 L
s
.25 g
.5 Mabswid
.64011 .50062 m
.65219 .49952 L
s
.44 .52517 m .59023 .4997 L .55683 .50089 L .363 .821 .928 r
F
.44 .52517 m .55683 .50089 L .4259 .52969 L F
0 g
.006 w
.44 .52517 m
.45281 .52083 L
s
.25 g
.5 Mabswid
.63228 .50134 m
.64011 .50062 L
s
.54018 .50972 m
.63228 .50134 L
s
.608 .50109 m
.6224 .49926 L
s
1 0 0 r
.003 w
.6224 .49926 m
.65219 .49952 L
s
.4259 .52969 m .55683 .50089 L .52333 .50286 L .402 .841 .939 r
F
.4259 .52969 m .52333 .50286 L .41075 .5344 L F
0 g
.006 w
.4259 .52969 m
.44 .52517 L
s
.25 g
.5 Mabswid
.59853 .5023 m
.608 .50109 L
s
.57378 .50249 m
.59023 .4997 L
s
.41075 .5344 m .49071 .50559 L .39477 .5393 L .438 .86 .948 r
F
.41075 .5344 m .52333 .50286 L .49071 .50559 L F
.25 g
.53856 .50491 m
.55683 .50089 L
s
.56282 .50434 m
.57378 .50249 L
s
.58675 .5038 m
.59853 .5023 L
s
.50397 .51432 m
.58675 .5038 L
s
.39477 .5393 m .45979 .50903 L .37815 .54438 L .47 .876 .952 r
F
.25 g
.41075 .5344 m
.41129 .53425 L
s
.39477 .5393 m .49071 .50559 L .45979 .50903 L .47 .876 .952 r
F
.25 g
.52614 .50764 m
.53856 .50491 L
s
.50323 .50849 m
.52333 .50286 L
s
0 g
.006 w
.39477 .5393 m
.41075 .5344 L
s
.25 g
.5 Mabswid
.54918 .50666 m
.56282 .50434 L
s
.46816 .52039 m
.54918 .50666 L
s
1 0 0 r
.003 w
.59023 .4997 m
.6224 .49926 L
s
.37815 .54438 m .43125 .51312 L .36105 .54963 L .497 .89 .952 r
F
.25 g
.5 Mabswid
.39477 .5393 m
.39514 .53917 L
s
.41129 .53425 m
.41181 .5341 L
s
.37815 .54438 m .45979 .50903 L .43125 .51312 L .497 .89 .952 r
F
.25 g
.48918 .51243 m
.50323 .50849 L
s
.46835 .51344 m
.49071 .50559 L
s
0 g
.006 w
.37815 .54438 m
.39477 .5393 L
s
.25 g
.5 Mabswid
.51058 .51106 m
.52614 .50764 L
s
.43366 .52798 m
.51058 .51106 L
s
.36105 .54963 m .4056 .51778 L .34358 .55502 L .519 .904 .948 r
F
.25 g
.37815 .54438 m
.37839 .54428 L
s
.39514 .53917 m
.39546 .53905 L
s
.36105 .54963 m .43125 .51312 L .4056 .51778 L .519 .904 .948 r
F
.25 g
.452 .51919 m
.46835 .51344 L
s
.43386 .52026 m
.45979 .50903 L
s
0 g
.006 w
.36105 .54963 m
.37815 .54438 L
s
.25 g
.5 Mabswid
.47121 .51746 m
.48918 .51243 L
s
.41181 .5341 m
.47121 .51746 L
s
1 0 0 r
.003 w
.55683 .50089 m
.59023 .4997 L
s
.34358 .55502 m .3832 .52296 L .32586 .56052 L .534 .915 .935 r
F
.25 g
.5 Mabswid
.36105 .54963 m
.36119 .54956 L
s
.37839 .54428 m
.37856 .5442 L
s
.34358 .55502 m .4056 .51778 L .3832 .52296 L .534 .915 .935 r
F
.25 g
.41325 .52918 m
.43386 .52026 L
s
.39792 .53045 m
.43125 .51312 L
s
0 g
.006 w
.34358 .55502 m
.36105 .54963 L
s
.25 g
.5 Mabswid
.43019 .52685 m
.452 .51919 L
s
.39546 .53905 m
.43019 .52685 L
s
.32586 .56052 m .3643 .52858 L .30795 .5661 L .536 .923 .906 r
F
.25 g
.34358 .55502 m
.34365 .55498 L
s
.36119 .54956 m
.36124 .54953 L
s
.32586 .56052 m .3832 .52296 L .3643 .52858 L .536 .923 .906 r
F
.25 g
.36645 .54682 m
.39792 .53045 L
s
.36124 .54953 m
.36645 .54682 L
s
.34365 .55498 m
.35027 .55101 L
s
0 g
.006 w
.32586 .56052 m
.34358 .55502 L
s
.25 g
.5 Mabswid
.38328 .54216 m
.41325 .52918 L
s
.37856 .5442 m
.38328 .54216 L
s
.30795 .5661 m .34904 .53461 L .28991 .57172 L .511 .913 .84 r
F
.25 g
.32586 .56052 m
.32587 .56052 L
s
.30795 .5661 m .3643 .52858 L .34904 .53461 L .511 .913 .84 r
F
0 g
.006 w
.30795 .5661 m
.32586 .56052 L
s
.25 g
.5 Mabswid
.35027 .55101 m
.4056 .51778 L
s
1 0 0 r
.003 w
.52333 .50286 m
.55683 .50089 L
s
.28991 .57172 m .33748 .54102 L .27178 .57735 L .415 .837 .676 r
F
.28991 .57172 m .34904 .53461 L .33748 .54102 L F
0 g
.006 w
.28991 .57172 m
.30795 .5661 L
s
.25 g
.5 Mabswid
.28991 .57172 m
.2901 .5716 L
s
.27178 .57735 m .33748 .54102 L .32957 .54779 L 0 0 0 r
F
.27178 .57735 m .32957 .54779 L .25364 .58295 L F
0 g
.006 w
.27178 .57735 m
.28991 .57172 L
s
.25 g
.5 Mabswid
.33376 .5442 m
.34904 .53461 L
s
1 0 0 r
.003 w
.49071 .50559 m
.52333 .50286 L
s
.25364 .58295 m .32957 .54779 L .32518 .55494 L .186 0 .222 r
F
.25364 .58295 m .32518 .55494 L .23555 .58849 L F
0 g
.006 w
.25364 .58295 m
.27178 .57735 L
s
.25 g
.5 Mabswid
.30795 .5661 m
.32404 .55538 L
s
.32551 .55441 m
.3643 .52858 L
s
.2901 .5716 m
.30249 .56382 L
s
.32587 .56052 m
.3832 .52296 L
s
.31316 .55447 m
.33748 .54102 L
s
.23555 .58849 m .32409 .56247 L .21761 .59395 L .412 .243 .54 r
F
.23555 .58849 m .32518 .55494 L .32409 .56247 L F
.25 g
.23555 .58849 m
.23573 .58842 L
s
.3121 .55983 m
.32518 .55494 L
s
.3029 .56014 m
.31316 .55447 L
s
.31345 .55526 m
.32957 .54779 L
s
1 0 0 r
.003 w
.45979 .50903 m
.49071 .50559 L
s
.21761 .59395 m .32594 .5704 L .19995 .59928 L .523 .424 .684 r
F
.21761 .59395 m .32409 .56247 L .32594 .5704 L F
0 g
.006 w
.21761 .59395 m
.23555 .58849 L
s
.25 g
.5 Mabswid
.21761 .59395 m
.21792 .59385 L
s
.31254 .56588 m
.32409 .56247 L
s
.29734 .57037 m
.31254 .56588 L
s
.29405 .56659 m
.3121 .55983 L
s
.28869 .56672 m
.31345 .55526 L
s
1 0 0 r
.003 w
.43125 .51312 m
.45979 .50903 L
s
.19995 .59928 m .33028 .57876 L .18275 .60449 L .583 .52 .75 r
F
.19995 .59928 m .32594 .5704 L .33028 .57876 L F
0 g
.006 w
.19995 .59928 m
.21761 .59395 L
s
.25 g
.5 Mabswid
.2003 .5992 m
.20044 .59917 L
s
.19995 .59928 m
.2003 .5992 L
s
.31538 .57282 m
.32594 .5704 L
s
.30179 .57594 m
.31538 .57282 L
s
.27719 .57633 m
.29734 .57037 L
s
.26834 .57622 m
.29405 .56659 L
s
.26752 .57652 m
.28869 .56672 L
s
.18275 .60449 m .33651 .58754 L .16621 .60955 L .621 .576 .783 r
F
.18275 .60449 m .33028 .57876 L .33651 .58754 L F
.25 g
.23573 .58842 m
.26834 .57622 L
s
.21792 .59385 m
.24995 .58439 L
s
0 g
.006 w
.18275 .60449 m
.19995 .59928 L
s
.25 g
.5 Mabswid
.1829 .60446 m
.18328 .60439 L
s
.18328 .60439 m
.18344 .60437 L
s
.18275 .60449 m
.1829 .60446 L
s
.32055 .58046 m
.33028 .57876 L
s
.30812 .58262 m
.32055 .58046 L
s
.29239 .58537 m
.30812 .58262 L
s
.28435 .57994 m
.30179 .57594 L
s
.26191 .58508 m
.28435 .57994 L
s
.24995 .58439 m
.27719 .57633 L
s
1 0 0 r
.003 w
.4056 .51778 m
.43125 .51312 L
s
.16621 .60955 m .34395 .59675 L .15058 .61446 L .647 .611 .8 r
F
.16621 .60955 m .33651 .58754 L .34395 .59675 L F
0 g
.006 w
.16621 .60955 m
.18275 .60449 L
s
.25 g
.5 Mabswid
.16621 .60955 m
.16648 .60951 L
s
.16648 .60951 m
.16697 .60945 L
s
.16697 .60945 m
.16716 .60943 L
s
.32766 .58869 m
.33651 .58754 L
s
.31631 .59015 m
.32766 .58869 L
s
.30196 .59201 m
.31631 .59015 L
s
1 0 0 r
.003 w
.3832 .52296 m
.4056 .51778 L
s
.10564 .66226 m .34839 .69621 L .33839 .70499 L .789 .726 .794 r
F
.09818 .65687 m .34839 .69621 L .10564 .66226 L .777 .719 .798 r
F
.09818 .65687 m .35744 .68704 L .34839 .69621 L F
.11568 .66796 m .33839 .70499 L .32819 .71341 L .803 .734 .788 r
F
.10564 .66226 m .33839 .70499 L .11568 .66796 L .789 .726 .794 r
F
.25 g
.5 Mabswid
.33529 .69438 m
.34839 .69621 L
s
1 0 0 r
.003 w
.33839 .70499 m
.34839 .69621 L
s
.0935 .65175 m .35744 .68704 L .09818 .65687 L .765 .712 .802 r
F
.0935 .65175 m .36488 .67749 L .35744 .68704 L F
1 0 0 r
.34839 .69621 m
.35744 .68704 L
s
.25 g
.5 Mabswid
.34607 .68571 m
.35744 .68704 L
s
.33872 .68486 m
.34607 .68571 L
s
.12808 .674 m .32819 .71341 L .31856 .7215 L .819 .74 .778 r
F
.25 g
.32982 .68382 m
.33872 .68486 L
s
.11568 .66796 m .32819 .71341 L .12808 .674 L .803 .734 .788 r
F
1 0 0 r
.003 w
.32819 .71341 m
.33839 .70499 L
s
.25 g
.5 Mabswid
.32687 .6932 m
.33529 .69438 L
s
.3239 .70258 m
.33839 .70499 L
s
.0917 .64686 m .36488 .67749 L .0935 .65175 L .755 .705 .805 r
F
.0917 .64686 m .37016 .66762 L .36488 .67749 L F
1 0 0 r
.003 w
.35744 .68704 m
.36488 .67749 L
s
.25 g
.5 Mabswid
.11797 .66835 m
.11807 .66836 L
s
.11736 .66824 m
.11797 .66835 L
s
.11568 .66796 m
.11736 .66824 L
s
.35555 .67661 m
.36488 .67749 L
s
.34939 .67602 m
.35555 .67661 L
s
.34187 .67531 m
.34939 .67602 L
s
.33261 .67443 m
.34187 .67531 L
s
.14252 .68038 m .31856 .7215 L .31023 .72932 L .839 .746 .761 r
F
.25 g
.31893 .68256 m
.32982 .68382 L
s
.12808 .674 m .31856 .7215 L .14252 .68038 L .819 .74 .778 r
F
1 0 0 r
.003 w
.31856 .7215 m
.32819 .71341 L
s
.25 g
.5 Mabswid
.31671 .69178 m
.32687 .6932 L
s
.31457 .70103 m
.3239 .70258 L
s
.31266 .71035 m
.32819 .71341 L
s
.12808 .674 m
.12825 .67403 L
s
.12825 .67403 m
.1302 .67442 L
s
.15058 .61446 m .35184 .60634 L .13616 .61924 L .667 .635 .808 r
F
.15058 .61446 m .34395 .59675 L .35184 .60634 L F
0 g
.006 w
.15058 .61446 m
.16621 .60955 L
s
.25 g
.5 Mabswid
.15058 .61446 m
.15101 .61442 L
s
.15101 .61442 m
.15162 .61437 L
s
.15162 .61437 m
.15181 .61435 L
s
.33611 .59747 m
.34395 .59675 L
s
.32592 .5984 m
.33611 .59747 L
s
.18344 .60437 m
.29239 .58537 L
s
.20044 .59917 m
.26191 .58508 L
s
.09278 .64215 m .37016 .66762 L .0917 .64686 L .744 .698 .807 r
F
.09278 .64215 m .37292 .65748 L .37016 .66762 L F
.25 g
.10741 .66251 m
.10817 .66262 L
s
.10564 .66226 m
.10741 .66251 L
s
.10817 .66262 m
.10823 .66262 L
s
1 0 0 r
.003 w
.36488 .67749 m
.37016 .66762 L
s
.25 g
.5 Mabswid
.36316 .6671 m
.37016 .66762 L
s
.35827 .66673 m
.36316 .6671 L
s
.35221 .66628 m
.35827 .66673 L
s
.15869 .6871 m .31023 .72932 L .30387 .73695 L .864 .749 .733 r
F
.14252 .68038 m .31023 .72932 L .15869 .6871 L .839 .746 .761 r
F
1 0 0 r
.003 w
.31023 .72932 m
.31856 .7215 L
s
.25 g
.5 Mabswid
.30432 .69005 m
.31671 .69178 L
s
.14388 .6807 m
.14435 .68081 L
s
.14252 .68038 m
.14388 .6807 L
s
1 0 0 r
.003 w
.3643 .52858 m
.3832 .52296 L
s
.17626 .69415 m .30387 .73695 L .30006 .74445 L .897 .742 .682 r
F
.15869 .6871 m .30387 .73695 L .17626 .69415 L .864 .749 .733 r
F
.25 g
.5 Mabswid
.3033 .69916 m
.31457 .70103 L
s
.30258 .70837 m
.31266 .71035 L
s
.30231 .7177 m
.31856 .7215 L
s
1 0 0 r
.003 w
.30387 .73695 m
.31023 .72932 L
s
.25 g
.5 Mabswid
.15986 .68743 m
.16022 .68753 L
s
.15895 .68717 m
.15986 .68743 L
s
.15869 .6871 m
.15895 .68717 L
s
.10823 .66262 m
.30432 .69005 L
s
.09667 .63755 m .37292 .65748 L .09278 .64215 L .734 .69 .809 r
F
.25 g
.0917 .64686 m
.09453 .64707 L
s
.0935 .65175 m
.0963 .65202 L
s
.0963 .65202 m
.09632 .65202 L
s
.09667 .63755 m .37304 .64716 L .37292 .65748 L .734 .69 .809 r
F
.25 g
.1 .65708 m
.10089 .65718 L
s
.09818 .65687 m
.1 .65708 L
s
.10089 .65718 m
.10092 .65719 L
s
.09632 .65202 m
.33261 .67443 L
s
1 0 0 r
.003 w
.37016 .66762 m
.37292 .65748 L
s
.25 g
.5 Mabswid
.10092 .65719 m
.31893 .68256 L
s
.36847 .65723 m
.37292 .65748 L
s
.3649 .65704 m
.36847 .65723 L
s
.36031 .65679 m
.3649 .65704 L
s
.45153 .80264 m .53117 .8367 L .57124 .84334 L .221 .687 .944 r
F
.44828 .80153 m .45027 .80238 L .45153 .80264 L F
.45027 .80238 m .53117 .8367 L .45153 .80264 L F
.44721 .80129 m .53117 .8367 L .44828 .80153 L F
.44479 .80043 m .53117 .8367 L .44568 .80065 L F
.44295 .79978 m .53117 .8367 L .44369 .79997 L F
.44069 .79895 m .44127 .79919 L .44223 .79948 L F
.44127 .79919 m .53117 .8367 L .44223 .79948 L F
.44069 .79895 m .44223 .79948 L .46048 .8066 L F
.45153 .80264 m .57124 .84334 L .46653 .8086 L F
.45153 .80264 m .46653 .8086 L .46048 .8066 L F
.47399 .81039 m .57124 .84334 L .61258 .84936 L .192 .678 .927 r
F
.46048 .8066 m .46945 .80957 L .47399 .81039 L F
.46945 .80957 m .57124 .84334 L .47399 .81039 L F
.48365 .81492 m .48447 .81526 L .48283 .81483 L F
.48365 .81492 m .48283 .81483 L .47969 .814 L F
.47004 .80928 m .48365 .81492 L .47969 .814 L F
.47004 .80928 m .59659 .84487 L .48447 .81526 L F
.59659 .84487 m .60521 .8474 L .48742 .81606 L F
.48731 .81601 m .48742 .81606 L .47969 .814 L F
.59659 .84487 m .48742 .81606 L .48731 .81601 L F
.59659 .84487 m .61258 .84936 L .60521 .8474 L F
.49605 .81781 m .61258 .84936 L .65428 .85466 L .16 .665 .905 r
F
.47969 .814 m .49105 .81702 L .49605 .81781 L F
.49105 .81702 m .61258 .84936 L .49605 .81781 L F
.60919 .84416 m .62994 .84899 L .59709 .84205 L F
.60919 .84416 m .59709 .84205 L .49811 .82114 L F
.48228 .8146 m .60919 .84416 L .49811 .82114 L F
.62994 .84899 m .63909 .8514 L .49811 .82114 L F
.62994 .84899 m .65428 .85466 L .63909 .8514 L F
.49811 .82114 m .65428 .85466 L .69532 .85915 L .126 .65 .88 r
F
.5013 .82176 m .6633 .85298 L .51549 .82801 L F
.6633 .85298 m .69532 .85915 L .6726 .85522 L F
.6633 .85298 m .6726 .85522 L .51549 .82801 L F
.53147 .83055 m .69532 .85915 L .73454 .8628 L .094 .633 .852 r
F
.52996 .83036 m .69532 .85915 L .53147 .83055 L F
.52275 .82927 m .69532 .85915 L .52646 .82975 L F
.69642 .85674 m .69643 .85675 L .69641 .85674 L F
.69643 .85675 m .73454 .8628 L .7055 .85876 L F
.69643 .85675 m .7055 .85876 L .53156 .8346 L F
.69642 .85674 m .69641 .85674 L .53156 .8346 L F
.52646 .82975 m .52996 .83036 L .53147 .83055 L F
.51549 .82801 m .52275 .82927 L .52646 .82975 L F
.51928 .82861 m .69642 .85674 L .53156 .8346 L F
.53156 .8346 m .73454 .8628 L .77074 .86558 L .064 .617 .824 r
F
.72914 .86019 m .73757 .86194 L .546 .84091 L F
.53156 .8346 m .53203 .83466 L .54652 .84097 L F
.53203 .83466 m .72914 .86019 L .54838 .84116 L F
.53203 .83466 m .54838 .84116 L .54652 .84097 L F
.53901 .83785 m .54652 .84097 L .546 .84091 L F
.53156 .8346 m .54652 .84097 L .53901 .83785 L F
.72914 .86019 m .77074 .86558 L .73757 .86194 L F
.55957 .84232 m .77074 .86558 L .80268 .86751 L .04 .602 .796 r
F
.546 .84091 m .55555 .84196 L .55957 .84232 L F
.55555 .84196 m .77074 .86558 L .55957 .84232 L F
.55546 .84475 m .77153 .86429 L .56125 .84719 L F
.54648 .84096 m .55086 .84141 L .55546 .84475 L F
.55086 .84141 m .77153 .86429 L .55546 .84475 L F
.77153 .86429 m .77779 .86542 L .55852 .84697 L F
.77153 .86429 m .80268 .86751 L .77779 .86542 L F
.56788 .84772 m .80268 .86751 L .8292 .86869 L .022 .591 .772 r
F
.55852 .84697 m .56449 .84747 L .56788 .84772 L F
.56449 .84747 m .80268 .86751 L .56788 .84772 L F
.56379 .84739 m .80913 .86708 L .56884 .85279 L F
.80913 .86708 m .8292 .86869 L .81313 .86771 L F
.80913 .86708 m .81313 .86771 L .56884 .85279 L F
.57438 .85312 m .8292 .86869 L .84928 .86921 L .011 .584 .752 r
F
.56884 .85279 m .57153 .85296 L .57438 .85312 L F
.57153 .85296 m .8292 .86869 L .57438 .85312 L F
.56884 .85279 m .57438 .85312 L .57669 .85843 L F
.57438 .85312 m .84203 .86879 L .57669 .85843 L F
.84203 .86879 m .84928 .86921 L .84368 .86899 L F
.84203 .86879 m .84368 .86899 L .57669 .85843 L F
.57669 .85843 m .84928 .86921 L .86207 .86925 L .008 .583 .739 r
F
.57669 .85843 m .86008 .86917 L .58187 .86392 L F
.86008 .86917 m .86046 .86919 L .86027 .86918 L F
.86008 .86917 m .86027 .86918 L .58187 .86392 L F
.86046 .86919 m .86156 .86923 L .86084 .86921 L F
.86046 .86919 m .86084 .86921 L .58187 .86392 L F
.55852 .84697 m .56379 .84739 L .56884 .85279 L .022 .591 .772 r
F
.86156 .86923 m .86207 .86925 L .8617 .86924 L .008 .583 .739 r
F
.86156 .86923 m .8617 .86924 L .58187 .86392 L F
.546 .84091 m .54648 .84096 L .55852 .84697 L .04 .602 .796 r
F
.54648 .84096 m .56125 .84719 L .55852 .84697 L F
.47969 .814 m .48228 .8146 L .49811 .82114 L .16 .665 .905 r
F
.49811 .82114 m .5013 .82176 L .51549 .82801 L .126 .65 .88 r
F
.51549 .82801 m .51928 .82861 L .53156 .8346 L .094 .633 .852 r
F
.44568 .80065 m .44721 .80129 L .44828 .80153 L .221 .687 .944 r
F
.44369 .79997 m .44479 .80043 L .44568 .80065 L F
.44223 .79948 m .44295 .79978 L .44369 .79997 L F
.44223 .79948 m .45153 .80264 L .46048 .8066 L F
.46048 .8066 m .47004 .80928 L .47969 .814 L .192 .678 .927 r
F
.42051 .7911 m .53117 .8367 L .44069 .79895 L .245 .692 .956 r
F
.42051 .7911 m .49312 .82955 L .53117 .8367 L F
1 0 0 r
.003 w
.53117 .8367 m
.53953 .83808 L
s
.17626 .69415 m .25599 .72655 L .19491 .7015 L .897 .742 .682 r
F
.25599 .72655 m .27479 .73418 L .25595 .72647 L F
.25599 .72655 m .25595 .72647 L .19491 .7015 L F
.27479 .73418 m .27242 .73318 L .19491 .7015 L F
.28906 .73998 m .28301 .73749 L .23629 .7184 L F
.23591 .71826 m .23629 .7184 L .19491 .7015 L F
.28906 .73998 m .23629 .7184 L .23591 .71826 L F
.27479 .73418 m .28906 .73998 L .27242 .73318 L F
.28906 .73998 m .30006 .74445 L .28301 .73749 L F
.19491 .7015 m .30006 .74445 L .29926 .75192 L .933 .711 .579 r
F
.19491 .7015 m .2488 .72754 L .21438 .70912 L F
.27124 .73838 m .29926 .75192 L .26934 .73683 L F
.28826 .75161 m .29926 .75192 L .30182 .7594 L .943 .605 .355 r
F
.2488 .72754 m .27124 .73838 L .25255 .72836 L .933 .711 .579 r
F
.27124 .73838 m .26934 .73683 L .25255 .72836 L F
.2488 .72754 m .25255 .72836 L .21438 .70912 L F
.21474 .70932 m .26937 .73686 L .28826 .75161 L .943 .605 .355 r
F
.26937 .73686 m .29926 .75192 L .28826 .75161 L F
.21501 .70943 m .29926 .75192 L .21474 .70932 L F
.21438 .70912 m .21501 .70943 L .21474 .70932 L F
.21438 .70912 m .30182 .7594 L .23442 .71697 L F
.23486 .71727 m .28385 .7481 L .30799 .76696 L .798 .313 0 r
F
.28385 .7481 m .30182 .7594 L .30799 .76696 L F
.23496 .71731 m .30182 .7594 L .23486 .71727 L F
.25521 .72531 m .30799 .76696 L .2552 .72531 L 0 .114 .572 r
F
.25521 .72531 m .25523 .72533 L .25521 .72531 L F
.25523 .72533 m .30799 .76696 L .25521 .72531 L F
.27581 .73351 m .31794 .77463 L .33174 .78242 L 0 .4 .819 r
F
.27571 .73342 m .2758 .7335 L .27581 .73351 L F
.2758 .7335 m .31794 .77463 L .27581 .73351 L F
.27548 .73321 m .27567 .7334 L .27571 .73342 L F
.27567 .7334 m .31794 .77463 L .27571 .73342 L F
.2552 .72531 m .30799 .76696 L .31794 .77463 L 0 .114 .572 r
F
.25483 .72502 m .25521 .72531 L .2552 .72531 L F
.23442 .71697 m .23496 .71731 L .23486 .71727 L .798 .313 0 r
F
1 0 0 r
.30006 .74445 m
.30387 .73695 L
s
.25 g
.5 Mabswid
.29354 .72467 m
.31023 .72932 L
s
.16022 .68753 m
.25199 .71309 L
s
.27866 .71218 m
.29164 .71521 L
s
.26281 .70848 m
.27866 .71218 L
s
.14435 .68081 m
.26281 .70848 L
s
.29037 .70596 m
.30258 .70837 L
s
.27551 .70304 m
.29037 .70596 L
s
.1302 .67442 m
.27551 .70304 L
s
.17724 .69448 m
.1775 .69456 L
s
.17653 .69424 m
.17724 .69448 L
s
.17626 .69415 m
.17653 .69424 L
s
.28958 .69688 m
.3033 .69916 L
s
.11807 .66836 m
.28958 .69688 L
s
1 0 0 r
.003 w
.29926 .75192 m
.30006 .74445 L
s
.40005 .78306 m .49312 .82955 L .42051 .7911 L .262 .692 .964 r
F
.40005 .78306 m .45768 .82203 L .49312 .82955 L F
.25 g
.5 Mabswid
.52331 .83342 m
.53117 .8367 L
s
1 0 0 r
.003 w
.49312 .82955 m
.53117 .8367 L
s
.10321 .63302 m .37304 .64716 L .09667 .63755 L .723 .683 .811 r
F
.25 g
.5 Mabswid
.09278 .64215 m
.09555 .6423 L
s
.10321 .63302 m .37058 .63678 L .37304 .64716 L .723 .683 .811 r
F
.25 g
.09453 .64707 m
.35221 .66628 L
s
.09555 .6423 m
.36031 .65679 L
s
1 0 0 r
.003 w
.37292 .65748 m
.37304 .64716 L
s
.25 g
.5 Mabswid
.37126 .6471 m
.37304 .64716 L
s
.36902 .64702 m
.37126 .6471 L
s
.09667 .63755 m
.36902 .64702 L
s
1 0 0 r
.003 w
.34904 .53461 m
.3643 .52858 L
s
.13616 .61924 m .3594 .61627 L .12325 .62391 L .684 .652 .812 r
F
.13616 .61924 m .35184 .60634 L .3594 .61627 L F
0 g
.006 w
.13616 .61924 m
.15058 .61446 L
s
.25 g
.5 Mabswid
.13616 .61924 m
.13749 .61916 L
s
.13749 .61916 m
.13769 .61915 L
s
.34518 .60674 m
.35184 .60634 L
s
.15181 .61435 m
.32592 .5984 L
s
.16716 .60943 m
.30196 .59201 L
s
.37942 .77488 m .45768 .82203 L .40005 .78306 L .27 .686 .968 r
F
.37942 .77488 m .42531 .81424 L .45768 .82203 L F
.25 g
.44069 .79895 m
.44127 .79919 L
s
.44127 .79919 m
.44219 .79958 L
s
.44219 .79958 m
.4435 .80012 L
s
.4435 .80012 m
.44527 .80086 L
s
.44527 .80086 m
.51323 .82921 L
s
.51323 .82921 m
.52331 .83342 L
s
.48489 .8252 m
.49312 .82955 L
s
1 0 0 r
.003 w
.45768 .82203 m
.49312 .82955 L
s
.29926 .75192 m
.30028 .7549 L
s
.30156 .75866 m
.30182 .7594 L
s
.35869 .7666 m .42531 .81424 L .37942 .77488 L .265 .673 .968 r
F
.35869 .7666 m .39634 .8063 L .42531 .81424 L F
.25 g
.5 Mabswid
.42051 .7911 m
.4209 .79131 L
s
.4209 .79131 m
.42156 .79166 L
s
.42156 .79166 m
.42253 .79217 L
s
.42253 .79217 m
.47379 .81931 L
s
.47379 .81931 m
.48489 .8252 L
s
.40005 .78306 m
.40077 .78355 L
s
.40077 .78355 m
.44867 .81593 L
s
.44867 .81593 m
.45768 .82203 L
s
1 0 0 r
.003 w
.42531 .81424 m
.45768 .82203 L
s
.30182 .7594 m
.30765 .76654 L
s
.11216 .62848 m .37058 .63678 L .10321 .63302 L .711 .674 .812 r
F
.11216 .62848 m .36586 .62645 L .37058 .63678 L F
1 0 0 r
.37058 .63678 m
.37304 .64716 L
s
.25 g
.5 Mabswid
.10321 .63302 m
.37058 .63678 L
s
.33789 .75825 m .39634 .8063 L .35869 .7666 L .243 .65 .962 r
F
.33789 .75825 m .371 .7983 L .39634 .8063 L F
.25 g
.3799 .77529 m
.4142 .80471 L
s
.4142 .80471 m
.42531 .81424 L
s
.37942 .77488 m
.3799 .77529 L
s
1 0 0 r
.003 w
.39634 .8063 m
.42531 .81424 L
s
.23442 .71697 m .30799 .76696 L .25483 .72502 L .798 .313 0 r
F
.25 g
.5 Mabswid
.29164 .71521 m
.30231 .7177 L
s
.25199 .71309 m
.26878 .71777 L
s
.26878 .71777 m
.28242 .72157 L
s
.28242 .72157 m
.29354 .72467 L
s
.1775 .69456 m
.26116 .72262 L
s
.31707 .74987 m .371 .7983 L .33789 .75825 L .194 .611 .946 r
F
.31707 .74987 m .34944 .79032 L .371 .7983 L F
.25 g
.35879 .7667 m
.37726 .78618 L
s
.37726 .78618 m
.39634 .8063 L
s
.35869 .7666 m
.35879 .7667 L
s
1 0 0 r
.003 w
.371 .7983 m
.39634 .8063 L
s
.33748 .54102 m
.34904 .53461 L
s
.25483 .72502 m .31794 .77463 L .27548 .73321 L 0 .114 .572 r
F
1 0 0 r
.30799 .76696 m
.31794 .77463 L
s
.25 g
.5 Mabswid
.27546 .72742 m
.28696 .73127 L
s
.26116 .72262 m
.27546 .72742 L
s
.25483 .72502 m
.25505 .72519 L
s
.25521 .72531 m
.25523 .72533 L
s
.25514 .72526 m
.25521 .72531 L
s
.25505 .72519 m
.25514 .72526 L
s
.29624 .74151 m .34944 .79032 L .31707 .74987 L .098 .54 .91 r
F
.29624 .74151 m .33174 .78242 L .34944 .79032 L F
.25 g
.33794 .75831 m
.371 .7983 L
s
.33789 .75825 m
.33794 .75831 L
s
1 0 0 r
.003 w
.34944 .79032 m
.371 .7983 L
s
.33435 .78359 m
.34944 .79032 L
s
.27548 .73321 m .33174 .78242 L .29624 .74151 L 0 .4 .819 r
F
.25 g
.5 Mabswid
.29624 .74151 m
.29628 .74155 L
s
.29628 .74155 m
.2964 .74169 L
s
.2964 .74169 m
.29643 .74173 L
s
.29643 .74173 m
.29647 .74176 L
s
.29647 .74176 m
.29649 .74179 L
s
.29649 .74179 m
.33174 .78242 L
s
1 0 0 r
.003 w
.33174 .78242 m
.33435 .78359 L
s
.25 g
.5 Mabswid
.31707 .74987 m
.31708 .74989 L
s
.31721 .75005 m
.31727 .75013 L
s
.31708 .74989 m
.31721 .75005 L
s
.31727 .75013 m
.34944 .79032 L
s
1 0 0 r
.003 w
.31794 .77463 m
.33174 .78242 L
s
.25 g
.5 Mabswid
.28783 .75106 m
.30799 .76696 L
s
.29085 .74821 m
.31794 .77463 L
s
.27577 .7335 m
.29085 .74821 L
s
.25523 .72533 m
.28783 .75106 L
s
.28696 .73127 m
.30387 .73695 L
s
.27576 .73349 m
.27577 .7335 L
s
.27569 .73342 m
.27576 .73349 L
s
.27567 .7334 m
.27569 .73342 L
s
.27548 .73321 m
.27567 .7334 L
s
.12325 .62391 m .36586 .62645 L .11216 .62848 L .698 .664 .813 r
F
.12325 .62391 m .3594 .61627 L .36586 .62645 L F
0 g
.006 w
.12325 .62391 m
.13616 .61924 L
s
1 0 0 r
.003 w
.36586 .62645 m
.37058 .63678 L
s
.25 g
.5 Mabswid
.11216 .62848 m
.36586 .62645 L
s
.13769 .61915 m
.34518 .60674 L
s
1 0 0 r
.003 w
.3594 .61627 m
.36586 .62645 L
s
.25 g
.5 Mabswid
.12325 .62391 m
.12509 .62385 L
s
.12509 .62385 m
.3594 .61627 L
s
0 g
.006 w
.11216 .62848 m
.12325 .62391 L
s
1 0 0 r
.003 w
.32957 .54779 m
.33748 .54102 L
s
.35184 .60634 m
.3594 .61627 L
s
.32518 .55494 m
.32957 .54779 L
s
.34395 .59675 m
.35184 .60634 L
s
.32409 .56247 m
.32518 .55494 L
s
.33651 .58754 m
.34395 .59675 L
s
0 g
.006 w
.10321 .63302 m
.11216 .62848 L
s
1 0 0 r
.003 w
.32409 .56247 m
.32594 .5704 L
s
.33028 .57876 m
.33651 .58754 L
s
.32594 .5704 m
.33028 .57876 L
s
0 g
.006 w
.09667 .63755 m
.10321 .63302 L
s
1 0 0 r
.003 w
.82663 .86857 m
.8292 .86869 L
s
0 g
.006 w
.09278 .64215 m
.09667 .63755 L
s
.0917 .64686 m
.09278 .64215 L
s
.25 g
.5 Mabswid
.82766 .86859 m
.8292 .86869 L
s
1 0 0 r
.003 w
.8292 .86869 m
.84928 .86921 L
s
0 g
.006 w
.0917 .64686 m
.0935 .65175 L
s
.0935 .65175 m
.09818 .65687 L
s
.25 g
.5 Mabswid
.83913 .86881 m
.84225 .86893 L
s
.84225 .86893 m
.84928 .86921 L
s
0 g
.006 w
.09818 .65687 m
.10564 .66226 L
s
.10564 .66226 m
.11568 .66796 L
s
.11568 .66796 m
.12808 .674 L
s
.12808 .674 m
.14252 .68038 L
s
.58187 .86392 m .86207 .86925 L .86701 .86898 L .014 .588 .732 r
F
.25 g
.5 Mabswid
.8617 .86924 m
.86207 .86925 L
s
.86102 .86923 m
.8617 .86924 L
s
1 0 0 r
.003 w
.84928 .86921 m
.86207 .86925 L
s
0 g
.006 w
.14252 .68038 m
.15869 .6871 L
s
.15869 .6871 m
.17626 .69415 L
s
.17626 .69415 m
.19491 .7015 L
s
.40005 .78306 m
.42051 .7911 L
s
.37942 .77488 m
.40005 .78306 L
s
.42051 .7911 m
.44069 .79895 L
s
.35869 .7666 m
.37942 .77488 L
s
.33789 .75825 m
.35869 .7666 L
s
.44069 .79895 m
.46048 .8066 L
s
.19491 .7015 m
.21438 .70912 L
s
.31707 .74987 m
.33789 .75825 L
s
.46048 .8066 m
.47969 .814 L
s
.29624 .74151 m
.31707 .74987 L
s
.21438 .70912 m
.23442 .71697 L
s
.27548 .73321 m
.29624 .74151 L
s
.25483 .72502 m
.27548 .73321 L
s
.23442 .71697 m
.25483 .72502 L
s
.47969 .814 m
.49811 .82114 L
s
.49811 .82114 m
.51549 .82801 L
s
.51549 .82801 m
.53156 .8346 L
s
.58187 .86392 m .86701 .86898 L .58423 .86933 L .014 .588 .732 r
F
.58423 .86933 m .86701 .86898 L .86389 .86863 L .027 .599 .731 r
F
1 0 0 r
.003 w
.86207 .86925 m
.86701 .86898 L
s
.25 g
.5 Mabswid
.84922 .869 m
.86102 .86923 L
s
0 g
.006 w
.53156 .8346 m
.546 .84091 L
s
.546 .84091 m
.55852 .84697 L
s
.55852 .84697 m
.56884 .85279 L
s
.56884 .85279 m
.57669 .85843 L
s
.58423 .86933 m .86389 .86863 L .58372 .87472 L .027 .599 .731 r
F
.58372 .87472 m .86389 .86863 L .85281 .8684 L .048 .616 .738 r
F
1 0 0 r
.003 w
.86389 .86863 m
.86701 .86898 L
s
.25 g
.5 Mabswid
.8464 .86901 m
.86701 .86898 L
s
0 g
.006 w
.57669 .85843 m
.58187 .86392 L
s
.58187 .86392 m
.58423 .86933 L
s
.58372 .87472 m .85281 .8684 L .58033 .88013 L .048 .616 .738 r
F
.58033 .88013 m .85281 .8684 L .83427 .86853 L .076 .637 .749 r
F
0 g
.58372 .87472 m
.58423 .86933 L
s
1 0 0 r
.003 w
.85281 .8684 m
.86389 .86863 L
s
.25 g
.5 Mabswid
.86233 .86866 m
.86389 .86863 L
s
.83109 .86934 m
.86233 .86866 L
s
.58033 .88013 m .83427 .86853 L .57417 .88565 L .076 .637 .749 r
F
0 g
.006 w
.58033 .88013 m
.58372 .87472 L
s
.25 g
.5 Mabswid
.80465 .87048 m
.85281 .8684 L
s
.57417 .88565 m .83427 .86853 L .80909 .86919 L .108 .662 .765 r
F
1 0 0 r
.003 w
.83427 .86853 m
.85281 .8684 L
s
.57417 .88565 m .80909 .86919 L .56539 .89131 L .108 .662 .765 r
F
0 g
.006 w
.57417 .88565 m
.58033 .88013 L
s
.25 g
.5 Mabswid
.76918 .87281 m
.83427 .86853 L
s
.56539 .89131 m .80909 .86919 L .77835 .87055 L .146 .69 .784 r
F
.56539 .89131 m .77835 .87055 L .55421 .89717 L F
.25 g
.7272 .87662 m
.80909 .86919 L
s
0 g
.006 w
.56539 .89131 m
.57417 .88565 L
s
1 0 0 r
.003 w
.80909 .86919 m
.83427 .86853 L
s
0 g
.006 w
.55421 .89717 m
.56539 .89131 L
s
.25 g
.5 Mabswid
.55421 .89717 m
.77835 .87055 L
s
1 0 0 r
.003 w
.77835 .87055 m
.80909 .86919 L
s
0 g
.25 Mabswid
.16533 0 m
.95682 .11407 L
s
.95682 .11407 m
1 .91909 L
s
1 .91909 m
.1381 .88379 L
s
.1381 .88379 m
.16533 0 L
s
.02976 .29805 m
0 .97475 L
s
0 .97475 m
.1381 .88379 L
s
.1381 .88379 m
.16533 0 L
s
.16533 0 m
.02976 .29805 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 286.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00017Q000`40O003h00O;goo1000kGoo000_
Ool01000Oomoogoo1`00iWoo000^Ool2000:Ool7003OOol002ioo`80015oo`L00=Qoo`00;Goo00<0
07oo000067oo1P00dWoo000]Ool00`00Ool0000NOol7003;Ool002aoo`04001oogoo000UOol70034
Ool002aoo`04001oogoo000/Ool7002mOol002]oo`05001oogooOol0000cOol7002fOol002]oo`05
001oogooOol0000jOol7002_Ool002Yoo`03001oogoo009oo`03001oogoo03moo`L00:Qoo`00:Woo
00<007ooOol00Woo00<007ooOol0AWoo1`00XGoo000ZOol00`00Oomoo`02Ool00`00Oomoo`1=Ool6
002KOol002Uoo`03001oogoo00=oo`03001oogoo05=oo`L009Aoo`00:Goo00<007ooOol00goo00<0
07ooOol0FWoo1`00SGoo000XOol00`00Oomoo`04Ool00`00Oomoo`1QOol70026Ool002Qoo`03001o
ogoo00=oo`03001oogoo06Uoo`L007moo`009goo00<007ooOol017oo00<007ooOol0L7oo1`00N7oo
000WOol00`00Oomoo`04Ool00`00Oomoo`1gOol7001aOol002Ioo`03001oogoo00Eoo`03001oogoo
07ioo`L006Yoo`009Woo00<007ooOol01Goo00<007ooOol0QGoo1`00Hgoo000UOol00`00Oomoo`06
Ool00`00Oomoo`2<Ool6001MOol002Eoo`03001oogoo00Ioo`03001oogoo099oo`L005Ioo`009Goo
00<007ooOol01Woo00<007ooOol0VGoo1`00Cgoo000TOol00`00Oomoo`07Ool00`00Oomoo`2POol7
0018Ool002Aoo`03001oogoo00Moo`03001oogoo0:Moo`L0045oo`008goo00<007ooOol027oo00<0
07ooOol0[Woo1`00>Woo000SOol00`00Oomoo`08Ool00`00Oomoo`2eOol7000cOol0029oo`03001o
ogoo00Uoo`03001oogoo0;aoo`L002aoo`008Woo00<007ooOol02Goo00<007ooOol0`goo1P009Woo
000QOol00`00Oomoo`0:Ool00`00Oomoo`39Ool7000OOol0025oo`03001oogoo00Yoo`03001oogoo
0=1oo`L001Qoo`0087oo00<007ooOol02goo00<007ooOol0egoo1`004Goo000POol00`00Oomoo`0;
Ool00`00Oomoo`3NOol4000=Ool0021oo`03001oogoo00]oo`03001oogoo0>1oo`8000eoo`007goo
00<007ooOol037oo00<007ooOol0gWoo0P0000=oo`00Ool037oo000OOol00`00Oomoo`0<Ool00`00
Oomoo`3MOol01@00Oomoogoo00003Goo000NOol00`00Oomoo`0=Ool00`00Oomoo`3LOol00`00Oomo
o`02Ool00`00Oomoo`0;Ool001ioo`03001oogoo00eoo`03001oogoo0=]oo`03001oogoo00=oo`03
001oogoo00]oo`007Goo00<007ooOol03Woo00<007ooOol0fWoo00<007ooOol017oo00<007ooOol0
2goo000MOol00`00Oomoo`0>Ool00`00Oomoo`3HOol20007Ool00`00Oomoo`0;Ool001aoo`03001o
ogoo00moo`03001oogoo0=Moo`03001oogoo00Moo`03001oogoo00]oo`0077oo00<007ooOol03goo
00<007ooOol0eWoo00<007ooOol027oo00<007ooOol02goo000KOol00`00Oomoo`0@Ool00`00Oomo
o`3EOol00`00Oomoo`0:Ool00`00Oomoo`0:Ool001]oo`03001oogoo011oo`03001oogoo0=Aoo`03
001oogoo00]oo`03001oogoo00Yoo`006goo00<007ooOol047oo00<007ooOol0dWoo0P003Woo00<0
07ooOol02Woo000JOol00`00Oomoo`0AOol00`00Oomoo`3AOol00`00Oomoo`0>Ool00`00Oomoo`0:
Ool001Yoo`03001oogoo015oo`03001oogoo0=1oo`03001oogoo00moo`03001oogoo00Yoo`006Goo
00<007ooOol04Goo00<007ooOol0d7oo00<007ooOol047oo00<007ooOol02Woo000IOol00`00Oomo
o`0AOol00`00Oomoo`3?Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool001Qoo`03001oogoo019oo`03
001oogoo0<eoo`8001Aoo`03001oogoo00Yoo`0067oo00<007ooOol04Woo00<007ooOol0c7oo00<0
07ooOol057oo00<007ooOol02Woo000GOol00`00Oomoo`0COol00`00Oomoo`3;Ool00`00Oomoo`0E
Ool00`00Oomoo`0:Ool001Moo`03001oogoo01=oo`03001oogoo0<Yoo`03001oogoo01Ioo`03001o
ogoo00Yoo`005goo00<007ooOol04goo00<007ooOol0bGoo00<007ooOol05goo00<007ooOol02Woo
000FOol00`00Oomoo`0DOol00`00Oomoo`37Ool2000JOol00`00Oomoo`0:Ool001Ioo`03001oogoo
01Aoo`03001oogoo0<Ioo`03001oogoo01Yoo`03001oogoo00Yoo`005Goo00<007ooOol05Goo00<0
07ooOol0aGoo00<007ooOol06goo00<007ooOol02Woo000EOol00`00Oomoo`0EOol00`00Oomoo`34
Ool00`00Oomoo`0LOol00`00Oomoo`0:Ool001Aoo`03001oogoo01Ioo`03001oogoo0<9oo`8001mo
o`03001oogoo00Yoo`0057oo00<007ooOol05Woo00<007ooOol0`Goo00<007ooOol07goo00<007oo
Ool02Woo000COol00`00Oomoo`0GOol00`00Oomoo`30Ool00`00Oomoo`0POol00`00Oomoo`0:Ool0
01=oo`03001oogoo01Moo`03001oogoo0;moo`03001oogoo029oo`03001oogoo00Uoo`004Woo00<0
07ooOol067oo00<007ooOol0_Woo00<007ooOol08goo00<007ooOol02Goo000BOol00`00Oomoo`0H
Ool00`00Oomoo`2lOol2000VOol00`00Oomoo`09Ool0019oo`03001oogoo01Qoo`03001oogoo0;]o
o`03001oogoo02Ioo`03001oogoo00Uoo`004Goo00<007ooOol06Goo00<007ooOol0^Woo00<007oo
Ool09goo00<007ooOol02Goo000AOol00`00Oomoo`0IOol00`00Oomoo`2iOol00`00Oomoo`0XOol0
0`00Oomoo`09Ool0011oo`03001oogoo01Yoo`03001oogoo0;Qoo`03001oogoo02Uoo`03001oogoo
00Uoo`0047oo00<007ooOol06Woo00<007ooOol0]Woo0P00;7oo00<007ooOol02Goo000?Ool00`00
Oomoo`0KOol00`00Oomoo`2eOol00`00Oomoo`0/Ool00`00Oomoo`09Ool000moo`03001oogoo01]o
o`03001oogoo0;Aoo`03001oogoo02eoo`03001oogoo00Uoo`003Woo00<007ooOol077oo00<007oo
Ool0/goo00<007ooOol0;Woo00<007ooOol02Goo000>Ool00`00Oomoo`0LOol00`00Oomoo`2bOol0
0`00Oomoo`0_Ool00`00Oomoo`09Ool000eoo`03001oogoo01eoo`03001oogoo0;1oo`80039oo`03
001oogoo00Uoo`003Goo00<007ooOol07Goo00<007ooOol0[goo00<007ooOol0<Woo00<007ooOol0
2Goo000=Ool00`00Oomoo`0MOol00`00Oomoo`2^Ool00`00Oomoo`0cOol00`00Oomoo`09Ool000ao
o`03001oogoo01ioo`03001oogoo0:eoo`03001oogoo03Aoo`03001oogoo00Uoo`0037oo00<007oo
Ool07Woo00<007ooOol0[7oo00<007ooOol0=Goo00<007ooOol02Goo000;Ool00`00Oomoo`0OOol0
0`00Oomoo`2ZOol2000hOol00`00Oomoo`09Ool000]oo`03001oogoo01ioo`03001oogoo0:Yoo`03
001oogoo03Qoo`03001oogoo00Uoo`002Woo00<007ooOol07goo00<007ooOol0ZGoo00<007ooOol0
>Goo00<007ooOol02Goo000:Ool00`00Oomoo`0OOol00`00Oomoo`2XOol00`00Oomoo`0kOol00`00
Oomoo`08Ool000Uoo`03001oogoo021oo`03001oogoo0:Ioo`8003ioo`03001oogoo00Qoo`002Goo
00<007ooOol087oo00<007ooOol0YGoo00<007ooOol0?Woo00<007ooOol027oo0008Ool00`00Oomo
o`0QOol00`00Oomoo`2TOol00`00Oomoo`0oOol00`00Oomoo`08Ool000Qoo`D000Yoo`03000LiacW
008Lia1oo`03001oogoo0:=oo`03001oogoo041oo`03001oogoo00Qoo`0027oo00<007ooOol00Woo
2`000acW00=J^AcW7>L01QcW27oo00<007ooOol0XWoo00<007ooOol0@Goo00<007ooOol027oo0008
Ool00`00Oomoo`0<Ool20002G]T77>L00eZiG]TLi`077>L00`00Oomoo`2POol20014Ool00`00Oomo
o`08Ool000Qoo`03001oogoo00ioo`09000LiacW7>MN^5kIF[QNfEjh00LLi`04F[UNfEZh00087>NI
Ool00`00Oomoo`14Ool00`00Oomoo`08Ool000Qoo`03001oogoo00moo`03000LiacW00LLi`ENf@<L
i`09000LiacW7>MJ^EkIG[UNfEZi00TLihmoo`03001oogoo04Eoo`03001oogoo00Qoo`0027oo00<0
07ooOol047oo0P001QcW00=Nf1cW7>L01AcW00EN^000F[QNfEjh00LLi`07F[UNfEZhG]UJ^EkIF[P0
2AcWQGoo00<007ooOol0AWoo00<007ooOol027oo0008Ool00`00Oomoo`0BOol2000:7>L2G]T00acW
000Li`047>L5G]T77>L02EZiG]UN^EkIF[UNfEjiG]UJ^@087>MlOol00`00Oomoo`17Ool00`00Oomo
o`08Ool000Qoo`03001oogoo01Aoo`8000037>MRfEkH00PLi`06000Lif;IG]QRfEkH21cW00ANfEZh
G]UN^0LLi`0:F[UNfEZhG]UJ^EkIF[QNfEZiG]T=7>M]Ool2001:Ool00`00Oomoo`08Ool000Qoo`03
001oogoo01Ioo`8000<Li`03H]QRfEkH00<Li`03000LiacW00DLi`INf@LLi`ANf@LLi`0@F[UNfEji
G]UJ^EkIG[UNfEZiG]UN^EkIF[UNfEjiO01/Ool00`00Oomoo`1:Ool00`00Oomoo`08Ool000Qoo`03
001oogoo01Qoo`8000DLi`04H]URf000G]P47>L00f;IG]PLi`047>L025kHH]UNf6;IG]QRfEkHH]T7
7>L015kIF[QNfEjh2acW00AJ^EkIF[Ql00L006Eoo`03001oogoo04]oo`03001oogoo00Qoo`0027oo
00<007ooOol06Woo0P001AcW00H001cWH]QRfF;HH]T57>L00f;IG]TLi`057>L9G]T57>L:G]T37>L0
0g`0Oomoo`05Ool9001KOol00`00Oomoo`1<Ool00`00Oomoo`08Ool000Qoo`03001oogoo01aoo`80
008Li`03H]P001cW00@Li`05H]UNf6;IH]QRf@057>L00f;IG]QRf@067>L025kHH]UNf6;IG]QRfEkH
H]T57>L025kIF[QNfEjhG]UJ^5kIO00AOol:001@Ool00`00Oomoo`1=Ool00`00Oomoo`08Ool000Qo
o`03001oogoo01ioo`@000037>MRf1cW00HLi`06H]QRfF;HH]UNfF;I1AcW00ARfEkIH]UNf0@Li`UN
f@HLi`03O01oogoo01Yoo`T004Eoo`80051oo`03001oogoo00Qoo`001goo00<007ooOol08Woo0P00
0acW00=ReacW7>L01QcW00MRfF;HH]UNf6;IG]QRf@047>L015kHH]UNf6;I1acW00QRfEkHH]UNf6;I
G]QRfG`09Woo2P00>Woo00<007ooOol0D7oo00<007ooOol027oo0007Ool00`00Oomoo`0ROol01000
Ool0000011cW0VKh0acW00=Vn1cW7>L00QcW00MRf6;IH]QRfF;HH]UNf@047>L01f;IG]QRfEkIH]UN
f6;I00HLi`03O01oogoo02moo`T0031oo`03001oogoo055oo`03001oogoo00Qoo`001goo00<007oo
Ool08Woo00@007ooOomoo`8000DLi`03H]MVn1cW008Li`03I_URf1cW00<Li`07H]UNf6;IH]QRfEkH
H]T01QcW00MNf6;IG]QRfEkHH]Ul000kOol:000UOol00`00Oomoo`1COol00`00Oomoo`07Ool000Mo
o`03001oogoo029oo`03001oogoo00=oo`<000DLi`9Vn0@Li`03H]QRn1cW00HLi`06H]URf6;IH]QR
fEkI0acW00=NfF;IO000AWoo2@006goo00<007ooOol0E7oo00<007ooOol01goo0007Ool00`00Oomo
o`0ROol00`00Oomoo`05Ool017J_000006Kg1AcW00=RefKhH]P00acW00IRf6KiH]QVnF;HH]T37>L0
26;IG]QRfF;HH]UNf1cWO01@Ool9000@Ool2001GOol00`00Oomoo`07Ool000Moo`03001oogoo029o
o`03001oogoo00Moo`05MXh00000001Vm`057>L3I_P47>L01F;hH]QVn6;HH]T00acW00ARfF;HH]Ul
05Yoo`X000Eoo`03001oogoo05Moo`03001oogoo00Moo`001goo00<007ooOol08Woo00<007ooOol0
27oo00=fSWZ_KJ400P0000AZn1cW7>MVm`@Li`03I_QVf6Ki00@Li`04H]QVnF;HI_T37>MUOol5001J
Ool00`00Oomoo`07Ool000Moo`03001oogoo029oo`03001oogoo00Yoo`03MZmfSVfR00<000<Li`9Z
m`<Li`9Vn006H_QRf1cW7>MRn6;H0W`0JWoo00<007ooOol0F7oo00<007ooOol01goo0007Ool00`00
Oomoo`0ROol00`00Oomoo`0<Ool017J>KJ9YXC`00P0000IVmacW7>LLifKgJ_P37>L00fKhI]QVn002
7>M/Ool00`00Oomoo`1HOol00`00Oomoo`07Ool000Moo`03001oogoo029oo`03001oogoo00eoo`03
MXif[ffQ008h00<00003J_LLifKg00=Zm`<Li`03O01oogoo06]oo`03001oogoo05Qoo`03001oogoo
00Moo`001goo00<007ooOol08Woo00<007ooOol03goo00=f[fVQKJ800SP000<Li`0000000QcW00AZ
n6KgJ_Ql06moo`03001oogoo05Qoo`03001oogoo00Moo`001goo00<007ooOol08Woo00<007ooOol0
47oo00=f[gJ>KJ800SP000<Li`6J00000P000QcWL7oo00<007ooOol0F7oo00<007ooOol01goo0007
Ool00`00Oomoo`0ROol00`00Oomoo`0BOol027J>KJ8h03P07>L1VP6I7>L2001`Ool00`00Oomoo`1H
Ool00`00Oomoo`07Ool000Moo`03001oogoo025oo`03001oogoo01Eoo`04KJ8h03P07>L20IX00acW
4S`00002001]Ool00`00Oomoo`1HOol00`00Oomoo`07Ool000Moo`03001oogoo025oo`03001oogoo
01Ioo`0:NZm]XCP07>L1VQcW4Sd>?18m7>L2001[Ool00`00Oomoo`1HOol00`00Oomoo`07Ool000Mo
o`03001oogoo025oo`03001oogoo01Qoo`08KJ4h01cW0IXLia8m4S`Li`8NOP8006Uoo`03001oogoo
05Qoo`03001oogoo00Moo`001goo00<007ooOol08Goo00<007ooOol06Woo00Xh01cW0IXLia8m3S`L
iaim8WhLi`8006Moo`03001oogoo05Qoo`03001oogoo00Moo`001goo00<007ooOol08Goo00<007oo
Ool06goo00Lh01cW0IXLia8m4S`Li`027Wh011cW9Yh00000IGoo00<007ooOol0F7oo00<007ooOol0
1goo0007Ool00`00Oomoo`0QOol00`00Oomoo`0LOol02SP07>L1VQcW4Sd>?1cW7WdLib:N0RJN0P00
Hgoo00<007ooOol0F7oo00<007ooOol01goo0007Ool00`00Oomoo`0QOol00`00Oomoo`0NOol01AcW
0IXLia8m7>L00Qin00DLibJN9YhVWQcW0080065oo`03001oogoo05Qoo`03001oogoo00Moo`001goo
00<007ooOol08Goo00<007ooOol07goo00Ul01cW4S`B?AcW8WhNOAcW8Yh00RJN00<LibJn00000P00
GWoo00<007ooOol0F7oo00<007ooOol01goo0007Ool00`00Oomoo`0QOol00`00Oomoo`0POol01G`0
7>LB?A8m7>L00Qin00PLibJN9YhZ_QcW9[hZ_QcW0P00G7oo00<007ooOol0FGoo00<007ooOol01Woo
0007Ool00`00Oomoo`0QOol00`00Oomoo`0ROol03acW4S`B?AcW8WhLibJN8YhVWRJn7>LV_RZo7>LZ
g`03001IOol00`00Oomoo`1IOol00`00Oomoo`06Ool000Moo`03001oogoo025oo`03001oogoo02=o
o`9l00047>LNOAin7>L39Yh022Zn7>LV_RZn7>LZgbZn7>L2001GOol00`00Oomoo`1IOol00`00Oomo
o`06Ool000Ioo`03001oogoo029oo`03001oogoo02Eoo`0?O00Liaim8WhLibJN8YhVWQcW:[lV_RZo
7>LZgbJn008Li`<005Aoo`03001oogoo05Uoo`03001oogoo00Ioo`001Woo00<007ooOol08Woo00<0
07ooOol09goo0W`000<NOQcW9Yh00RJN00/LibZn9[hZ_QcW:]lZ_R[N7>LZgacW0080059oo`03001o
ogoo05Uoo`03001oogoo00Ioo`001Woo00<007ooOol08Woo00<007ooOol0:Goo0W`00RJN00hRWRJN
7>LZ_bJn:[lLib[O9[hZgacW:]lVgQcW0P00D7oo00<007ooOol0FGoo00<007ooOol01Woo0006Ool0
0`00Oomoo`0ROol00`00Oomoo`0[Ool2O0029Yh02BZn7>LZ_RJn:[hLib[O:[hZgP027>L00b[N7>LL
i`02001>Ool00`00Oomoo`1IOol00`00Oomoo`06Ool000Ioo`03001oogoo029oo`03001oogoo02eo
o`=l000=7>LV_RZo9[hZ_acW:]lV_R[O:[hLibKN:]l00QcW0`00Bgoo00<007ooOol0FGoo00<007oo
Ool01Woo0006Ool00`00Oomoo`0ROol00`00Oomoo`0`Ool3O0002BZn9[hZ_QcW:]lZ_R[N:[hLi`02
:]h47>L2001:Ool00`00Oomoo`1HOol00`00Oomoo`06Ool000Ioo`03001oogoo029oo`03001oogoo
03=oo`Al00057>LZgbJn:]lZ_P027>L012[O9]hLibKN0QcW0P00B7oo00<007ooOol0F7oo00<007oo
Ool01Woo0006Ool00`00Oomoo`0ROol00`00Oomoo`0gOol3O0001BZn:]hZ_R[O7>L00R[N0QcW00<V
gQcW7>L00P0000<N_GooOol0@goo00<007ooOol0F7oo00<007ooOol01Woo0006Ool00`00Oomoo`0R
Ool00`00Oomoo`0jOol4O00022[O7>LZgbKN:]lLib[O9]h27>L300000akNOomoo`10Ool00`00Oomo
o`1HOol00`00Oomoo`06Ool000Ioo`03001oogoo029oo`03001oogoo03ioo`Al0006:]hZgacW7>LV
gR[O0QcW00DVgP00000002;N03moo`03001oogoo05Qoo`03001oogoo00Ioo`001Woo00<007ooOol0
8Woo00<007ooOol0@Woo17`000@LibKN:]lVgP8Li`039]l0000000<003aoo`03001oogoo05Qoo`03
001oogoo00Ioo`001Woo00<007ooOol08Woo00<007ooOol0AWoo1G`000DVgQcW7>LLibKN0080008J
_@03001oogoo03Moo`03001oogoo05Qoo`03001oogoo00Ioo`001Woo00<007ooOol08Woo00<007oo
Ool0Bgoo17`00QcW00LRgP00000F_AJl6[dF_@0fOol00`00Oomoo`1HOol00`00Oomoo`06Ool000Io
o`03001oogoo029oo`03001oogoo051oo`Al00<000<BW0035[`J_Goo035oo`03001oogoo05Qoo`03
001oogoo00Ioo`001Woo00<007ooOol08Woo00<007ooOol0EGoo0W`00P000`jK00@B_0jK4[`F_2io
o`03001oogoo05Qoo`03001oogoo00Ioo`001Woo00<007ooOol08Woo00<007ooOol0FGoo00@000ZJ
2YX:VP8>V`034Y`>V`jK008BW0035[aoogoo02Moo`03001oogoo05Qoo`03001oogoo00Ioo`001Woo
00<007ooOol08Woo00<007ooOol0FWoo00`000ZJ3Y/:VPjK2YX>V`ZJ3Y/:VPjK4Y/33Y/00a:K5[dB
_00ROol00`00Oomoo`1IOol00`00Oomoo`05Ool000Ioo`03001oogoo029oo`03001oogoo05]oo`80
00H:VP053Y/:VPZJ2YX>V`032YX010jK2YX>V`jK7goo00<007ooOol0FGoo00<007ooOol01Goo0006
Ool00`00Oomoo`0ROol00`00Oomoo`1MOol200005@Ii2YX6N@ZJ2WT:VPIi2YX:N@ZJ1WT:VPYi3Y/:
VPjK2YX>V`ZJ3Y/:VP023Y/HOol00`00Oomoo`1IOol00`00Oomoo`05Ool000Ioo`03001oogoo029o
o`03001oogoo05ioo`03000:V@ZI00P:V@042YX:V@ZI2YT<2YX010jK2YX:VPZJ4Goo00<007ooOol0
FGoo00<007ooOol01Goo0006Ool00`00Oomoo`0QOol00`00Oomoo`1OOol06@002YT:VPZI2YX:V@ZJ
2YT:VPZI2YX:V@ZJ2YT:VPZI2YX:V@ZJ2YT:VPZI2YX:V@ZJ01Yl05Uoo`03001oogoo00Eoo`001Woo
00<007ooOol08Goo00<007ooOol0Ggoo00<000jI2YT00PZI00<>VG`0O0004G`00QcW0bLl5AcW47`0
BGoo00<007ooOol01Goo0006Ool00`00Oomoo`0QOol00`00Oomoo`1KOol:O0037>L012mM<ed_GC=M
6QcW00DJnakk6_/Nna[k01XLidIoo`03001oogoo00Eoo`001Woo00<007ooOol08Goo00<007ooOol0
Dgoo27`00acW13Mm0acW0c=M41cW5goo00<007ooOol01Goo2acW0W`0Agoo00<007ooOol01Goo0005
Ool00`00Oomoo`0ROol00`00Oomoo`1=Ool6O0027>L00c]n>gdkOP037>L00cMn=gdgOP0B7>LOOol0
0`00Oomoo`1IOol00`00Oomoo`05Ool000Eoo`03001oogoo029oo`03001oogoo04Uoo`Al00047>Lo
WCnM?ih27>L00c]m>ghkO@027>L4=gd<7>LWOol00`00Oomoo`1IOol00`00Oomoo`05Ool000Eoo`03
001oogoo029oo`03001oogoo04Aoo`El0006@ihLiacW?gdoWS]m0QcW00<kOS]m7>L00QcW00<gOCMn
7>L01QcW<7oo00<007ooOol0FGoo00<007ooOol01Goo0005Ool00`00Oomoo`0ROol00`00Oomoo`0o
Ool5O00014>m7>LLicnM0QcW00<oWSnM?id00QcW00DkOAcW7>LLicMm00LLicAoo`03001oogoo05Uo
o`03001oogoo00Eoo`001Goo00<007ooOol08Woo00<007ooOol0?Goo0W`000@Lid>L@ke3W@8Li`06
@ihLiacW>gdoWSmm2acW>Goo00<007ooOol0FGoo00<007ooOol01Goo0005Ool00`00Oomoo`0ROol0
0`00Oomoo`0jOol3O00011cW@ke3WD>m0QcW00<oWD>M7>L00SnM00<oWQcW7>L01acW?Goo00<007oo
Ool0FGoo00<007ooOol01Goo0005Ool00`00Oomoo`0ROol00`00Oomoo`0gOol3O0037>L01T>m@ia3
_AcW@ihoW@8Li`03?ihkOAcW00@Lid=oo`03001oogoo05Uoo`03001oogoo00Eoo`001Goo00<007oo
Ool08Woo00<007ooOol0=Goo0W`000LoVQcW@k`Lid>M@ke3W@027>L01D>M7>LLicnM>gd00acWAgoo
00<007ooOol0FGoo00<007ooOol01Goo0005Ool00`00Oomoo`0ROol00`00Oomoo`0cOol2O0001d>j
7>LLid>k7>M3WD>m008Li`05?idLiacW?ih000037>M9Ool00`00Oomoo`1IOol00`00Oomoo`05Ool0
00Eoo`03001oogoo029oo`03001oogoo035oo`037>Ml03nJ008Li`04@k`LiacW@id27>L00d>M7>LL
i`047>M<Ool00`00Oomoo`1IOol00`00Oomoo`05Ool000Eoo`03001oogoo029oo`03001oogoo02mo
o`8Li`03O00oVAcW0093_0087>M3_AcW7>LoWD>N7>L0055oo`03001oogoo05Uoo`03001oogoo00Eo
o`001Goo00<007ooOol08Woo00<007ooOol0;Goo0acW00Al01cW7>M3_08Li`04@kdLi`0000027>MC
Ool00`00Oomoo`1IOol00`00Oomoo`05Ool000Eoo`03001oogoo029oo`03001oogoo02aoo`8Li`8D
1P04O017_4>l7>L200000acW001oo`1FOol00`00Oomoo`1JOol00`00Oomoo`04Ool000Eoo`03001o
ogoo029oo`03001oogoo02Yoo`8Li`8D1P8Li`04O00LiacW001KOol00`00Oomoo`1JOol00`00Oomo
o`04Ool000Eoo`03001oogoo029oo`03001oogoo02Qoo`8Li`0840HLiacW7>L`l1cWO00005eoo`03
001oogoo05Yoo`03001oogoo00Aoo`001Goo00<007ooOol08Woo00<007ooOol09Woo0QcW00@D1QcW
7>L`l0<Li`03?KEl07oo05eoo`03001oogoo05Yoo`03001oogoo00Aoo`001Goo00<007ooOol08Woo
00<007ooOol097oo1AcW00PdlAcW7>Lm]46e?KE1]G`0GWoo00<007ooOol0FWoo00<007ooOol017oo
0005Ool00`00Oomoo`0ROol00`00Oomoo`0QOol97>L2@KD47>L00g`0Oomoo`1LOol00`00Oomoo`1J
Ool00`00Oomoo`04Ool000Eoo`03001oogoo029oo`03001oogoo01moo`LLi`03?K@LiacW00<Li`06
?KE:5dHFBQM65g`0GGoo00<007ooOol0FWoo00<007ooOol017oo0005Ool00`00Oomoo`0ROol00`00
Oomoo`0MOol47>L2@KD47>L01Cfe@KE:5dXGAQL00dXG00=65dXGO000GGoo00<007ooOol0FWoo00<0
07ooOol017oo0005Ool00`00Oomoo`0ROol00`00Oomoo`0JOol57>L02T6e7>LLiacW@KE65TXGAQM:
5dHF21cW00=>F7`0Ool0Fgoo00<007ooOol0FWoo00<007ooOol017oo0005Ool00`00Oomoo`0ROol0
0`00Oomoo`0HOol87>L00dXGAQM:5`067>L9CUP00g`0Oomoo`1JOol00`00Oomoo`1JOol00`00Oomo
o`04Ool000Eoo`03001oogoo029oo`03001oogoo01Aoo`PLi`03AQLLiacW00@Li`09CUQ:>4iHBSQ>
F4XhCUQ:>4iH00LLi`03O01oogoo05Uoo`03001oogoo05Yoo`03001oogoo00Aoo`001Goo00<007oo
Ool08Woo00<007ooOol047oo00<001cW7>L02QcW00=:5diHCUP01TiH1QcW0TiH00MBNDihDWUBN59i
CWQl001JOol00`00Oomoo`1JOol00`00Oomoo`04Ool000Aoo`03001oogoo02=oo`03001oogoo00io
o`03000LiacW00HLi`07BQM65TiHBSQ>F4XhCUP021cW011>N59iCWQBNDihDWU>N59iCWQBNDihDWU>
N59iCWQl05Uoo`03001oogoo05Yoo`03001oogoo00Aoo`0017oo00<007ooOol08goo00<007ooOol0
2goo1QcW00=65dXGBQL00TiH21cW00aBNE9hDWU>N59iDWQBNDihDWUBN59iCWP;7>L00e9iO01oo`1G
Ool00`00Oomoo`1JOol00`00Oomoo`04Ool000Aoo`03001oogoo02=oo`03001oogoo00Moo`@Li`03
BQM65dXG00PLi`08CWQBNDihDWU>N59iCWQBN@`Li`0=DWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIO000
FGoo00<007ooOol0FGoo00<007ooOol017oo0004Ool00`00Oomoo`0SOol00`00Oomoo`05Ool00`00
7>LLi`067>L00e9iCWQBN@0=7>L04E:IDWUBVE9iDYUBNE:IDWUBVE9iDYUBNE:IDWUBVE9iDYT021cW
00=l07ooOol0EWoo00<007ooOol0FGoo00<007ooOol017oo0004Ool00`00Oomoo`0ROol00`00Oomo
o`02Ool00`007>LLi`0=7>L03eJIDWQFVE9hEYUBN5JIDWQFVE9hEYUBN5JIDWQFV@0?7>L00eJIDYQF
V@02EYT01E:HEYUFVEJIO000Egoo00<007ooOol0FGoo00<007ooOol017oo0004Ool00`00Oomoo`0R
Ool00`00OolLi`067>L0359iDYUBNE:IDWUBVE9iDYUBNE:IDWUBV@lLiaUFV@03O01oogoo05Aoo`03
001oogoo05Uoo`03001oogoo00Aoo`0017oo00<007ooOol08Woo0P0000ABN5JIDWQFV@lLi`03EYUB
V5JI009FV@05DYQFVEJIEYUBV003EYT01E:HEYUFVEJIDYP00eJI00ABV5JIEYUFVA0Li`03O01oogoo
05=oo`03001oogoo05Uoo`03001oogoo00Aoo`0017oo00<007ooOol07goo00@001cW7>L000DLi`IF
VB8Lia5FV@03O01oogoo059oo`03001oogoo05Yoo`03001oogoo00=oo`0017oo00<007ooOol06goo
0P001AcW00<001cW7>L02AcW03AFVEZiEYUJ^EJIF[UFVEZiEYUJ^EJIF[UFVEZiEYUJ^EJIF[UFVEZi
EYUJ^EJIF[UFVEZiEYUJ^EJIF[UFVEZiEYUJ^EJIF[UFVEZiEYUJ^EJIF[UFVEZiEYUJ^EJIF[UFVEZi
EYUl05Aoo`03001oogoo05Yoo`03001oogoo00=oo`0017oo00<007ooOol06Goo0P001acW00<001cW
7>L0?AcW00=l07ooOol0DGoo00<007ooOol0FWoo00<007ooOol00goo0004Ool00`00Oomoo`0GOol2
0000BUZiE[UJ^EJhF[UF^EZiE[QJ^@00F[UF^5ZiE[UJ^EJhF[UF^EZiE[QJ^EJiF[UF^5ZiE[UJ^EJh
F[UF^EZiE[QJ^EJiF[UF^5ZiE[UJ^EJhF[UF^EZiE[QJ^EJiF[UF^5ZiE[UJ^EJhF[UF^EZiE[QJ^EJi
F[UF^5ZiE[UJ^EJhF[UF^EZiE[QJ^EJiF[UF^5ZiO01COol00`00Oomoo`1JOol00`00Oomoo`03Ool0
00Aoo`03001oogoo01Ioo`03000LiacW00TLi`03000LiacW01PLibIJ^@03O01oogoo051oo`03001o
ogoo05Yoo`03001oogoo00=oo`0017oo00<007ooOol057oo0P002acW00=J^@00G[T00UZi00IJ^5ji
F[UJ^EZhG[T2F[T01UZhG[UJ^EZiF[QN^@9J^@07F[QN^EZiF[UJ^5jiF[T09QcW00=l07ooOol0D7oo
00<007ooOol0FWoo00<007ooOol00goo0004Ool00`00Oomoo`0COol00`007>LLi`067>L2F[T01Eji
F[UJ^AcW000061cW:5Zi00=l07ooOol0D7oo00<007ooOol0FWoo00<007ooOol00goo0004Ool00`00
Oomoo`0COol02@00F[QNfEZhG]UJ^5kIF[QNf@067>L00`007>LLi`067>L045jiF[QN^EZiG[UJ^5ji
F[UN^EZhG[UJ^EjiF[QN^EZi6QcW00EN^EZiF[UJ^5ji009J^@06F[QN^EZiF[UJ^5ji0UZi00=l07oo
Ool0Cgoo00<007ooOol0FWoo00<007ooOol00goo0004Ool00`00Oomoo`0COol00`007>LLi`067>L0
3ekIG[UNfEjiG]UN^@00G[UNfEjiG]UN^EkIG[UNf@0?7>L2F[T01EjiF[UJ^EZiG[T00eZi00EN^EZi
F[UJ^Eji00=J^@05G[UJ^EZiF[UN^@03F[T00eji7>LLi`0=7>L00g`0Oomoo`1?Ool00`00Oomoo`1J
Ool00`00Oomoo`03Ool000Aoo`03001oogoo01=oo`03000LiacW00<Li`03G]UJ^5kI00HLi`03000L
iacW00HLi`0?G]UJ^5kIF[QNfEZhG]UJ^5kIF[QNfEZhG]UJ^5kI010Li`0KF[QN^EZiG[UJ^5jiF[UN
^EZhG[UJ^EjiF[QN^EZiG[UJ^5jiF[UN^EZhG[UJ^EjiF[QN^G`0055oo`03001oogoo05Yoo`03001o
ogoo00=oo`0017oo00<007ooOol057oo00D005kI7>MNf5kI00TLi`03001NfEkI00ANf@03G[UNfAcW
00dLi`0AG[UNfEjiG]UN^EkIG[UNfEjiG]UN^EkIG[UNfEjiG]UN^@0?7>L00eZiG[UJ^@02F[T01eji
F[UJ^EZiG[UJ^G`0055oo`03001oogoo05Yoo`03001oogoo00=oo`0017oo00<007ooOol05Goo00<0
01cW7>L00QcW00UNf6;IG]QRfEkHH]UNf6;I00002QcW00aRfEkHG]UNf6;IG]QNfEkHG]UJ^5kIF[P?
7>L04EZhG]UJ^5kIF[QNfEZhG]UJ^5kIF[QNfEZhG]UJ^5kIF[P02acW00=l07ooOol0Cgoo00<007oo
Ool0FWoo00<007ooOol00goo0004Ool00`00Oomoo`0FOol2000:7>L01000G]URfEkH0UkI00ERfEkH
G]UNfF;I00TLi`eNf@05G[UNfEjiG]UN^@0?7>L03UjiG]UN^EkIG[UNfEjiG]UN^EkIG[UNfEjiO01A
Ool00`00Oomoo`1JOol00`00Oomoo`03Ool000Aoo`03001oogoo01Qoo`800003H]QRfAcW00DLi`03
000LiacW00LLi`0:G]QRfEkHH]UNf6;IG]QRfEkHH]T:7>L05ekHG]UNf6;IG]QNfEkHH]UNf5kIG]QR
fEkHG]UNf6;IF[QNfEZhG]UJ^5kIF[P02acW00=J^7`0Ool0DGoo00<007ooOol0FWoo00<007ooOol0
0goo0004Ool00`00Oomoo`0JOol200027>L01F;IH]QRf6;H00001acW00=RfF;H7>L021cW00=NfF;I
G]P00UkI00IRfEkHG]UNfF;IG]P:7>LHG]T00acWO01oo`1AOol00`00Oomoo`1JOol00`00Oomoo`03
Ool000Aoo`03001oogoo01aoo`8000@Li`08000Lif;HI_URf6;iH]QRf@LLi`04H]UNf6;IG]P97>L0
35kHH]UNf6;IG]QRfEkHH]UNf6;IG]QRf@XLi`0?G]QRfEkHG]UNf6;IG]QNfEkHH]UNf5kIG]QRfG`0
05=oo`03001oogoo05Yoo`03001oogoo00=oo`0017oo00<007ooOol07Woo0P0000@Lif;h001Vn0HL
i`9Rf005H]URf6;HH]QRf@077>L01V;IH]QRfF;HH]URf0TLi`03G]URfEkH009Nf@06H]UNf5kIG]UR
fEkH0UkI3AcW00=l07ooOol0DWoo00<007ooOol0FWoo00<007ooOol00goo0004Ool00`00Oomoo`0P
Ool300037>L016;HI_URf6Kh1QcW00QRf6;iH]QVnF;HH_URf6;I1acW00QRfEkHH]UNf6;IG]QRfEkH
2AcW015Nf6;IG]QRfEkHH]UNf6;IG]QRfEkHH]UNf6;IG]QRfG`005Eoo`03001oogoo05Yoo`03001o
ogoo00=oo`000goo00<007ooOol08goo0`001acW0fKh00=Rn1cW7>L01AcW0f;H00ERfF;HH]QRf6;I
00LLi`0:H]URf6;IH]QRfF;HH]URf6;IH]P97>L00ekIH]UNf002G]T00f;IG]Ql001EOol00`00Oomo
o`1JOol00`00Oomoo`03Ool000=oo`03001oogoo02=oo`03001oogoo00<000TLi`06I_URf6KhH]QV
nF;H1QcW00UVnF;HH_URf6KiH]QRnEkHH]T01acW00aRfEkHH]UNf6;IG]QRfEkHH]UNf6;IG]P67>L0
0g`0Oomoo`1DOol00`00Oomoo`1KOol00`00Oomoo`02Ool000=oo`03001oogoo02=oo`03001oogoo
00=oo`80008Li`03I_PLiacW00LLi`=Vn004H_QVn6KhI_P67>L00f;HH]URf002H]P01F;IH]QRf6;H
H]T01AcW00eRfF;HH]URf6;IH]QRfF;HH]URf6;IH]Ql001GOol00`00Oomoo`1KOol00`00Oomoo`02
Ool000=oo`03001oogoo02=oo`03001oogoo00Eoo`<000<Li`03I_PLiacW00PLi`08I_URf6KhH]QV
nF;HI_QRf0HLi`09H_URf6KiH]QRnF;HI_URf6;i00TLi`03H]UNf7`005Qoo`03001oogoo05]oo`03
001oogoo009oo`000goo00<007ooOol08goo00<007ooOol027oo0P0011cW0V[g00=Vn1cW7>L00QcW
00=Vn1cW7>L011cW0VKh00IRn6KhI_QVn6;hI_P57>L01F;IH]QRf6;HH]T00f;H00MRfF;HH]QRf6;I
7>Ml001IOol00`00Oomoo`1KOol00`00Oomoo`02Ool000=oo`03001oogoo02=oo`03001oogoo00Yo
o`8000DLi`04I_MZn6KgJ_P47>L2I_P00fKg7>LLi`037>L026;HI_QRf6KiH]QVn6;HI_T67>L026;H
I_URf6;iH]QVnF;HO01JOol00`00Oomoo`1KOol00`00Oomoo`02Ool000=oo`03001oogoo02=oo`03
001oogoo00aoo`8000HLi`AZm`03I_PLiacW008Li`AVn0@Li`=Vn005H_QVn6KhI_QRn002I_P77>MK
Ool00`00Oomoo`1KOol00`00Oomoo`02Ool000=oo`03001oogoo02=oo`03001oogoo00ioo`800003
K_LLiacW00DLi`05J_QVmf[hI_MVn0047>L016KgJ_QVn6Kh1acW00UVn6;HI_URf6KhH]QVnF;HO000
G7oo00<007ooOol0Fgoo00<007ooOol00Woo0003Ool00`00Oomoo`0SOol00`00Oomoo`0@Ool30000
1Fkf7>LLiacWK_H00acW1V[g11cW1fKh11cW0VKh00=Rn7`0Ool0G7oo00<007ooOol0Fgoo00<007oo
Ool00Woo0003Ool00`00Oomoo`0SOol00`00Oomoo`0BOol01GI[00000000K_L00acW00=^macW7>L0
0QcW00IVmf[hI_MZn6KgJ_P47>L2I_P01FKgJ_QVn6KhI_L00acWGWoo00<007ooOol0Fgoo00<007oo
Ool00Woo0003Ool00`00Oomoo`0SOol00`00Oomoo`0DOol00gI:MVX00002000016kf7>LLiacW0Vkf
11cW1V[g11cW0fKh0W`0Ggoo00<007ooOol0Fgoo00<007ooOol00Woo0003Ool00`00Oomoo`0ROol0
0`00Oomoo`0GOol00gY[MTYU800300001fkg7>LLiacWK_MZmVkg00@Li`06I_MZn6KgJ_QVmf[h0acW
HGoo00<007ooOol0Fgoo00<007ooOol00Woo0003Ool00`00Oomoo`0ROol00`00Oomoo`0IOol017I:
MVYQ86DP0`0000A^mQcW7>MZmP9^mP03K_MZmQcW00<Li`=Zm`03O01oogoo061oo`03001oogoo05]o
o`03001oogoo009oo`000goo00<007ooOol08Woo00<007ooOol06Woo00IfBWI[HB1U864P7>L30003
7>L01V[fK_MZmVkgJ_I^m`<Lif=oo`03001oogoo05]oo`03001oogoo009oo`000goo00<007ooOol0
8Woo00<007ooOol077oo00EfJWI:IB1Q81cW0080L@800005J_HLiacW7>MZmP02K_H00fkgO01oo`1S
Ool00`00Oomoo`1KOol00`00Oomoo`02Ool000=oo`03001oogoo029oo`03001oogoo01ioo`07MTYU
864P7>L0L@1b7>L00P0000MbmF[f7>LLifkgJ_Il001TOol00`00Oomoo`1KOol00`00Oomoo`02Ool0
00=oo`03001oogoo029oo`03001oogoo021oo`07MVYQ81cW7>L0LAcW0IT00P000W;e0QcWIGoo00<0
07ooOol0Fgoo00<007ooOol00Woo0003Ool00`00Oomoo`0ROol00`00Oomoo`0QOol01WY[HB1U81cW
078Li`81V@<006Ioo`03001oogoo05]oo`03001oogoo009oo`000goo00<007ooOol08Woo00<007oo
Ool08goo00EfBVDP7>L0LAcW00<1V@047>L00000001SOol00`00Oomoo`1KOol00`00Oomoo`02Ool0
00=oo`03001oogoo029oo`03001oogoo02Eoo`04IB0Li`1b7>L20IT0106J7>L:?0XL0P00HGoo00<0
07ooOol0Fgoo00<007ooOol00Woo0003Ool00`00Oomoo`0ROol00`00Oomoo`0WOol00acW074Li`03
0IT011cW2S`:70Xl0P00Ggoo00<007ooOol0G7oo00<007ooOol00Goo0003Ool00`00Oomoo`0ROol0
0`00Oomoo`0XOol37>L20IT01QcW2Q`:?0XL3S`Li`800003OolLigoo05Yoo`03001oogoo05aoo`03
001oogoo005oo`000goo00<007ooOol08Woo00<007ooOol0:Woo0QcW00Moo`6I7>L:70Xl2Q`Li`02
5Wd2001LOol00`00Oomoo`1KOol00`00Oomoo`01Ool000=oo`03001oogoo029oo`03001oogoo02]o
o`<Li`090ITLi`XL2S`:71cW5WdFOQcW00<005Uoo`03001oogoo05]oo`03001oogoo005oo`000Woo
00<007ooOol08goo00<007ooOol0;Goo0QcW00H1VAcW2Q`:?0XL7>L25Wd00acW7YhNWP03001FOol0
0`00Oomoo`1KOol00`00Oomoo`01Ool0009oo`03001oogoo02=oo`03001oogoo02ioo`0?O00Li`6I
7>L:70Xl2Q`LiaIm5WhLiajN6YdNWQcW00<005=oo`03001oogoo05]oo`03001oogoo005oo`000Woo
00<007ooOol08goo00<007ooOol0<7oo00HLi`6I7>L:70Xl7>L35Wd01AcW7YhNWQjN7>L00Qjn0P00
DGoo00<007ooOol0Fgoo00<007ooOol00Goo0002Ool00`00Oomoo`0SOol00`00Oomoo`0aOol04G`0
7>L>?0XL2S`LiaYn5WdFOQcW7YhJWAjN7>LR_Qjn8[h00P00Cgoo00<007ooOol0Fgoo00<007ooOol0
0Goo0002Ool00`00Oomoo`0SOol00`00Oomoo`0bOol2O00010Xl2Q`:?1cW0QIm00<LiajN7Yh00QjN
00DLiajn7[hR_QcW008004eoo`03001oogoo05]oo`03001oogoo005oo`000Woo00<007ooOol08goo
00<007ooOol0=7oo0W`0010:70Xl7>LJOQIm7>LJWAjN6YdNWQcW8[hN_R:n7>LR_P<004Yoo`03001o
ogoo05]oo`03001oogoo005oo`000Woo00<007ooOol08goo00<007ooOol0=Woo0W`000DLiaIm5WdF
OAcW00@NWP057>LN_Qjn8[hLi`038[h30017Ool00`00Oomoo`1KOol00`00Oomoo`01Ool0009oo`03
001oogoo02=oo`03001oogoo03Qoo`0>O00Lig`06WhFOAcW6YdNWQZM7YhLib:n7[hR_P8Li`047[hR
_Qjm7>L30014Ool00`00Oomoo`1KOol00`00Oomoo`01Ool0009oo`03001oogoo02=oo`03001oogoo
03]oo`=l00037>LNWQjN008NWP067>LN_Qjn8[hN_QcW0R:n00@N_QcW7>LN_P<0045oo`03001oogoo
05]oo`03001oogoo005oo`000Woo00<007ooOol08goo00<007ooOol0?Woo0g`0014NWQZM7YhLib:n
7[hR_Qjm7>LN_R:n7[dRgQcW8]hJ_AcW008003moo`03001oogoo05]oo`03001oogoo005oo`000Woo
00<007ooOol08goo00<007ooOol0@Goo17`000HLiajn7[hR_Qjn7>L28[h27[h01AcW8[hN_Qjn7>L0
0P00?Goo00<007ooOol0Fgoo00<007ooOol00Goo0002Ool00`00Oomoo`0SOol00`00Oomoo`15Ool3
O00021jn8[hN_AcW7[hR_Qjm8[h27>L011jm8]hJ_AcW0P00>goo00<007ooOol0Fgoo00<007ooOol0
0Goo0002Ool00`00Oomoo`0SOol00`00Oomoo`18Ool3O0001Ajn7>LR_R:n7[h00R:n00@Liajn7[hN
_P8Li`<003Qoo`03001oogoo05]oo`03001oogoo005oo`000Woo00<007ooOol08goo00<007ooOol0
Bgoo0g`000DLib:n7[dR_Qjn008Li`038]hN_B;N008Li`046[d000006[heOol00`00Oomoo`1KOol0
0`00Oomoo`01Ool0009oo`03001oogoo02=oo`03001oogoo04ioo`Al00<R_P057>LN_Qjn8[hN_P02
7>L01Ajn000000005[d0<Woo00<007ooOol0Fgoo00<007ooOol00Goo0002Ool00`00Oomoo`0SOol0
0`00Oomoo`1BOol4O0027>L021jm8]hN_B;N7>LNgQZm7]h200000a:K6[eoo`0^Ool00`00Oomoo`1K
Ool00`00Oomoo`01Ool0009oo`03001oogoo02=oo`03001oogoo05Ioo`El008N_P8Li`037[dN_Qjm
00<000034Y`F_Goo02]oo`03001oogoo05aoo`40005oo`5oo`000Woo00<007ooOol08goo00<007oo
Ool0Fgoo17`00QcW00@NgQZm7]hJ_@8000044[`BVa:l4Y`XOol00`00Oomoo`1LOol10001Ool1Ool0
009oo`03001oogoo02=oo`03001oogoo061oo`El00037[dN_P000080008>V`034[`BW1:l02Aoo`03
001oogoo05aoo`40005oo`5oo`000Woo00<007ooOol08Woo00<007ooOol0IWoo1G`00P0000@:NPZK
2WX>W08>V`034Y/B_7oo01ioo`03001oogoo05aoo`40005oo`5oo`000Woo00<007ooOol08Woo00<0
07ooOol0K7oo00el0000000000Yj2YX:NPZJ2WX:VPYj3Y/BW00KOol00`00Oomoo`1LOol10001Ool1
Ool0009oo`03001oogoo029oo`03001oogoo06moo`0?O0000000000:NPZK2WX:V`Yj2Y/:NPZK3Y/:
Va:K01Ioo`03001oogoo05aoo`40005oo`5oo`000Woo00<007ooOol08Woo00<007ooOol0Lgoo0P00
00<6NGooOol00`Ii00T:VPYj2YX:NPZJ2WX:VPYj4[`047oo00<007ooOol0G7oo0@000Goo0Goo0002
Ool00`00Oomoo`0ROol00`00Oomoo`1eOol200004PIH1WT6F0Ii1UQooaJl5[dF_1:l1WT6NPIi2Y/:
NPZK2WX:V`]oo`03001oogoo05aoo`40005oo`5oo`0000=oo`00Ool097oo00<007ooOol0Mgoo0P00
0`IH00`2Egoo1UP6N@IH1WP6F0Ii1UP6N1:L4[`51WT00`ZJOomoo`04Ool00`00Oomoo`1LOol10001
Ool1Ool00003Ool007oo02Aoo`03001oogoo07Uoo`0A0006F09G1UP2E`IH0UL6F09G1UP2E`IH0UL6
F09G1UQoo`021UP02`Ii1UP6N@IH1WX6N@Ij1WT6NPjK3Y`0G7oo0@000Goo0Goo00000goo001oo`0T
Ool00`00Oomoo`1jOol200080UL21UP01@9G1UP6F0IH0UL00`IH00D2E`IH1UP6F09G00<6F0030UL6
F0IH00D6N@032WX:VWoo059oo`40005oo`5oo`0000=oo`00Ool097oo00<007ooOol0O7oo02d0009F
1UL2EPIG0UH6E`9F1UL2EPIG0UH6E`9G1UL2E`IG0UL6E`9G1UL2E`IG0UL6E`9G1UL2E`IH0UL6F09G
1UP2E`IH0UL6F09G1UP2E`Ij1WT6NPIi1WX0BWoo0@000Goo0Goo00000goo001oo`0TOol00`00Oomo
o`1lOol01@000UL2E`9G0UH00`9G00D2EP9G0UL2E`9F00<2E`050UH2E`9G0UL2EP030UL01@9F0UL2
E`9G0UH00`9G00D2EP9G0UL2E`9F00<2E`030UH2E`9G00H2E`<6F0050UL6N0IH1WT6F00nOol10001
Ool1Ool00003Ool007oo02Aoo`03001oogoo07eoo`0m0006E`9F1UL2EPIG0UH6E`9F1UL2EPIG0UH6
E`9F1UL2EPIG0UH6E`9F1UL2EPIG0UH6E`9F1UL2EPIG0UH6E`9F1UL2EPIG0UH6E`9F1UL2EPIG0UH6
E`9F1UL2EPIG0UH6E`9F1UL2EPIG0UH6E`9F1UL2EPIG0UH04G`011cW97oo0@000Goo0Goo00000goo
001oo`0TOol00`00Oomoo`1mOol01@001UH6EPIF1UL00`IF00D6E`IF1UH6EPIG00<6EP051UL6EPIF
1UH6E`031UH01@IG1UH6EPIF1UL00`IF00D6E`IF1UH6EPIG00<6EP051UL6EPIF1UH6E`031UH01@IG
1UH6EPIF1UL00acW1G`03acW:Woo0@000Goo0Goo00000goo001oo`0TOol00`00Oomoo`1mOol0;@00
1WL6MPIg1WH6M`If1WL6MPIg1WH6M`If1WL6MPIg1WH6M`If1WL6MPIg1WH6M`If1WL6MPIg1WH6M`If
1WL6MPIg1WH6M`If1WL6MPIg1WH6M`If1WL:U`0=7>LlOol10001Ool1Ool00003Ool007oo02Aoo`03
001oogoo07aoo`0L0006M`If1WL6MPIg1WH6M`If1WL6MPIg1WH6M`If1WL6MPIg1WH6M`If1WL6MPIg
1WH6M`If2YL31YL01@jH2YL:U`ZG3YP00PZG2AcWB7oo0@000Goo0Goo00000goo001oo`0TOol00`00
Oomoo`1lOol07P001WH:U`Ig2YL6MPZG1WL:U`If2YL6M`ZG1WH:U`Ig2YL6MPjh2YL>^0ZG3[P:U`jh
2YL>^0ZG3[P:U`PLie5oo`40005oo`5oo`0000=oo`00Ool097oo3@00L7oo0P0000<:U`jH2YL00PZG
00D>V0ZG2YL:U`jH00<:U`053YP:U`ZG2YL>V0022YL24[P87>MIOol10001Ool1Ool00003Ool007oo
029oo`8000eooaT005Ioo`0A000>^0ZG3[P:U`jh2YL>^0ZG3[P:U`jh2YLB^0jh4[P>^0087>L2Ool0
0`00Oomoo`1MOol10001Ool00003Ool007oo025oo`03001oogoo02IooaP003eoo`05000B^1:h4[P>
^0034[P00`jh4[PLi`077>L:Ool00`00Oomoo`1MOol10001Ool00003Ool007oo01moo`80045ooaT0
029oo`8000034[P>^1cW00LLia9oo`03001oogoo05eoo`40005oo`0000=oo`00Ool07Woo00<007oo
Ool0FWoo6@0027oo1AcW6Woo00<007ooOol0GGoo0@000Goo00000goo001oo`0LOol2001fOolH000?
Ool00`00Oomoo`1MOol10001Ool00003Ool007oo01]oo`03001oogoo08iooaT005Ioo`40005oo`00
00=oo`00Ool06Goo0P00X7oo00<007ooOol01goo6@00?Goo0@000Goo00000goo001oo`0HOol00`00
Oomoo`2POol00`00Oomoo`0POolH000UOol10001Ool00003Ool007oo01Ioo`800:Aoo`03001oogoo
03MooaT000aoo`40005oo`0000=oo`00Ool05Goo00<007ooOol0Y7oo00<007ooOol0D7oo3@000Goo
00000goo001oo`0COol2002WOol00`00Oomoo`1FOol40004Ool00003Ool007oo019oo`03001oogoo
0:Moo`03001oogoo055oo`D000Qoo`0000=oo`00Ool047oo0P00ZWoo00<007ooOol0CGoo10003Goo
00000`00Oomoo`0?Ool00`00Oomoo`2ZOol00`00Oomoo`18Ool5000AOol00003001oogoo00eoo`80
0:eoo`03001oogoo04Aoo`@001Ioo`0000<007ooOol037oo00<007ooOol0[Goo00<007ooOol0?goo
1@006Woo00000`00Oomoo`0:Ool2002`Ool00`00Oomoo`0kOol4000OOol00003001oogoo00Uoo`03
001oogoo0;1oo`03001oogoo03Ioo`D002=oo`0000<007ooOol01goo0P00/goo00<007ooOol0<Woo
1000:7oo00000`00Oomoo`06Ool00`00Oomoo`2cOol00`00Oomoo`0]Ool5000/Ool00003001oogoo
00Aoo`800;Ioo`03001oogoo02Qoo`D0035oo`0000<007ooOol00goo00<007ooOol0]Woo00<007oo
Ool097oo1000=Woo00001000Oomoogoo0P00^Goo00<007ooOol07goo1@00>Woo00001000Oomoo`00
^goo00<007ooOol06goo1000?goo0003002lOol00`00Oomoo`0FOol50013Ool001@00:]oo`03001o
ogoo019oo`@004Qoo`0057oo9P00QGoo00<007ooOol03Goo1@00C7oo000jOolV001OOol00`00Oomo
o`09Ool4001AOol0061oobH003Uoo`03001oogoo00Aoo`D005Eoo`00QWoo9P004goo00<007ooOol0
1000FWoo002/OolF001NOol00001
\>"],
  ImageRangeCache->{{{0, 287}, {285.438, 0}} -> {0.102314, -4.37612*^-06, 
  0.00306626, 0.00306626}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator] Graphics3D \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open]]
},
FrontEndVersion->"Microsoft Windows 3.0 Beta 2",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{0, 0},
WindowMargins->{{0, Automatic}, {0, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 26, 0, 28, "Input"],
Cell[1738, 51, 81, 2, 81, "Title"],
Cell[1822, 55, 118, 5, 159, "Subtitle"],

Cell[CellGroupData[{
Cell[1965, 64, 93, 2, 47, "Subsection"],
Cell[2061, 68, 1917, 61, 2237, "Text"]
}, Open]],
Cell[3991, 132, 175, 10, 299, "Text"],
Cell[4169, 144, 2369, 79, 2921, "Text"],

Cell[CellGroupData[{
Cell[6563, 227, 91, 2, 47, "Subsection"],
Cell[6657, 231, 1424, 31, 1097, "Text"]
}, Open]],

Cell[CellGroupData[{
Cell[8116, 267, 126, 2, 47, "Subsection"],

Cell[CellGroupData[{
Cell[8267, 273, 2377, 45, 489, "Input"],
Cell[10647, 320, 173, 3, 44, "Message"]
}, Open]]
}, Open]],
Cell[10843, 327, 177, 3, 44, "Message"],
Cell[11023, 332, 179, 3, 44, "Message"],
Cell[11205, 337, 161, 3, 44, "Message"],
Cell[11369, 342, 177, 3, 44, "Message"],
Cell[11549, 347, 78, 2, 47, "Subsection"],

Cell[CellGroupData[{
Cell[11652, 353, 109, 2, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[11786, 359, 156, 4, 48, "Input"],
Cell[11945, 365, 72422, 2235, 296, 21877, 1607, "GraphicsData", 
"PostScript", "Graphics"]
}, Open]]
}, Open]],
Cell[84390, 2604, 130, 3, 27, "Output"],

Cell[CellGroupData[{
Cell[84545, 2611, 119, 2, 43, "Subsubsection"],
Cell[84667, 2615, 135, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[84827, 2623, 163, 4, 48, "Input"],
Cell[84993, 2629, 40783, 2794, 296, 40660, 2790, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open]]
}, Open]],
Cell[125799, 5427, 130, 3, 27, "Output"],

Cell[CellGroupData[{
Cell[125954, 5434, 126, 3, 28, "Input"],
Cell[126083, 5439, 38953, 2740, 296, 38830, 2736, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open]],
Cell[165049, 8182, 130, 3, 27, "Output"],

Cell[CellGroupData[{
Cell[165204, 8189, 164, 4, 48, "Input"],
Cell[165371, 8195, 93879, 4528, 296, 93756, 4524, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open]],
Cell[259263, 12726, 130, 3, 27, "Output"],

Cell[CellGroupData[{
Cell[259418, 12733, 120, 3, 28, "Input"],
Cell[259541, 12738, 153462, 5157, 296, 88250, 4347, "GraphicsData", 
"PostScript", "Graphics"]
}, Open]],
Cell[413016, 17898, 130, 3, 27, "Output"],
Cell[413149, 17903, 115, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[413289, 17909, 163, 4, 48, "Input"],
Cell[413455, 17915, 88871, 3779, 296, 45717, 3242, "GraphicsData", 
"PostScript", "Graphics"]
}, Open]],
Cell[502339, 21697, 130, 3, 27, "Output"],
Cell[502472, 21702, 119, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[502616, 21708, 163, 4, 48, "Input"],
Cell[502782, 21714, 120942, 4446, 296, 75038, 3875, "GraphicsData", 
"PostScript", "Graphics"]
}, Open]],
Cell[623737, 26163, 130, 3, 27, "Output"],

Cell[CellGroupData[{
Cell[623892, 26170, 119, 2, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[624036, 26176, 165, 3, 48, "Input"],
Cell[624204, 26181, 124742, 4491, 296, 78214, 3912, "GraphicsData", 
"PostScript", "Graphics"]
}, Open]]
}, Open]],
Cell[748969, 30676, 130, 3, 27, "Output"],

Cell[CellGroupData[{
Cell[749124, 30683, 95, 2, 28, "Input"],
Cell[749222, 30687, 99, 2, 25, "Message"]
}, Open]],
Cell[749334, 30692, 805, 19, 46, "Output"],
Cell[750142, 30713, 76, 1, 28, "Input"],
Cell[750221, 30716, 495, 13, 27, "Output"],

Cell[CellGroupData[{
Cell[750741, 30733, 124, 2, 43, "Subsubsection"],
Cell[750868, 30737, 244, 6, 147, "Text"],

Cell[CellGroupData[{
Cell[751137, 30747, 198, 4, 63, "Input"],
Cell[751338, 30753, 70219, 2802, 296, 33622, 2346, "GraphicsData", 
"PostScript", "Graphics"]
}, Open]]
}, Open]],
Cell[821580, 33559, 130, 3, 27, "Output"],

Cell[CellGroupData[{
Cell[821735, 33566, 97, 2, 28, "Input"],
Cell[821835, 33570, 74015, 2844, 296, 34255, 2349, "GraphicsData", 
"PostScript", "Graphics"]
}, Open]],
Cell[895863, 36417, 130, 3, 27, "Output"],

Cell[CellGroupData[{
Cell[896018, 36424, 198, 4, 63, "Input"],
Cell[896219, 36430, 172538, 5584, 296, 122483, 4962, "GraphicsData", 
"PostScript", "Graphics"]
}, Open]],
Cell[1068770, 42017, 130, 3, 27, "Output"],

Cell[CellGroupData[{
Cell[1068925, 42024, 112, 2, 28, "Input"],
Cell[1069040, 42028, 198008, 5877, 295, 126041, 4984, "GraphicsData", 
"PostScript", "Graphics"]
}, Open]],
Cell[1267061, 47908, 130, 3, 27, "Output"],

Cell[CellGroupData[{
Cell[1267216, 47915, 119, 2, 43, "Subsubsection"],
Cell[1267338, 47919, 94, 2, 33, "Text"],
Cell[1267435, 47923, 17, 0, 28, "Input"],

Cell[CellGroupData[{
Cell[1267477, 47927, 82, 1, 28, "Input"],
Cell[1267562, 47930, 186935, 5695, 296, 119051, 4852, "GraphicsData", 
"PostScript", "Graphics"]
}, Open]]
}, Open]],
Cell[1454520, 53629, 130, 3, 27, "Output"],
Cell[1454653, 53634, 99, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[1454777, 53640, 135, 7, 100, "Input"],
Cell[1454915, 53649, 89398, 3649, 296, 53570, 3202, "GraphicsData", 
"PostScript", "Graphics"]
}, Open]],
Cell[1544326, 57301, 130, 3, 27, "Output"],

Cell[CellGroupData[{
Cell[1544481, 57308, 82, 1, 28, "Input"],
Cell[1544566, 57311, 77072, 3141, 295, 46825, 2763, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1621641, 60454, 130, 3, 27, "Output"]
}, Open]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

